(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      6338,        284]
NotebookOptionsPosition[      5333,        244]
NotebookOutlinePosition[      5889,        266]
CellTagsIndexPosition[      5846,        263]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

This solves a Multiple Sphere 

Impact
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

In these equations, mass is equal so divide it out. i12 is impulse between 1 \
and 

2 per kilogram for example. v means velocity, 1,2,3 is particle, o,f,s is after

none, first and second impact.
\
\>", "Text",
 Evaluatable->False],

Cell["\<\

(*First hit, one strikes two*)

e1 = -i12 == v1f - v1o;

e2 = i12 == v2f - v2o;



(*Second hit, two strikes three*)

e3 = -i23 == v2s - v2f;

e4 = i23 == v3s - v3f;



(*Restitution equation for first hit*)

e5 = rone == -(v2f - v1f)/(v2o - v1o);



(*Restitution equation for second hit*)

e6 = rtwo == -(v3s - v2s)/(v3f - v2f);



(*Equation for checking logic, system is balls

\ttwo and three*)

e7 = i12 == v2s + v3s - v2o - v3f;
\
\>", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

(*Initial conditions*)

ic = {v1o->v,v2o->0,v3f->0};
\
\>", "Input",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell["\<\

ans = Simplify[

\tSolve[{e1,e2,e3,e4,e5,e6}//.ic,

\t{i12,i23,v1f,v2f,v2s,v3s}]]
\
\>", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"i12", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rone"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"i23", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rone"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rtwo"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"v1f", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"v", "-", 
        RowBox[{"rone", " ", "v"}]}], ")"}]}]}], ",", 
    RowBox[{"v2f", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rone"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"v2s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rone"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "rtwo"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"v3s", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rone"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "rtwo"}], ")"}], " ", "v"}]}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181781388836*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

(*What if restitutions are the same*)

Simplify[ans//.{rone->r,rtwo->r}]
\
\>", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"i12", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"i23", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], "2"], " ", "v"}]}], ",", 
    RowBox[{"v1f", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"v", "-", 
        RowBox[{"r", " ", "v"}]}], ")"}]}]}], ",", 
    RowBox[{"v2f", "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"v2s", "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "4"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "r"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "r"}], ")"}], " ", "v"}]}], ",", 
    RowBox[{"v3s", "\[Rule]", 
     RowBox[{
      FractionBox["1", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "r"}], ")"}], "2"], " ", "v"}]}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181781452956*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

(*Check all the equations.*)

Simplify[({e1,e2,e3,e4,e5,e6,e7}/.ic)/.ans]
\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181781519026003`*^9, 3.5181781525056*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
    ",", "True"}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{{3.5181781466456003`*^9, 3.5181781533936*^9}}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 143, 9, 299, "Title",
 Evaluatable->False],
Cell[703, 31, 243, 10, 137, "Text",
 Evaluatable->False],
Cell[949, 43, 601, 42, 609, "Input"],
Cell[1553, 87, 101, 7, 99, "Input"],
Cell[CellGroupData[{
Cell[1679, 98, 130, 9, 133, "Input"],
Cell[1812, 109, 1405, 46, 47, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[3254, 160, 121, 7, 99, "Input"],
Cell[3378, 169, 1308, 44, 47, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[4723, 218, 305, 13, 99, "Input"],
Cell[5031, 233, 286, 8, 30, "Output",
 Evaluatable->False]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

