(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    177412,       3256]
NotebookOptionsPosition[    175595,       3190]
NotebookOutlinePosition[    176151,       3212]
CellTagsIndexPosition[    176108,       3209]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["These are the equations for x.", "Text",
 Evaluatable->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{"anot", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"omega", " ", "t"}], "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"xd", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"x", "'"}], "[", "t", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"xdd", "[", "t_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"xd", "'"}], "[", "t", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785253286*^9, 3.5181785253306*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["These are the dynamic equations.", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"mb", " ", "+", " ", "mc"}], " ", ")"}], " ", "g"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"eqnc", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "t", "]"}], " ", "-", " ", 
     RowBox[{"f", "[", "t", "]"}]}], " ", "==", " ", 
    RowBox[{"mc", " ", 
     RowBox[{
      RowBox[{"yd", "'"}], "[", "t", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"eqnb", " ", "=", " ", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"F", "[", "t", "]"}]}], " ", "==", " ", 
    RowBox[{"mb", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"yd", "'"}], "[", "t", "]"}], " ", "-", " ", 
       RowBox[{
        RowBox[{"xd", "'"}], "[", "t", "]"}]}], ")"}]}]}]}], ";"}]}], "Input",\

 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785303276*^9, 3.5181785303296003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\
These are the sticking and sliping solutions. It solves the equations for the \
highest 
derivative.\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sticksol", " ", "=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqnc", ",", "eqnb", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"yd", "'"}], "[", "t", "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", 
       RowBox[{"F", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"possol", " ", "=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqnc", ",", "eqnb", ",", 
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], "==", 
        RowBox[{"mu", " ", "n"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", 
       RowBox[{"F", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"negsol", " ", "=", " ", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqnc", ",", "eqnb", ",", 
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], "==", 
        RowBox[{
         RowBox[{"-", "mu"}], " ", "n"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "t", "]"}], ",", 
       RowBox[{"F", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785337455997`*^9, 3.5181785337476*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\
This one gets hairy.  Basically it does the logic to see which solution to \
perform.\
\>", "Text",
 Evaluatable->False]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"YddAndFs", "[", 
   RowBox[{"time_", ",", "ydot_"}], "]"}], " ", ":=", " ", "\n", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"solution", ",", "thef"}], "}"}], ",", "\n", "   ", 
    RowBox[{"(*", 
     RowBox[{"Ask", " ", "are", " ", "you", " ", 
      RowBox[{"stationary", "?"}]}], "*)"}], "\n", "   ", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"ydot", "//", "N"}], ")"}], " ", "!=", " ", "0"}], ",", "\n", 
      "      ", 
      RowBox[{"(*", 
       RowBox[{
       "Moving", " ", "so", " ", "friction", " ", "is", " ", "known", " ", 
        "finished"}], "*)"}], "\n", "      ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ydot", "//", "N"}], ")"}], " ", "<", " ", "0"}], ",", " ", 
        
        RowBox[{"negsol", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
        RowBox[{"possol", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}], ",", "\n", "         ", 
      RowBox[{"(*", 
       RowBox[{
       "Not", " ", "moving", " ", "so", " ", "check", " ", "sticking"}], 
       "*)"}], "\n", "         ", 
      RowBox[{
       RowBox[{"solution", " ", "=", " ", 
        RowBox[{"sticksol", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "         ", 
       RowBox[{"thef", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], "/.", "solution"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "//", "N"}]}], ";", "\n", 
       "         ", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Ask", " ", "is", " ", "friction"}], " ", "<=", " ", 
         RowBox[{"mu", " ", 
          RowBox[{"n", "?"}]}]}], "*)"}], "\n", "         ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Abs", "[", 
           RowBox[{"(", "thef", ")"}], "]"}], " ", "<", " ", 
          RowBox[{"mu", " ", "n"}]}], ",", " ", "\n", "           ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Friction", " ", "is"}], " ", "<=", " ", 
           RowBox[{"mu", " ", "n", " ", "so", " ", "finished"}]}], "*)"}], 
         "\n", "           ", "solution", ",", "\n", "           ", 
         RowBox[{"(*", 
          RowBox[{
          "Friction", " ", "is", " ", "too", " ", "big", " ", "so", " ", "it",
            " ", "is", " ", "moving"}], "*)"}], "\n", "           ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", "thef", ")"}], " ", "<", " ", "0"}], ",", " ", 
           RowBox[{"negsol", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
           RowBox[{"possol", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}]}], "]"}]}]}], "\n", 
     "   ", "]"}]}], "\n", " ", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785357276*^9, 3.5181785357306004`*^9}}],

Cell["This is a standard integration package.", "Text",
 Evaluatable->False],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EulerStepAux", "[", 
    RowBox[{"t_", ",", "dt_", ",", "y_", ",", "dy_"}], "]"}], " ", ":=", " ", 
   
   RowBox[{"Module", "[", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"auxvar", ",", "dyvar", ",", "tempdy"}], "}"}], ",", "\n", 
     "   ", 
     RowBox[{
      RowBox[{"tempdy", " ", "=", " ", 
       RowBox[{"dy", "[", 
        RowBox[{"t", ",", "y"}], "]"}]}], ";", "\n", "   ", 
      RowBox[{"auxvar", " ", "=", " ", 
       RowBox[{"tempdy", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\n", "   ", 
      RowBox[{"dyvar", " ", "=", " ", 
       RowBox[{"tempdy", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "   ", 
      RowBox[{
       RowBox[{"dyvar", " ", "dt"}], " ", "+", " ", "auxvar"}]}]}], "\n", 
    "   ", "]"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{"IntegAux", "[", 
   RowBox[{"yo_", ",", "dy_", ",", 
    RowBox[{"{", 
     RowBox[{"t_", ",", "tn_", ",", "tx_", ",", "dt_"}], "}"}]}], "]"}], ":=",
   " ", 
  RowBox[{"Module", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"answer", ",", "y", ",", "fini", ",", "time"}], "}"}], ",", "\n",
     "   ", 
    RowBox[{
     RowBox[{"y", " ", "=", " ", "yo"}], ";", "\n", "   ", 
     RowBox[{"answer", " ", "=", " ", 
      RowBox[{"{", "y", "}"}]}], ";", "\n", "   ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"y", " ", "=", " ", 
         RowBox[{"EulerStepAux", "[", 
          RowBox[{"t", ",", "dt", ",", "y", ",", "dy"}], "]"}]}], ";", "\n", 
        "      ", 
        RowBox[{"answer", " ", "=", " ", 
         RowBox[{"Append", "[", 
          RowBox[{"answer", ",", "y"}], "]"}]}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"tn", "+", "dt"}], ",", "tx", ",", "dt"}], "}"}]}], "]"}], 
     ";", "\n", "   ", 
     RowBox[{"answer", " ", "=", " ", 
      RowBox[{"Transpose", "[", "answer", "]"}]}], ";", "\n", "   ", 
     RowBox[{"time", " ", "=", " ", 
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "tn", ",", "tx", ",", "dt"}], "}"}]}], "]"}]}], 
     ";", "\n", "   ", 
     RowBox[{"fini", " ", "=", " ", 
      RowBox[{"{", "}"}]}], ";", "\n", "   ", 
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"fini", " ", "=", " ", 
        RowBox[{"Join", "[", 
         RowBox[{"fini", ",", " ", 
          RowBox[{"{", 
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"time", ",", 
              RowBox[{"answer", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "}"}], "]"}], "}"}]}], 
         "]"}]}], ",", " ", "\n", "      ", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "answer", "]"}]}], "}"}]}], "]"}], ";", "\n", 
     "   ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Interpolation", "[", 
        RowBox[{"fini", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "fini", "]"}]}], "}"}]}], "]"}]}]}], "\n", 
   "   ", "]"}]}]}], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785381136*^9, 3.5181785381156*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["Here are some parameters.", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{
  RowBox[{"mb", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"mc", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"g", " ", "=", " ", 
   RowBox[{"981", "/", "100"}]}], ";", " ", 
  RowBox[{"mu", " ", "=", " ", 
   RowBox[{"1", "/", "10"}]}], ";", " ", 
  RowBox[{"anot", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"omega", " ", "=", " ", "10"}], ";"}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785406566*^9, 3.5181785406596003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"Y", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"y", ",", "yd", ",", "f", ",", "F"}], "}"}]}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5181785420566*^9, 3.5181785867125998`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"yd", "[", 
   RowBox[{"time_", ",", "yvec_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"yddvec", ",", "thef", ",", "theF"}], "}"}], ",", "\n", "   ", 
    RowBox[{
     RowBox[{"yddvec", " ", "=", " ", 
      RowBox[{"(", 
       RowBox[{"YddAndFs", "[", 
        RowBox[{"time", ",", 
         RowBox[{"yvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ")"}]}], ";", "\n", "   ", 
     
     RowBox[{"thef", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], "/.", "yddvec"}], ")"}], "/.", 
       RowBox[{"t", "->", "time"}]}]}], ";", "\n", "   ", 
     RowBox[{"theF", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"F", "[", "t", "]"}], "/.", "yddvec"}], ")"}], "/.", 
       RowBox[{"t", "->", "time"}]}]}], ";", "\n", "   ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "yddvec"}], ",", "0", 
         ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"yvec", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"yvec", "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", "thef", ",", "theF"}], "}"}]}],
       "}"}]}]}], " ", "]"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785431146*^9, 3.5181785431166*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"start", " ", "=", " ", "sticksol"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"y", " ", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"f", "[", "t", "]"}], ",", 
          RowBox[{"F", "[", "t", "]"}]}], "}"}], "/.", "sticksol"}], ")"}], 
      "[", 
      RowBox[{"[", "1", "]"}], "]"}], ")"}], "/.", 
    RowBox[{"t", "->", "0"}]}]}], ";"}]}], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785447076*^9, 3.5181785447096*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"answer", " ", "=", " ", 
  RowBox[{"IntegAux", "[", 
   RowBox[{"y", ",", "yd", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10", ",", ".05"}], "}"}]}], 
   "]"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181785459526*^9, 3.5181785459546003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], ",", 
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], ",", 
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], ",", 
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "10.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False]}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181785930526*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"they", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"answer", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
      "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUlnk8lG8Xxu1jX2aGVDKyjQxjSUrJfUfIUqmESiotyBKSJJXoJ8latgrZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {-26.358759606252068`, 0.004405861291401781}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181785953456*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"theyd", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"answer", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
      "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c81d8fx+91r3mNOyTzushIUmRUxjlRJKMSUgnJjIym0JKsyMj6WlEq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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {-9.65932323112561, 3.688991357768161}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181785973386*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"friction", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"answer", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}],
      "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxE2Xk8Fe/7P/AZS9mF07FGKcu7JCRJcl8oRYpsRUIqRAmphKSkRWQpFBJS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {-2.213724689857103, 2.9478741589144617`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181785991976*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TheF", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"answer", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}],
      "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmHk4lU8bx+37cpyjTZJIyC5kn5uzl0oSESrJWpIQIkXZIhJSFEoltEmK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 10}, {-51.037841692670156`, 49.01727477356431}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181786006656*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 67, 1, 29, "Text",
 Evaluatable->False],
Cell[627, 23, 622, 20, 72, "Input"],
Cell[1252, 45, 69, 1, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1346, 50, 1012, 35, 72, "Input"],
Cell[2361, 87, 145, 5, 47, "Text",
 Evaluatable->False],
Cell[2509, 94, 1668, 54, 72, "Input"],
Cell[4180, 150, 130, 4, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[4325, 157, 3042, 78, 352, "Input"],
Cell[7370, 237, 76, 1, 29, "Text",
 Evaluatable->False],
Cell[7449, 240, 3355, 94, 392, "Input"],
Cell[10807, 336, 62, 1, 29, "Text",
 Evaluatable->False],
Cell[10872, 339, 586, 16, 31, "Input"],
Cell[11461, 357, 214, 5, 31, "Input",
 Evaluatable->False],
Cell[11678, 364, 1582, 46, 112, "Input"],
Cell[CellGroupData[{
Cell[13285, 414, 707, 23, 52, "Input"],
Cell[CellGroupData[{
Cell[14017, 441, 417, 13, 31, "Input"],
Cell[14437, 456, 1048, 37, 30, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15534, 499, 430, 14, 31, "Input"],
Cell[15967, 515, 41590, 688, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57594, 1208, 314, 9, 31, "Input"],
Cell[57911, 1219, 42145, 697, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100093, 1921, 317, 9, 31, "Input"],
Cell[100413, 1932, 32319, 536, 237, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[132769, 2473, 313, 9, 31, "Input"],
Cell[133085, 2484, 42494, 703, 230, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

