(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    120400,       2397]
NotebookOptionsPosition[    118504,       2329]
NotebookOutlinePosition[    119060,       2351]
CellTagsIndexPosition[    119017,       2348]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

This Program Simulates a Scooting Grocery Cart.
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

These are the equations for x.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{"anot", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"omega", " ", "t"}], "]"}]}]}], "\n", "\n", 
   RowBox[{
    RowBox[{"xd", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"x", "'"}], "[", "t", "]"}]}], "\n", "\n", 
   RowBox[{
    RowBox[{"xdd", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"xd", "'"}], "[", "t", "]"}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788447096*^9, 3.5181788447116003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

These are the dynamic equations.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"n", " ", ":=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"mb", " ", "+", " ", "mc"}], " ", ")"}], " ", "g"}]}], "\n", 
   "\n", 
   RowBox[{"eqnc", " ", ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"F", "[", "t", "]"}]}], " ", "-", " ", 
      RowBox[{"f", "[", "t", "]"}]}], " ", "==", " ", 
     RowBox[{"mc", " ", 
      RowBox[{
       RowBox[{"yd", "'"}], "[", "t", "]"}]}]}]}], "\n", "\n", 
   RowBox[{"eqnb", " ", ":=", " ", 
    RowBox[{
     RowBox[{"F", "[", "t", "]"}], " ", "==", " ", 
     RowBox[{"mb", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"yd", "'"}], "[", "t", "]"}], " ", "+", " ", 
        RowBox[{
         RowBox[{"xd", "'"}], "[", "t", "]"}]}], ")"}]}]}]}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788458006*^9, 3.5181788458026*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

These are the sticking and sliping solutions. It solves the equations for the \
highest 

derivative plus the friction force and F (the force between the bodies). 
\
\>", "Text",
 Evaluatable->False,
 FontFamily->"Arial",
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"sticksol", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eqnc", ",", "eqnb", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"yd", "'"}], "[", "t", "]"}], "==", "0"}]}], "}"}], ",", 
       "\n", "\n", "                 ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], ",", 
         RowBox[{"F", "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{
    RowBox[{"possol", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eqnc", ",", "eqnb", ",", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], "==", 
          RowBox[{"mu", " ", "n"}]}]}], "}"}], ",", "\n", "\n", 
       "                ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], ",", 
         RowBox[{"F", "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{
    RowBox[{"negsol", " ", "=", " ", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"eqnc", ",", "eqnb", ",", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], "==", 
          RowBox[{
           RowBox[{"-", "mu"}], " ", "n"}]}]}], "}"}], ",", "\n", "\n", 
       "               ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], ",", 
         RowBox[{"F", "[", "t", "]"}], ",", 
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], ";"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788467636003`*^9, 3.5181788467656*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

The following implements the assumption checks. The which statement has a 

series of tests followed by a statement. If the test is true, the statement \
is executed.

First it tests if the cart is moving left by checking the velocity (v[t]),

         if it is, it uses the acceleration computed via the negsol from \
above. The 

         (Evaluate statement says to put the actual algebra in not just the \
word negsol)

Second it test if the cart is moving right.

Third it assumes the cart is stuck and computes the friction then asks if it \
is 

        less than the most negative it can be, if so the cart is in impending \
motion.

Fourth it assumes the cart is stuck and computes the friction then asks if it \
is 

        greater than the most positive it can be, if so the cart is in \
impending motion

If none of the above are true then the cart is stuck and the acceleration is \
zero.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"mb", "=."}], ";", " ", 
    RowBox[{"mc", "=."}], ";", " ", 
    RowBox[{"g", "=."}], ";", " ", 
    RowBox[{"mu", "=."}], ";"}], " ", "\n", "\n", 
   RowBox[{
    RowBox[{"anot", "=."}], ";", " ", 
    RowBox[{"omega", "=."}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"eqn", " ", "=", " ", 
     RowBox[{"Which", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], "<", "0"}], ",", " ", "\n", "\n", 
       "               ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "negsol"}], ")"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\n", "\n", 
       "            ", 
       RowBox[{
        RowBox[{"v", "[", "t", "]"}], ">", "0"}], ",", " ", "\n", "\n", 
       "               ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "possol"}], ")"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\n", "\n", 
       "            ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"F", "[", "t", "]"}], "/.", "sticksol"}], ")"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", "<", " ", 
         RowBox[{
          RowBox[{"-", "mu"}], " ", "n"}]}], "]"}], ",", " ", "\n", "\n", 
       "               ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "negsol"}], ")"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\n", "\n", 
       "            ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"F", "[", "t", "]"}], "/.", "sticksol"}], ")"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], " ", ">", " ", 
         RowBox[{"mu", " ", "n"}]}], "]"}], ",", " ", "\n", "\n", 
       "               ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "possol"}], ")"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", "\n", "\n", 
       "            ", "True", ",", "\n", "\n", "               ", 
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"yd", "'"}], "[", "t", "]"}], "/.", "sticksol"}], ")"}], 
         "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "\n", "\n", "            ", 
      "]"}]}], ";"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788477866*^9, 3.5181788477886*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]]
}, Open  ]],

Cell["\<\

Here are some parameters.

Integrate the equations to find position and velocity.
\
\>", "Text",
 Evaluatable->False,
 FontFamily->"Arial",
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"mb", " ", "=", " ", "1"}], ";", " ", 
    RowBox[{"mc", " ", "=", " ", "1"}], ";", " ", 
    RowBox[{"g", " ", "=", " ", 
     RowBox[{"981", "/", "100"}]}], ";", " ", 
    RowBox[{"mu", " ", "=", " ", 
     RowBox[{"1", "/", "10"}]}], ";"}], " ", "\n", "\n", "    ", 
   RowBox[{
    RowBox[{"anot", " ", "=", " ", 
     RowBox[{"1", "/", "10"}]}], ";", " ", 
    RowBox[{"omega", " ", "=", " ", "10"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"MaxTime", " ", "=", " ", "20"}], ";"}], "\n", "\n", 
   RowBox[{"sol", " ", "=", " ", 
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"v", "'"}], "[", "t", "]"}], "==", " ", "eqn"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "==", 
         RowBox[{"v", "[", "t", "]"}]}], ",", 
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "==", "0"}], ",", "\n", "\n", "\t", 
        RowBox[{
         RowBox[{"v", "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], ",", 
        RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "MaxTime"}], "}"}]}], "]"}]}], "\n", "\n", 
   
   RowBox[{"endtime", " ", "=", "2.5"}], "\[IndentingNewLine]"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788489206*^9, 3.5181788489226*^9}, {
  3.5181789047296*^9, 3.5181789721196003`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      TagBox[
       RowBox[{"InterpolatingFunction", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"0.`", ",", "20.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
        "]"}],
       False,
       Editable->False], "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{{3.5181789056546*^9, 3.5181789727466*^9}}],

Cell[BoxData["2.5`"], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{{3.5181789056546*^9, 3.5181789727496*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"v", "[", "t", "]"}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<Ydot\>\""}], "}"}]}]}], "]"}]], "Input",\

 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3k81F8XHkRZQpJ2lDVJSETqDJUKkb1FEqFsUYqftBISkVIoksiSPWS/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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Ydot\"", TraditionalForm]},
  PlotRange->{{0, 2.5}, {-0.558490677189197, 0.4690683732190866}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5181789076696*^9, {3.5181789480156*^9, 3.5181789743126*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<y\>\""}], "}"}]}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81e8XdylJkkp9S7IyMlKpJMn5aNgkGSnZO2RkFGWW7D0ie69rXyN5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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"y\"", TraditionalForm]},
  PlotRange->{{0, 2.5}, {-0.10583143739841468`, 0.059687289244394474`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181789881006002`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"thev", "[", "time_", "]"}], " ", ":=", " ", 
    RowBox[{
     RowBox[{"v", "[", "time", "]"}], "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"sol", "/.", 
        RowBox[{"t", "->", "time"}]}], ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788540766*^9, 3.5181788540786*^9}}],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"theF", "[", "time_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"speed", ",", "neg", ",", "pos", ",", "stick"}], "}"}], ",", 
      "\n", "\n", "      ", 
      RowBox[{
       RowBox[{"speed", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"v", "[", "time", "]"}], "/.", 
           RowBox[{"(", 
            RowBox[{"sol", "/.", 
             RowBox[{"t", "->", "time"}]}], ")"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"neg", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"F", "[", "t", "]"}], "/.", "negsol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"pos", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"F", "[", "t", "]"}], "/.", "possol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"stick", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"F", "[", "t", "]"}], "/.", "sticksol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"speed", "<", "0"}], ",", " ", "neg", ",", "\n", "\n", 
         "            ", 
         RowBox[{"speed", ">", "0"}], ",", " ", "pos", ",", "\n", "\n", 
         "            ", 
         RowBox[{"stick", " ", "<", " ", 
          RowBox[{
           RowBox[{"-", "mu"}], " ", "n"}]}], ",", " ", "neg", ",", "\n", 
         "\n", "            ", 
         RowBox[{"stick", " ", ">", " ", 
          RowBox[{"mu", " ", "n"}]}], ",", " ", "pos", ",", "\n", "\n", 
         "            ", "True", ",", " ", "stick"}], "]"}]}]}], "]"}]}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788545996*^9, 3.5181788546015997`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"thefriction", "[", "time_", "]"}], " ", ":=", " ", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"speed", ",", "neg", ",", "pos", ",", "stick"}], "}"}], ",", 
      "\n", "\n", "      ", 
      RowBox[{
       RowBox[{"speed", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"v", "[", "time", "]"}], "/.", 
           RowBox[{"(", 
            RowBox[{"sol", "/.", 
             RowBox[{"t", "->", "time"}]}], ")"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"neg", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], "/.", "negsol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"pos", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], "/.", "possol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"stick", " ", "=", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"f", "[", "t", "]"}], "/.", "sticksol"}], ")"}], "/.", 
           RowBox[{"t", "->", "time"}]}], ")"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\n", "\n", "      ", 
       RowBox[{"Which", "[", 
        RowBox[{
         RowBox[{"speed", "<", "0"}], ",", " ", "neg", ",", "\n", "\n", 
         "            ", 
         RowBox[{"speed", ">", "0"}], ",", " ", "pos", ",", "\n", "\n", 
         "            ", 
         RowBox[{"stick", " ", "<", " ", 
          RowBox[{
           RowBox[{"-", "mu"}], " ", "n"}]}], ",", " ", "neg", ",", "\n", 
         "\n", "            ", 
         RowBox[{"stick", " ", ">", " ", 
          RowBox[{"mu", " ", "n"}]}], ",", " ", "pos", ",", "\n", "\n", 
         "            ", "True", ",", " ", "stick"}], "]"}]}]}], "]"}]}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788554826*^9, 3.5181788554846*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"thefriction", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<Friction\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF0GdQEwYYBuAITsBTFKkjhmApMYgIPelJKQ1Ur4ootUAUcUEYoSBhWCgV
WqkioCcYkSWWpoGylBEQhCAmEMCUEECmg2gZCYqijBAhEUzbH37fj+/ee369
732mjFA3fx0CgZD93/2fOb8yltr4BX9ts7yE6OWnpS0bGKa8MblB+2iuhBP+
2qQYXFZ+aeC0VR2YSeu6MR7RBGYpqCNVZa3gxrUbbtitbgfrmcZT/tn1EKzD
rt17LBit+TDOfJSDrt2oCY26hY76Yln0uhqwcKebUVxVE3o6xDTJ/SGalW+f
dW0M/VpGL+rU6QLL6gQvxUy0NItCbZCiSz3UxbyMbnDK6jYLrncPeE61KtLN
uA/MGPAQ6kr7weEt8YxQylNwRZiB+3rnZ2BuTPAr6yOD4POc+e9nxofATnyW
8+M7w2BCz6Bj/dkRcPyYgHv2N/QKQo6OXRI6xTjGdzYFTFuz/WhzdTqa6LUu
4fM89GeJXXvLeehdQ85tRW3o/fYi19xRNGuikp5OlIOv5+UdT3JDy/QvBrEE
aPMfA6I9LBTgJbbnXpQr0XJV5mH9+6PYpwj6JTX8JdhVzt5GIr3C/b1qulKB
ftXEiPu79DXYPlNIoWwcB18JInZeTEB7c5TROVz0zl7Jlup69B+su7OOEvTy
FblS6SO0Q/8nNanPwcKIvGSupwJdFKZ7hTSOfubwc5R8Gp1QSJGspb4BWxn2
b959Ck0sUgivUt+C9WgqH5kSvfeN1+wW+iT4schvkZflFLg6qfkkWYUOWBI5
2NExDZbbz0lCdirBvhEx1QbZaF740pq4AvR82LXamUp0p/VMreFdMC138jDf
io+O4vH5LvVo5zBiXaAQPTkxVJfbgs4ILbwna0Nbs+4LmuXo1tM9jSUL6Pkf
tOLYHTPgHcxtHQd80Nr62+Pe7ejONZb6kXYq8L2y8zctdd+BYxZZHJI+Q+vJ
zu5jVc2Co51c3yasnwMrCkzTOLHoaQb3VOAFNMHEdJvNZfTShUF2ejJ65cCf
79RstBHf+/jJNLBwYyZZJMpE264iH/XIRx9KNJlUVKITfiKRVnSg65mbD1iO
obfu21QUYaIGp23dsJhPR6cOCf1X3kOzswPEPmQN2CvtRIfBC/Tcnnw1R/Ae
PKL4JlqUOA8WGda1imfQuQ42m9p9FsB/PVAfdYxB538nyrqThjZPM98VwkUX
PL78yLwM/WDMl0avQI9qviq8ULWA/zYwXlVZg6ZsnogarEMH0rjfOjSii3zc
jbPF6Ftn5NfjNOjSi5GGzO0fwNkhp61sr6ET6b4uuiq0rYxbnNiuBWdRb5a2
uxAcP/pcQ3KWCx89GjJF0p9AH9xEz5eYLQKX+H8a626D1uNNuckc0HZ9ngLy
HnSgRkj1348mJJ85lXgQnWVCSS8+hJa/JPC+dENbVz6VtLmjY2OqFMfpYKF4
Twrh7WF0/BOLMm0o2oklPmZ4CR3WYtTAEqI5RIaZVIU2ayrMcD2mA2ZvF1l0
C9ABysVdrRa6YL/u99HUE2hGxTT50lW0ulHbX3Abze42SG4Wo+8aszVtHWiZ
19rAnj70xHwv6cgTtA4no++pDK0fNsv7/TmYZuTkeeXkIJq0hs8kD6MpIxt2
D4+gI4LJpKkptEBprtZq0f8CRTFidA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Friction\"", TraditionalForm]},
  PlotRange->{{0, 2.5}, {-1.962, 1.962}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181789986316*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Fplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"theF", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<Time\>\"", ",", "\"\<F\>\""}], "}"}]}]}], "]"}]}]], "Input",\

 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c4le8fxx1k73GehqQSJSNNJX3uhCKpFEUqM5SVopIvhRApFElZpbKL
pIw6t72SvWf2nsc45u/5/eV6Xzfvz7zP87y4bDW117VgZmJi0mBlYvr/1wg3
UzZF81vHZNxCTviPErigVkL7koQm5EXzZ5uTeq3ot6eEhAGUPU+TnBohMF9w
xleuJlNwi1T22EPqCBywZZ2ENTivBTZsGyaw7IT58zVLe7j9JXdHySCB2/ki
V5cbHSHr5joniQECS37iPLi45AR8YTllu/sIbKPiZDu/5QGsKTjID3cT+Ftd
Vyz9hCssR1XHXeki8OIt7bYpS3coics68aidwNGUtqfz6o/BT0mO63ILgdUq
gnbMNXqAGbrA0dNA4MGwk7l0ay8IfuJ2emstgZ+ZrxjNLD0BCbud3UKVBK5d
sno1ueUpOAW/1xQoIrBzsfieiVQ/kEnbpSKWS+CNL+vKx048g2s/3pW2ZhPY
VAaxjFi+AJf9RmtOXwnMvORSSXcNBH7T4LpzCQSu69LbTFcPgvOHfMI7PxD4
fhJ35nRjMFjt2Xh1QyiBtYL72aajX0LLqbLnBc8JLHY/9+KU9SvI2GG0SdKH
wPjEvcmJpRCAkepspnsEZm/tlh7b8gay/mmH7btA4Cb8y2l08A10WesTTzQJ
nPApLH8kNRyemfEt+wOBdRx1rg+feAfeEleCsmQIHMqZFTpgGQVSAzSLqBUq
Tr+n5XhnfTSoGKV7RU9R8bvhQxtmXKNhqoFx5XIfFdtVCVlOq8fA3dmmqdFy
KhZ6V8I81fgeLolQ5L6EUPESX0a8w9EP0DjedP+WDxX3Pv5wbjL6AxCH9lO7
7lNxhqVb5IR1LKy4pEjNGFKx4b79R8aXPgJf3hmW4k1UHFMWdXtkSzwsTuw7
bRQoiulh32U6n8XD3dXTcztcRbGGZXlPDSMe3jmqiUVbiuJRlnm9rNoE2Bww
f+aziihWUtE58tQnCS5vv1zG3S+Cq74sM0tPfIED3oyMJztFsBBwXuOV/woM
5YIPT/hFsLLUqyM+5l9BON/f7eicMH5Oj59xqf4KDz8ZlFblCeP9QfUWpomp
MD5s6Rd9WRi7l8lqKV7/Bmltir4n7wnhuNQfUokh36A/b2fuuIEQrglTZdnx
5xsspEV8vHhUCEtaXs5ZfzgdnuVd9LvGJITLWLzkmYS/w9nzg98ePBHEVJVW
ocqiDLD55fv1lJcATvnytNVGPgsc6ro7077y4GGh4WdaJlnAdlPhzzcbHizt
rHVs56ssSFva4Wq2kwdHH+WO6WFkwUX9jddrI7lxcOmzG4aF2aB9/fuKkC8X
du55MXXS6Bc0hk43sJzhwFHc5Z6C6hjs2l89d4pjwZZQ/WbUMR9Yd699ulwx
Q2N6P5fV6p8Pgj3O6l8UZ2hhrGJtZbH5EMffGLEQMk0rKb0hHt+QD3Ml9B82
16ZoOy8uv7c4UgCrX97fPdgxRhu0kk7qoBSCpJ/xG7ntvbSbwf/9rgosAqRo
nSpTFk5jnn3fSYsvAnz3xfFdzd4QfqmE6UteEVQ5BZlsK4uDMjHhEwH0Ioib
dZPktaXB7s9xxZqXiyFN6dcPK91qGM2urcrbUgID794u/2LuBru+XT3pKaUQ
OarQcUpgGrquNXPklpaCOcfxkWPx03ChyVe+opc8b5x/8fb4DCiVDzzo21gG
e0xrKG4OdGBJ/ShA9SkDkcSYPxFFcxDmuvXYvevlcOxCWSar7hJwzVWZebqU
gykl5MPuriX4z/7R0xch5TD94gBToO0ymJp21n0uL4flAUKJ3XsFZE9F3Go6
9AdUAwUdbiWvQa7whjeHBSrgnexS7OIQBe0PKPmtvrsCUvIdYqxlmNEntvu9
5zUq4GlBtLP5TWb0jNGgcNO1AvLzfA4yBpmRfuerovDBCmh77nz2URcLGk4Q
oC/hvyAWdmBe9Oc6ZCSJN3C0/QWKzb69uZPrUGWEPYjM/4XzaZtvDexkQ+mB
f/1k5SrhPs+B8ejXbMjd+dnWq28qwdsv2STZjh1xbfWS7lSqAsMo1R1XmTlR
ydEgBTf1Kpi8GTS0QYETeV+OPLRZtwoCGcGH9K9wIubAnyev3KqCup8eeVpp
nAgnFp5dvFcFZfLqyZR2TuRWXHPpjVcV+Ipa/XeAnQsd7em8rhRUBXtlyp/3
7eFCi6ujlo0RVTD3RAcEDbnQz42L9s4JVRAmUj/+w4MLOR9kvy/6owpCPf+y
ecqLov26Io/S86vgpKjT7XOqomjadqvvhaoqcFLwvt2iJ4q+PpUPnG6rApkJ
1mwJa1Fk91E5LGioCmaLl5i3u4qikTa9uErmavgl8tnSMEYUJSyYfrXjrwaK
dtTM82+iyErE4SevWDVU6L0xcisURb2n/UpOH6iGc7ejvzwbFEVtWb8Hiy2r
4TQleun6bir6Eya9C/+pBu0MuZz4D1Tkl75f8XpzNXS6NGbbplLRqarjh1f7
qsHqyf5fg7+pqIDdSPPoWjUM0x3ozM1UlOMcaP1TsQYqo4GWx0kgl+CI25eO
1YBipuDZw6IEUkpJeDCnVQPd61yNLCQIlN5X8HS/eQ2Zj8OJ9gMESr7IiP8a
WgOmT/tLTl4lkI0DW9rZDzXQi6MKLG4QSOaZcNb4lxqIfHKcWcmeQJ/y5cpk
S2vAzVo2e8GdQOadR2rK62sg7Y3ObL8PgbYtnWy52V0D4c48E74vCBS513Q4
bqkG1q0VJw5EEMhIx376JEct6C92H4yNJdDGm66L/SKk3lQvKJJIoNCYUK4d
8rXAg05e5P1BoIu/PggVHKkFT8uDAaE5BBJq/rrR7GQtnExt/VmTS6DnAuUy
Mca1cKyONcysnECZhzZ/17GrhdtGbXcEqwjUe80elh+S2vHsffM6Agl455bG
P62F1aqIIKMmAiknC1+89LoWLO59Sma0EuhGnUUH68dauLg8kK3cSaDgpR9W
aWm1sK/5UfK2bgL92sY1cx3XgnSKglNKL4EGNY3+4/1bCy/dLrB39hNI5HYK
e3ZrLaD+EYP0QQJBGFOw1VAtMJ18Yy4/TKCbNF0x6nwtzI+/kzgzQtbbH/sp
n7UOzA41+wqMEiiXd37PbaE6WHlb/eY+qUf3a2aLS9RBX1nC+SekXm/0Vv2P
XB1sSpb5epDUJzzHKh8o10GA5c+MZ6SfXQIYSmvWQcJFIysfMl54dVBvnX4d
eM/RSqWGCFS40GPnYV4H4f/k/t0cINDkloMMBcc6WIwKyrjQRyCxk76e7e51
oBhw78I/st6Tdi28/gF1EJ3Aky/cRSDHENkwpbd14GwjLjTSRs43x21bf1wd
HHDfeNaymUClPVVJLzPqoOQJn59vPYHoXNsPHS8gz6s+1+lUE0hir1PueHUd
dHDtU836Q6DTBsWn33XWgVH/24GyYgI5P9rQoDlWByM/bFof5RHo/edbxvOL
dfBI6O+BNnL+C7P8TrrUeghRZ3h7fiXQ9s2ma2vb68HNUTqjMp5AOmrpT5MV
6yGpMjkn9z2BPgZfjuQ4Uw9sJ4/XvH5JoKrMhJ0ZhvVgPxIo5epPoOWu5TQz
q3pQD8tpY/MkkK5CTPFvz3qQOV7CJXCbQG76M+dtgupBVel73XNLAsX/p962
IaoeNvwIjU0n7wvTn6HJu1n1IL70h3vuFHmfrPZu3D1VD6L2cSf1NhGo6YVX
bNNqPch3/HgiyE8g1h8N8t48DaApN3jVmZlAhusenvgn3QBel58WHBmkIo73
+TavrzVAhWvO+u9fqGhfqei8mk0DqLf+LcuJpqJrk5aPpx80QNvGKT77ICr6
fown9ExIA2z57XGj7jYVmbZepLH8aYC4nc6XEuSpiOvtP9vbzQ2g4iTpa7KZ
itIM7cQ6+xuAsyPkQwk3FbG0+DzIojRCvxdzzecBURTblLXv9qFG6EzQaUt7
K4r66yXiOt43Auv9bc81ZkXQ85Bkfe2vjbB5e3Lq9k4RdFDvyLqsX41w8wrl
cEaJCPKpu2Aa0tQIFhLH1pbDRdDOWm8xbb4m6I6P8xY7KoJuVo0GZj5ogl2w
0Y3ptjASCnwA0j5NULUnuddcXxhlnWUbf/WqCXRa+ByeKAsj7sotpx2+NIGb
UVTlMqswSqrQXSfd1wRJifwj1a+E0HjZzwevzjWDt+9HHs84QXS70MvUXroF
ZAslWbVO8iPxXg22uX0t4Lsqx5TAzo/KmTkTXFELcAslKaQW86EdKGDqqUEL
qN3zXv2pwYeas0Iexfq3gMbMiksp4kXHv36KbJ5oAQHnxXXlO7iR4NuSlhM/
W+GsVwS7cxYbSnXgubBesx3cqnJvPA1ZhD/hwg+S9duh7uBZJ5UxBvQXbIxS
NW+H3lkH+3w1BmzcsGvExp08v+PFfH5mHrxy1T1zv7fDKcPVykKdWdAXcv92
c1sH1N33lUulTMLitynhX0sdULOr7EJFaj2IdCwc1uXsBPGF7Kh4gVqQ52Ay
HqB2wrZM7XothyowM+JLEtzbCWJnrEKp5kXwh3W32g2rTkC/U9TrN/hCpJ75
Xf76Tli8VOt4dbiWFvPw1vCeS11w1nVn7WnOcdoezLngc7ULhDu+DPnITdAw
a9y6TrMukKU1KlrunKR1BfRKBDh0wbs0pYv7taZo4tFXLw097YIEPYp8os8M
LbzgbEFMThdwPP71cuvgPC2Yd3+k0LZ/8F/UoUdy65nwNt2aROud/yDsrUO2
yyUmnBrqkInl/0G6qSmzdSgTrtqSXGen/A84l8ubJIUpmG+vFHf5xX9QamzF
tMbOjP3019/39PkHg+wLbLYdLNgjavk8ffQf7BLV02RRYsfn9vy8vXvmH2zV
5qv/acWOxXPvBJky/sEfkHVeCGPHWd3DVVXrukFWRn2b8AI7nt7RfDZZvBuM
snfHvf/KgU2Tvp+5ca4b3mcJ/feKiwvvUbltG6HfDYYCT6bf7OPCqxWyAXVG
3cCm604XN+LC4RMf/qhad4Nxr8fRj4lcuGZv8OktHt0gHs0SEazGjY9n2mk2
feuGgm2CK3ev8mA+LRlr/qxuODJ94I+CGw9ua+nz1cDdoLqb2dMkkgffXzYq
Sf/TDYsapfnS7Tz4K5w+GdTXDV4vnpTuvciL3arYLEtGuqGEC629duDF2iZ5
3mtT3ZAWu9PP4RkvHvQ4XGS72g3p7pYrD/J4sUSRtLoW0QNCtcHXe6T58Lh+
j/njzT2gtfvowSbgwzkDkV4/t/eAn++RiyqX+PBlTmqB1J4eUEvVYb/kxYel
wqt7rh7sge7PaJornA/TZQJYQo72QOxD1Sq5L3w4UJv1BItmD7j9iNtJa+TD
19pppkfO9oBsGjOX3AgflrV76HFbrwe8Jg2SOFb5cMmL6dxOkx6w8QzbwLGN
H4dKpPyjWvVAU3+a0e59/Ng81ZqiY9cDk4l7z2ef4MdMtV0ox6UHdJ++15cw
48deQ79jXB73wJGHTo177vBjTqYI5sO+pL9UUnWwBz9+Tn1oNv+8BwJqPvpk
xhBYSM6g4HtID/yLVXiTHUfg1ycO7bj7rgcuj7mtu/GF5GFDUe+9H3rgtxYj
5ed3Au/wqT755WsP2DN/0NIneTwh4kuc7Y8eeK19lDOG5HX59ABO2d9kvQ71
ES/LCfyt7NbN4YIeuGfnNC1XRWClf5rlceU90Lovcdq+jsA589KyljU9UDIb
4G/QRODjfGwBO5p7QOLJr8ThVgIXSfaO9XT2QMZb0xPbO0leV87Ted/fA5Hb
FNRYugn893z0F+OxHii6fS3Gr5fAF6zcBLbQyXx8v5/N7Cf53M3odvtiD/SB
p/qLQQIbhRypeUvphfG70S48wwTuSly/z5CjF0LlHAb///sSi7y5l+v5e6H0
e+fTZVIPN9XRG0R7Yf77jSv2owS2m0jTCxHrhUpV9itPST29jnwv2N4Lgv1n
fLVIfU/MnhCSIf2iz/emkT+/vPfM/ao9vSQ3fbudR8Z7pLm7+fmhXlB5Hr3/
wRCB1xlzHjlzrBeSSir2Ng4Q2M95IJxbnfRbeXinrY/AfAGFS6Wne+FAitOa
bw+BX374YOSr2ws6uvz/2roIvD7r8S8Ng14Q3yEt2dRO4HdV18XXGffC4RnJ
BpcWAm8dUHHPv9ELTzoY6wobCPxpZVPXY9teqN0kUZBRQ2AZkUWE7vZCbnz4
tnN/CfxFpilm1aUX4phm9weVEvjnpVdmD317YcfRLeVcNAIftXMsOPyCjHci
+b8TmQTO9Tq3YyGkF9R8Q49LfiNwWSrPwN0PvXCsMPdWx0cC65QMn9yX0Ata
9bM8PyMJXNtREjf1tRdkdawOHHlN4DbuJzftfvdC/LuY90o+BDbeZlYuW0jG
k3ST/+5G4D6l47Ij5b3geTS/ssWJwOMWK2OWzb1QLXBmaqsZgSnY6bYJvRee
ugxfiT1MYO+GCzVblnpBr5F5v508gbnGFPd1UPrgkg+Hd/c2AotsHKcb8veB
T7DDjXIuAkvdvXH/okwfmKC7grENVCx3pPNC1J4+qIhtzvhRSsX7mS4rDB/s
g97SD7c8cqhY9Zlmv/uJPnA1LalSiaHia7GyFxON+uDBhivmupZUbHHzo8Kc
aR84uu+9LHmZim32iHMft+6DP4dChb6comKXHP68Bqc+OK8hUz6xk4pD66YV
mF/0ga2K4/od/aI4IvwW95mQPnCp4mIrqBPFsca9/a/f9kHpmd0Zm/NFcdpo
fYRcXB907ud0YI4SxX9ZM7kNcvugseY+85sLonjdAfeBLzN9cCbmKlb+KoJ5
lubzFhl9oNzlLhwfLoKFch0i1Zn64ZdA6kC9lwiWOGOq18rTD2+MiyzsL4vg
oxbq+WxS/XCm1nxP4rIwvhvCHXX1cj+oGL5penVYGPfOvtbn/tUPc41L+xp9
BPH74/vutOf3A1OBD6+LlSC+HvD3xZeyfritfCK285QgbpFcV3qhqR9EJpJP
zXII4uoLjsrvZvpBQL/Z3NBbAP9O1ZaQkxkAjTwzQnyMD7+2pQzrvB6AzqZd
060mXFir7+Z/wbcHgW1ST2K/BRPW6Q3cLS4+DF8GdosaipDPrd29dUaSw5D6
b29bgEo3nL5zyO2tzDDQdlyKYr3RA6eYO6rWHxqGtQf4fnx6H6hK7HYWPjcM
ycHG6XqnhuGAUSHm8BiGsI/tJzLeT4FYHUNvpm8YLgbYV947ugjhm86sKY4O
Q0Z8vphY7iJsMIuOc5geBps1JSyuvgTUaY2lsdVhYN3Npnjo9DIICLyKHiRG
QJc7+LLb2VVg0ZYfadccgaQeK7+rmyhoON/0UUnyCIw+wgKvMlnRlqCmm8/T
R0CRfzjxJZ0VXbymo3cxewQe65mpCCmsQ78XDst0lYyAlYS+nO/7dShYTrBu
vmcETFSkdyp7siHl1zRp6Y2jUDcs4dwrw4EczA8IjUmMgoP7gayrVznQJ8XE
5TTpUTh62D9F4wUHEvgTWn3swCj4lW+XNZ/iQL1Mdg/1z42ClZL25+8pnOjZ
TbHKJ96j0Hsv5+kyDzfKPRSceTpgFO5HiyTxHuRGc6wcsYKvRkHLUvH342vc
yDhq5n5EzCi4fgnsfJHMjUJsrM3M4kbhq3r8s5113KjscOeZXV9GwaVByWLr
IjfaX1e27XvOKBivXz+zR40HWccg3of5oyBZH2GkYcWDIu0y5lHZKMg48hhm
+vOgWmXZbrbqURg0faX9NIUHcXC+//OncRSUfFDY9yoepNJA/AjuGAUhJ2mD
A7pU5PghIOZy3yikfhmb+WRKRXEOLM/ER0fBXnymudCRitpVHjj3To/CLvu1
vCAPKhLinjBOYIzCufU6VlzBVHSqyfy0A9MYdIe88FKIIXnA8ZzEMu8Y/Ge4
Iuz2m4q8P0uXCe8agyCqufuOWSrKvhuR3qwwBrvYZvMWKSQvHheOijo4Bozw
FR8XPpJf2lbv7FYbAz6LxR/3pQgkL9iw+cT1MVBwvDdurUug/oB+jxCLMSCi
Nh7puUKgCK75gYFbY7BPxD1RwIJAPKzr057dH4MbQ7a3fZwJVPBoJ9HpNgat
FyofV7kR6OGKkqvikzHQ2RGjUOFNoOE5A42GoDHQHuYf7Aoh+fDOzcSdYWMg
X1L3Y/4dgQwmXQQeRo6BabHhl9wPBCoZetuyJXEMUoRakuxIXnS/kQSOqWNg
7mn4+HwGgQ725MQW/BgD2pbEjQPZJC+2tdtZF4xB2bkcdZkiAhkZjNdml42B
m579l8Yyku8bVpX4qsn6mJsCDlUSqFyXP9K4cQwa3/ZUatYSyKNyC8u39jEI
PptiwddIoCPae6zW9Y7BJwdP9KSFQFMlqOLS8BgMpbbrprQTKE79/N6ESdLf
0DLwKcnXxnkmr5fnxoDNeXGM2kPyPjgu66yMwXqmGBN9ks8rsz1MYljGYQd3
SPdJkt+9lV4WzXCOw89uZD0ySKBj3z/s1hAYB55dMIFI/p9TTA8Mo46Tny+G
9qdGSD5NKZgdFhsHn4oXfZRRApnvrjdU2T4O1BHOs7akFovro73YNQ5jAlIJ
fqSuk5yT7FYYh2tJt+cMSO0fw+a3/+A4+Fcn7G8l/VTFiQnvo6RWwjf4SL0Y
Ln2xWXUcGg5Uv5gZIlAaoZS5W3McNqbIpfuR+Vm/OiXudnYcbqzTb67tJ5CE
oIFnld44pHAuravsJXk5wHpwm9E4pDWtHHftJlAgl8sZJ9NxUMm1D23tJNBJ
H7+0Yqtxcl7BvGNtBFpleUtstB8HzYMNaV+bCZTxKNHVxmkcutfagqUaCGS7
kv3v98NxOLbmnK1TQyBJlz8agh5kfhyxyrv+EujlnTGBjOfj8F9ujNdsAYG0
JlecOELGQfeZ0e0BGoGYbflaDd+OQxaP24p/FoEcbih8XPs8Dtk3Ck+NpRBo
Zw9w6aaMw/ND6gcS4gjUef2cfWz6ONgudWza+J5AOga3D2vmjsP9UAoIvyIQ
W8PjyLfF4+C7RzPt3TMC/dINZhmvGIdMW+mAZi8CyWp/qwhuGYeoIia67V0C
ccGsSdvMOFzWKNyy7hyB7h/fyZGxOA7T4QvXL6mT9+vElZQXlAnQ6pqeP3eE
QHmnchdV+Sfgo8ng4pHtBHLRDXgZLzMBy2UshyYnqWjwIj7sqTgBLEX3RDx7
qEj/0kynkdIE9OkycdHqqWivkYGsgMYE8FH2KO/LpKIRix2FziYTEPj3z4qw
KxUZWl2+dc5qAtyTspvmblFRyU1/QRn7CcjZ83LC6woVxdpPXW13nYAt7BNr
Hw5TkdGDX3MnwiYg5MjVU3NToujPM72dgpVkfrxBqgcuiKIjL3z/DtdPgIxC
/J1pFVEUF5R9t6BtAhr+xJ0y3imKvEK35t4bngDPFrlbZ5dFkHjVnOwE8yTc
a6BleUeLoIbmvEI98Um4s833/I8WYcR7pS0sb+skfKfe2foVCyO1ttlbCjsm
weuXuZXxJ2GU1rFTiFN2EkwuTh4bchBGz3ueX8s5PAnVZ++/iGcWRifHDOe3
6U1C8NaYfxc3CKFIEc9a98uTwKuaeuX5kiCiKyd+absyCWF/ruQ8bRdE0X5L
lqGmk3CoflKtJFoQLUq/a+J0mISsP/IH70gKoiTT9sxJv0nY8LCBd1FCAAk0
XXf9jSehqyIav+zjRk155hRD2Snwz5QN01RiRt99C65JzE7Bq8aqsSWWfFqc
Vvl6n4UpSP+jMsy+p4QWzlNTM7Y0BUeN9u60N6igPQrs1MhmngY7nwxhRnUt
TTtsUV5fYBo6uD5ujObqoHV/3rPmv3sapJ9lfzsoOkTjK34XNW8yDf3SfKra
B+ZolKcfDK5ZTMOjB6zRmWVzNLpWgnCh1TTwhdcKPLg+T2v++8Mn2H4aqv5c
Su7xXqDFNtTYy/03DeF6L4W3VCzSjvRzILOwaeg6m+Q6s3+NdmOdU9ffv9Mw
5ZnI8/ArC964pbRxqXoajqp3/GoeYsF/lTZX7qyfBu2/TkLl21jxQZvCXx6t
0xAXfFzK9CUrZqsVfXtwcBrMtPhaNe3X4Y/RGXqRlBkQdBnSURNkx5ezuM6U
s85AaNKZDssT7Jin7praAvsMDBr0dgg4seO77Oz7dPlm4HcPt/RkAztWs7sk
wLZpBrQOdvf9fcWBe5UXymz3z4BO/z8RmwVOHKannRd+aAbKnjrBi21cWNs+
OrP4yAyMWhzyl9XmwunvT8VtPT4D5sS7hZoILuzF+eZJ/ZkZksczab+OcGOl
7WOuzOfJ85l9LtHG3Hj06PG7ChdnQPtaj8PCE2580WHI9KnhDHhHhZasq+TG
ko2HkYrlDGjU1gR5G/LgpsmAQzdvzkDazZAXLK48+BlXt/xrW/L7axVtp97x
YLqK3+apOzNgmnImf3M7Dy6IbVmMfTQD7/e/PZioz4vv/5afrvacgWtVl9xj
7vBi2SaPoVXvGWghXJtYA3nxK+7dTZcDZmDjrvFVgWJebOb48DtP+AzICDo7
7JPnwwf3dnzfFUHGl8mK59Xgw1zTKEMjegYm3z4LuHSVD3+9zfbj0acZCNyt
M6fkx4c9Fa1/RMTPwN2qc9WVUXxYf6r8R1bSDBhf5WapT+fDu1LlfzZ+mYHL
3QPKp0r58LJD0E962gzwbHogv6udD1fuof8UzJgB5j+DOrrnCfx+Uj9TPpOs
x4Iq9NWQwM5fMzNP58xAzUYXtQKSfzQdxLKsaGT9iun5z21IXt/jnvUkbwZ6
Fh7a8ZO8NDnxL+t9IdmvU9GSGv8RONT+c3Zb+Qz5PE07VP+MwNYKXDmMvzPQ
8PGHgdwrku8mbHKoNWS+NzUFld8SuMdu769zTTNgSDNodI4jcIZ8yC/b1hn4
nvPrW2wKyavj87/8Osj9KHuQ65NO4D12v34X9M7AbZbx9bYkL7LIS9D+DcxA
tYHFYfsCAjeMedBWh2fgV/o3JSmSL+OT+2ibxmegTWmNNbiCwK62p7DS1Az8
zfULSKsm8Fm5RKxHJ/dpa0aeTz2Bt43x5jrOz4DjldUQwWYCzyU55L5YnIFH
rSuMs20ELrWpzU1amYH0OJtu1U6Sh2UP5pUy0aHspYTa8D8CO4yG5fWz0MHS
hFdUo5fAJ5KW8ljY6SA9qaat309gqs21fAkuOjgbzv/bOEjgod25+Sq8dKCK
3Kl8SfJ6zsj2AkMBOjxm2cGfS/L8i0TvgnvCdKC8Dnv3nuR901tDBa+odHhe
f++u0iiBD+zWLkzdQAe7W/6vPEjNMZJS+FeMDhFpWUuPSN2WIFg0soUOExnc
CftI/eXm3SKO7XRYPvAhOpz085BpLNohReYfXvDvOxlPf/hwseouOqjMVjs8
IfPZlfCu+LosHU6OndblJPNdtl4rdlWgQ2tqtf9xsp7KXaYlb/bS4VOPhKQ8
We/7oYKSjAN08H0our2S7IdzvHRprRIdqpPigyTJfmla+5VOKtNBK3/2gTzZ
T7FdY6W8QAf6ssLAaBO5T4Nny2RU6fDmelLfdXIeoVai5ean6JDy+GyFGTk/
6533yx+fJut1Sa2jl5D7NNhSHqlDB9135fFHyPl3W0b/abpI9udo27q+TAJ/
l2apmL1EBw/XmW+a5P74DlhUCF0h/epY3MzI/VKw3P1X24QOqw88cEYMgTus
t9gnm9MhZGq+yiCcwM9shAX4rOiwLshU8WMwOa/bS+cr7ejwqoRuc8CDwGF3
J6YVHOngUm8Q5PKAwBr3el4GOtHBNlkuzMqBwB9cy+vPu9JhUfPsJFwlsK47
zTnNnQ6cZUuhuy4QmMnjGyHsSfaPv7Ys5xSBr/q8Nah7SuYnoBvStZfARPCt
dv3XZD1/4nduZyFw0avrbj/C6fBE6kDMtTkqvvv6wpb1kXRQvm6hpj5ExdXv
lE2aY+mgEfVpVuQvFft/5u67kkaHFlPfvIKXVLyWkzhqXEGHou7AvGh+Kk6h
RQXkVpHzcLnrmLwiio3yXspvq6NDUNT2GOsRUZxZ/NChp4UOCcINuVOFovhO
zWm6xSAdXHtWdLTuieKBgZGlmyyzYNWVy32rXASHDne+K2ebBXYmXB2WLoLV
xmpVZLlmYTamt+phhAiOmc52HxOYBetHPYSZnQi+suLP4iA+C3JJkVfzeERw
pZAst9PhWaAEsYRIHhXGx2xth94enQVVMZP+5G3COKU4pTgPZkGE8X3PMocw
fu6q6CWgMQvm+kswVCeEtfsPriTqzoIZ61UrgZtCuCzz+ET3rVn43Tv3dfyp
IC40vlR7LnIW4pI9KobU+fH+7LDUezGzsCdmR1b7On4cK9ryIjJ2Fs6tdf28
V8iHvcqMtEcTZqENvaiPOcGHVfebFvr8mIWVScb+YWVejNltf/yumgXsIcIr
t5kbZ6d4vJVlmYNjsjNvCuPZMJu23sbXbHOg1Z3ofc6QDZ8fkn5D4ZoD1ZIy
vTdcbHhge0Vog8Ac3I+t1rx5cx0WfkMEPxKfg5qbh54rSrPiW55JvnWH5yBp
Y9SWN6EUvOlyg5OrwxzEnj4jpJCyQHtIkTn3p30OvGRERlsVymn9atxNUv/m
4O5KuewBliLaOd/R64975+CVnLmxXhOmSfJ/sT84MgdVo+rvRLcm0P6I7X8R
vTAHgzWNy2or2SCudOzvXeF5MGw8Mzqt2Qp5drramzXn4Rnbu7274yZBNm1f
3T3teRjfs/8CHJ+C0FkRo5qz8/DI8uXXvOYpuOXaeMtHfx7Wd3En8XDOgIif
kf+U2TwwB5StmhvPwo2PN8oK3eYh3Px3/vAEA7jaXE7Zpc9D0ffMBx6Igg7e
i+d98WMehMPdvxz4j4JMhJpqvmTNgxqXM59vJgX9PHXg6hSeh1T7A1/YFJnR
je8Tt+9WzIPD1JEY3U0sKPe5+VuX/nmoO/PY2qyNFY3uemn8dmgeRu8cs44W
WofWF+buyBkl/QKLO+1OrUN2S+JfV6bnYebLmeWctHVIzKq54NHaPLC0GnSw
e7CR7/s6497rF0BZ11UlmYsDxba5fvu8aQHK8oSWYw9zoMp7ifdLxBdgWIdl
xzYrDiSVwsHCtWMBMmL5p+LzOVDtxnwiQHEBeNJO3Gu7y4nk6YeOv9RaANWi
qVfKNC5k+OIGW/qZBYidO1RypJ8LPZEJKa87twAu1y7JfefhRm3G03rUSwvA
nNyuuuEyN/KrSLr5xmwB6KbSLC8GuVGGVatC1o0F6HDw3HKZmwf9Y+GabbFe
gO4BW94wOR6kdMTSXcxhATYev37RxYEH9X3a+irKdQHE4vRoWRM8aNTrH4Pl
0QJ4GEef/inAi6ZNY65beS5A1nX3UX5FXsRAJoV/vBcggemlQO45XsS0Zetu
RT/Sf8ZyV7k9L2Jb6QoMCVgAKfwgUe45L+JtjZ5jBC6A94EDfIOJvEgk09jo
2qsFiLu10/blLyra+FoiL+/1AmwIVv5ZXE5FW526pKXfLoDif58UPjdT0c4L
0QH+kQvg0M0bojhARQf4JQwuflyAqf72QxoUAp3z2TLZl7YA7vyTL60UCXTJ
olNPK2MBOnNUpN8cJdC1E1HZKZkLYBpZOuJ4kkC31sR97uEFMHPjObnViECO
7R2jrfkLoCT399GsBclz2ZG6qHgBEoX6FB3tSZ6/Jy7O+XcBPulxnTd/TKAA
vQ5P2+oF6K+3s2t+SqBX+yKHqusWoP5og8lcEIFiJjZ/D29dgBoToyPSMQSK
q2jfuNaxAElX97UeIXk0JTHikVn3AsSPu5XOkryaY7lZW3ZoAfb+oRAm2QTK
V29PDRxdgNSoG8cEcwlUtj2CmJ1YgO2C705YFRGoinL1P4OZBdgdEsN3o5xA
jZ1iPb/mFuDRV/anXFUE6vjVdmrb4gKUGk1G6NURqPftuxTvFbL+G/xHTjYR
aOSBkcgIEwNk8hNOd7YSaPqSmMtZVgZs6A7P20zyPONAW+c3dgZMzWgFMpO8
zyTyTn09NwN+y2Z+DugleXn6SqIrHwPOrTqv/O4nEG/VJsF/ggyIPB3vEzpI
IJGUVmd1UQYIhnAcExkm0MZnb9vi1zMga/O/DUojBNp684oqnxgD7nMKU5lH
SV4/tSnOcQsDFu4IKTiSWkGqlbdxGwNSHg2Y+pL6IOvbO8pSDIgzk09VI/XR
bsPmqF1kfDNi02fS7wTeCKxyDKDW3vjwhYynFdkSa7WHAUzsTjrXhsj9cA3n
qtjHAHEkv+3bALkfhoYOiocYMB0kJJXSR+6H0saGkCMM+IYPmJ3tIZAFtUV5
UYUBT9ZDb2gXgWzob2KuHWfAcxXr717t5L7UGLD//+/GfLOPe9e3EOjB1w22
0qcYAANDjy40EOjR8+Ya/9MM0DB89XZ/Dbk/Nm+UJnUYsNbHdjKngtyXnRtY
M/UY0Km2/z0tn0BG16Q+91xmQPY+kz3vfhNI8tU+LT4jBmzZ5iq2O5NA6Wtn
As1MGXD84pi5cTKBXA9c2ffcgqxH884E22cCqd2yavhpxYD2YfX9xtEEqmvw
EOOzZ8Ddu/v1dwcT6B1PIE3JkQFXlGZvRvgRyFw1wtTMiQEXfE7H53kQiJ78
I+7nQwaEbqOLSzsSSPjJ6H4zXwY4KdwNuXKGQC1ZjMYAfwas2v4LuXmCQO8n
2R7+fM6A+Nm8BrnDBNprtDWXN4QBEx/tsqu3E0h3n/6ZnzEMqDNvzX45S95v
a7PJ7lgGHBhSNtMcoqLuSIeXvHEMiEgUTUpvoyJHLv9m0xQG+Mw5DiblUVHw
P5oFbza5j6pDGbv8qciQqOBQ+s2AOe3dvMGuVLTtTEuiaS4DlPb8TEm1paK0
n/SpH8UM+J7f9Ys4S0U1L3a5mdYx4Ab369QnfFQkeOxl6I8xBhhwGadsfSSK
mu5EH+6eZMB/Dhn2YraiKDo+uY2HzoA/Da8/1BiIoj2iJdtMFxlgfEEp2HGv
KDo3upzCw74Iuyxq+J92iaDA8BvFJhKLYFi8WeDyHhF0z9njjuv2RcBjq5SP
G0TQNd3ILa+lFkFg/K3Ad2YRJMvVcO+P7CKYnNHo2FInjEofqO88dHgRfqm+
6d11VxgxG0g+5dFdhJ82A/h6vBByIrq1fngugqxxwZe1YQFkNLMyV+29CEsP
hihWFQJIrXLDh9Gni7DzwdOWqC8CSMjn/NLWwEVwsNPrcr8jgFLmcOKzd4vQ
Nb3ecNM0Pxqsj+Ix/b4INHYphv88LzJ8dfUvz8AiSIxPtEwWciKxb1ybbg0v
QqZz6ofHLpyos/qHZenYIrRSQbNAnhOZ8wtRvOmLMDxbcNM8lAPZ+RXtW6Ms
wWhSq8ABU3bk8UjhzZTYEoS4WyC1MVYUb0Mxb9BdAvM93fw239dgQe0jI+r3
EoRrB3XfedoHrtlRngW5S5BxM9+/5WwvMO0N5x0qWIJB51v0W9QeYN/yYuve
8iVQvG0+uDW2C6iM+5oFjUvAdYbWnOPVCPuStd8MTi4BB2+RWObtr2AnSldS
3L4MvFHMgktLXbRp//E8PallsPz3+4qcdDfNiXlI22XXMtzz0HkUfb6H5jrR
bpyvQJ47Chkdiu2j+ZcW++odXQZrQmV3AgzT4v572/RAbxk6xlVDuj9O0Xr6
VO/n+SwDtlacOH1mkaYa9fe9jP8ycKTWig+2L9KiLxtWBD9fhqqRoxfzbZdo
18pvbzMLWQajysH3sv7LtJav0X9YPizDer50Pa+cVVrNw1UJ9d/L4MJ0c3Pg
QwpWPOB3Ojl3GczVFO4d/0XBgeOizqKFy1C6T/Cv2yoF65jIlfeVL8P+N0IN
Ye7MuEzDyMm7eRn2UX/cl3FlwXmCWaXF9GU4aBFw68/VdXhruTpdYWEZMnvM
In+8XocfeVWLhy0tw1bXYr3N1evwsfnBO1bMK9DR+fHERVU2nNVGiHMKrMDX
N3uPXhRnx2mfnRy1dq9AeO/vtMJsDixoQolIk1+BOoffPr2jHNhhY0Dxxr0r
sKzNXWi3mRPLB8SKjSitgPGGHq48V06c4Fhb5K+xAu+uzl3W3s+F36sobqow
WQElfWqAijc3ztPh8lwyX4F+/4KMDYncuPt6z/AuqxXwaNa9b13Jjbd7hGR5
262A331OHxMqD44tYhighytgpyoSHxvBgwsaa3Lt3FZg//nmy3y/eXDvYOKu
iMcrcETd02SgnQdLcl9jMHxWIE5RyrdvEy/+eDYv7NurFTCVZUyzBvHiIuO3
TN2vV2BjVNS2tiRe3H/7rpXA2xUoG9m4JF7Ci6VeSSnZxqyA79UiRt8yL9b4
uBb1NnYFPvmcP2tN5cM3MprYyz6vQMnfm0n6CnzYuzjVfiFhBbQLvVOST/Lh
T01+jVIpKzBpZjNre50PFw2ZgV7qCoh7H9z+2pkP9y8e/eyZTvp91ZtN2EJg
Nh4qf9qPFdCYmB7+LENg6c0Tzl1ZZH+eyv29fIDAp+RLOvh+r4BPYe7dX0Bg
K4jRUMkl69d6871ek8BxJheo4cUrEO0bZSlB8mSJo6xbSdkKpEn4PdO9QeBB
z3X9cxUrsDKy59shewLv/PTj+4W6FUhkVnbZ+Ij0/xG42aNxBf4TaW8kfEn/
EusnX1vIfMYzU4tfEDh+eJMe778VmPlXYnIsksBlS/Qc5d4VcNpZscr6kcDD
PH8lbw6sAHJM/fhfIoFlFB7Ri8ZWoO07I9HrB4G1kIHR7OQKLJhWtwr9IvDN
83sLttNXYOrA7QzdPAIn3Ol9+WiR7Efy0Y0D5aS/16+llJUVSDj99D/lKtI/
JNSsnWkV6l93wfE6AnN9ti/nZl0Fx+gr5xcaCbz756l9R9hX4a6f1gfjVgJr
l259a8W1Ck7l+3e6dBDYpmWR+TXvKjBfb65V+0fy+0jtzUKBVeCdl3+Lewic
tJxUMyO8Cn7S5nfH+gj8h9f7yDZiFVBAp375AIFHxa+/P7dxFUonQNlwiMA8
e5S43DevAu2a0abw//9/y3FBx2SJVRDWUpv2GyHj6w43t25fhTchkCM7SsY3
yz/OJb0KGZ//OruT+tndd/FKMqtw8k6ChCepk584CVrKrUKCa0HmIVKPHr3q
8WTPKkj19PLEkH6ydLWZD/tWocjMzPw3Ge9Woqx53sFVeHk8Iv8FmU+CqUh9
1+FVCL8loCA6SPZrw7L62tFV6L51JUmnn8C7qnsyNqNV4NJVUT3aS87Xt1z6
6IlV+P4mZKGd7EccfAsz1CDr5zFv2tdJ7stcOOcDzVWgRpeMqLSR+5ji4fJa
exW0zrIcW24i8A2LmyPfz65C1sSdVrt6An8S0zWq0yXjM4dXh1QTuL/2cMW0
3ircfyyicLuCwDv8tx4TNFiFz59iWCilBI5lTG7Rub4K9I8++sdoBO792hRo
Y7oKwxzzjJFMAm+3whR/i1WYD/14TSedwO8bXvQU31oFc1ulPMU4Av8LuHex
324V1rltm0iLIbCE+vVCVsdVsHyrf3gonMBR3+Q/H7+/Crnb+wKcnhG44yZ1
vfHDVQiI21VZ7kVg8W2rvm5uqyAW4f+20ZXA7wIrbmZ7rUKo9OezAjYEDre1
kT8QtArBrIM/OU8SuEXyYtSFV6sgxMzSya9C4A1tygKOr1eBb39l9J+9BA7T
4p5OiSDnWRjw6uZmAodIJ3zfmbAK/2x6C45OUHFdR5DUyeRVUGDeobncTcUi
oQ9eW3xdhT0HrtLuNFBxMKvmg/cZq7CDUD/un0PFgf8Gjorlk/0481DY9AkV
V4VVJh8pWoX3O9zD+p2pmP/cD3GD0lVIeyefIGlFxc9/ezOFVq6C/N6hi381
qfjZ2x0F/G2rYCt1a3cHJxX76JmdZpldhcjA9QZS/4ni92fbjCwWVuF44wXB
IitRnKOpZ1e8tAors6YRxEVRPK1yMsifeQ0+vleMrd4lio2kdjcKC6xBQyqt
I7FaBO+dnzaV3L0GTOKn5s8Ji+AzU7fuesuvkfHEFY8uCmOrkd4ng4prkHDi
v4+dXcI4orMhLklpDUIORbOeTxbGHCVZ4/s1yPeCOO3zw6rCuCPMw0XdZA3u
uFMKjU2EMCN4yf+z+RrIh8bcZ1cTwiIBdyM4rdbgsd0gr52UENZ8fANX2K1B
3o6WCddhQZxurcWm77oGw/Y8577aC2K/I0LBN16vgXfbwlK/nQA+0BYT71Ox
Bloz7P27nvJgAXmrhS9Va3D/h3KyozoPHnWXP9lUuwbmcn4jtyjk82Z7du/O
ljXoPHlh+s59bixyq25LWf8aLK1/bTNvyoUXXVlOszExoXun0vszZThwM/fB
3FMbmNAexVLT6mcsOGzX2+SK00wotDBj+WDGDI0+o/HR8wwT+uuQX3yOe4Z2
9vf0u8NnmZBt3rjqFeNpGtsFrWcfdZlQ0Qm5xzpcUzQnV8bN/wyY0NUNsfrs
OaM03cpLO+UsmdArnu/KCXzdNB4nkQ/PPJjQ+o/8fPFBP8EKcLiqF3nOcol1
06NcyOe0CV54woREMuwP16YXgUtk/mPzp0xIKmiiQsy/CoaKHY2PBjKhY4vL
httbW6BoY/Xm0QgmxHm8sC09ZADccUDY6UwmVCWwKCPyYhaG2/ErRhYTmhz3
32WxfQ70l2YCP+cwIbehGhP+H3Mge9DwKQtmQpL7CvUt2uahKVHKJbuICdU9
rm6pEl+Eva9pV3bXMaFeJYdM10erEJE+fam5ngn57eTsO8i5Bhw1Oy76NDKh
ny2xgtuDyL7zPNPuaWFCg+DApUb26ZnHZZW3/5hQgVMG//tLFNRvOyXOPcGE
/rH2ZKlfYEHn/SU3ZU4yIe40UdeEQBaUE3eJsJxmQuMnKm+EVrCglz2/+PNn
mZCJar7vmjorQgZ+TA+XmZDxo0TJxT3rULja9u5hTgrqDXjAmzrOhtaZ6neE
cVNQV9NGFX5JduTg/rRFg5eCOFvlansvs6OTWRM17wUoaNTEMWgasyO6Qk6+
IUFBXgY2d9z9ONCZTXofyyQpqCYVvkQxc6GwXnl8RYqCvDdlHxaV5UK9yRyt
o9IUVCWao86hx4VcUY4A/24KKhhetDf/yIWSLLa7XlCkoLQNH6/0AjdakF8J
7d1LQc8c+/YesOBGagsNqU77Kejdvtctq0+5Uauf38DrQxS099yA1WI1N+L6
OqXbpkLGP/kr2PMKD9J/UG5rCxSkOzYy6e/Kg96rfvRdRRTkaCowyRHBgw7X
X/4toUZBF++1dF1r40FekXubU9UpSIz+vPPgEg+qsuShq54k/SIN3zzewIus
Fmm7LLQo6Oe1IHvbi7woPf+N2txpCuresRjPe5sXMQXcue5zhoLy/t1vFQ/g
Rdr6Z1zWnyX9fpmHRcfxorAt0iHx5yhom5TyveB8XtQ7yPT1iC4FyZjFCNDb
edGetJay8gtkPVturBWQvOL6ML3PSI+C1j2wmQ/7R0XFas+ZxvUp6F9f5p7J
MSoS4rPa5H6Zgm4jB89VBhVdazx+UMCQgmKFzufmryPQnPXsrb1XKUg2SOi0
oxiBVPdVeudfo6CM6Gm4Ik2g58txMReNKYiuvHJ7UZFAUi+MGp3NKEg6IX3E
UIPk/csHp9ktKEj7iFLfpnME+r1VgPfNDbKfy6/cgw0IpJeer5ptTUESbwrZ
om8RyKtZJmXNnoI0Y6jJSs8IVPWetTTwNgU9vZI88/4lgcRsOnq23qGg7AGi
KTecQN9WgzaoOVOQxU5Nvs1xBFotvrW//h4FXfOskzVIIZBWkPrZGw8oqD73
l4dmOoG6tzO8fF0p6JVKiosGjUDyYzVRG9woaMX/xbRuAYFcMpKyEtwpqPSx
5xnhUgIVuXvXKz+moA+O5x74VBBISNN48o8HBTFGusy/VBPomtAR7mteFPR5
7gSTfz2BElqFpSaekH4XyBeyZrJ/sWPokQ8FRWY48VxtI9Bxu+Irgk8pqGhu
o9mFTgItNg1pFPhR0HUuYs++bgKln+DZe+8ZBZl/zWX87CWQbYr8Zpnn5L19
kZXe20/2d8N5jvYXZL/uHLqUMUigLs87My+CKMjvDmuz3DCB3oyHdKi+JPdJ
3Gvf6REC6Rr8LJ19RUHMIV9M+EYJxFPQkh4XSkEekVTje6Qukl+JuhJGQWo5
nbLepHZ/s8WfL5yC8hVKio+QWolV1Tn3LTmP5e17Q0i/aTtzk7sRFDTQ1W4X
QsZLavbWlo6iIP3T9zyUhwhkoRZ/qCWagj6e4LjjM0Ag8S/l2wLek/fxHJx6
0Eegpg3jvCiWgkL1TLgFewgU7CXAmP5IQZWWmsU6XQQ6PbG39+NnMl6kle/e
dgKxGupVXo6nIK3mQqMcsp+/C+5lcSeS9XuuXBgl+31fIfzj7yQKatA87p5H
zkMxPCfwdgoFPa++NHWMnFesPcWyMZWC2B6tLsvkk/Nq2a7r943sRzSlIPwX
gQh1DRWV7xT0+FOObOoPAvlt9Bf+8JOCtn55dbYmgUBqT5JX9bIoaF9Ozon2
DwRamagc4sgh509LPfPiHYEcCkWwHY2CNl2/tHOI3FeZPYcSt+aS88wOhyAv
AvWEG4TW5VFQ7flKRtdDAuk7RNocKSLz+6k3e8+aQAKt+NJYMQX92ZTylHad
QKXqParRpRSUY8Vi+UWPQEc37dzAVkFBO7wzvvkicp+eaLFm/iX7rXfPw/EA
gb5M2kzcqiL9rjIur5Mh0Lai1MLqWgo66DEwKiVEII7byo4RLWQ9s0bfrndQ
UV7r1avn2sh52Fz6+bqKih5qPDrF0kFB/30Y8HfJo6LxTYXi1v8oqPF5d+Tx
j1RUV6RTvn+QgqyfuJW03aCiKDFTyT+zFDSxGhzr3SKKjuzbLW86T0HVP/b/
qi4RRXWa9EMLCxS0FOoV05AhijjueZ+WXCY//77PD/IFiyKH6gRHV2ZmdMn2
2e3j6qIIec9gWX5mJKORUTMVKYJa3uWU5QkwIw3ZrPUrviLo7rcndZeFmJHT
llDhYkcRFNdFDHqJMiMmdj7vMHURJKh8lL99EzOaqhbcpTwojLonvK4G7GRG
GV4fpqu2CiNXNh3L7TLMiD/S+PU0uzCibiZuZ+5mRn5eji1NY0JISyveq0+e
GUnGtjXQfwqhtNiKRJUDzKhCZMtGZ20h5GlAXRw7zoyq3G0OLVsJIsn8z6E6
V5iRWLWylc0cH/oruxDbZkRqtviQigw+dD/01Leb15jRtuJgkyZnPlRuPVTp
bcKMTu8Ifjc+y4scBXZz0iyZ0Y1hnitKkzyIdjXlocJdsp7WO6UbG7iQ4UK6
sUAAMzr6pkFF0o4NBcrlydT8ZkZmSr+m5UUXIU7pCqcHZkarVcITNbYMoJ2g
DyjmMaPY5uQPp4sWYNxA6mNQITMKFN/fUuQ8D6e9/bac/8OMbJi/ShxsoANb
p65IVTMz0lH7GsG7fQIeBvasVNCZUUJwdtDvw3UQ/Na17b85ZiRve6j3fEQ1
JHwSzZZbYEZNNVcljVj+QlPOyfsBS8woTtwYd7zJh4NDidPazCwIl6YxV0p6
0CaP3x0o52dB14yrfsWK1tNuzLBWl8qwoDGN53Ln7o/TriWo/TWSZUGW9+JD
FcMnaPomXuUTcizoU3Gs/4urkzSNSpYiUUUWlFS37i7bf1M0qUTmbJNDLGj9
6kb59u8ztD5Tpo+MEyzIaovnwbO8CzTzmqX7u66yIFl/8yjjbUzY6Kmyc841
FtTlsuv0HhMmfBE9vHPWmAU9tTm9830UE1ZLWbR1MmNB28XmvlptomBJv/8F
rgJR/fliwWkDQES+IOVmDgLA40H3TFl2A0BDVdYHXOEDwGKx8iCJjwNAW5+R
Zh01B8BsglP8SpEDQIG07pEybAfAdVO01wyTA0AQHsbcsKIHwIj1dY6QlgNA
rgsPuOQNCMCuOfn7l50DQHp9m3gN3QjAuApa11mfA0DyDZZ/Tw8JwMHburIb
oQNAULbfv/JACcDUfXxpn6QDQJYtZzFZognA+cH/1qarA0BqyP9kjF0KwAKT
YLJorQNAZtdWrr6KCsAMZMGNKq8DQOqiQwpLtwrAHgaDRK6yA0BEhUChbg4L
wERKBrK1uQNAFkJXkMq0C8CQ0gyNxMcDQOh65Bwq4QzAmqNtaIbJA0BWyUbK
nwMNwKN0zkNIywNAcB+unGMlDcC2FpD6y84DQBiPQyjTZg3AwOfw1Y3QA0BA
gbmlfYYNwMm4UbFP0gNAih/K0HOlDcDcWhNo09UDQKoPmd1A4Q3A5it0Q5XX
A0D0Fs+eFv4NwO/81B5X2QNAYqWUzDUaDsD4zTX6GNsDQCKTOt+dNQ7AAp+W
1drcA0AaL4VSTlAOwAtw97Cc3gNAdGAC2jkOF8AUQViMXuADQPXy37TZGhfA
HhK5ZyDiA0BOAx0EHScXwCfjGUPi4wNAt8iOjAMzF8AwtHoepOUDQDodyhSN
PhfAOoXb+WXnA0COkiRluUkXwEwnnbDp6gNA7v9WiPleF8BW+P2Lq+wDQMf4
pvQMaRfAX8leZ23uA0CeAghcwnIXwHJrIB7x8QNAm7lkYhKFF8B8PIH5svMD
QHlBBamsjRfAhQ3i1HT1A0AQOgI66JUXwJivo4v4+ANA6TP4nUKlF8CigARn
uvoDQBaO3SZhrBfAq1FlQnz8A0BNcPllILMXwLQixh0+/gNAzhm+OoC5F8C+
8yb5//8DQAEoaoaAvxfAfw4cfQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"F\"", TraditionalForm]},
  PlotRange->{{0, 2.5}, {-5.98099999999935, 5.980997713635799}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181790008976*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{"fplot", ",", "Fplot", ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181788596596003`*^9, 3.5181788596616*^9}, {
  3.5181790093856*^9, 3.5181790120766*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF0GdQEwYYBuAITsBTFKkjhmApMYgIPelJKQ1Ur4ootUAUcUEYoSBhWCgV
WqkioCcYkSWWpoGylBEQhCAmEMCUEECmg2gZCYqijBAhEUzbH37fj+/ee369
732mjFA3fx0CgZD93/2fOb8yltr4BX9ts7yE6OWnpS0bGKa8MblB+2iuhBP+
2qQYXFZ+aeC0VR2YSeu6MR7RBGYpqCNVZa3gxrUbbtitbgfrmcZT/tn1EKzD
rt17LBit+TDOfJSDrt2oCY26hY76Yln0uhqwcKebUVxVE3o6xDTJ/SGalW+f
dW0M/VpGL+rU6QLL6gQvxUy0NItCbZCiSz3UxbyMbnDK6jYLrncPeE61KtLN
uA/MGPAQ6kr7weEt8YxQylNwRZiB+3rnZ2BuTPAr6yOD4POc+e9nxofATnyW
8+M7w2BCz6Bj/dkRcPyYgHv2N/QKQo6OXRI6xTjGdzYFTFuz/WhzdTqa6LUu
4fM89GeJXXvLeehdQ85tRW3o/fYi19xRNGuikp5OlIOv5+UdT3JDy/QvBrEE
aPMfA6I9LBTgJbbnXpQr0XJV5mH9+6PYpwj6JTX8JdhVzt5GIr3C/b1qulKB
ftXEiPu79DXYPlNIoWwcB18JInZeTEB7c5TROVz0zl7Jlup69B+su7OOEvTy
FblS6SO0Q/8nNanPwcKIvGSupwJdFKZ7hTSOfubwc5R8Gp1QSJGspb4BWxn2
b959Ck0sUgivUt+C9WgqH5kSvfeN1+wW+iT4schvkZflFLg6qfkkWYUOWBI5
2NExDZbbz0lCdirBvhEx1QbZaF740pq4AvR82LXamUp0p/VMreFdMC138jDf
io+O4vH5LvVo5zBiXaAQPTkxVJfbgs4ILbwna0Nbs+4LmuXo1tM9jSUL6Pkf
tOLYHTPgHcxtHQd80Nr62+Pe7ejONZb6kXYq8L2y8zctdd+BYxZZHJI+Q+vJ
zu5jVc2Co51c3yasnwMrCkzTOLHoaQb3VOAFNMHEdJvNZfTShUF2ejJ65cCf
79RstBHf+/jJNLBwYyZZJMpE264iH/XIRx9KNJlUVKITfiKRVnSg65mbD1iO
obfu21QUYaIGp23dsJhPR6cOCf1X3kOzswPEPmQN2CvtRIfBC/Tcnnw1R/Ae
PKL4JlqUOA8WGda1imfQuQ42m9p9FsB/PVAfdYxB538nyrqThjZPM98VwkUX
PL78yLwM/WDMl0avQI9qviq8ULWA/zYwXlVZg6ZsnogarEMH0rjfOjSii3zc
jbPF6Ftn5NfjNOjSi5GGzO0fwNkhp61sr6ET6b4uuiq0rYxbnNiuBWdRb5a2
uxAcP/pcQ3KWCx89GjJF0p9AH9xEz5eYLQKX+H8a626D1uNNuckc0HZ9ngLy
HnSgRkj1348mJJ85lXgQnWVCSS8+hJa/JPC+dENbVz6VtLmjY2OqFMfpYKF4
Twrh7WF0/BOLMm0o2oklPmZ4CR3WYtTAEqI5RIaZVIU2ayrMcD2mA2ZvF1l0
C9ABysVdrRa6YL/u99HUE2hGxTT50lW0ulHbX3Abze42SG4Wo+8aszVtHWiZ
19rAnj70xHwv6cgTtA4no++pDK0fNsv7/TmYZuTkeeXkIJq0hs8kD6MpIxt2
D4+gI4LJpKkptEBprtZq0f8CRTFidA==
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c4le8fxx1k73GehqQSJSNNJX3uhCKpFEUqM5SVopIvhRApFElZpbKL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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Friction\"", TraditionalForm]},
  ImageSize->{666., Automatic},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{{3.5181790027866*^9, 3.5181790124186*^9}}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 152, 7, 191, "Title",
 Evaluatable->False],
Cell[712, 29, 77, 5, 65, "Text",
 Evaluatable->False],
Cell[792, 36, 699, 22, 152, "Input"],
Cell[1494, 60, 79, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1598, 69, 1034, 34, 152, "Input"],
Cell[2635, 105, 443, 18, 101, "Text",
 Evaluatable->False],
Cell[3081, 125, 1936, 61, 272, "Input"],
Cell[5020, 188, 949, 33, 425, "Text",
 Evaluatable->False],
Cell[5972, 223, 3082, 91, 552, "Input"]
}, Open  ]],
Cell[9069, 317, 361, 17, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9455, 338, 1549, 42, 272, "Input"],
Cell[11007, 382, 890, 30, 30, "Output",
 Evaluatable->False],
Cell[11900, 414, 136, 3, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[12073, 422, 544, 17, 31, "Input"],
Cell[12620, 441, 24872, 416, 246, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37529, 862, 422, 11, 31, "Input"],
Cell[37954, 875, 23215, 388, 242, "Output"]
}, Open  ]],
Cell[61184, 1266, 429, 13, 72, "Input"],
Cell[61616, 1281, 2506, 67, 432, "Input"],
Cell[64125, 1350, 2509, 67, 432, "Input"],
Cell[CellGroupData[{
Cell[66659, 1421, 429, 12, 31, "Input"],
Cell[67091, 1435, 2179, 44, 254, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69307, 1484, 413, 12, 31, "Input"],
Cell[69723, 1498, 23297, 390, 253, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93057, 1893, 314, 8, 72, "Input"],
Cell[93374, 1903, 25114, 423, 440, "Output",
 Evaluatable->False]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

