(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     74437,       1650]
NotebookOptionsPosition[     72337,       1575]
NotebookOutlinePosition[     72893,       1597]
CellTagsIndexPosition[     72850,       1594]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

This Program Simulates a 

Scooting Grocery Cart. It has a specified force applied
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

These are the equations for F.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", "t_", "]"}], " ", ":=", " ", 
    RowBox[{"anot", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"omega", " ", "t"}], "]"}]}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790422906*^9, 3.5181790422916*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

These are the dynamic equations.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"n", " ", ":=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"mb", " ", "+", " ", "mc"}], " ", ")"}], " ", "g"}]}], "\n", 
   "\n", 
   RowBox[{"eqnc", " ", ":=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"F", "[", "t", "]"}], " ", "-", " ", 
      RowBox[{"f", "[", "t", "]"}]}], " ", "==", " ", 
     RowBox[{"mc", " ", 
      RowBox[{
       RowBox[{"yd", "'"}], "[", "t", "]"}]}]}]}], "\n", "\n", 
   RowBox[{"eqnb", " ", ":=", " ", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"F", "[", "t", "]"}]}], " ", "==", " ", 
     RowBox[{"mb", " ", 
      RowBox[{
       RowBox[{"zd", "'"}], "[", "t", "]"}]}]}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790435906*^9, 3.5181790435936003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

These are the sticking and sliping solutions. It solves the equations for the 

highest derivatives plus the friction force. 
\
\>", "Text",
 Evaluatable->False,
 FontFamily->"Arial",
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"sticksol", " ", ":=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqnc", ",", "eqnb", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}], "==", "0"}]}], "}"}], ",", 
      "\n", "\n", "                 ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], "\n", "\n", 
   RowBox[{"possol", " ", ":=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqnc", ",", "eqnb", ",", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], "==", 
         RowBox[{"mu", " ", "n"}]}]}], "}"}], ",", "\n", "\n", 
      "                ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], "\n", "\n", 
   RowBox[{"negsol", " ", ":=", " ", 
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"eqnc", ",", "eqnb", ",", 
        RowBox[{
         RowBox[{"f", "[", "t", "]"}], "==", 
         RowBox[{
          RowBox[{"-", "mu"}], " ", "n"}]}]}], "}"}], ",", "\n", "\n", 
      "               ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"f", "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}]}], "]"}]}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790448966*^9, 3.5181790448986*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

Give the solution convenient names.  Only for convenience.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"stickf", ",", "stickzdd", ",", "stickydd"}], "}"}], " ", "=", 
     " ", "\n", "\n", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}], "/.", "sticksol"}], 
       ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"posf", ",", "poszdd", ",", "posydd"}], "}"}], " ", "=", " ", 
     "\n", "\n", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}], "/.", "possol"}], 
       ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"negf", ",", "negzdd", ",", "negydd"}], "}"}], " ", "=", " ", 
     "\n", "\n", "\t", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"zd", "'"}], "[", "t", "]"}], ",", 
          RowBox[{
           RowBox[{"yd", "'"}], "[", "t", "]"}]}], "}"}], "/.", "negsol"}], 
       ")"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790458926*^9, 3.5181790458946*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

The next are if statements to define which solution region we are in.
  \
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.5181790484686003`*^9, 3.5181790511116*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"isnegregion", "[", 
     RowBox[{"t_", ",", "v_"}], "]"}], " ", ":=", " ", "\n", "\n", "\t", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"v", "<", "0"}], ")"}], " ", "||", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"v", "==", "0"}], ")"}], " ", "&&", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"F", "[", "t", "]"}], " ", "<", " ", 
           RowBox[{
            RowBox[{"-", "mu"}], " ", "n"}]}], ")"}]}], ")"}]}], ",", "\n", 
      "\n", "\t\t", "True", ",", "False"}], "]"}]}], "\n", "\n", 
   RowBox[{
    RowBox[{"isposregion", "[", 
     RowBox[{"t_", ",", "v_"}], "]"}], " ", ":=", " ", "\n", "\n", "\t", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"v", ">", "0"}], ")"}], " ", "||", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"v", "==", "0"}], ")"}], " ", "&&", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"F", "[", "t", "]"}], " ", ">", " ", 
           RowBox[{"mu", " ", "n"}]}], ")"}]}], ")"}]}], ",", "\n", "\n", 
      "\t\t", "True", ",", "False"}], "]"}]}], "\n", "\n", 
   RowBox[{
    RowBox[{"isstickregion", "[", 
     RowBox[{"t_", ",", "v_"}], "]"}], ":=", "\n", "\n", "\t", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"v", "==", "0"}], ")"}], "&&", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"F", "[", "t", "]"}], "<", 
         RowBox[{"mu", " ", "n"}]}], ")"}], " ", "&&", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"F", "[", "t", "]"}], " ", ">", " ", 
         RowBox[{
          RowBox[{"-", "mu"}], " ", "n"}]}], ")"}]}], ",", "\n", "\n", "\t\t",
       "True", ",", "False"}], "]"}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790541736*^9, 3.5181790541756*^9}}],

Cell["\<\

The following allows us to cut and paste the equations solved above into the 

integration statement that comes next.  Cutting and pasting is an ugly way

to do it but it makes the equation easier to understand because there will

be fewer criptic Mathematica commands.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"InputForm", "[", "posydd", "]"}], "\n", "\n", 
   RowBox[{"InputForm", "[", "negydd", "]"}], "\n", "\n", 
   RowBox[{"InputForm", "[", "stickydd", "]"}], "\n", "\n", 
   RowBox[{"InputForm", "[", "poszdd", "]"}], "\n", "\n", 
   RowBox[{"InputForm", "[", "negzdd", "]"}], "\n", "\n", 
   RowBox[{"InputForm", "[", "stickzdd", "]"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790555755997`*^9, 3.5181790555776*^9}}],

Cell["-((anot*Sin[omega*t])/mb)", "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181790849476*^9}]
}, Open  ]],

Cell["\<\

Integrate the equations to find position and velocity. Note that the previous

statements are pasted into this equation. The first statement makes sure the

parameters are undefined so we will get a general equation and can change 

parameters on the fly.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"mb", "=."}], ";", 
    RowBox[{"mc", "=."}], ";", 
    RowBox[{"g", "=."}], ";", 
    RowBox[{"mu", "=."}], ";", 
    RowBox[{"anot", "=."}], ";", 
    RowBox[{"omega", "=."}], ";", 
    RowBox[{"MaxTime", "=."}], ";"}], "\n", "\n", 
   RowBox[{"integrate", " ", ":=", " ", 
    RowBox[{"NDSolve", "[", "\n", "\n", "\t", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"zv", "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
         RowBox[{"z", "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
         RowBox[{"y", "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
         RowBox[{"yv", "[", "0", "]"}], "==", "0"}], ",", "\n", "\n", "\n", 
        "\n", "  ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Second", " ", "derivative", " ", "of", " ", "y"}], ",", 
          " ", 
          RowBox[{"yv", " ", "is", " ", "velocity", " ", "of", " ", "y"}]}], 
         "*)"}], "\n", "\n", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"yv", "'"}], "[", "t", "]"}], "==", " ", "\n", "\n", "   ", 
         
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"isnegregion", "[", 
            RowBox[{"t", ",", 
             RowBox[{"yv", "[", "t", "]"}]}], "]"}], ",", 
           RowBox[{"(*", 
            RowBox[{
            "Next", " ", "line", " ", "is", " ", "pasted", " ", "in"}], 
            "*)"}], "\n", "\n", "        ", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"g", "*", 
               RowBox[{"(", 
                RowBox[{"mb", " ", "+", " ", "mc"}], ")"}], "*", "mu"}], 
              ")"}], "/", "mc"}], " ", "+", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"anot", "*", 
               RowBox[{"Sin", "[", 
                RowBox[{"omega", "*", "t"}], "]"}]}], ")"}], "/", "mc"}]}], 
           ",", "\n", "\n", "   ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"isposregion", "[", 
              RowBox[{"t", ",", 
               RowBox[{"yv", "[", "t", "]"}]}], "]"}], ",", 
             RowBox[{"(*", 
              RowBox[{"Next", " ", "is", " ", "pasted"}], "*)"}], "\n", "\n", 
             "     ", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"g", "*", 
                   RowBox[{"(", 
                    RowBox[{"mb", " ", "+", " ", "mc"}], ")"}], "*", "mu"}], 
                  ")"}], "/", "mc"}], ")"}]}], " ", "+", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"anot", "*", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"omega", "*", "t"}], "]"}]}], ")"}], "/", "mc"}]}], 
             ",", "\n", "\n", "   ", 
             RowBox[{"(*", 
              RowBox[{
              "If", " ", "neither", " ", "above", " ", "then", " ", "it", " ",
                "is", " ", "sticking"}], "*)"}], "\n", "\n", "          ", 
             RowBox[{"(*", 
              RowBox[{
              "Next", " ", "line", " ", "is", " ", "pasted", " ", "in"}], 
              "*)"}], "\n", "\n", "\t", "0"}], "\n", "\n", "\t", "]"}]}], 
          "]"}]}], ",", 
        RowBox[{"(*", 
         RowBox[{
         "Ends", " ", "the", " ", "two", " ", "if", " ", "statements"}], 
         "*)"}], "\n", "\n", "\n", "\n", "  ", 
        RowBox[{"(*", 
         RowBox[{"First", " ", "derivative", " ", "of", " ", "y"}], "*)"}], 
        "\n", "\n", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}], "==", 
         RowBox[{"yv", "[", "t", "]"}]}], ",", "\n", "\n", "\n", "\n", "  ", 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{"Second", " ", "derivative", " ", "of", " ", "z"}], ",", 
          " ", 
          RowBox[{"zv", " ", "is", " ", "velocity", " ", "of", " ", "z"}]}], 
         "*)"}], "\n", "\n", "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"zv", "'"}], "[", "t", "]"}], " ", "==", " ", "\n", "\n", 
         "   ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"isnegregion", "[", 
            RowBox[{"t", ",", 
             RowBox[{"yv", "[", "t", "]"}]}], "]"}], ",", 
           RowBox[{"(*", 
            RowBox[{
            "Next", " ", "line", " ", "is", " ", "pasted", " ", "in"}], 
            "*)"}], "\n", "\n", "        ", 
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"anot", "*", 
                RowBox[{"Sin", "[", 
                 RowBox[{"omega", "*", "t"}], "]"}]}], ")"}], "/", "mb"}], 
             ")"}]}], ",", "\n", "\n", "   ", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"isposregion", "[", 
              RowBox[{"t", ",", 
               RowBox[{"yv", "[", "t", "]"}]}], "]"}], ",", 
             RowBox[{"(*", 
              RowBox[{
              "Next", " ", "line", " ", "is", " ", "pasted", " ", "in"}], 
              "*)"}], "\n", "\n", "        ", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"anot", "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"omega", "*", "t"}], "]"}]}], ")"}], "/", "mb"}], 
               ")"}]}], ",", "\n", "\n", "   ", 
             RowBox[{"(*", 
              RowBox[{"Must", " ", "be", " ", 
               RowBox[{"sticking", ".", " ", "Next"}], " ", "line", " ", "is",
                " ", "pasted", " ", "in"}], "*)"}], "\n", "\n", "        ", 
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"anot", "*", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"omega", "*", "t"}], "]"}]}], ")"}], "/", "mb"}], 
               ")"}]}]}], "\n", "\n", "\t", "]"}]}], "]"}]}], ",", 
        RowBox[{"(*", 
         RowBox[{
         "Ends", " ", "the", " ", "two", " ", "if", " ", "statements"}], 
         "*)"}], "\n", "\n", 
        RowBox[{"(*", 
         RowBox[{
         "Should", " ", "have", " ", "noticed", " ", "that", " ", "all", " ", 
          "three", " ", "regions", " ", "are", " ", "the", " ", "\n", "\n", 
          "same", " ", "hence", " ", "we", " ", "did", " ", "not", " ", 
          "need", " ", "the", " ", "If", " ", 
          RowBox[{"statements", ".", " ", "\n", "\n", "\t", "Oh"}], " ", 
          "well"}], "*)"}], "\n", "\n", "\n", "\n", "    ", 
        RowBox[{"(*", 
         RowBox[{"First", " ", "derivative", " ", "of", " ", "z"}], "*)"}], 
        "\n", "\n", "    ", 
        RowBox[{
         RowBox[{
          RowBox[{"z", "'"}], "[", "t", "]"}], "==", 
         RowBox[{"zv", "[", "t", "]"}]}]}], "}"}], ",", "\n", "\n", "\n", 
      "\n", "    ", 
      RowBox[{"(*", 
       RowBox[{
       "What", " ", "to", " ", "integrate", " ", "for", " ", "and", " ", 
        "time", " ", "period"}], "*)"}], "\n", "\n", "    ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], ",", 
        RowBox[{"yv", "[", "t", "]"}], ",", 
        RowBox[{"z", "[", "t", "]"}], ",", 
        RowBox[{"zv", "[", "t", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "MaxTime"}], "}"}]}], "]"}]}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790618816*^9, 3.5181790618836*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

Here are some parameters.
\
\>", "Text",
 Evaluatable->False,
 FontFamily->"Arial",
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"mb", " ", "=", " ", "1"}], ";", " ", 
    RowBox[{"mc", " ", "=", " ", "1"}], ";", " ", 
    RowBox[{"g", " ", "=", " ", 
     RowBox[{"981", "/", "100"}]}], ";", " ", 
    RowBox[{"mu", " ", "=", " ", 
     RowBox[{"1", "/", "10"}]}], ";"}], " ", "\n", "\n", "    ", 
   RowBox[{
    RowBox[{"anot", " ", "=", " ", "5"}], ";", " ", 
    RowBox[{"omega", " ", "=", " ", "10"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"MaxTime", " ", "=", " ", "1"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"sol", " ", "=", " ", "integrate"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"endtime", " ", "=", " ", "1"}], ";"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181790646596003`*^9, 3.5181790646616*^9}, 
   3.5181791189646*^9},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

Plot the velocity of the cart.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"yv", "[", "t", "]"}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<Ydot\>\""}], "}"}]}]}], "]"}]], "Input",\

 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxFl3k8lN8b91uUpaJFQiupVJLKUpJPRTvaVMiSElFRtmSJbKFok2TJliVL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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Ydot\"", TraditionalForm]},
  PlotRange->{{0, 1}, {-0.3902239190916603, 0.4616449112537077}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181791214686003`*^9}]
}, Open  ]],

Cell["\<\

Plot the position of the cart.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<Y\>\""}], "}"}]}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k01F/4B3CkUqTskrJEZVfatMxbKELaiBCSJEVIKGTJlki2Grvsa3Yz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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Y\"", TraditionalForm]},
  PlotRange->{{0, 1}, {0., 0.10090325002159943`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181791231766*^9}]
}, Open  ]],

Cell["\<\

Plot the position of the torso mass.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"z", "[", "t", "]"}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<Z\>\""}], "}"}]}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8lV8YAHCrMgoJGSU7KyREw1Moe48SoYiUsosiVCghP1lJ2Sole2Tc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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Z\"", TraditionalForm]},
  PlotRange->{{0, 1}, {-0.527201040380765, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181791250466003`*^9}]
}, Open  ]],

Cell["\<\

Plot the distance x.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"z", "[", "t", "]"}], "-", 
     RowBox[{"y", "[", "t", "]"}]}], "/.", "\[InvisibleSpace]", "sol"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "endtime"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time\>\"", ",", "\"\<X\>\""}], "}"}]}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c4Vm0YAHCjkGTLSNkiQoVSdAuVjAbKCBEpKtmllJG9N8meRaKshPeR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"X\"", TraditionalForm]},
  PlotRange->{{0, 1}, {-0.6281042904023644, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181791264156*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 187, 9, 299, "Title",
 Evaluatable->False],
Cell[747, 31, 77, 5, 65, "Text",
 Evaluatable->False],
Cell[827, 38, 423, 14, 72, "Input"],
Cell[1253, 54, 79, 5, 65, "Text",
 Evaluatable->False],
Cell[1335, 61, 904, 29, 152, "Input"],
Cell[2242, 92, 405, 17, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2672, 113, 1902, 59, 272, "Input"],
Cell[4577, 174, 105, 5, 65, "Text",
 Evaluatable->False],
Cell[4685, 181, 1849, 60, 272, "Input"],
Cell[6537, 243, 184, 6, 65, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[6736, 252, 1989, 57, 392, "Input"],
Cell[8728, 311, 316, 11, 173, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[9069, 326, 493, 10, 272, "Input"],
Cell[9565, 338, 126, 3, 44, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[9706, 344, 302, 11, 173, "Text",
 Evaluatable->False],
Cell[10011, 357, 7651, 195, 1472, "Input"],
Cell[17665, 554, 305, 15, 65, "Text",
 Evaluatable->False],
Cell[17973, 571, 934, 26, 232, "Input"],
Cell[18910, 599, 77, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[19012, 608, 428, 12, 31, "Input"],
Cell[19443, 622, 15078, 255, 246, "Output"]
}, Open  ]],
Cell[34536, 880, 77, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[34638, 889, 422, 11, 31, "Input"],
Cell[35063, 902, 12600, 215, 247, "Output"]
}, Open  ]],
Cell[47678, 1120, 83, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[47786, 1129, 422, 11, 31, "Input"],
Cell[48211, 1142, 11593, 198, 248, "Output"]
}, Open  ]],
Cell[59819, 1343, 67, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[59911, 1352, 483, 14, 31, "Input"],
Cell[60397, 1368, 11924, 204, 248, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

