(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    120601,       2223]
NotebookOptionsPosition[    119091,       2166]
NotebookOutlinePosition[    119647,       2188]
CellTagsIndexPosition[    119604,       2185]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

This is a mass that is being forced back and forth.
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

The solution when F is ignored.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "k"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "-", "L"}], ")"}]}], " ", "==", " ", 
        
        RowBox[{"m", " ", 
         RowBox[{
          RowBox[{"v", "'"}], "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], " ", "==", " ", 
        RowBox[{"v", "[", "t", "]"}]}], ",", "\n", "\n", "\t", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], " ", "==", " ", "L"}], ",", " ", 
       RowBox[{
        RowBox[{"v", "[", "0", "]"}], " ", "==", " ", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181791576426*^9, 3.5181791576446*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"L", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["k"], " ", "t"}], 
          SqrtBox["m"]], "]"}], "2"]}], "+", 
      RowBox[{"L", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["k"], " ", "t"}], 
          SqrtBox["m"]], "]"}], "2"]}]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181791736226*^9}]
}, Open  ]],

Cell["\<\

The solution when F is present. Often the solution is easiest to find using 

complex numbers. The complexexpand statement simply converts from 

complex to real after the solution is obtained.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "a"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"omega", " ", "t"}], "]"}]}], " ", "-", 
           RowBox[{"k", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "-", "L"}], ")"}]}]}], " ", "==", 
          " ", "\n", "\n", "\t\t", 
          RowBox[{"m", " ", 
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}]}]}], ",", "\n", "\n", "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}], " ", "==", " ", 
          RowBox[{"v", "[", "t", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"x", "[", "0", "]"}], " ", "==", " ", "L"}], ",", " ", 
         RowBox[{
          RowBox[{"v", "[", "0", "]"}], " ", "==", " ", "0"}]}], "}"}], ",", 
       "\n", "\n", "\t", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], ",", 
         RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{
    RowBox[{"complexans", " ", "=", " ", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "/.", "sol"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"realans", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "complexans", "]"}]}], ";"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181791603185997`*^9, 3.5181791603236*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

Simplify the answer and use some numbers so the reader can follow easier.

Note that complex exponents are equivalent to sines and cosines.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"simpans", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"realans", "/.", "\n", "\n", "\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m", "->", "1"}], ",", 
        RowBox[{"k", "->", "1"}], ",", 
        RowBox[{"a", "->", "0.00001"}]}], "}"}]}], "]"}]}], "\n"}]}]], "Input",\

 PageWidth->Infinity,
 CellChangeTimes->{{3.5181791621586*^9, 3.5181791621605997`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], "+", 
   FractionBox["L", 
    RowBox[{"1", "-", 
     SuperscriptBox["omega", "2"]}]], "+", 
   FractionBox[
    RowBox[{"L", " ", 
     SuperscriptBox["omega", "2"]}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["omega", "2"]}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.00001`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", "omega", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["omega", "2"]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"0.00001`", "\[VeryThinSpace]", "+", 
       RowBox[{"0.`", " ", "\[ImaginaryI]"}]}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"omega", " ", "t"}], "]"}]}], 
    RowBox[{
     RowBox[{"-", "1.`"}], "+", 
     SuperscriptBox["omega", "2"]}]]}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181791756896*^9}]
}, Open  ]],

Cell["\<\

Generate a plot of the response when omega is far from 1.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"simpans", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"omega", "->", ".5"}], ",", 
        RowBox[{"L", "->", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "40"}], "}"}], ",", "\n", "\n", "\t", 
     RowBox[{"PlotLabel", "->", "\"\<Omega = 0.5, L = 1\>\""}], ",", "\n", 
     "\n", "\t", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Time in Seconds\>\"", ",", "\n", "\n", "\t\t", 
        "\"\<Position\>\""}], "}"}]}], ",", "\n", "\n", "\t", 
     RowBox[{"Frame", " ", "->", " ", "True"}]}], "]"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181791640856*^9, 3.5181791640875998`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl3Hk8VG0bwHFRkn0n+74vg7Evc5lJiApFKSlSSCRFkjZEkrJkiSyJEkpJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.9999849999999999},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Position\"", TraditionalForm]},
  PlotLabel->FormBox["\"Omega = 0.5, L = 1\"", TraditionalForm],
  PlotRange->{{0, 40}, {0.9999826795139234, 1.0000173201445366`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181791780546*^9}]
}, Open  ]],

Cell["\<\

Now let omega get closer to 1.  Note the response is still building even after

1000 seconds.  Eventually the response will \"level off\" but when it does it \
will

have a noticable \"wiggle\" centered about 1.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"simpans", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"omega", "\[Rule]", "0.9999`"}], ",", 
      RowBox[{"L", "\[Rule]", "1"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1000"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Omega = 0.9999, L = 1\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time in Seconds\>\"", ",", "\"\<Position\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwcnHc8lt8bx60QUomyshWShIwGl5Hsvffe43l4jMiWlQYRJVEJiZLRUCgV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.996},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Position\"", TraditionalForm]},
  ImageSize->{538., Automatic},
  PlotLabel->FormBox["\"Omega = 0.9999, L = 1\"", TraditionalForm],
  PlotRange->{{0, 1000}, {0.9950294394239633, 1.0049652417377934`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181791803126*^9}]
}, Open  ]],

Cell["\<\

The following shows a detail of the first part of the response.  Notice the 

response is sinusoidal.  This effect comes from the complex exponential \
terms.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"simpans", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"omega", "\[Rule]", "0.9999`"}], ",", 
      RowBox[{"L", "\[Rule]", "1"}]}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "40"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Omega = 0.9999, L = 1\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time in Seconds\>\"", ",", "\"\<Position\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwc3Hc8ll8UAHDZOyQ7O3u+9nzPq0iSSgihaBjZLZUiRMnOimxKkQYqQlap
RPZKKqOyZ1mV33N+v39+n++nvJ7n3nPPPec+z5uYi4/lCWoqKiorOioq/H/G
FRd61eNFhlT//zdH9jQ467UsUkGWfCS9sbExS+5cd0ucE3lHLr1stIoWuNXV
PL3jA3nmsftvtIsc0Ey6fiQPKX5eQFOvX/y4FNhGTr/WMofu+mq9bcm4naxW
d2MGffeNyqlF9g7yeOjmKXRAMUvFQm8HWeeswzjaLOE7/UJ2J5me4v0dLRRQ
ZzXv3kX+kGI0gp5xvJM7R+omNyv1fkHX7jg/N7veTdaplR1EJ8haGs429pC9
WLT70Mc3K0bNRPeSObo3OtEMn4alp0X6ycOcpe/RfbXVZ6d+9pOj5NJeox/c
TW2YfDJAnmMl1aIt/C2OTOwYJL+sOlWGFrWVfTjO+pks7MxUgl4woF3/2f2Z
fPPyvnvoZKbK5B+uX8jtPC2p6LLzZv6n+b6SE3Ko4tF3JrT4FwO/ki/Xdl1H
e7dxuS4YfyMryhw6j+a685Z6vneYTHMwfh96nf3ZfV/9EXLsRtJO9OjVvP1z
2SNktUkFHfQz1yuZs+6jZIFfzGLorIFTxj6to2SHUQtu9PW9dlMzpDHyRpkw
A9peTV13Zn2MXLrJYfIf4R13xb55Hf1OFr39ZhCtwL/5+nTjd/Kk6fMW9L9/
491T0T/IF25tL0HnvM/ymxQZJ3ef5XJHL6WWy32JGifPif6yQpu4No90rI6T
LekMAD1Fs2xd2TlB1j24zI3WNrDQvRExRdY3/fXsL+GbLMcXA5emyFNpXzPQ
Q/0Xin2dp8nm7jJh6LBzBcK2ejPkRuP3Fui2R3+opWdnyabSOwf/4HiRmZzY
lObIfpxUNWg9qUTdiONz5PmXW7LQMUv3Fy+2z5HZSJQjaPX47hMuRfNkoZDH
veuEg94rmKkeWSRP3lkpXCNc+OS5VFHSIvl+OikY3ZFqRLP9wyI5vbLJBi3p
alvFp7NELk2jp0a/pwlTotryixyfNL9/lTCPwSeuj29+k1svRrUvEwbJk7Om
f3+Ttdk3MtHuLPPN9WrL5Nu9306hq/rprz3LXiaPVW7QoF3OkZYzLq6QSw70
KP4mXPLoxidPpTXy05UF9yXCE1wTUWbOa+RHp23U0NLnzAxlEtfIZ746/lkk
nK3PkjOyukbOlneJRie8izpp/3qdvNc5vGiB8LmR2PldDn/JMefiB+YwXlia
QzmNqeBEcRDfNGFDg0sOwU5UELi579MU4UFveY3Z81Sg6K2RhebruPn9wwPi
76eySaHjU813X+fYBDnn0tQnCYdub2Xf+LQJzAL8bMcJu5Lbb0/504CCuG/P
GGGq3N+Vn27SQFziQC46lVZo8H0+DXzaVu+DfvvupPD9HhoQ7udlQctY/ck9
oUsLsrm7TUdxvT8Ta7Q6SAunAxj50bb8u8Z2eNKCq9ixiRGM96F4afFMWvir
vh6D/ukmXTy0iQ4OL4t+HSYc3Gze0iJAB3epZJ+h+ZT8Z6rU6OCWxmQU2nSx
SiX9BB0U8j3UR9+/bFl+6B3x88UxBd8IG30932MyTAdMnG1X0QNGGcsa63Qw
LznuhGZm/KnDrUgP6w2PBdEeCZdr2uLo4cyN1ayvmB9/5X55dZ8eOtUdQtFp
h95SPaqnh0/vn7qi3wtt2RG9RA/n7HeroV2CtI8HsjFAy5Y4AfTaN8drp6QY
4ItmHzVa/l5h025bBngydqHnC+FGptaf2n4MsLbQX4d28FxkkolkgFxP0xL0
UiufPG8eA+y48jYdHaVqaE5fxQB3zBwj0ZKJx7x+dTGA4yTTRXTV7+sxo9MM
MOfb7oG2sit51EnPCDuHnzmgp152ttWLMEKyfvU+dJjw6vwTbUagnP6xAy10
VXhLzgFGCPPR1kGXjexQj/NghAMcpcpocxN366BQRuCRs5dGjxbGnPO+wwhx
4Sqi6ECWshTHckaIHdUWQHN7978wb2WE5uWzW9EP2/716/1ghIduE5zooaTd
QgL8THC0OZQdzX440WnFjAliTvJzoO9WVwT9OMYETXNvudCGol+yewKZYKOj
hgfdE0Jb/zqJCbY7/xVEe4/JjpSVMIHDcLg4+qtTP2PdOybwZOSVRx/su67U
MsoEn6hIGug3B7St+jeYwDFoANDazT8ujAkww4jkFgt00c6UrHkNZrANGvp/
/IRrTF7/3c8Mx5jIXug4rd8TTJ7MICanFYSmeVLAwRPBDJPq7xLQ5+SsNcVz
mYHHffke+mcerYNSNTOUzzfUoA9vK7uq28cMDmMqvejW5GP3TBaZ4YcxzKOB
Y0uLJTsLkKmWWDF+Sm/ULzjJssC2qb1y6NRAMcPzR1hAxnzdHc38u+1Y6EUW
+E1jGYW+7BN8IzaJBUTOWD/+Pz5dvnTda2aBu5xuf9Fdn2LWSr+zQGvbBSmM
/13WhqK1m1gh4pTBAbSCacapPi1WSDw8VITOrDOPH7VkherI6k9oTr0/z+a8
WOGDqSUbrr/fioepmfJZoVcs6yy6bgv/bR0ONtDp77TH9a0e/bbGWJ4NNsq9
UtF36QNGD5iwQTFbbS86arVH2SOQDfa2Rx/GfGHzJfFN2k82eH/39fn/843t
zqm7NOwgRifUgNbrWOQsFWaH2GRpju+437+2dGy2YgfZZvtH6IkHHEvrteyg
KL6F+ieuL8lafsZBdjA7/cse/THDh8y9zA6Lu0LL0WVxrZEKipthpTzNB/Nh
0LkoMcfbm4EUEro8geMrFib9RZsDTnQYWM3g9ejHK18x5gAx6u2v0OG2mVrb
LDngZZuT/Czmj7gXuw6f4oDp0FcMmL/X/k259mZwQGHU2Md5wpOD1oUfqTmB
YZw+/RfhD6nSsrUfOCGiu5sa99/IMnXVI/2c4CLkG482baPo/BvjhNGfw6JY
HzQyOOzW3+CEfl4RMawHq87Fub9Q5YLeo8K7NhF+aLV6/3EyF7z4Y5tHQziG
o1ku5+gWEKsvus5IuEJrW7mF9xbYdKdlCD3q5EP+c2kL6HJs0mAirPdwi9Wh
lC3QQRv1Df1zt8NlttYt8P7yS10WwjtCpz9e0OMGapfKcTbC3g/I9tK7ueH7
x0VDdsJp7fGjXTbcIHJx9RZ6TkRzVdmfG67lHDLYTDiz6or490JuIn98i+Ig
vPJr81lLnq2wOVJbcAthiW0uGxsSW6Hal/8U2mJn2Y2HqlvhhcOVSnRBgm0m
496twKtcf4ibsKVyTlNN6FYwCii9uRXv340kID+/FeS7DnTzEu6LDcvv+7cV
FltsBfkI0z7vUQpn5QHrmDtH0fZ0l3Z8k+YBF553P9GMuQ2eKU480OtoOMtP
2OWT1SuaDzzwW2q2TZAwc/o3L79+HnhZ+ZpBiPBTe2+hL995wHJ/tgGaZiDi
QuUmXrjUbnkXnd9XqeanxQtJu0xPbSNsnrpreGgnL1i09N9GLx3qijO35AX2
L5ZNaOPe6WlpL14QF5sRFib8vVu0cCiXF9pqPWvRMUkPbcwf84IjzdAYWtNa
l66ymhfkB4WYRQhHdB10SerjhcdyyxZolcSvHDTfeWFPUZQPuu+g1yvfRV44
2DcSg5bpDBcyZ+eDnq7md+i2hC3NFYJ8kM91aAwdYJl9QVqWD8b7UzfQolyK
MkmafHA8JIZPlPC79ooe6p18oO6noYL2jze55nuAD2j5b5qgBQ50qg058YHW
WtRhtEfbVFzFBT7Y/PjmVTRX3AWydAQfPGkOTUBX7qOfSUzkA/ZHwrlol823
7lDn8kGTmP1jNMtHkT2+j/jAYE2tGl0WU7z6uYoPqrY9eIt2sNAp3POeD+4G
V3agadnf2FT08kGi1LFP6OIWSzrpMT4IF88dRltFfylNXOADhpSzP9F/zD1d
qKn4Yd+zT1PofNZVDl82fjhd3zGL3vvh2qvPAvxwhc1uHv37Jpf3Hhl+yFr1
/N+Ze7KEKjT4wXSVdQ5twqLQLLWDHyxjtabRM+9fXEjczw/C+yb//33JkcYy
1E788HJQagRtaNbR43OKHzamfv5/vd+Zjlz7HMAPj41VOtGx7ybV9oTzQ1r1
+v/3q30jYPjFLX54rm/2/3h8NaWLl8rhB+Mqgf/H6zpjAjmxhB9+mHjmoFXe
Cs9squKHVysG8ei+iKI7Pu/44eZGTBA6eJf2ns89xJ+nOXmiZRher5qNEvcn
WHwI3fbmQOGLeX6wGTtHQQeED9lIbfADl1eNLFrU5BRdIqsA8OmGcKD9Xoe5
+EgLAKvQ5X6MH+FRE/rfagKgsKe2Gt1MzfQgEARAUuBJNno7RM/fsBOAo5R0
F3SH074kjpMCUBqfSEEHXebUSfEXgC3+eiLo/sqk4PybAtDlndCD6yG8/5Ck
fKoA1C4ZPUarrfC/fZIvAF8+51xHR2tkbn5VLQBg5qmBpjy+m9k/KwDXX0MQ
rr+ZVjejo38E4J2unwU6fVru+3dGQThyykoI/UvukeKSmCC8NtAsw/V9v+B5
FbuVINyLu9qF+cGm8cLRpKOCwHTc+TaaZkSPVshLECIn1x3QjqK1e2TDBeGb
9MmvAoQ5098O7HghCNFrGn2Yb2oqIq+8bxSE+Iect9Cn+szFD7QLgsDjUnP0
663t7k4TgnA47EAV5qsLcf0rAUJCEP5UOhrz3bdrEzwlwUIgqMSwjPkxJr+4
Uj1aCMIq1LLQeg3eTi9vC0FVhKkJOolqseDtUyEYPKARj/l196V19ZFRIXCx
dRXgIvzEl/Ug3+5tYFny7A/m8w9pWy48tNkGTnkTN9HfGwWyjI5vg85FNgG0
AL/spGfQNnjNra6G+0NYnXFoXfk2OPj3kh3uHzZcQaUe4sJgHCZ0kYHwWun8
lup1YThbePUI7nfcQys6lkwi0Hxy0hz7SSVGqqM/eEQgLSFUB/vDYw7sxZwk
EThT68OB/d0HWvmdJ91EYPuN2Ge4n2ZaHz+zuVsEbO5+n8H+J+fSqQmVQ6JA
53rb4xNhlVqmlQhHUbj7oMVtAPsV2kK6L8dEgUGuzLUf68foUdFoX1F4d7fB
tRfrv2zHQ+M3RMFDWMS/E/uBxn2NOVWiMPzPpqKZsBzTTPtKvSh0qrU2vSdc
sTfqy753opC+VND7jnBfz9u1v92iELUld70J+89xiqr9rCg8nVu2bsT+j009
k0tcDB76WjtWExa37ChylxED2UsfwqsIP0n2rahVEoO4J3ueviTcJvKwy1tP
DIJ/RG6uxPqZJMXSbCUG/mwSo8/w/s818okfFgNerwVhtOJLF6kLzmLQNMnn
UI71/M4sirS3GMRcif9civWGDV9AaIQY8Ltq/3tMWCD92bWBaDEoufvWHH3/
i9Ut1UQx6A5ay3iE9Y9bfMmXbDEofnbStIQw/SXmMb1KMWB1sKkpIpz8qnAh
oVYMZkTHxdHbaXdRTbwRA6NMl8gHhHdGhwqmdorB30g5l/uEQ7L+HFiaEoOj
bDMa9wjvV3nhJ78oBlxdkuV3cfzrTse7rIoB83NnLXTl8ERbG504GCUwGRdg
P3n67hwDqzj0yIS05WP9SOvCQeYSh2JeoSPohe39+x4Ki8MlztZref/3p4k+
o5LiMPJ1YRs6Ztf+WEF5caiNs6zIxfl0b2q9oSUOC8MDqzlYPxeX7z25Xxx+
SJXmZmP8GPh5ZdiIw7mkg9bofy0K0V0O4jAY7sCCTpvN+2DkLg5LIVVXswi7
BR+ZuuAjDskR24zQmpyCrE/OisNJ6nU6dAcpYY9IiDjYzhqkZhLObth7yua6
OFTZF59Ee1sx3YyOEYedSve10fpjjQ8aE8WBkqjNjmY+F/x+PU0c7iQ5/cjA
eKPXnyDliEMev0gj+m7KMpPHPXF4PXY5H31GplQ256E42GRcuY6mVHjv7isV
h8N1kr5odjM5982V4mD8+PRh9ODA2HWTWnF4U+Bthn5wKqfw8htxiKvkM0AH
/HF4W/ZBHMRGz6ihTaL5fk52iEPS0jVFNLdwF4NEvzh4plnIo4dLYqXtv4iD
49F2BfRj8p5d8WPEzz/kIKGvtNG7vp0UB9MGdj20uXN9+Ma8OLDVtexCCyxc
vqu5Ig7i2fts0T9DdN54/ROHWI1kT/SzLb/G8mklIFg1Lwwdlv+YbpBZAiRF
ArLRlhqe27dwSkDIcZ5atOgbaWMzXgmwMgoaQc/YjBy/uk0CfnaWMuP4Vv3I
DHshIQG/2cs10JEB9vmzshIQ3hB6HG3LxNMopSIBremiKWiptPYRR00J2CIU
1YJekoumSdKXgOjcNww433HmtDtodkuAQuD9CLTT51cuuvskIP3DgRa0gvel
ED9rCbi77R0PxtPb2IW6L84SwL5VohydLFryjcdNArLDaJkxPo8/cd9k4U38
voinLmiqzq9QdVECOhV8RTCew8Zrci5elYC9e+Wj0ExUGdQ61yVgOcTuL5pL
0a6xPEkC6ivpp3E9pOzQ2n7mjgTo/gk+hetHyH5rOClPAiLaj8+gt0e073r0
WALcjjluwvX4IONRoddzCXhYcioerVQWzaRQQ9xfUc92XM/a33Y3FzZLQFlI
6eFCwmZ69Ra53yUg5xTXOuaD1gPZj45OS4DNpfiHmC8Oul3hEFmSgGa73ceL
sX9L0u1I3yQJb5L3Dj3E9TD71DpJSBKurFHTPiF8Ky/P4bqlJETN7uF4QZiv
8mq1iZ0k/KGyo6kgfKftiDDdUUmgOqm8hr77V/DrVS9J6N25dRHz6YtDiccu
XZeEVKU3HLUY7yzXPLxrJOFbv8TiW5zPMycDrOS2w8/n4XSfMZ/qfjmYpbId
7svuMBkirE5lqzyhuR0Mg1lvYP9uFLX7e9CO7VBYn8KN/bBTvoJVkcN2uMdi
avQD569rQZk6djuQAs9PYz9IpxH049HidggmdXHTEvsh6/py/drqdqDrW3yH
5qrzzTSmkgK9r3uC6LC+2uti/YlVCkqYbkzQE9Y/YdxALyUFGwL+9divnUli
yXK0lYL9rvV+2G+N/kqxYamWAvFfPelYb+RS1E5/bpCC1IpqW6xHjkS3xj56
LwVvPHu5sZ4ZkKR7d7BPCr6uXInEeqf9oL/enUUp0NLK8sB6ruaJuaiinDRc
5jH8vZ1w4N8f+hsq0sBIuzVXirDO7lC7di1p2G0bay6N9fnXioSzxtLwLGFP
hgzhB5ul6WqOSoNYxIKCPOEUr00TFinSQBtS+FcZ6/GKO/RimdKwJFofq4L3
T6ctsZgvDaaf1kRUsZ654+2Q8lQa9tQ+0CVhfdH8qfVLizQYGKrYqhM24j0/
+aRLGnYpew+gN1y4GMM+ScOMV6y9BuGLa6YUmXFpYPE9YqVJ2Ff2WakvrQzI
3T6tqE1Y6eyBNiMWGfhxjikTPVk7NcXNJQMnRM1ZdQiftJWQqhCRgZUDNd/Q
jhFxqZv0ZOD0RqGPHtY/nfLlnRQZsD6+/AHdJ9zUXmAqAyFC9dL6eH/P/jKb
2chAg96zbrTZmMflBD8Z8FEK5TLEfuGyRPHOABm4/uSjHdpo6+DA7yvE9TyN
yETrGu/VPhwlA+s+MqJk7P8+07my3ZKBgDhGRzTpbE3Sq9syYLJqlIKWK1Be
lLgnAx65z2iAsJTBT7GehzIQJPtTAy3enb3/epkMDIUfP4EW9rIL0n0pA25S
MgloATqukqk6GXCPV65C82S8H8x8KwMt3udH0FwaoSwHPsrAodA/DBTC7C16
ujQ9MtD95KUsmuXEklv5IDEe609M0Yx/i1NcR2TAPmjwOJo26cQb/gkZYAzU
voKmUhT+1TxHfJ5FQyL6T2OPxJVlGdjhf7EQveIQa6nyT4bIX4cr0EtLu64O
08rCmu7xJvRcFNXjRBZZsD2T0IGekqwYMuGShY8yowPon1V+bKt8srDkd+gr
etRKTr9IRBYO3ZgYRn+dGvZwlJKFJ2/T//dgWPrtzYqy8Oe++xd0n5DV2zo1
WchqsuxHd5WxLp/WlYUbg9Zt6Dbz19ulKLJg3ejXiP4wetmqb5csuFwqKEe/
DdQMjbSQhRXhuTx0I/fsE31r4nqn98eia4vvfZ05LAvfjJvOo6t2Ht2c4yIL
4vctHdEvBvkMD7rLwtyLBTK67Ey7J52vLARp3xNBF+cbvXe/TPy57t4enJ9C
/fUVwTBZKJs0fIjO7yqVbo2UBSE346voO7Tbr5FSZaE5PkEUnXrnc+lopiz4
XhyYxPhJVE8eTi4g7q9ApwwdfZwB1p/KwteHFH105J9X3g8rZEGre2od4zM8
MSDjSC3hztIX6CuN42sNLbJg7JAui77okCt7rksWMuDVZwPC55bsbWU+yYJi
CV0s2lvyQ3nUT1mQN6cex/XhURU2ajgrC29Hq+LRJ60Mtsz/koWfPblaaKew
El9rGjk4yrJ+EdebxWicvLCwHHwel/+K6/OD/GiXg6Qc5BUxXkTvOa11JV1O
DmIaQznRptRDbXxacqB196gOrncjUflzW/bLAfMuVi/MD7WuV0QsbeSgWZm0
hPmD/Kj9bZyDHPSZcVxA6xsGCLK7y4F9P00g5hsNh9e1jCFycGhW3RXzU1ke
n8eu63IwYn19EPMXafLUlvAYOTAfLd2HVrrIdZImXQ7stAqUMd/JpB5h+Vcq
B++o/XsUCQt1rVovjsmBwUGmRsyfaYJ7N1Sn5ODPvDg/mv9YdqHvghxwrp7w
xHzLs2CyPv1PDmxuBrFhPubgSMz+ySsP3/YW6kpgP2quNPl5tzyIsFuYYH6f
aHAJfvtQHrQfFljieZxIfJ9HTJk87GvXdMX9w8rJwtrqpTyUzORdxP6uZkVH
7utbeXjxXjeTlXCCImfX8og8bGm+1I/niXopr6SlBRSA0+KaLJ5HRnkIfbwW
rgBDvzxW/j8f1kqo2BOtAPcpgtR4nvybljGfM1EB/KqBFffPo1mLARk5CvCb
eZc49mvqXe/Fy6sUYFas8RD2X58NLpwbXVAAA6Xbfxqw3uDs2bbjiCIc+8XX
gvXH9+jvIUknFOFTG5cy9gcZzMs/fpxShLEr329hfcNKy/c0KkARzq0ePYn1
1MRvO5OeeEUYmQlTSSNcMPjZ271REdy/73aLwfrDbqbz5XtF6JTu3YjCerbn
nzZ7uyJQZHan38T+5aMITelnRZjbKjB0Ha+/3jnlz29F0JoXTgrF+qlw7FWs
rBJs+D7vvkC4S/K35LCyEgT1ZD4NIHwzhz5SXVMJGBmtE88TXkuTtuo3UgK/
NpeTZ7Gej3b/Ke6gBLQ7vEz8sH5kvrj3rIsSHAnW2ONLeFdE5NMmNyWI/6Vq
7YP1b3BRoOdZJYh7/TvAC+uj09Mcz2KUQGJplsoD66+5v2cZk5Tggnq6ijth
ai/2T/bpStCwreuEG2Hfk8Sw3VOCx/28304SlhkhM1uWKIFnlqY0+suR/T75
ZUrgtMh8+gRhCzs/nd11SuA4uCp4HPvBnquZ6U1K0FUqdeEY4WrLBJqZFiVw
y1AcdMH61ry0JWFACWaaJkudCY++bSCNfVWC7VGlMuh0464UrR9KIO92Lu8o
9jfkX86Di0pQtcxSdAT7DYoM47M1JSj6l6iE/r7jcEnsJmUQXjCpcCJsZRJj
5c6oDPfd5fag603r1ow2K8PHB7tGHbF/27OULcSjDBcK74ahM/dK7/otpAw+
1PsU0Kz77ac/SijDV1rTTw6EL1pG37ovR/heajz6p1WtTqiqMizE7NqHtjm0
+MVBWxlSGA9zoxvtpMI1ycrQy9b/9TBhkoOdAoeJMgxSmsrQ2U5RHePmyhAy
LxeHZnd+FdBwUBnWuJhOowOPLQhn2CvDMeOTjujJE9tfn3NWBv82k31oezfb
U/vdlIE7v8QU/dbjJqecD3H/tjm70ZpeNc9pzhGfJy9uic73mXf8HKgMh+nV
XdBc/pK0z0OVYelM/wV08JlDD+IilYFUzH0bPXMucr9HvDJshP94hXa4UP17
R6oyhIUfnEG/vzR3Z1uWMsy220ni/WpfkdixXKAMRprrzui7wTbjbcXKICql
fQ/NHXoj9kGpMhRUcCyhQ65VaYRVKoNBSZgpjvdcxOwnxzplCDp5Kx/9Icpa
hvOjMlwfCzyN86cbe711olsZHB9YfUcXxr880zioDB+U6o7i/Icli9Wdn1AG
vggLT4yXhVQr1wPzxPVfcf+LPpoewSa/ogw3r7AlY3wJt/1WmKVWAdm5r58x
Hq0PcFA50KtAfxFDNMZrVIds51smFYiivrsD43mty+FCLocKPJBVb8J47+mv
f20trALtAtNSuH7YDg+m1oupQPa4LCeur52Dv04pb1eBG94PqE8Rfjokw8Wk
oAKXflmvexKOGYlxqtJRgT8/nIxwPb8+Xqgqa6ACK60NJ/wJ/xmro00GFWDl
FY87Tdjj59IDn10qIMSdtYr5YNe0/bK4tQoIN1sLX8L45Q7tDLJVAbP8H36B
2G/qFT0aPKwCgcvdzZcx3iLXXZNdVOBCamJCMN6P9J0+Jl8VWHou6hFOuNjl
c8VcpAqcXi5Vv4X5IJIueW+MCuRnu/1IxP72iaL/g3gVSP92IysZ+xWqK3LH
U1VgzOqDCOZLpwzh9N4CFTC3tHPC/pOj70hgTa0KiB7aqMfzo5MbEbaCjSrQ
Wfm64SnhKqnH6gFNKvBypuFtGWH3s1TTqq0qMG7M9QX7t3quHMeCTypgKZyo
W0f4zN5hw6jfKjDS63m7A/Nh/fFN9gqqUFVHtQ/fx5ijDAhcVlaFU6/JV/H9
Doa6ferZJFWQk40qw/dHNF/pun7XVoUTeevs+Lws8SVHi7+xKnTbfg7E/mpf
WVXqTSdVaEtaPIrnlW8KuFWq41Qh++nuv3g+PCQZufvrLVW4cZCdC/ufX3kb
LjQpqnCMem27GGHJ3Imk3RmqkJApsAf315DM2vXu+6owHWdxA/djwxTPppl6
VeippPuA/U359UYn0V+qEH71zf/1e6FZM1/Eiiokbp/nw/orjbWjY3pdFcI+
3mLHei447ovJS2oS0L7mWDCiwudHa0o2HCSoHElPNcF6xH7TeNUWEjx5oX1p
F9YXQox5ErwkMPCZtTclzJu9lXd+Gwmab17mNCM8fE9l46Y8+qfdXsLd7loV
C0ok0H0gImmB9am84Wk7EgnOzvNPoh8+2vNDSocEYpuVffYTDnh+8mOdCQlO
vmm0OEj41AWvGzJmJNgR9Pcv2knvzI7YvSRQkCu6b0V4x6urzx2sSEC3Br+t
sT9oupO17EyCc9eOHrMlvOlGnp3TCRLMvt/9C71k9mDLazcSCFscC7Uj3N/6
PCLBhwQBFQyJ9ljPxdVQVv1JoO0cynMY6xHL1+tHzpHg0RuOJHR+T4eP4mUS
vJDYGe6A/WVqv2xiMAn8NAZX0JH2X0fWQknwW8fD1ZGwz9D0obeRJLiga6Ht
RNgle4lTOYYE7s9T0tBWLuvNSfHEeMvWrKB1vzPCsVQStE9EFh4hrFi4ee1d
OgliFaTW0KIePGUqWSQgm13fdRT7I4Vt3im5JEhWK45D081IyPwrIIEoY3Q3
euWR3PDx+ySI5JXiccZ6zE/1TnMxCSa/+Vui234ZctwuJcHtdJ4adMNz4/cb
z0iQEHRiGv3sgnnYyUoS2DHa8rlgPOkdNGypJgF98YQhOv2v3YpaHQlyuQSc
0TGvjj5NayTBEZ6RK+jgq66em96S4EODUSr69A5vKbdmErDZaz5En6Q7+7W1
lfCel9VoAZF3vevtJPBx3v4O3aq97aNMNwlyokra0CGWfm+s+0iwqmLdhdb0
fF0d8okEP/p5//fENf7yR0Mk2KL76yM6M8urePAbMT/yU01oy4q6PKYx4voe
rb9E03duTdf8SYz/jHgxunLKPeHYJAmWdZz/v15v+pobcTMkUGF6FowWF+W6
Wj1PAvgjegLdo3MyYGKJuL+BHGN05MFKH94VEtgkaoujDb3YXXeuk8AMxtZw
PBfCXZz8/pGARbjwI7og+5l15iY1+Jt4NRttW8m8t5lWDWLU/b3QrF1OO1cY
1IBcdlETfYaBQc2SXQ3OrPVU4fzKiB2WC+JUg8AVhYvoQd1HYsXcavDQOEsN
vdP7EAe9oBoM/xpKw/hZiShiUBNWA+v2R6bo4pyNf0fE1OD1VN4Cxh93973p
Cmk1kIn+p4se1Vt576WuBiLd9RkY36nW5vVpWmrwZmVeAW3uk13RpKsGEtV2
L3B9lOWaFopR1OB689cGXE9hTLevde9VA3pejRJcf9oS04HUB9TAzShOBD2l
TzmjbKUGVgd3RB/C9eA77nLDXg1UHzY42mD+69UBA1c1+Oz0vBPXf99ctJaH
hxpQNdrLoKOYh5VSvNRgmSrogiWub4PIbfOnieszc+Y8QLgxf2AtP1gN3mlq
82G+OeZ/qZw1TQ0cOzYiMJ9pkobKZTPUIHyLVDHmO+YFeGaSrQb2UnYtxoQf
+9E/D76rBrwctAw7Cf/xjX+x9FQN8np22WI+Tfa593KwWQ1276m9gP3dO8/O
uuK/ahD6+e8y9kd3FDTr31Gpw4G9Ma14nuU7lVr/nUYd9AIO5kliP+Xp1CDK
rA5tbvd2iWN+ODXemMijDqf/3g/E/umP+0ZToLI6cKyt5uDzM2VX+VZzZ3UY
2a5qi8+zhtxFfB4eVwebq0XhuB9FeW7hYHdThyNN7mUrhMf91g989FYH4xQS
O74PmBfY3H0gUB1uegbW4Hkhb8KpzzYp6sBIu1+pnfBGVdHU0RZ18Ljqr4T9
TcmrrOi6NnX4/lIuDM9zHepvKYl3qUOTvcpnPE+uaLrkOzKgDurJObdxvz7d
sWfpxE/iev9dI8cR/vFjct2DRgOSj5HssX5Invhyp5leA5h8tBexX9k53Wmg
wKwBSeX+8dif5Cy8DJrm0ICPRcufsV45/Pcmja+wBuTddq7EeugjlwLLWR0N
8N4/mWpL2NDLazxdXwPkXlWX2eD1NpU01ZM1YN9sQo8V1kOBqmEcJhqwsjVF
4QBh8++af4ssNUCkQ13SDOsFCPjUYa0Bv3n2+pti/5BeUbFqqwHqh+maTAiz
7Nc/t+uIBggKZ4ftwPq0gjI7fEoDnG4EWBpg/cgd2sLkowEsHlG9eoQfeDcW
qfhrwMGDrcd0Cd+Q2OV2JUADotyFE7QIm0abf+O/pgFtrY92kQi/+BH9Cq5r
AOvsLwZVwtJGHzNcb2qAjMuPj8rY7ywfsC+P14D4TLrziljPHT3UuT9TAx70
PJaQJaz+MvXJ+RwNsJrqEpfBenzrQGxmvgZ8D9wsJ43163sH86kHGkT2Wd6/
Hes3yUy5LSUaUCtQ7StJ+FjQF0bdJxpgzN+UKkHYSN3ldcRzDXhW0rVJHOvL
mLy8kkoNmFibMhIjLD4+erW7WgNsYk9HiRLelOlqKNGoAY2B89oi2N+tFAqZ
NWnA379r6cKEv1pOrPm+14B/PCkM6FoGr+c1bRpA03pvRQj7JZeSpLFODehe
kb+Czq6aPc3aqwGGXc6saA5eVUu1AQ3osNyfJ0g4yM9fxf6zBtRx/jNCzzSX
sl/9qgHnbf0mBbBelPo1dW9EA3bzPb6Dbg3WbG79rgHCU69s0Iafzt//Na4B
Anx3+dElGhURQtMa4HDDdYyf8La4tRM75jTgbjdjJTpqQm+nx6IGiOnFpKD/
7LwsHv9bAzZnr19Ge2bVUL1Y1YDbCVZe6MHVjaGhPxpw1fTOCbS5FaWajkoT
VjK7T6JfloSkK9BowlEBGj80vbm1QAq9Joz1yIajD4xL397ErAmfR/sL0HfC
13g92TTh+datbegfEi3JPRya4PBqkBavn1SXtZXCrQmLL1V3oi87+ScW8WrC
E3fuGPTb9Z1beAQ1ofRB2DB6y23ehGBhTegdvUrB8XPSnOCYFNOEzE0sRej7
nVWx1ts1gctbWATHf8k3lr1Whvg8gcoMNJndJVpOQRNcLn2S2kY4skidNUlZ
E/wigirR3aYMNzdImnClItcW5/tUaPH1Lh1NkGaxKcP4eCYaxEA20ASJJ4N+
/8dPzYHw+6AJdJEfdTC+UlZ+h17ZpQmj17/9xPgbTnpHPW6mCRWWix8xPhXV
7lw9aKEJPik2dRi/DV6UIBlrTdgfMV8vRZidhftfgq0mTK3wdmL82xV+D/x7
WBM6/L2mcX3MDt+82OGiCbONl0GesKBtz9lAX01I5aE5ooL9xK/Cpe+nCTuc
eYXr8UnCpdMHzmsC9+ALWTXsj1pE/aSuaIJmSZigJuY7o1OebTc1wbM62l+f
cM0Xg0ndWE2g16IWNSTMdJnDoyBBE/r123rIhLOel7tevK0JIqfVjmI+aVag
OiZ5TxPYD/J+xXzE877jW8wDTTgr7tBjTtjZteDo6kNNeM11vNuC8HKOmVNr
mSZMjLlPWxKW4E2yC6jXhNDa6RDsny9tktv/4bMmXLYLUfYm/H0nS5/UN00I
O1+Tjuc5+69PHbk6SozPr7/s2P9Jbn7kozmpCUM7RZnxvOiDkHps9oomvPi1
eX8IYWFtw9YzW7RAbkcQdSr2T96W5tt2a0F8fowqvm/APHjR1LtMC9R32Vfz
4H56/j5b7HMtEJVcMMD3R5y5+joeVWpBuSZ1Db5f8sJUw3G+VgsSAvdV4fOg
k+WzfmdatMD11r9HuP/VxRxPv/hdCwQOVZ9UwvpA9tbR9HEt0I780Yv9Dd/r
uu1VU8Tnc2TuwvNN73Xhx38XtKBD7pw4no8KufU3Bm8Qf/8NuRHPXwMoFjPh
fNpwRrC1CPfv/MHA0nuC2vBcYPMG7u8fzxcFvBXWhhim9X1YD0iVMNIwb9cG
ufsZE7sJdwo08EarakMzd+qmfYSVlrQot8y0Yb5x/QHWL/axJ+nL9mpDsX9D
B/YT1+SSmrv2a8N9HrdlrH8Gjy5Y8xzSBmpdPi3sByJbij1uH9OGPLr3MVjP
jd0VS8wK1IbDnyKS3PF+w76t0gRrQ4V7320PrBddco64hWoD33TB7VOEqUTE
5FUjtWH3QNhNL6yXU0Tr61O04aHPiqYfYbGzX6Wl07Xh1rnurf5YHx7Mjr6Z
qQ1Od1tn0RqbRe2sCrTh9vrPxDOE90eIzI091YazLfG55wkfOvHF2uyZNuiv
itsFYL+1I+tlSYU2NH0NZL6A/diGcMT5Wm0Idj7heJGw/+ehqU8N2rD5w7d/
6ICXmZbQpA3sydTplwiHnxcWZmrVhosBmxsCCUdbD4V6tRP3R560uEw4US1z
vL1LGxYbzbrRObPbytM+aUM1w/n2K9hvtHwW2BjShitHNHYFES4pygg+NqwN
Lg/sn6OrXLeZK4wT40FVGx6M/Yvx5ydxU9pwImNxDP1eIoP316w2RFueJV/F
fmeT42W7RW0QvkG+he79IjRS/VsblCbNv6GHqgdNxde0oedYqmwI1r/pd0rC
/2rDNZFtnujJCw7ck1Q6sCuqpxC9cEjo4j5aHWC0r/2CXtUY/FLKoAPfLvZw
hOJ8cd8x5mPRgb0SW/XR9AuHiwLZdcD/fYAzmq1NkPMbpw5Yy/0LRnOXfDpn
vFUHeCA3DS0QlT54n08HxMxdStBiHoeN2IV04FiHXhVaxlSw0F9EBwLSFBrR
ylKf2HrFdaDvEekNWpM2/bSelA5sOJvXo/WH7fuzZHUgYWfAC/SOWgEyraIO
BCuXF6LNMgfy3VR0QI5MfQu9PzCNuUVNB852OZ1HH7K391XV0oHJxPfWaCdt
gZ4kXR1o8TBWQp/gGdBbMyB+/tpHKrTn0u0cJ4oOTB1yb8Hx8e+wY2jYqQPf
07ckoi885veSNiXGy+KjFTo4pr/j5h4dyCjN2IwO97ytPWdB3M+B4Eacn0QZ
ftoKax14/fSGENrBSereiK0OXD7C8QbnWzJRzYzdQQd2VJ71QJdt7I075qID
RktjeRgvgRqH1WJO6IDelt/a6J2n3HpeuOnA/SOzbzHeunpChNh9dKDX4EE/
xuMd1rhX2v46wPTY3x593CjD5dhZHTjJQerBeF56+LzwxSUd8E4uqMF433Jt
Sv3YdeLz+gYO4noZqFztjb6pAz1+XcW4nnLn6C+9iNGBcKkJKjTJQayOLUkH
eI2C084RtlSz2fsiRwcOf/t36zTOv/uxueF8HeiKD3qD63c40/cWW6EOZKlZ
LOF692e+2e9SogNBI/MUX8IJ316dYHupAy9qt9/1xPzE28KoXaMDId4/SjF/
iO8dKHKp0wEXKY1qzC9PXyzNP2/SAYHdKfVuhDtiZa+4dBHjH+9/+zhhTsNb
yc+nift/vR6E/V3f6Wyd4Tli/CfHzTC/Zd9/OMi6pAM7h6m5MP+pbH0r7rKm
Ayt9w4nYv+2f+lPCyqALv+nyvLEfi0s72eQsqguBZWOB2G+dPxdyOlBCF/Kk
nHkxHztZZoqkSOlCVf50yQ7CCsw95z8o6MJUlFc39lvvLhjLaOnoQqH6xU34
PI7aTvIGq6Uu+Jg9+ob7xVneYbPnobpw5qGANL6v7bD493d7uC6IyrVfwf5p
50f+vKkburDi7NbNSZgr4sC6WJwuHDUOCMLnTyW/a4ui7ujCyZRPb/H9wZ/d
Wawu5boQOxhxGb9vZZ/o2Mr6QxdC3qVa1hAWKmUWPDWhCxFla4/wfbkv7c9d
303rArVZ+ObnG/j9Q65N4Uu6IF1U143vt3lHvlHb2KQHZj2HQvE8MyRY+fa8
kB6x/0lHXMN+KGtwbJ+oHmz7Ei2A+y9DzQ1SiYQeNOx+9PQK1qPrI80ecnow
x9Iwj/1S8rnUfyNaeuD9OvgRng/f99x0vMdSD/Y80tmD/Y7nzZLH6jZ6MPYv
VR/rB6UHh/8m2OlBzS8+jT1Y3/8oT953VA94Aln0jbEfcvF499ZLD3o/Zhbo
EL5ylZdH2k8PuBTHO7HeoWQ3ulw7owdGSV7M6oTffBb+Q7mkBwtiRXFKhNts
O5VeXteDNvpEOqzPEs4HX+KP0oONb3suYH1nnaz49nysHvxqpfzG+nCgM8JZ
PVkPagddWLE+HbXQT3yYR4xHaW0xB+GVnQWrWTV6ILHzXc/Gv1ly4Mus0MY6
PcjMv8z6jzAVKY1tvFEPHOtq9vwhzCASK0ZqJq5/Vv3HCmGe1YDdjb16kE/5
e2uBcJrP6c6fA3pgwSfFN09423cvR7YhPfB96XV3lrBkp4ufzage5Dqnf5si
rPbQ/PbPOT0ojJPp+kH4mcQuCbYl4v5bqYu+E9ZNozxUXdaDtLqzUWOEjSI0
6y7+1YOcnYd9Rgi/+auyJ4tKH87F/fAdJrz7jHx3A40+iDPB5W+E9zuLjrMy
68OW4LBnXwh39QqcVmXTh9e/w0eGCNtabP1rzaEPApEhgujBxs0RF7foQ4fn
VafPhI/oMXNm8ehD+sno4kHCw09o0xv49SGp8xEd+qTMhuRPIX0YzJt3/0TY
e+uStqqEPvBz/Do4QHjh5ky9tZQ+2Hq+6e8nfJZ63PyirD48KOrxQK8EjPRk
KuhDb7oCAzpw9vPRBmV90LzTWtKH43+yb+IHSR+cM+qd0WGDHWdYNYnfJ8ou
imY82PJPRUcf3mg/G+8lfPNd03VrfX2IiXhVg2aHeq6LZH0oIitloROeVd3J
NNIHRwn6m2gexedSDcb64B5mFoJOy3vy+IepPvzY8S8MLSxQrMtqrg80HRK3
0DlxdxtV9ulDp2J1MVqSIcfC2lIfZMea29GFl9P7LlgTn8d9gBqvT2EpySXT
Vh9OnNxriH7sETdVf1gfDLnrrqHVv0We++GkD7vGivrQzw9do2J10YdFJTYt
HA/d1qBIlRP68KprJBtds/Mit7WbPgibKvHg+Bq9PJN54ZQ+BF6fSEa/UfWR
yfTWBzUJHgmcD7NC96f1fvpwTa2kEt0ifFz/xxl9uO/yyBHnr4vFbr/KJX2Q
vP75Nc63bcjBAasr+rCavOnm//Gwsvf4hav6UP8r8DDGz8iYUUB9hD6EzrkI
Y3wZZbXmyt3Uh9HavO0Yf9m29i0JMfoQcFlAF+PTqdlP/FiSPpScDY3E+K0O
+2venErcH6PzG4xvIcMb59Xu6IOT9p7NPwkPPM7+QJOnDxTfrW8nCOt4KCyf
uqsP21Y/aeF6SZV4IdZ1Xx8+iASWTRO2Sf54Lv+xPpg+2tw1R7jj0j9R4xp9
8PD6+GCZsKpG5J6Hdfpw8vHToFXCcTNbz219rQ/+m6aPrhO2cFZsHmsm1oOb
gCmu//cmDmfD+/Vh5pTYPQbsRzgr3zUt6UOY2v5EzB9izcZLyiv6sLs5TBL7
0eCwduHUdX2w6854hf2n4fLP027UBvCsiI0Hz0MqB3mFmTgM4Ft2JWD/9/Te
WX8zeQNYsrH//zyI03lTxlMlA5jwq8jFfOkrEN0kQDKAd/50g//n0+h8oUlt
A5Bb63azxvMf/843N00MQJ/B6Qc+/8s1UBVscTYAncpPNkF4vRbMoevHDaB8
aek15vfhIyMTsm4GAOa1uvi8TCIkqTLc2wAEK8bUo/E8582qHVwygLx7ha7p
hAv21aeWJhpAgZt2IT7PKnQ+yJPWZADnnVIT8f30t/4KV96+N4CNKYsz+Lzq
Zyjd998tBpCYI2iN77vL3H1efrDLAKouPIyiJva3+xOC1mzfiN+3xGXFTPjB
6dFbwWsGYFuuOYT92sNrZzldFQ2BaeKFNZ5vTuk7hlxTMQSa8XBpXdyfl3Yu
5qkZwl3LoGXcjx+4cHd/1TGEQMN78f8/fyKXptqbGEJqy+f/z1fzV+dELI4Y
gvqEvw8+vxl93Bfn6UL8fFWyINYLEm61m26eMATd7A+NeB6c2xM70nTKEBZC
5Nmx/sgqVbpHCTCE9wNjF7F/SvPyVNKIN4TER/Il2A8NSFplHUw0hAPfWiR8
CPMP6nH4pxiC2UhIEtZHqWYsCyUZhqC8OO6J9VWS9INymQeGYHCZewLrsa6h
eKldDw1BLqDMEPsZ7uQLKSceG4ImLMVgfZdAu/tC7jNDqE0SEsd6Me7bD32h
BkP4PpLGifVuW+rHh7pvDEGwrp4SRnjz/ufCdu8MgeGYmNc1wjE14VTJHw2h
MO9AeQThqPTtjZsHDaGiQYk5ivAHSzYNpS+G8JdcxRVNmIX5V4H5sCGwXBPn
icH+MaAx4sZPQ9g1sZctjnCE9bE9NL8M4eCRtZe3cLz2DTqcWDGEJoMXxYnY
H+229m5aJ8YvkTYlCfsVg13xN6nJcO0gv20KYVbt2txpOjKk179XSiUsTdIp
28dEhonKwX9oByn53i0cZMi5vByZhvWaaP7Ps1vIcDlj0iQdx0Ng21ovDxnC
F3j+oJvYN2+7s40MT7ZPH8jAepXxutI/UTLMP7+2gP5DvQmOSpIh5qdKVCbW
v8sLLpLyZOD7lvEgi/De+VNnwpXIwNK8TzmbsNvk6LWfqmSA1KVidMiYY4qZ
BhlCRK5J5BDO+NJTWKxNhjMRawnoF/37Ktn1yTBpYrGO7uh82+xLJsO+7Rcd
cglPt1A+dxiRYU434Bma8W3ljLoJGY7OGzHlYfzVq1Gl7CbDK5puK7RhVTHn
qjkZOINkb6Ntn22XOLyfDMH1ej3o048z1asPkuFBEANrPs7vA14TkUNk+FZ5
XRddmB936Ko9GTyaXzqjGzKZ3EccyVB1OOMqeig15KKxMxnK3eXS0KsJ6zfv
HSdDu8nRIjR39JkMJjcyHErVL0crRUyXnDpFjN+h6ufo3VdP1rZ4k+Fz+9en
6OOXvrQr+5Phd2HBXfSVs7Yj8WcJdzDfQt/2aV9aDCDmP21zALrM3YzeJpAM
05ml1uiPxxp4XwSRQaPrtzx6wlFfViCUDIqh/Wt4v7S25bqB4cTP73aoR4tY
KpkP3SBDG39wCFrX/J4jRJMhQc9ED21lIuqTG0cG8p7HUzjePnA7mDaRDPq6
tcnoSF2uhJMpZPhkEaCDLlC/mfc2jQyWkp+6cP5qlWjL5TLJ8PjBpBv6l/jv
3pl8MuiSJC5hPHBs8xnfX0iGbS8PrGL8yPH+XHtaRAYpWgNf9FGWgW3nn5JB
JcLBFOPtIt1B5f5yMsxOpt3HeEzaaAa9CjL8OfGABv1+sfrYxisy0EZa5WI8
awzm3I9oIcN9h9hIXA8cSm4rj9rI8GI0vw7Xz1SQ0q6+TjKkKN5fSMb8JvFy
VGaAmL+a20a43rhPdYm8/04Gk7CJtHjCc1Vp3gvjRPzQ7MzF9fuB3blaYJoM
zcvv8mIJhz2dtj+1SIzX7StJuP7XAmn20FMBqJJi1W9gP1Jw0j9tE8D37fvY
rxPuaX13W4kG4CtcHw7Hfk407qcNPYBYctxFzD8ejULh91gBPtereGC/28+i
WWfKDxDRJWSJ5z9v1G//HBTAnx/uw/6yzPHPZj8hAG/3UXvsL+Me1TvdFgHQ
YOjd703Y9OC+P+PbAeTHGemxX3yR5qZ1kwRwTro3F/vBVNn0hy17AIQKRvnw
fculRZOC0L0A3EGT67hf7KtZuKOzD6CdqvUT7if0B82iCiwBzlMiEvD87mzg
qsdlO4Ay68AhfH/b8uMhGUVX4nofn6HH98tZz3LnRYUASA173cbvT7uRa9OM
wgA+DHuu4ve3G5g8E1auAQyZ3bPD9/8uZjZcPX4DQDrynmAf4fEm/6P6cQDq
fE1Fr7F/EWjfNpUBIHPwnzz2Y0G10al7KgC6srZI4nnqxOfaxNVKgPoDxgyH
CNusL8bdqyLGs59nHs9fFTTtb9DUAjQfPNSP57d9RVIXX74BOPDPZxM+DyKl
vDos3wVAE7G1D8/PM8oWDvV3E/ebM6GL5/mMHdutInoBZqfU7m3F/pE1ynxk
AOAu44c77NjvhdgapH8jfC2NahOe53rNC7PMAqwIxLRgP3LgpqRgxRzA07+J
A6OEqwoP8bouALgqhixi/XdrpHpzwy+AmaL03VhPgl0k1aU/ANX0YZHthIvO
Vf+R+QfQWXBhrRXr7cS5lZ4NAOuwo+c/EJ5utZkn0VCgz/xyahPW3zslhieY
KFD2kXSphjCdi81QKgsFTNZ/WVcR9g26MWDCRoFs0wTDSsK7Kmc7cjko0Kv6
SucZ4ae94h/3c1FgsT7EvAzr91/Wzf+2UGDQ8ZrXU8JLylUN9rwUsJi4O1CC
/c3e2VeM/BRgnl6Ueoj1n4d41TMBCuTxD14twnq24HoZlzAFUpQ6jxUSZml4
+bhWhALXRFgm7xI+93Wm2FuMAl67Va4WEN4raF3wXpIC3SbRA7lYr44q1R6W
Iq73YenTHMKjDxk/TUlT4MIj7tRs7HegimOzPAWoxV9GZhJ+y5Qsn61AgZ4s
/tQMwtydPiaqShR43z769A7h4hMSgQdViZ/vm+ZIx/5J6W/yKIkC0vfBKo3w
zpWeJ2fVKfBDUq7gNta7dY8/0GtSgBJcSoP+FBn5I0WLAoqnxnxSCUtZHaeW
1aFABsfb8RTC/tsMt1XqUoCJ55gfuuY7r/YefQpIplfTo5kfz1sOGlDAWWfo
fjLW3xeavbzIFHhK02yPzjUquP4PKCAXfoMfPcMSlBdrRIH818Lfk7Ce77at
Ed1JIVJ4bC06LJPU/8SYAgnjQ4XoNlfWJaNdFHBQ5cxCC6l+Z+8ypYDbH5k8
tNvaK9kTZhR4eU+mHF3WcHvn7z0UeM3A1Y2mij59JGIvBUhu36nx95vb7L3I
t48C5TfvGqJTRaST7u+nwKZiy+vo0Z9Uj3Utifm9MPEFrfJ04H3zQQrUC3oZ
4/0GXiobc7CmQLBK/wt0084YqhkbCnh+UNDF8eNidxMMsqVAy8UT79BOvRRN
DnsKRBoEn8TxfpAteCDnMDE/0Rc4cX5+u/86RXKkwIjt3vdoI7WP4Q1OFHhC
vxyH8xnzpzDH6igFjp32O4HzLRXr0HvuGBFf++q0MD78bTUXGE4Qn998QyML
50eMg+32SQo4iTJRMJ6syxqMXrpTICyW9SrGX/blDEfzUxTgPh1Unkd4yuR8
wGdPCtjVhy/n4/j3y5Vs+FBAyEUu/x6Ofy7tuzg/CkyQn7Dfx/H3HBoRO02B
ovyc8AeES//F8+88R4Eqm5hMXC/DEqth1wMpMHtmuxeuN6Xpjiz+K8T1HIik
4Hq8+Ky48kEQBf4NjIu/wPHafXTuQwgFluoOseJ6png3Hea8QYFb/MwBjYTX
+sZNGiMp8CqEaeQNzu8OVtL5KArwVGQ7vMPx4D/A+DmWGO9ipUuYT1gbB8oK
kynwfLnZBfvjPv4ZNsinQE75vzo8f0kI41hdKCDGs3uO8RfhPbOk0YJ7FPAI
iHXA85uaxvOVLEUUGLtBkcX+L99nk2vvE2J8nrlYsWE/9pq71vsVBURYWT7i
8zw5Fa0isTri85KyWvH5+UiaXXJXPQXS9zr04fM7G99MT903RH5pSGPC53X6
gjL89C0UmDkgM4TP2xj99PwzBijglzSzHZ+XZQm5SH74RQHja8db8ftcumry
Si7LRLx+LDiK3+fq2r2ktbJCASMZzd/4fVvG8+F7JP8Q8WAXLdeK19f+wD+Q
2gjqm9lL8d9HgfDFWoXNRsB4w4kN//2M4dkwx2gZI3j1sOYyvm8fSG/hKiFn
BFv601vlCPNs4/WrkDcC/ipVYXxf38zsftiYkhEw58hW4POvp/ktRQYaRuBH
XfkJ99dQO561aYoRbH/L/MqcsGTDvWSLw0bgebn9CO7frQor+YMORvAiPeQA
9kMByaalHk5GEJS4m4z7f7P7+MdwZyOw72pmx/Nofw55pleuRpD8KOoSnn+/
ciy5pHzGCL669V66ifV5078b1WeNYFxRWgrrFS7Vfal7zhtB+Wn3ZuxXTtLO
lbleNAKn/zq487AaszAA4C2YUMkYJqONaUqNrecRMZW3c0Tqlj3KMrpFjBZj
qmnRtJdQWoi0oUUplUpo3xRFtKC4FGkSuXdum27LvXNef/6e57vf833nnO/7
3ve873NDAmfE4Pc7W4+f4k/ggrGhEcZTtmNFh5QiCBwLU0n5Fl9yp7smR7Lr
26EhxPgzt2m377IoAo0Wi40ymKVTRuPNYgmcu/uhJhPja1ODNv94AmtDZINv
YbyQd/qdYgI7fktAWi7zhHKnIDGRgLroYkUes9WAl/z9FALWNru7bmM8GVNq
KkwnMGU22HKHOXly9i6/GwT2ffpcXozxzpH9XIUsAhGGv6TeZU5cN/WPTg4B
HelVNveZN6VaRty9RcAxga9TwiyQT04wzSPAX9MwhCbdxvfsCghwI1NPlmG8
uOV8vaCQHe8bp13OHFfY1e57h8C19oDn6P5Qf2H8PfZ78RKVSsyv/nsm0S5h
XtRYhDa0XaxYXEogTZ+zqQrjs+U1uq0VBCLf1u+sxvEw2DczsIrA39YfOtGV
dLhPr4ZAZrb3nhqMF60i6t/VEjApD3yM5ttopUc/YOuzccSglnn64cogkwYC
nm5PEtEqJ/ZyhQ8JvCiVHUOv9hHCtUYC1bKx5nXMFqFn1Lc/JiBU8riA5kb/
LJZqJrByVuZztHdiGS//KbteT03FB8zRN3aXHmohoGXWZ4TOLODHK7Wx+W8Y
cEBXlYd5VrUTMM3UC0K/fKix58QLdv+Sgstoftt9fY0ONp+bXdLRM7p2/PCs
k8B2W7sstOqnz4N+rwn0eJ1JQ68eCW5Z+YbAevOPcWiOlFp+11sCgjYvf7T9
7LuR57sJ8IKM7dDeC7Y5b3hPWIC7Zh06ZnG/haCHQJvkkBw6a1mgbkovgccJ
lc14f1VrF83c2kdgaGrHOXQHKeoTfySQE65ighZYWtbnfmLXP0PtC47fDJt/
0w4OsPu7bhOFVnPwC1LkE2gfaNFF67sqcysEbD3zwstwfjjet8FFSCCsMdgU
7RPVM/VkmIBYeqcRzm9Mwime7yiB2uEVObgebmbML10+RsB53e/fozvKNntG
TBAw39NaV4H5R0O3tdEUAWmRxlz0d21e+l/EBIx8X+/C9bemP3uQI0OhVzq/
ppTZcnhjy6QshYCejgFczw6SN3k505mPnVVEx85XcpafScH3QJ7BPTy/iVtf
0xwKtXNGlxYxy1kq1PvMpZAU4aRUiPni3oy0X+dRMPYrEeDzZ+XSYXd2AYXu
ullx+HxmXzHkmatSiE5vC7zJXJP+vGRcjcKUwEY3i/lVvkv8TQ0KjsaqjTfw
/A1XrWdpUigOuzCI74sjQ9NaHulSyHo18BHzvYM3NzbvX0ZBqG/livmdtV1w
k2A5hfjCvQLM7zY9la2fr0fhc+lVHr6PtLJlSu3WUsi7FOWM76terlS6iFLo
s7fxwHyKtxCunzOl0JmyKxnrk+3P/FLUN1PYVDlUhfXGOmNJvKk5BTknh1Gs
D6b9JI6M3kYhvHWWpjuOX+uEp84BCiErhq5gfW1/+G8eZQcphEb0umO/6C7w
+WvrIQq6/rmcb/2buePO7vYUjjj+yMf9L80zIm71MQri5Isy2P/YY/KVY+NB
YQXPIgTrY9zbgxrh5yksLV8cjft3ToE7J82jKUj/kdSA/RnuO4teysdS4Lj5
TWI97PSIe2RUHIU/n0jsvtW/1okmLiVRcC0rVsfvk6ha8iIjm8JwTKUc/n9F
VKt8RF0DhdGtBs24n3kl1flo6CM2HjLH93kzp7o1U7MmCpvFynw37PdZEDXe
1EwhUuarJtaneLbzjrY9Z7+XUe/G/jztnoX0fQ+bL1fLevx+ryryVkvrpZDW
fboR+3nWh7wWHe6j4OF0sAPrRxztpPz+TxQy+1vnKjOfPK6hJhRS0FfPkJnO
fMowQFQwREGn38tWijlE4X272wgFgVxrOe4nX85LPTs2xtbbvIkbWA+67j/N
sWScgtV5WMnHfGj7YXJqksIGn6GafoxvltSrGospKFRw7HF/vGJISySRULDP
DlbC/Op/u6wZxQ==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0.9998500000000001},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Position\"", TraditionalForm]},
  PlotLabel->FormBox["\"Omega = 0.9999, L = 1\"", TraditionalForm],
  PlotRange->{{0, 40}, {0.9998272043972452, 1.0001885048310621`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181792054826*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 156, 7, 191, "Title",
 Evaluatable->False],
Cell[716, 29, 78, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[819, 38, 999, 31, 112, "Input"],
Cell[1821, 71, 714, 25, 54, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[2550, 99, 240, 9, 137, "Text",
 Evaluatable->False],
Cell[2793, 110, 1704, 51, 272, "Input"],
Cell[4500, 163, 186, 7, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4711, 174, 443, 13, 112, "Input"],
Cell[5157, 189, 1137, 36, 52, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[6309, 228, 104, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6438, 237, 785, 21, 232, "Input"],
Cell[7226, 260, 21950, 369, 249, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[29191, 632, 258, 10, 137, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[29474, 646, 735, 21, 31, "Input"],
Cell[30212, 669, 62174, 1027, 369, "Output"]
}, Open  ]],
Cell[92401, 1699, 205, 8, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[92631, 1711, 733, 21, 31, "Input"],
Cell[93367, 1734, 25708, 429, 253, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

