(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65851,      10923]*)
(*NotebookOutlinePosition[     66705,      10955]*)
(*  CellTagsIndexPosition[     66661,      10951]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[TextData[
"\nThis is a Trebuchet With a Specified Rocker Motion and a Draging \
Projectile\n"], "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Arial",
  FontSize->24,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nQuit\n"], "Input",
  PageWidth->Infinity],

Cell[TextData["\n<<highorde.h\n"], "Input",
  PageWidth->Infinity],

Cell[TextData[
"\nSpecify Theta as a simple Cosine.  This allows theta to start at rest and \
end at rest. \n"], "Text",
  Evaluatable->False,
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"\nanot = -bnot + thetanot;\n\nbnot = (thetanot - thetafinal)/2;\n\nomega = \
Pi/tf;\n\ntheta[t_] := anot + bnot Cos[omega t]\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[
"\nCompute the position of mass 1. At first the projectile is dragging along \
a surface located h below the rocker pivot. During the draging period, we \
know the alpha because there is zero degree of freedom. Notice that there are \
two possible solutions for alpha. One has negative values and the other \
positive. When the program was developed, the first solution was used until, \
it became obvious that alpha was negative. Once this was understood, the \
second solution was realized and used. It was left here to make sure the \
reader realizes that these programs are developed iteratively. \n"], "Text",
  Evaluatable->False,
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"\nydrag[t_] := -h\n\nalphadrag[t_] := ArcSin[(h-l1 Sin[theta[t]])/d] -\n\n\t \
theta[t]\n\nalphadrag[t_] := Pi - ArcSin[(h-l1 Sin[theta[t]])/d] -\n\n\t \
theta[t]\n\nxdrag[t_] := -l1 Cos[theta[t]] - \n\n\td \
Cos[theta[t]+alphadrag[t]]\n"], "Input",
  PageWidth->Infinity],

Cell[TextData["\nNow for the eom during the draging phase.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nde1 := Tension[t] Sin[theta[t]+alphadrag[t]] - \n\n\tm1 g + n1 == m1 \
ydrag''[t]\n\nde2 := Tension[t] Cos[theta[t]+alphadrag[t]] == \n\n\tm1 \
xdrag''[t]\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[
"\nThere are zero degree of freedom therefore there are no differeential \
equatons to solve.\n"], "Text",
  Evaluatable->False],

Cell[TextData["\nPick some parameters.\n"], "Text",
  Evaluatable->False,
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"\nm1 = 1; l1 = 10;\n\ng = 9.81;\n\nd = 10;\n\nthetanot = 45 Degree;\n\n\
thetafinal = -45 Degree;\n\ntf = 2;\n\nh = l1 Sin[thetanot];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\ndrag = Solve[{de1,de2},\n\n\t{Tension[t],n1}];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[
"\nDoes the projectile lift off? Look at the normal force. Where it drops to \
zero is liftoff.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nOriginally the plot extended to tf but it becomes complex beyond about 1.2 \
seconds. Don't worry because it lifts off before then.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\nPlot[n1/.drag,{t,0,1.1},Frame->True,\n\n\tFrameLabel->{\"Time\",\"Normal \
Force\"}];\n"], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 0.865801 0.485843 0.0119751 [

[(0)] .02381 0 0 2 0 Minner Mrotsboxa

[(0.2)] .19697 0 0 2 0 Minner Mrotsboxa

[(0.4)] .37013 0 0 2 0 Minner Mrotsboxa

[(0.6)] .54329 0 0 2 0 Minner Mrotsboxa

[(0.8)] .71645 0 0 2 0 Minner Mrotsboxa

[(1)] .88961 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(-40)] -0.0125 .00684 1 0 0 Minner Mrotsboxa

[(-30)] -0.0125 .12659 1 0 0 Minner Mrotsboxa

[(-20)] -0.0125 .24634 1 0 0 Minner Mrotsboxa

[(-10)] -0.0125 .36609 1 0 0 Minner Mrotsboxa

[(0)] -0.0125 .48584 1 0 0 Minner Mrotsboxa

[(10)] -0.0125 .60559 1 0 0 Minner Mrotsboxa

[(Normal Force)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.02381 0 m

.02381 .00625 L

s

P

[(0)] .02381 0 0 2 0 Minner Mrotshowa

p

.002 w

.19697 0 m

.19697 .00625 L

s

P

[(0.2)] .19697 0 0 2 0 Minner Mrotshowa

p

.002 w

.37013 0 m

.37013 .00625 L

s

P

[(0.4)] .37013 0 0 2 0 Minner Mrotshowa

p

.002 w

.54329 0 m

.54329 .00625 L

s

P

[(0.6)] .54329 0 0 2 0 Minner Mrotshowa

p

.002 w

.71645 0 m

.71645 .00625 L

s

P

[(0.8)] .71645 0 0 2 0 Minner Mrotshowa

p

.002 w

.88961 0 m

.88961 .00625 L

s

P

[(1)] .88961 0 0 2 0 Minner Mrotshowa

p

.001 w

.05844 0 m

.05844 .00375 L

s

P

p

.001 w

.09307 0 m

.09307 .00375 L

s

P

p

.001 w

.12771 0 m

.12771 .00375 L

s

P

p

.001 w

.16234 0 m

.16234 .00375 L

s

P

p

.001 w

.2316 0 m

.2316 .00375 L

s

P

p

.001 w

.26623 0 m

.26623 .00375 L

s

P

p

.001 w

.30087 0 m

.30087 .00375 L

s

P

p

.001 w

.3355 0 m

.3355 .00375 L

s

P

p

.001 w

.40476 0 m

.40476 .00375 L

s

P

p

.001 w

.43939 0 m

.43939 .00375 L

s

P

p

.001 w

.47403 0 m

.47403 .00375 L

s

P

p

.001 w

.50866 0 m

.50866 .00375 L

s

P

p

.001 w

.57792 0 m

.57792 .00375 L

s

P

p

.001 w

.61255 0 m

.61255 .00375 L

s

P

p

.001 w

.64719 0 m

.64719 .00375 L

s

P

p

.001 w

.68182 0 m

.68182 .00375 L

s

P

p

.001 w

.75108 0 m

.75108 .00375 L

s

P

p

.001 w

.78571 0 m

.78571 .00375 L

s

P

p

.001 w

.82035 0 m

.82035 .00375 L

s

P

p

.001 w

.85498 0 m

.85498 .00375 L

s

P

p

.001 w

.92424 0 m

.92424 .00375 L

s

P

p

.001 w

.95887 0 m

.95887 .00375 L

s

P

p

.001 w

.99351 0 m

.99351 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .00684 m

.00625 .00684 L

s

P

[(-40)] -0.0125 .00684 1 0 0 Minner Mrotshowa

p

.002 w

0 .12659 m

.00625 .12659 L

s

P

[(-30)] -0.0125 .12659 1 0 0 Minner Mrotshowa

p

.002 w

0 .24634 m

.00625 .24634 L

s

P

[(-20)] -0.0125 .24634 1 0 0 Minner Mrotshowa

p

.002 w

0 .36609 m

.00625 .36609 L

s

P

[(-10)] -0.0125 .36609 1 0 0 Minner Mrotshowa

p

.002 w

0 .48584 m

.00625 .48584 L

s

P

[(0)] -0.0125 .48584 1 0 0 Minner Mrotshowa

p

.002 w

0 .60559 m

.00625 .60559 L

s

P

[(10)] -0.0125 .60559 1 0 0 Minner Mrotshowa

p

.001 w

0 .03079 m

.00375 .03079 L

s

P

p

.001 w

0 .05474 m

.00375 .05474 L

s

P

p

.001 w

0 .07869 m

.00375 .07869 L

s

P

p

.001 w

0 .10264 m

.00375 .10264 L

s

P

p

.001 w

0 .15054 m

.00375 .15054 L

s

P

p

.001 w

0 .17449 m

.00375 .17449 L

s

P

p

.001 w

0 .19844 m

.00375 .19844 L

s

P

p

.001 w

0 .22239 m

.00375 .22239 L

s

P

p

.001 w

0 .27029 m

.00375 .27029 L

s

P

p

.001 w

0 .29424 m

.00375 .29424 L

s

P

p

.001 w

0 .31819 m

.00375 .31819 L

s

P

p

.001 w

0 .34214 m

.00375 .34214 L

s

P

p

.001 w

0 .39004 m

.00375 .39004 L

s

P

p

.001 w

0 .41399 m

.00375 .41399 L

s

P

p

.001 w

0 .43794 m

.00375 .43794 L

s

P

p

.001 w

0 .46189 m

.00375 .46189 L

s

P

p

.001 w

0 .50979 m

.00375 .50979 L

s

P

p

.001 w

0 .53374 m

.00375 .53374 L

s

P

p

.001 w

0 .55769 m

.00375 .55769 L

s

P

p

.001 w

0 .58164 m

.00375 .58164 L

s

P

[(Normal Force)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.02381 .61178 m

.02381 .61803 L

s

P

p

.002 w

.19697 .61178 m

.19697 .61803 L

s

P

p

.002 w

.37013 .61178 m

.37013 .61803 L

s

P

p

.002 w

.54329 .61178 m

.54329 .61803 L

s

P

p

.002 w

.71645 .61178 m

.71645 .61803 L

s

P

p

.002 w

.88961 .61178 m

.88961 .61803 L

s

P

p

.001 w

.05844 .61428 m

.05844 .61803 L

s

P

p

.001 w

.09307 .61428 m

.09307 .61803 L

s

P

p

.001 w

.12771 .61428 m

.12771 .61803 L

s

P

p

.001 w

.16234 .61428 m

.16234 .61803 L

s

P

p

.001 w

.2316 .61428 m

.2316 .61803 L

s

P

p

.001 w

.26623 .61428 m

.26623 .61803 L

s

P

p

.001 w

.30087 .61428 m

.30087 .61803 L

s

P

p

.001 w

.3355 .61428 m

.3355 .61803 L

s

P

p

.001 w

.40476 .61428 m

.40476 .61803 L

s

P

p

.001 w

.43939 .61428 m

.43939 .61803 L

s

P

p

.001 w

.47403 .61428 m

.47403 .61803 L

s

P

p

.001 w

.50866 .61428 m

.50866 .61803 L

s

P

p

.001 w

.57792 .61428 m

.57792 .61803 L

s

P

p

.001 w

.61255 .61428 m

.61255 .61803 L

s

P

p

.001 w

.64719 .61428 m

.64719 .61803 L

s

P

p

.001 w

.68182 .61428 m

.68182 .61803 L

s

P

p

.001 w

.75108 .61428 m

.75108 .61803 L

s

P

p

.001 w

.78571 .61428 m

.78571 .61803 L

s

P

p

.001 w

.82035 .61428 m

.82035 .61803 L

s

P

p

.001 w

.85498 .61428 m

.85498 .61803 L

s

P

p

.001 w

.92424 .61428 m

.92424 .61803 L

s

P

p

.001 w

.95887 .61428 m

.95887 .61803 L

s

P

p

.001 w

.99351 .61428 m

.99351 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .00684 m

1 .00684 L

s

P

p

.002 w

.99375 .12659 m

1 .12659 L

s

P

p

.002 w

.99375 .24634 m

1 .24634 L

s

P

p

.002 w

.99375 .36609 m

1 .36609 L

s

P

p

.002 w

.99375 .48584 m

1 .48584 L

s

P

p

.002 w

.99375 .60559 m

1 .60559 L

s

P

p

.001 w

.99625 .03079 m

1 .03079 L

s

P

p

.001 w

.99625 .05474 m

1 .05474 L

s

P

p

.001 w

.99625 .07869 m

1 .07869 L

s

P

p

.001 w

.99625 .10264 m

1 .10264 L

s

P

p

.001 w

.99625 .15054 m

1 .15054 L

s

P

p

.001 w

.99625 .17449 m

1 .17449 L

s

P

p

.001 w

.99625 .19844 m

1 .19844 L

s

P

p

.001 w

.99625 .22239 m

1 .22239 L

s

P

p

.001 w

.99625 .27029 m

1 .27029 L

s

P

p

.001 w

.99625 .29424 m

1 .29424 L

s

P

p

.001 w

.99625 .31819 m

1 .31819 L

s

P

p

.001 w

.99625 .34214 m

1 .34214 L

s

P

p

.001 w

.99625 .39004 m

1 .39004 L

s

P

p

.001 w

.99625 .41399 m

1 .41399 L

s

P

p

.001 w

.99625 .43794 m

1 .43794 L

s

P

p

.001 w

.99625 .46189 m

1 .46189 L

s

P

p

.001 w

.99625 .50979 m

1 .50979 L

s

P

p

.001 w

.99625 .53374 m

1 .53374 L

s

P

p

.001 w

.99625 .55769 m

1 .55769 L

s

P

p

.001 w

.99625 .58164 m

1 .58164 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

p

.002 w

0 .48584 m

1 .48584 L

s

P

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .60332 m

.02505 .60332 L

.02629 .60332 L

.02753 .60332 L

.02877 .60332 L

.03125 .60331 L

.03373 .6033 L

.03621 .6033 L

.03869 .60329 L

.04365 .60326 L

.04861 .60323 L

.05357 .60319 L

.06349 .60308 L

.08333 .60279 L

.10317 .60239 L

.14286 .60126 L

.18254 .59976 L

.22222 .59792 L

.2619 .59583 L

.30159 .59353 L

.34127 .59105 L

.38095 .58842 L

.42063 .58558 L

.46032 .58245 L

.5 .57886 L

.53968 .57453 L

.57937 .56904 L

.61905 .5618 L

.65873 .55189 L

.67857 .54553 L

.69841 .53794 L

.71825 .52882 L

.7381 .51779 L

.75794 .50435 L

.77778 .48785 L

.79762 .46741 L

.81746 .44183 L

.8373 .40944 L

.85714 .36786 L

.87698 .31356 L

.89683 .24124 L

.91667 .14254 L

.92659 .07933 L

.93651 .00376 L

s

.93692 0 m

.93651 .00376 L

s

s

s

s

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]}, Open]],

Cell[TextData[
"\nCompute the actual liftoff time. The FindRoot sometimes needs a different \
starting point.  That is why it helps to plot the function first so you can \
see where the root ought to appear.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\nliftoff = FindRoot[(n1/.drag)[[1]] == 0,\n\n\t{t,0.8}][[1,2]]\n"], "Input",\

  PageWidth->Infinity],

Cell[OutputFormData["\<\

0.873312433794596






\
\>", "\<\

0.873312
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False]}, Open]],

Cell[TextData[
"\nThe values at liftoff are the intial conditions for the no drag phase \
coming up.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\ninitialalpha = alphadrag[liftoff];\n\n%/Degree//N\n\ninitialalphadot = \
alphadrag'[liftoff];\n\n%/Degree//N\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[OutputFormData["\<\

137.5676928164819






\
\>", "\<\

137.568
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[OutputFormData["\<\

-12.83794071391462






\
\>", "\<\

-12.8379
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False]}, Open]],

Cell[CellGroupData[{Cell[TextData[
"\nPlot[alphadrag[t]/Degree,{t,0,liftoff},Frame->True,\n\n\t\
FrameLabel->{\"Time\",\"Alpha (Degrees)\"}];\n"], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

0.0238095 1.09054 -22.1171 0.163939 [

[(0)] .02381 0 0 2 0 Minner Mrotsboxa

[(0.2)] .24192 0 0 2 0 Minner Mrotsboxa

[(0.4)] .46002 0 0 2 0 Minner Mrotsboxa

[(0.6)] .67813 0 0 2 0 Minner Mrotsboxa

[(0.8)] .89624 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(135)] -0.0125 .01472 1 0 0 Minner Mrotsboxa

[(135.5)] -0.0125 .09668 1 0 0 Minner Mrotsboxa

[(136)] -0.0125 .17865 1 0 0 Minner Mrotsboxa

[(136.5)] -0.0125 .26062 1 0 0 Minner Mrotsboxa

[(137)] -0.0125 .34259 1 0 0 Minner Mrotsboxa

[(137.5)] -0.0125 .42456 1 0 0 Minner Mrotsboxa

[(138)] -0.0125 .50653 1 0 0 Minner Mrotsboxa

[(138.5)] -0.0125 .5885 1 0 0 Minner Mrotsboxa

[(Alpha \\(Degrees\\))] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.02381 0 m

.02381 .00625 L

s

P

[(0)] .02381 0 0 2 0 Minner Mrotshowa

p

.002 w

.24192 0 m

.24192 .00625 L

s

P

[(0.2)] .24192 0 0 2 0 Minner Mrotshowa

p

.002 w

.46002 0 m

.46002 .00625 L

s

P

[(0.4)] .46002 0 0 2 0 Minner Mrotshowa

p

.002 w

.67813 0 m

.67813 .00625 L

s

P

[(0.6)] .67813 0 0 2 0 Minner Mrotshowa

p

.002 w

.89624 0 m

.89624 .00625 L

s

P

[(0.8)] .89624 0 0 2 0 Minner Mrotshowa

p

.001 w

.06743 0 m

.06743 .00375 L

s

P

p

.001 w

.11105 0 m

.11105 .00375 L

s

P

p

.001 w

.15467 0 m

.15467 .00375 L

s

P

p

.001 w

.1983 0 m

.1983 .00375 L

s

P

p

.001 w

.28554 0 m

.28554 .00375 L

s

P

p

.001 w

.32916 0 m

.32916 .00375 L

s

P

p

.001 w

.37278 0 m

.37278 .00375 L

s

P

p

.001 w

.4164 0 m

.4164 .00375 L

s

P

p

.001 w

.50365 0 m

.50365 .00375 L

s

P

p

.001 w

.54727 0 m

.54727 .00375 L

s

P

p

.001 w

.59089 0 m

.59089 .00375 L

s

P

p

.001 w

.63451 0 m

.63451 .00375 L

s

P

p

.001 w

.72175 0 m

.72175 .00375 L

s

P

p

.001 w

.76538 0 m

.76538 .00375 L

s

P

p

.001 w

.809 0 m

.809 .00375 L

s

P

p

.001 w

.85262 0 m

.85262 .00375 L

s

P

p

.001 w

.93986 0 m

.93986 .00375 L

s

P

p

.001 w

.98348 0 m

.98348 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .01472 m

.00625 .01472 L

s

P

[(135)] -0.0125 .01472 1 0 0 Minner Mrotshowa

p

.002 w

0 .09668 m

.00625 .09668 L

s

P

[(135.5)] -0.0125 .09668 1 0 0 Minner Mrotshowa

p

.002 w

0 .17865 m

.00625 .17865 L

s

P

[(136)] -0.0125 .17865 1 0 0 Minner Mrotshowa

p

.002 w

0 .26062 m

.00625 .26062 L

s

P

[(136.5)] -0.0125 .26062 1 0 0 Minner Mrotshowa

p

.002 w

0 .34259 m

.00625 .34259 L

s

P

[(137)] -0.0125 .34259 1 0 0 Minner Mrotshowa

p

.002 w

0 .42456 m

.00625 .42456 L

s

P

[(137.5)] -0.0125 .42456 1 0 0 Minner Mrotshowa

p

.002 w

0 .50653 m

.00625 .50653 L

s

P

[(138)] -0.0125 .50653 1 0 0 Minner Mrotshowa

p

.002 w

0 .5885 m

.00625 .5885 L

s

P

[(138.5)] -0.0125 .5885 1 0 0 Minner Mrotshowa

p

.001 w

0 .03111 m

.00375 .03111 L

s

P

p

.001 w

0 .0475 m

.00375 .0475 L

s

P

p

.001 w

0 .0639 m

.00375 .0639 L

s

P

p

.001 w

0 .08029 m

.00375 .08029 L

s

P

p

.001 w

0 .11308 m

.00375 .11308 L

s

P

p

.001 w

0 .12947 m

.00375 .12947 L

s

P

p

.001 w

0 .14587 m

.00375 .14587 L

s

P

p

.001 w

0 .16226 m

.00375 .16226 L

s

P

p

.001 w

0 .19505 m

.00375 .19505 L

s

P

p

.001 w

0 .21144 m

.00375 .21144 L

s

P

p

.001 w

0 .22784 m

.00375 .22784 L

s

P

p

.001 w

0 .24423 m

.00375 .24423 L

s

P

p

.001 w

0 .27702 m

.00375 .27702 L

s

P

p

.001 w

0 .29341 m

.00375 .29341 L

s

P

p

.001 w

0 .30981 m

.00375 .30981 L

s

P

p

.001 w

0 .3262 m

.00375 .3262 L

s

P

p

.001 w

0 .35899 m

.00375 .35899 L

s

P

p

.001 w

0 .37538 m

.00375 .37538 L

s

P

p

.001 w

0 .39178 m

.00375 .39178 L

s

P

p

.001 w

0 .40817 m

.00375 .40817 L

s

P

p

.001 w

0 .44096 m

.00375 .44096 L

s

P

p

.001 w

0 .45735 m

.00375 .45735 L

s

P

p

.001 w

0 .47375 m

.00375 .47375 L

s

P

p

.001 w

0 .49014 m

.00375 .49014 L

s

P

p

.001 w

0 .52293 m

.00375 .52293 L

s

P

p

.001 w

0 .53932 m

.00375 .53932 L

s

P

p

.001 w

0 .55571 m

.00375 .55571 L

s

P

p

.001 w

0 .57211 m

.00375 .57211 L

s

P

p

.001 w

0 .6049 m

.00375 .6049 L

s

P

[(Alpha \\(Degrees\\))] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.02381 .61178 m

.02381 .61803 L

s

P

p

.002 w

.24192 .61178 m

.24192 .61803 L

s

P

p

.002 w

.46002 .61178 m

.46002 .61803 L

s

P

p

.002 w

.67813 .61178 m

.67813 .61803 L

s

P

p

.002 w

.89624 .61178 m

.89624 .61803 L

s

P

p

.001 w

.06743 .61428 m

.06743 .61803 L

s

P

p

.001 w

.11105 .61428 m

.11105 .61803 L

s

P

p

.001 w

.15467 .61428 m

.15467 .61803 L

s

P

p

.001 w

.1983 .61428 m

.1983 .61803 L

s

P

p

.001 w

.28554 .61428 m

.28554 .61803 L

s

P

p

.001 w

.32916 .61428 m

.32916 .61803 L

s

P

p

.001 w

.37278 .61428 m

.37278 .61803 L

s

P

p

.001 w

.4164 .61428 m

.4164 .61803 L

s

P

p

.001 w

.50365 .61428 m

.50365 .61803 L

s

P

p

.001 w

.54727 .61428 m

.54727 .61803 L

s

P

p

.001 w

.59089 .61428 m

.59089 .61803 L

s

P

p

.001 w

.63451 .61428 m

.63451 .61803 L

s

P

p

.001 w

.72175 .61428 m

.72175 .61803 L

s

P

p

.001 w

.76538 .61428 m

.76538 .61803 L

s

P

p

.001 w

.809 .61428 m

.809 .61803 L

s

P

p

.001 w

.85262 .61428 m

.85262 .61803 L

s

P

p

.001 w

.93986 .61428 m

.93986 .61803 L

s

P

p

.001 w

.98348 .61428 m

.98348 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .01472 m

1 .01472 L

s

P

p

.002 w

.99375 .09668 m

1 .09668 L

s

P

p

.002 w

.99375 .17865 m

1 .17865 L

s

P

p

.002 w

.99375 .26062 m

1 .26062 L

s

P

p

.002 w

.99375 .34259 m

1 .34259 L

s

P

p

.002 w

.99375 .42456 m

1 .42456 L

s

P

p

.002 w

.99375 .50653 m

1 .50653 L

s

P

p

.002 w

.99375 .5885 m

1 .5885 L

s

P

p

.001 w

.99625 .03111 m

1 .03111 L

s

P

p

.001 w

.99625 .0475 m

1 .0475 L

s

P

p

.001 w

.99625 .0639 m

1 .0639 L

s

P

p

.001 w

.99625 .08029 m

1 .08029 L

s

P

p

.001 w

.99625 .11308 m

1 .11308 L

s

P

p

.001 w

.99625 .12947 m

1 .12947 L

s

P

p

.001 w

.99625 .14587 m

1 .14587 L

s

P

p

.001 w

.99625 .16226 m

1 .16226 L

s

P

p

.001 w

.99625 .19505 m

1 .19505 L

s

P

p

.001 w

.99625 .21144 m

1 .21144 L

s

P

p

.001 w

.99625 .22784 m

1 .22784 L

s

P

p

.001 w

.99625 .24423 m

1 .24423 L

s

P

p

.001 w

.99625 .27702 m

1 .27702 L

s

P

p

.001 w

.99625 .29341 m

1 .29341 L

s

P

p

.001 w

.99625 .30981 m

1 .30981 L

s

P

p

.001 w

.99625 .3262 m

1 .3262 L

s

P

p

.001 w

.99625 .35899 m

1 .35899 L

s

P

p

.001 w

.99625 .37538 m

1 .37538 L

s

P

p

.001 w

.99625 .39178 m

1 .39178 L

s

P

p

.001 w

.99625 .40817 m

1 .40817 L

s

P

p

.001 w

.99625 .44096 m

1 .44096 L

s

P

p

.001 w

.99625 .45735 m

1 .45735 L

s

P

p

.001 w

.99625 .47375 m

1 .47375 L

s

P

p

.001 w

.99625 .49014 m

1 .49014 L

s

P

p

.001 w

.99625 .52293 m

1 .52293 L

s

P

p

.001 w

.99625 .53932 m

1 .53932 L

s

P

p

.001 w

.99625 .55571 m

1 .55571 L

s

P

p

.001 w

.99625 .57211 m

1 .57211 L

s

P

p

.001 w

.99625 .6049 m

1 .6049 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .01472 m

.02505 .01472 L

.02629 .01473 L

.02753 .01475 L

.02877 .01477 L

.03001 .0148 L

.03125 .01484 L

.03373 .01494 L

.03621 .01506 L

.03869 .01521 L

.04365 .0156 L

.04861 .01609 L

.05357 .0167 L

.06349 .01824 L

.07341 .02021 L

.08333 .02262 L

.10317 .02873 L

.14286 .04596 L

.18254 .06956 L

.22222 .099 L

.2619 .13365 L

.30159 .17272 L

.34127 .21535 L

.38095 .26057 L

.42063 .30735 L

.46032 .35457 L

.5 .40109 L

.53968 .44571 L

.57937 .48721 L

.61905 .52433 L

.65873 .55582 L

.67857 .56904 L

.69841 .58036 L

.71825 .58961 L

.72817 .59341 L

.7381 .59663 L

.74802 .59924 L

.75794 .60123 L

.7629 .60198 L

.76786 .60257 L

.77034 .6028 L

.77282 .60299 L

.7753 .60314 L

.77654 .6032 L

.77778 .60324 L

.77902 .60328 L

.78026 .6033 L

.7815 .60332 L

.78274 .60332 L

.78398 .60331 L

Mistroke

.78522 .60329 L

.78646 .60326 L

.7877 .60322 L

.78894 .60317 L

.79018 .6031 L

.79266 .60294 L

.79514 .60273 L

.79762 .60248 L

.80258 .60183 L

.80754 .60099 L

.81746 .59874 L

.82738 .5957 L

.8373 .59184 L

.85714 .58157 L

.87698 .5677 L

.89683 .55 L

.93651 .50211 L

.97619 .43566 L

Mfstroke

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False],

Cell[TextData[
"\nNow for the no drag solution.  This is valid from liftoff until tf. \
Hopefully it releases before tf.\n"], "Text",
  Evaluatable->False]}, Open]],

Cell[TextData[
"\nHere is the position of the mass during freeflight.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nxx[t_] := -l1 Cos[theta[t]] - \n\n\td Cos[theta[t]+alpha[t]]\n\nyy[t_] := \
-l1 Sin[theta[t]] - \n\n\td Sin[theta[t]+alpha[t]]\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nHere are the eom for freeflight.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nnde1 := Tension[t] Sin[theta[t]+alpha[t]] - \n\n\tm1 g == m1 yy''[t]\n\n\
nde2 := Tension[t] Cos[theta[t]+alpha[t]] == \n\n\tm1 xx''[t]\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nThere is one degree of freedom. \n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nderivsnd = Solve[{nde1,nde2},{Tension[t],alpha''[t]}];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nThe differential equation.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\neqns = {alpha[liftoff]==initialalpha,\n\n\t\
alpha'[liftoff]==initialalphadot,\n\n\talpha''[t] == \
(alpha''[t]/.derivsnd)[[1]]};\n\nfirsteqns = \
SecondToFirstOrder[eqns,alpha,t];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nIntegrate the differential equation.\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nsol = NDSolve[firsteqns,\n\n\t{alpha[t],alphadot[t]},\n\n\t\
{t,liftoff,tf}];\n\nendtime = %[[1,1,2,0,1,2]];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[CellGroupData[{Cell[TextData[
"\nalphaplot = \n\nPlot[(alpha[t]/.sol)/Degree,{t,liftoff,endtime},\n\n\t\
Frame->True,\n\n\tFrameLabel->{\"Time\",\"Alpha (Degrees)\"}];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.714395 0.845293 -0.495392 0.0079867 [

[(1)] .1309 0 0 2 0 Minner Mrotsboxa

[(1.2)] .29996 0 0 2 0 Minner Mrotsboxa

[(1.4)] .46901 0 0 2 0 Minner Mrotsboxa

[(1.6)] .63807 0 0 2 0 Minner Mrotsboxa

[(1.8)] .80713 0 0 2 0 Minner Mrotsboxa

[(2)] .97619 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(70)] -0.0125 .06368 1 0 0 Minner Mrotsboxa

[(80)] -0.0125 .14354 1 0 0 Minner Mrotsboxa

[(90)] -0.0125 .22341 1 0 0 Minner Mrotsboxa

[(100)] -0.0125 .30328 1 0 0 Minner Mrotsboxa

[(110)] -0.0125 .38314 1 0 0 Minner Mrotsboxa

[(120)] -0.0125 .46301 1 0 0 Minner Mrotsboxa

[(130)] -0.0125 .54288 1 0 0 Minner Mrotsboxa

[(Alpha \\(Degrees\\))] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.1309 0 m

.1309 .00625 L

s

P

[(1)] .1309 0 0 2 0 Minner Mrotshowa

p

.002 w

.29996 0 m

.29996 .00625 L

s

P

[(1.2)] .29996 0 0 2 0 Minner Mrotshowa

p

.002 w

.46901 0 m

.46901 .00625 L

s

P

[(1.4)] .46901 0 0 2 0 Minner Mrotshowa

p

.002 w

.63807 0 m

.63807 .00625 L

s

P

[(1.6)] .63807 0 0 2 0 Minner Mrotshowa

p

.002 w

.80713 0 m

.80713 .00625 L

s

P

[(1.8)] .80713 0 0 2 0 Minner Mrotshowa

p

.002 w

.97619 0 m

.97619 .00625 L

s

P

[(2)] .97619 0 0 2 0 Minner Mrotshowa

p

.001 w

.16471 0 m

.16471 .00375 L

s

P

p

.001 w

.19852 0 m

.19852 .00375 L

s

P

p

.001 w

.23233 0 m

.23233 .00375 L

s

P

p

.001 w

.26614 0 m

.26614 .00375 L

s

P

p

.001 w

.33377 0 m

.33377 .00375 L

s

P

p

.001 w

.36758 0 m

.36758 .00375 L

s

P

p

.001 w

.40139 0 m

.40139 .00375 L

s

P

p

.001 w

.4352 0 m

.4352 .00375 L

s

P

p

.001 w

.50283 0 m

.50283 .00375 L

s

P

p

.001 w

.53664 0 m

.53664 .00375 L

s

P

p

.001 w

.57045 0 m

.57045 .00375 L

s

P

p

.001 w

.60426 0 m

.60426 .00375 L

s

P

p

.001 w

.67189 0 m

.67189 .00375 L

s

P

p

.001 w

.7057 0 m

.7057 .00375 L

s

P

p

.001 w

.73951 0 m

.73951 .00375 L

s

P

p

.001 w

.77332 0 m

.77332 .00375 L

s

P

p

.001 w

.84094 0 m

.84094 .00375 L

s

P

p

.001 w

.87476 0 m

.87476 .00375 L

s

P

p

.001 w

.90857 0 m

.90857 .00375 L

s

P

p

.001 w

.94238 0 m

.94238 .00375 L

s

P

p

.001 w

.09709 0 m

.09709 .00375 L

s

P

p

.001 w

.06327 0 m

.06327 .00375 L

s

P

p

.001 w

.02946 0 m

.02946 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .06368 m

.00625 .06368 L

s

P

[(70)] -0.0125 .06368 1 0 0 Minner Mrotshowa

p

.002 w

0 .14354 m

.00625 .14354 L

s

P

[(80)] -0.0125 .14354 1 0 0 Minner Mrotshowa

p

.002 w

0 .22341 m

.00625 .22341 L

s

P

[(90)] -0.0125 .22341 1 0 0 Minner Mrotshowa

p

.002 w

0 .30328 m

.00625 .30328 L

s

P

[(100)] -0.0125 .30328 1 0 0 Minner Mrotshowa

p

.002 w

0 .38314 m

.00625 .38314 L

s

P

[(110)] -0.0125 .38314 1 0 0 Minner Mrotshowa

p

.002 w

0 .46301 m

.00625 .46301 L

s

P

[(120)] -0.0125 .46301 1 0 0 Minner Mrotshowa

p

.002 w

0 .54288 m

.00625 .54288 L

s

P

[(130)] -0.0125 .54288 1 0 0 Minner Mrotshowa

p

.001 w

0 .07965 m

.00375 .07965 L

s

P

p

.001 w

0 .09562 m

.00375 .09562 L

s

P

p

.001 w

0 .1116 m

.00375 .1116 L

s

P

p

.001 w

0 .12757 m

.00375 .12757 L

s

P

p

.001 w

0 .15952 m

.00375 .15952 L

s

P

p

.001 w

0 .17549 m

.00375 .17549 L

s

P

p

.001 w

0 .19146 m

.00375 .19146 L

s

P

p

.001 w

0 .20744 m

.00375 .20744 L

s

P

p

.001 w

0 .23938 m

.00375 .23938 L

s

P

p

.001 w

0 .25536 m

.00375 .25536 L

s

P

p

.001 w

0 .27133 m

.00375 .27133 L

s

P

p

.001 w

0 .2873 m

.00375 .2873 L

s

P

p

.001 w

0 .31925 m

.00375 .31925 L

s

P

p

.001 w

0 .33522 m

.00375 .33522 L

s

P

p

.001 w

0 .3512 m

.00375 .3512 L

s

P

p

.001 w

0 .36717 m

.00375 .36717 L

s

P

p

.001 w

0 .39912 m

.00375 .39912 L

s

P

p

.001 w

0 .41509 m

.00375 .41509 L

s

P

p

.001 w

0 .43106 m

.00375 .43106 L

s

P

p

.001 w

0 .44704 m

.00375 .44704 L

s

P

p

.001 w

0 .47898 m

.00375 .47898 L

s

P

p

.001 w

0 .49496 m

.00375 .49496 L

s

P

p

.001 w

0 .51093 m

.00375 .51093 L

s

P

p

.001 w

0 .5269 m

.00375 .5269 L

s

P

p

.001 w

0 .0477 m

.00375 .0477 L

s

P

p

.001 w

0 .03173 m

.00375 .03173 L

s

P

p

.001 w

0 .01576 m

.00375 .01576 L

s

P

p

.001 w

0 .55885 m

.00375 .55885 L

s

P

p

.001 w

0 .57482 m

.00375 .57482 L

s

P

p

.001 w

0 .5908 m

.00375 .5908 L

s

P

p

.001 w

0 .60677 m

.00375 .60677 L

s

P

[(Alpha \\(Degrees\\))] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.1309 .61178 m

.1309 .61803 L

s

P

p

.002 w

.29996 .61178 m

.29996 .61803 L

s

P

p

.002 w

.46901 .61178 m

.46901 .61803 L

s

P

p

.002 w

.63807 .61178 m

.63807 .61803 L

s

P

p

.002 w

.80713 .61178 m

.80713 .61803 L

s

P

p

.002 w

.97619 .61178 m

.97619 .61803 L

s

P

p

.001 w

.16471 .61428 m

.16471 .61803 L

s

P

p

.001 w

.19852 .61428 m

.19852 .61803 L

s

P

p

.001 w

.23233 .61428 m

.23233 .61803 L

s

P

p

.001 w

.26614 .61428 m

.26614 .61803 L

s

P

p

.001 w

.33377 .61428 m

.33377 .61803 L

s

P

p

.001 w

.36758 .61428 m

.36758 .61803 L

s

P

p

.001 w

.40139 .61428 m

.40139 .61803 L

s

P

p

.001 w

.4352 .61428 m

.4352 .61803 L

s

P

p

.001 w

.50283 .61428 m

.50283 .61803 L

s

P

p

.001 w

.53664 .61428 m

.53664 .61803 L

s

P

p

.001 w

.57045 .61428 m

.57045 .61803 L

s

P

p

.001 w

.60426 .61428 m

.60426 .61803 L

s

P

p

.001 w

.67189 .61428 m

.67189 .61803 L

s

P

p

.001 w

.7057 .61428 m

.7057 .61803 L

s

P

p

.001 w

.73951 .61428 m

.73951 .61803 L

s

P

p

.001 w

.77332 .61428 m

.77332 .61803 L

s

P

p

.001 w

.84094 .61428 m

.84094 .61803 L

s

P

p

.001 w

.87476 .61428 m

.87476 .61803 L

s

P

p

.001 w

.90857 .61428 m

.90857 .61803 L

s

P

p

.001 w

.94238 .61428 m

.94238 .61803 L

s

P

p

.001 w

.09709 .61428 m

.09709 .61803 L

s

P

p

.001 w

.06327 .61428 m

.06327 .61803 L

s

P

p

.001 w

.02946 .61428 m

.02946 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .06368 m

1 .06368 L

s

P

p

.002 w

.99375 .14354 m

1 .14354 L

s

P

p

.002 w

.99375 .22341 m

1 .22341 L

s

P

p

.002 w

.99375 .30328 m

1 .30328 L

s

P

p

.002 w

.99375 .38314 m

1 .38314 L

s

P

p

.002 w

.99375 .46301 m

1 .46301 L

s

P

p

.002 w

.99375 .54288 m

1 .54288 L

s

P

p

.001 w

.99625 .07965 m

1 .07965 L

s

P

p

.001 w

.99625 .09562 m

1 .09562 L

s

P

p

.001 w

.99625 .1116 m

1 .1116 L

s

P

p

.001 w

.99625 .12757 m

1 .12757 L

s

P

p

.001 w

.99625 .15952 m

1 .15952 L

s

P

p

.001 w

.99625 .17549 m

1 .17549 L

s

P

p

.001 w

.99625 .19146 m

1 .19146 L

s

P

p

.001 w

.99625 .20744 m

1 .20744 L

s

P

p

.001 w

.99625 .23938 m

1 .23938 L

s

P

p

.001 w

.99625 .25536 m

1 .25536 L

s

P

p

.001 w

.99625 .27133 m

1 .27133 L

s

P

p

.001 w

.99625 .2873 m

1 .2873 L

s

P

p

.001 w

.99625 .31925 m

1 .31925 L

s

P

p

.001 w

.99625 .33522 m

1 .33522 L

s

P

p

.001 w

.99625 .3512 m

1 .3512 L

s

P

p

.001 w

.99625 .36717 m

1 .36717 L

s

P

p

.001 w

.99625 .39912 m

1 .39912 L

s

P

p

.001 w

.99625 .41509 m

1 .41509 L

s

P

p

.001 w

.99625 .43106 m

1 .43106 L

s

P

p

.001 w

.99625 .44704 m

1 .44704 L

s

P

p

.001 w

.99625 .47898 m

1 .47898 L

s

P

p

.001 w

.99625 .49496 m

1 .49496 L

s

P

p

.001 w

.99625 .51093 m

1 .51093 L

s

P

p

.001 w

.99625 .5269 m

1 .5269 L

s

P

p

.001 w

.99625 .0477 m

1 .0477 L

s

P

p

.001 w

.99625 .03173 m

1 .03173 L

s

P

p

.001 w

.99625 .01576 m

1 .01576 L

s

P

p

.001 w

.99625 .55885 m

1 .55885 L

s

P

p

.001 w

.99625 .57482 m

1 .57482 L

s

P

p

.001 w

.99625 .5908 m

1 .5908 L

s

P

p

.001 w

.99625 .60677 m

1 .60677 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

p

.002 w

0 .06368 m

1 .06368 L

s

P

p

.002 w

.1309 0 m

.1309 .61803 L

s

P

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .60332 m

.06349 .59764 L

.10317 .59021 L

.14286 .58101 L

.18254 .57002 L

.22222 .55724 L

.2619 .54269 L

.30159 .52638 L

.34127 .50835 L

.38095 .48862 L

.42063 .46725 L

.46032 .44428 L

.5 .41976 L

.53968 .39376 L

.57937 .36631 L

.61905 .33747 L

.65873 .30725 L

.69841 .27569 L

.7381 .24278 L

.77778 .20851 L

.81746 .17284 L

.85714 .13571 L

.89683 .09705 L

.93651 .05676 L

.97619 .01472 L

s

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]}, Open]],

Cell[TextData["\nIt Doesn't look like it releases.  Oh well.\n"], "Text",
  Evaluatable->False]}, Open]],

Cell[CellGroupData[{Cell[TextData["\n((alpha[t]/.sol)/.t->tf)/Degree//N\n"], "Input",
  PageWidth->Infinity],

Cell[OutputFormData["\<\

{63.86965898434058}






\
\>", "\<\

{63.8697}
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False],

Cell[TextData["\nMake sure tension is still positive throughout.\n"], "Text",
  Evaluatable->False]}, Open]],

Cell[CellGroupData[{Cell[TextData[
"\nPlot[\n\n((((Tension[t]/.derivsnd)/.\n\n{alpha'[t]->alphadot[t]})/.sol)),\n\
\n{t,liftoff,tf},Frame->True,\n\nFrameLabel->{\"Time\",\"Tension\"}];\n"], 
  "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.714395 0.845293 -0.450089 0.0261761 [

[(1)] .1309 0 0 2 0 Minner Mrotsboxa

[(1.2)] .29996 0 0 2 0 Minner Mrotsboxa

[(1.4)] .46901 0 0 2 0 Minner Mrotsboxa

[(1.6)] .63807 0 0 2 0 Minner Mrotsboxa

[(1.8)] .80713 0 0 2 0 Minner Mrotsboxa

[(2)] .97619 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(20)] -0.0125 .07343 1 0 0 Minner Mrotsboxa

[(25)] -0.0125 .20431 1 0 0 Minner Mrotsboxa

[(30)] -0.0125 .3352 1 0 0 Minner Mrotsboxa

[(35)] -0.0125 .46608 1 0 0 Minner Mrotsboxa

[(40)] -0.0125 .59696 1 0 0 Minner Mrotsboxa

[(Tension)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.1309 0 m

.1309 .00625 L

s

P

[(1)] .1309 0 0 2 0 Minner Mrotshowa

p

.002 w

.29996 0 m

.29996 .00625 L

s

P

[(1.2)] .29996 0 0 2 0 Minner Mrotshowa

p

.002 w

.46901 0 m

.46901 .00625 L

s

P

[(1.4)] .46901 0 0 2 0 Minner Mrotshowa

p

.002 w

.63807 0 m

.63807 .00625 L

s

P

[(1.6)] .63807 0 0 2 0 Minner Mrotshowa

p

.002 w

.80713 0 m

.80713 .00625 L

s

P

[(1.8)] .80713 0 0 2 0 Minner Mrotshowa

p

.002 w

.97619 0 m

.97619 .00625 L

s

P

[(2)] .97619 0 0 2 0 Minner Mrotshowa

p

.001 w

.16471 0 m

.16471 .00375 L

s

P

p

.001 w

.19852 0 m

.19852 .00375 L

s

P

p

.001 w

.23233 0 m

.23233 .00375 L

s

P

p

.001 w

.26614 0 m

.26614 .00375 L

s

P

p

.001 w

.33377 0 m

.33377 .00375 L

s

P

p

.001 w

.36758 0 m

.36758 .00375 L

s

P

p

.001 w

.40139 0 m

.40139 .00375 L

s

P

p

.001 w

.4352 0 m

.4352 .00375 L

s

P

p

.001 w

.50283 0 m

.50283 .00375 L

s

P

p

.001 w

.53664 0 m

.53664 .00375 L

s

P

p

.001 w

.57045 0 m

.57045 .00375 L

s

P

p

.001 w

.60426 0 m

.60426 .00375 L

s

P

p

.001 w

.67189 0 m

.67189 .00375 L

s

P

p

.001 w

.7057 0 m

.7057 .00375 L

s

P

p

.001 w

.73951 0 m

.73951 .00375 L

s

P

p

.001 w

.77332 0 m

.77332 .00375 L

s

P

p

.001 w

.84094 0 m

.84094 .00375 L

s

P

p

.001 w

.87476 0 m

.87476 .00375 L

s

P

p

.001 w

.90857 0 m

.90857 .00375 L

s

P

p

.001 w

.94238 0 m

.94238 .00375 L

s

P

p

.001 w

.09709 0 m

.09709 .00375 L

s

P

p

.001 w

.06327 0 m

.06327 .00375 L

s

P

p

.001 w

.02946 0 m

.02946 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .07343 m

.00625 .07343 L

s

P

[(20)] -0.0125 .07343 1 0 0 Minner Mrotshowa

p

.002 w

0 .20431 m

.00625 .20431 L

s

P

[(25)] -0.0125 .20431 1 0 0 Minner Mrotshowa

p

.002 w

0 .3352 m

.00625 .3352 L

s

P

[(30)] -0.0125 .3352 1 0 0 Minner Mrotshowa

p

.002 w

0 .46608 m

.00625 .46608 L

s

P

[(35)] -0.0125 .46608 1 0 0 Minner Mrotshowa

p

.002 w

0 .59696 m

.00625 .59696 L

s

P

[(40)] -0.0125 .59696 1 0 0 Minner Mrotshowa

p

.001 w

0 .09961 m

.00375 .09961 L

s

P

p

.001 w

0 .12579 m

.00375 .12579 L

s

P

p

.001 w

0 .15196 m

.00375 .15196 L

s

P

p

.001 w

0 .17814 m

.00375 .17814 L

s

P

p

.001 w

0 .23049 m

.00375 .23049 L

s

P

p

.001 w

0 .25667 m

.00375 .25667 L

s

P

p

.001 w

0 .28284 m

.00375 .28284 L

s

P

p

.001 w

0 .30902 m

.00375 .30902 L

s

P

p

.001 w

0 .36137 m

.00375 .36137 L

s

P

p

.001 w

0 .38755 m

.00375 .38755 L

s

P

p

.001 w

0 .41372 m

.00375 .41372 L

s

P

p

.001 w

0 .4399 m

.00375 .4399 L

s

P

p

.001 w

0 .49225 m

.00375 .49225 L

s

P

p

.001 w

0 .51843 m

.00375 .51843 L

s

P

p

.001 w

0 .5446 m

.00375 .5446 L

s

P

p

.001 w

0 .57078 m

.00375 .57078 L

s

P

p

.001 w

0 .04726 m

.00375 .04726 L

s

P

p

.001 w

0 .02108 m

.00375 .02108 L

s

P

[(Tension)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.1309 .61178 m

.1309 .61803 L

s

P

p

.002 w

.29996 .61178 m

.29996 .61803 L

s

P

p

.002 w

.46901 .61178 m

.46901 .61803 L

s

P

p

.002 w

.63807 .61178 m

.63807 .61803 L

s

P

p

.002 w

.80713 .61178 m

.80713 .61803 L

s

P

p

.002 w

.97619 .61178 m

.97619 .61803 L

s

P

p

.001 w

.16471 .61428 m

.16471 .61803 L

s

P

p

.001 w

.19852 .61428 m

.19852 .61803 L

s

P

p

.001 w

.23233 .61428 m

.23233 .61803 L

s

P

p

.001 w

.26614 .61428 m

.26614 .61803 L

s

P

p

.001 w

.33377 .61428 m

.33377 .61803 L

s

P

p

.001 w

.36758 .61428 m

.36758 .61803 L

s

P

p

.001 w

.40139 .61428 m

.40139 .61803 L

s

P

p

.001 w

.4352 .61428 m

.4352 .61803 L

s

P

p

.001 w

.50283 .61428 m

.50283 .61803 L

s

P

p

.001 w

.53664 .61428 m

.53664 .61803 L

s

P

p

.001 w

.57045 .61428 m

.57045 .61803 L

s

P

p

.001 w

.60426 .61428 m

.60426 .61803 L

s

P

p

.001 w

.67189 .61428 m

.67189 .61803 L

s

P

p

.001 w

.7057 .61428 m

.7057 .61803 L

s

P

p

.001 w

.73951 .61428 m

.73951 .61803 L

s

P

p

.001 w

.77332 .61428 m

.77332 .61803 L

s

P

p

.001 w

.84094 .61428 m

.84094 .61803 L

s

P

p

.001 w

.87476 .61428 m

.87476 .61803 L

s

P

p

.001 w

.90857 .61428 m

.90857 .61803 L

s

P

p

.001 w

.94238 .61428 m

.94238 .61803 L

s

P

p

.001 w

.09709 .61428 m

.09709 .61803 L

s

P

p

.001 w

.06327 .61428 m

.06327 .61803 L

s

P

p

.001 w

.02946 .61428 m

.02946 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .07343 m

1 .07343 L

s

P

p

.002 w

.99375 .20431 m

1 .20431 L

s

P

p

.002 w

.99375 .3352 m

1 .3352 L

s

P

p

.002 w

.99375 .46608 m

1 .46608 L

s

P

p

.002 w

.99375 .59696 m

1 .59696 L

s

P

p

.001 w

.99625 .09961 m

1 .09961 L

s

P

p

.001 w

.99625 .12579 m

1 .12579 L

s

P

p

.001 w

.99625 .15196 m

1 .15196 L

s

P

p

.001 w

.99625 .17814 m

1 .17814 L

s

P

p

.001 w

.99625 .23049 m

1 .23049 L

s

P

p

.001 w

.99625 .25667 m

1 .25667 L

s

P

p

.001 w

.99625 .28284 m

1 .28284 L

s

P

p

.001 w

.99625 .30902 m

1 .30902 L

s

P

p

.001 w

.99625 .36137 m

1 .36137 L

s

P

p

.001 w

.99625 .38755 m

1 .38755 L

s

P

p

.001 w

.99625 .41372 m

1 .41372 L

s

P

p

.001 w

.99625 .4399 m

1 .4399 L

s

P

p

.001 w

.99625 .49225 m

1 .49225 L

s

P

p

.001 w

.99625 .51843 m

1 .51843 L

s

P

p

.001 w

.99625 .5446 m

1 .5446 L

s

P

p

.001 w

.99625 .57078 m

1 .57078 L

s

P

p

.001 w

.99625 .04726 m

1 .04726 L

s

P

p

.001 w

.99625 .02108 m

1 .02108 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

p

.002 w

0 .07343 m

1 .07343 L

s

P

p

.002 w

.1309 0 m

.1309 .61803 L

s

P

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .01472 m

.06349 .07538 L

.10317 .13979 L

.14286 .20631 L

.18254 .27315 L

.22222 .33842 L

.2619 .40019 L

.30159 .45657 L

.34127 .50576 L

.38095 .54617 L

.40079 .56265 L

.42063 .57646 L

.44048 .58749 L

.4504 .59193 L

.46032 .59566 L

.47024 .59865 L

.48016 .6009 L

.48512 .60175 L

.49008 .60242 L

.49256 .60269 L

.49504 .6029 L

.49752 .60308 L

.5 .6032 L

.50124 .60325 L

.50248 .60328 L

.50372 .60331 L

.50496 .60332 L

.5062 .60332 L

.50744 .60331 L

.50868 .60328 L

.50992 .60325 L

.51116 .6032 L

.5124 .60315 L

.51488 .603 L

.51736 .60281 L

.51984 .60257 L

.5248 .60195 L

.52976 .60116 L

.53968 .59903 L

.5496 .59619 L

.55952 .59266 L

.57937 .58357 L

.61905 .55781 L

.65873 .5232 L

.69841 .48172 L

.7381 .4357 L

.77778 .38783 L

.81746 .34102 L

.85714 .29829 L

.89683 .2627 L

Mistroke

.91667 .2485 L

.93651 .23717 L

.94643 .23269 L

.95635 .22904 L

.96131 .22755 L

.96627 .22628 L

.97619 .22443 L

Mfstroke

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]}, Open]],

Cell[TextData[
"\nFind the initial conditions for the next phase (freeflight with rocker \
stopped).\n"], "Text",
  Evaluatable->False],

Cell[TextData[
"\nnextalpha = (alpha[t]/.sol/.t->tf)[[1]];\n\nnextalphadot = \
(alphadot[t]/.sol/.t->tf)[[1]];\n"], "Input",
  PageWidth->Infinity],

Cell[TextData["\nThe theta is fixed.\n"], "Text",
  Evaluatable->False],

Cell[TextData["\ntheta[t_] := thetafinal\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[
"\nThe equations are the same so resolve them with the new theta.\n"], "Text",\

  Evaluatable->False],

Cell[TextData[
"\nfixedder = Solve[{nde1,nde2},{Tension[t],alpha''[t]}];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nThe differential equation with fixed theta.\n"], "Text",
  Evaluatable->False,
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"\nfixedeqns = {alpha[tf]==nextalpha,\n\n\talpha'[tf]==nextalphadot,\n\n\t\
alpha''[t] == (alpha''[t]/.fixedder)[[1]]};\n\nfixedfirsteqns = \
SecondToFirstOrder[fixedeqns,alpha,t];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nIntegrate the differential equation.\n"], "Text",
  Evaluatable->False,
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[
"\nfixedsol = NDSolve[fixedfirsteqns,\n\n\t{alpha[t],alphadot[t]},\n\n\t\
{t,tf,5}];\n\nendtime = %[[1,1,2,0,1,2]];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData["\nSee if alpha goes to zero.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\nPlot[(alpha[t]/.fixedsol)/Degree,{t,tf,endtime},\n\n\tFrame->True,\n\n\t\
FrameLabel->{\"Time\",\"Alpha\"}];\n"], "Input",
  PageWidth->Infinity],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-0.611111 0.31746 0.464801 0.00216877 [

[(2)] .02381 0 0 2 0 Minner Mrotsboxa

[(2.5)] .18254 0 0 2 0 Minner Mrotsboxa

[(3)] .34127 0 0 2 0 Minner Mrotsboxa

[(3.5)] .5 0 0 2 0 Minner Mrotsboxa

[(4)] .65873 0 0 2 0 Minner Mrotsboxa

[(4.5)] .81746 0 0 2 0 Minner Mrotsboxa

[(5)] .97619 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(-200)] -0.0125 .03105 1 0 0 Minner Mrotsboxa

[(-150)] -0.0125 .13949 1 0 0 Minner Mrotsboxa

[(-100)] -0.0125 .24792 1 0 0 Minner Mrotsboxa

[(-50)] -0.0125 .35636 1 0 0 Minner Mrotsboxa

[(0)] -0.0125 .4648 1 0 0 Minner Mrotsboxa

[(50)] -0.0125 .57324 1 0 0 Minner Mrotsboxa

[(Alpha)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.02381 0 m

.02381 .00625 L

s

P

[(2)] .02381 0 0 2 0 Minner Mrotshowa

p

.002 w

.18254 0 m

.18254 .00625 L

s

P

[(2.5)] .18254 0 0 2 0 Minner Mrotshowa

p

.002 w

.34127 0 m

.34127 .00625 L

s

P

[(3)] .34127 0 0 2 0 Minner Mrotshowa

p

.002 w

.5 0 m

.5 .00625 L

s

P

[(3.5)] .5 0 0 2 0 Minner Mrotshowa

p

.002 w

.65873 0 m

.65873 .00625 L

s

P

[(4)] .65873 0 0 2 0 Minner Mrotshowa

p

.002 w

.81746 0 m

.81746 .00625 L

s

P

[(4.5)] .81746 0 0 2 0 Minner Mrotshowa

p

.002 w

.97619 0 m

.97619 .00625 L

s

P

[(5)] .97619 0 0 2 0 Minner Mrotshowa

p

.001 w

.05556 0 m

.05556 .00375 L

s

P

p

.001 w

.0873 0 m

.0873 .00375 L

s

P

p

.001 w

.11905 0 m

.11905 .00375 L

s

P

p

.001 w

.15079 0 m

.15079 .00375 L

s

P

p

.001 w

.21429 0 m

.21429 .00375 L

s

P

p

.001 w

.24603 0 m

.24603 .00375 L

s

P

p

.001 w

.27778 0 m

.27778 .00375 L

s

P

p

.001 w

.30952 0 m

.30952 .00375 L

s

P

p

.001 w

.37302 0 m

.37302 .00375 L

s

P

p

.001 w

.40476 0 m

.40476 .00375 L

s

P

p

.001 w

.43651 0 m

.43651 .00375 L

s

P

p

.001 w

.46825 0 m

.46825 .00375 L

s

P

p

.001 w

.53175 0 m

.53175 .00375 L

s

P

p

.001 w

.56349 0 m

.56349 .00375 L

s

P

p

.001 w

.59524 0 m

.59524 .00375 L

s

P

p

.001 w

.62698 0 m

.62698 .00375 L

s

P

p

.001 w

.69048 0 m

.69048 .00375 L

s

P

p

.001 w

.72222 0 m

.72222 .00375 L

s

P

p

.001 w

.75397 0 m

.75397 .00375 L

s

P

p

.001 w

.78571 0 m

.78571 .00375 L

s

P

p

.001 w

.84921 0 m

.84921 .00375 L

s

P

p

.001 w

.88095 0 m

.88095 .00375 L

s

P

p

.001 w

.9127 0 m

.9127 .00375 L

s

P

p

.001 w

.94444 0 m

.94444 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .03105 m

.00625 .03105 L

s

P

[(-200)] -0.0125 .03105 1 0 0 Minner Mrotshowa

p

.002 w

0 .13949 m

.00625 .13949 L

s

P

[(-150)] -0.0125 .13949 1 0 0 Minner Mrotshowa

p

.002 w

0 .24792 m

.00625 .24792 L

s

P

[(-100)] -0.0125 .24792 1 0 0 Minner Mrotshowa

p

.002 w

0 .35636 m

.00625 .35636 L

s

P

[(-50)] -0.0125 .35636 1 0 0 Minner Mrotshowa

p

.002 w

0 .4648 m

.00625 .4648 L

s

P

[(0)] -0.0125 .4648 1 0 0 Minner Mrotshowa

p

.002 w

0 .57324 m

.00625 .57324 L

s

P

[(50)] -0.0125 .57324 1 0 0 Minner Mrotshowa

p

.001 w

0 .05273 m

.00375 .05273 L

s

P

p

.001 w

0 .07442 m

.00375 .07442 L

s

P

p

.001 w

0 .09611 m

.00375 .09611 L

s

P

p

.001 w

0 .1178 m

.00375 .1178 L

s

P

p

.001 w

0 .16117 m

.00375 .16117 L

s

P

p

.001 w

0 .18286 m

.00375 .18286 L

s

P

p

.001 w

0 .20455 m

.00375 .20455 L

s

P

p

.001 w

0 .22624 m

.00375 .22624 L

s

P

p

.001 w

0 .26961 m

.00375 .26961 L

s

P

p

.001 w

0 .2913 m

.00375 .2913 L

s

P

p

.001 w

0 .31299 m

.00375 .31299 L

s

P

p

.001 w

0 .33467 m

.00375 .33467 L

s

P

p

.001 w

0 .37805 m

.00375 .37805 L

s

P

p

.001 w

0 .39974 m

.00375 .39974 L

s

P

p

.001 w

0 .42143 m

.00375 .42143 L

s

P

p

.001 w

0 .44311 m

.00375 .44311 L

s

P

p

.001 w

0 .48649 m

.00375 .48649 L

s

P

p

.001 w

0 .50818 m

.00375 .50818 L

s

P

p

.001 w

0 .52986 m

.00375 .52986 L

s

P

p

.001 w

0 .55155 m

.00375 .55155 L

s

P

p

.001 w

0 .00936 m

.00375 .00936 L

s

P

p

.001 w

0 .59493 m

.00375 .59493 L

s

P

p

.001 w

0 .61661 m

.00375 .61661 L

s

P

[(Alpha)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.02381 .61178 m

.02381 .61803 L

s

P

p

.002 w

.18254 .61178 m

.18254 .61803 L

s

P

p

.002 w

.34127 .61178 m

.34127 .61803 L

s

P

p

.002 w

.5 .61178 m

.5 .61803 L

s

P

p

.002 w

.65873 .61178 m

.65873 .61803 L

s

P

p

.002 w

.81746 .61178 m

.81746 .61803 L

s

P

p

.002 w

.97619 .61178 m

.97619 .61803 L

s

P

p

.001 w

.05556 .61428 m

.05556 .61803 L

s

P

p

.001 w

.0873 .61428 m

.0873 .61803 L

s

P

p

.001 w

.11905 .61428 m

.11905 .61803 L

s

P

p

.001 w

.15079 .61428 m

.15079 .61803 L

s

P

p

.001 w

.21429 .61428 m

.21429 .61803 L

s

P

p

.001 w

.24603 .61428 m

.24603 .61803 L

s

P

p

.001 w

.27778 .61428 m

.27778 .61803 L

s

P

p

.001 w

.30952 .61428 m

.30952 .61803 L

s

P

p

.001 w

.37302 .61428 m

.37302 .61803 L

s

P

p

.001 w

.40476 .61428 m

.40476 .61803 L

s

P

p

.001 w

.43651 .61428 m

.43651 .61803 L

s

P

p

.001 w

.46825 .61428 m

.46825 .61803 L

s

P

p

.001 w

.53175 .61428 m

.53175 .61803 L

s

P

p

.001 w

.56349 .61428 m

.56349 .61803 L

s

P

p

.001 w

.59524 .61428 m

.59524 .61803 L

s

P

p

.001 w

.62698 .61428 m

.62698 .61803 L

s

P

p

.001 w

.69048 .61428 m

.69048 .61803 L

s

P

p

.001 w

.72222 .61428 m

.72222 .61803 L

s

P

p

.001 w

.75397 .61428 m

.75397 .61803 L

s

P

p

.001 w

.78571 .61428 m

.78571 .61803 L

s

P

p

.001 w

.84921 .61428 m

.84921 .61803 L

s

P

p

.001 w

.88095 .61428 m

.88095 .61803 L

s

P

p

.001 w

.9127 .61428 m

.9127 .61803 L

s

P

p

.001 w

.94444 .61428 m

.94444 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .03105 m

1 .03105 L

s

P

p

.002 w

.99375 .13949 m

1 .13949 L

s

P

p

.002 w

.99375 .24792 m

1 .24792 L

s

P

p

.002 w

.99375 .35636 m

1 .35636 L

s

P

p

.002 w

.99375 .4648 m

1 .4648 L

s

P

p

.002 w

.99375 .57324 m

1 .57324 L

s

P

p

.001 w

.99625 .05273 m

1 .05273 L

s

P

p

.001 w

.99625 .07442 m

1 .07442 L

s

P

p

.001 w

.99625 .09611 m

1 .09611 L

s

P

p

.001 w

.99625 .1178 m

1 .1178 L

s

P

p

.001 w

.99625 .16117 m

1 .16117 L

s

P

p

.001 w

.99625 .18286 m

1 .18286 L

s

P

p

.001 w

.99625 .20455 m

1 .20455 L

s

P

p

.001 w

.99625 .22624 m

1 .22624 L

s

P

p

.001 w

.99625 .26961 m

1 .26961 L

s

P

p

.001 w

.99625 .2913 m

1 .2913 L

s

P

p

.001 w

.99625 .31299 m

1 .31299 L

s

P

p

.001 w

.99625 .33467 m

1 .33467 L

s

P

p

.001 w

.99625 .37805 m

1 .37805 L

s

P

p

.001 w

.99625 .39974 m

1 .39974 L

s

P

p

.001 w

.99625 .42143 m

1 .42143 L

s

P

p

.001 w

.99625 .44311 m

1 .44311 L

s

P

p

.001 w

.99625 .48649 m

1 .48649 L

s

P

p

.001 w

.99625 .50818 m

1 .50818 L

s

P

p

.001 w

.99625 .52986 m

1 .52986 L

s

P

p

.001 w

.99625 .55155 m

1 .55155 L

s

P

p

.001 w

.99625 .00936 m

1 .00936 L

s

P

p

.001 w

.99625 .59493 m

1 .59493 L

s

P

p

.001 w

.99625 .61661 m

1 .61661 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

p

.002 w

0 .4648 m

1 .4648 L

s

P

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .60332 m

.06349 .57318 L

.10317 .54493 L

.14286 .51855 L

.18254 .49396 L

.22222 .47099 L

.2619 .44942 L

.30159 .42903 L

.34127 .40954 L

.38095 .39069 L

.42063 .3722 L

.46032 .35378 L

.5 .33516 L

.53968 .31605 L

.57937 .29619 L

.61905 .27529 L

.65873 .25311 L

.69841 .22942 L

.7381 .20403 L

.77778 .1768 L

.81746 .14768 L

.85714 .1167 L

.89683 .08401 L

.93651 .04989 L

.97619 .01472 L

s

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]}, Open]],

Cell[TextData["\nFind the release time.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\nrelease = \n\n\tFindRoot[(alpha[t]/.fixedsol)[[1]] == 0,\n\n\t\
{t,2.5}][[1,2]]\n"], "Input",
  PageWidth->Infinity],

Cell[OutputFormData["\<\

2.660093261442335






\
\>", "\<\

2.66009
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False]}, Open]],

Cell[TextData["\nMake sure the tension stays positive.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\nPlot[\n\n((((Tension[t]/.fixedder)/.\n\n\
{alpha'[t]->alphadot[t]})/.fixedsol)),\n\n{t,tf,release},Frame->True,\n\n\
FrameLabel->{\"Time\",\"Tension\"}];\n"], "Input",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->12,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[GraphicsData["PostScript", "\<\

%!

%%Creator: Mathematica

%%AspectRatio: .61803 

MathPictureStart

%% Graphics

/Courier findfont 10  scalefont  setfont

% Scaling calculations

-2.86179 1.4428 -0.234449 0.0194077 [

[(2)] .02381 0 0 2 0 Minner Mrotsboxa

[(2.1)] .16809 0 0 2 0 Minner Mrotsboxa

[(2.2)] .31237 0 0 2 0 Minner Mrotsboxa

[(2.3)] .45665 0 0 2 0 Minner Mrotsboxa

[(2.4)] .60093 0 0 2 0 Minner Mrotsboxa

[(2.5)] .74521 0 0 2 0 Minner Mrotsboxa

[(2.6)] .88949 0 0 2 0 Minner Mrotsboxa

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotsboxa

[(15)] -0.0125 .05667 1 0 0 Minner Mrotsboxa

[(20)] -0.0125 .1537 1 0 0 Minner Mrotsboxa

[(25)] -0.0125 .25074 1 0 0 Minner Mrotsboxa

[(30)] -0.0125 .34778 1 0 0 Minner Mrotsboxa

[(35)] -0.0125 .44482 1 0 0 Minner Mrotsboxa

[(40)] -0.0125 .54186 1 0 0 Minner Mrotsboxa

[(Tension)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotsboxa

[ -0.001 -0.001 0 0 ]

[ 1.001 .61903 0 0 ]

] MathScale

% Start of Graphics

1 setlinecap

1 setlinejoin

newpath

[ ] 0 setdash

0 g

p

p

.002 w

.02381 0 m

.02381 .00625 L

s

P

[(2)] .02381 0 0 2 0 Minner Mrotshowa

p

.002 w

.16809 0 m

.16809 .00625 L

s

P

[(2.1)] .16809 0 0 2 0 Minner Mrotshowa

p

.002 w

.31237 0 m

.31237 .00625 L

s

P

[(2.2)] .31237 0 0 2 0 Minner Mrotshowa

p

.002 w

.45665 0 m

.45665 .00625 L

s

P

[(2.3)] .45665 0 0 2 0 Minner Mrotshowa

p

.002 w

.60093 0 m

.60093 .00625 L

s

P

[(2.4)] .60093 0 0 2 0 Minner Mrotshowa

p

.002 w

.74521 0 m

.74521 .00625 L

s

P

[(2.5)] .74521 0 0 2 0 Minner Mrotshowa

p

.002 w

.88949 0 m

.88949 .00625 L

s

P

[(2.6)] .88949 0 0 2 0 Minner Mrotshowa

p

.001 w

.05267 0 m

.05267 .00375 L

s

P

p

.001 w

.08152 0 m

.08152 .00375 L

s

P

p

.001 w

.11038 0 m

.11038 .00375 L

s

P

p

.001 w

.13923 0 m

.13923 .00375 L

s

P

p

.001 w

.19695 0 m

.19695 .00375 L

s

P

p

.001 w

.2258 0 m

.2258 .00375 L

s

P

p

.001 w

.25466 0 m

.25466 .00375 L

s

P

p

.001 w

.28351 0 m

.28351 .00375 L

s

P

p

.001 w

.34122 0 m

.34122 .00375 L

s

P

p

.001 w

.37008 0 m

.37008 .00375 L

s

P

p

.001 w

.39894 0 m

.39894 .00375 L

s

P

p

.001 w

.42779 0 m

.42779 .00375 L

s

P

p

.001 w

.4855 0 m

.4855 .00375 L

s

P

p

.001 w

.51436 0 m

.51436 .00375 L

s

P

p

.001 w

.54322 0 m

.54322 .00375 L

s

P

p

.001 w

.57207 0 m

.57207 .00375 L

s

P

p

.001 w

.62978 0 m

.62978 .00375 L

s

P

p

.001 w

.65864 0 m

.65864 .00375 L

s

P

p

.001 w

.6875 0 m

.6875 .00375 L

s

P

p

.001 w

.71635 0 m

.71635 .00375 L

s

P

p

.001 w

.77406 0 m

.77406 .00375 L

s

P

p

.001 w

.80292 0 m

.80292 .00375 L

s

P

p

.001 w

.83178 0 m

.83178 .00375 L

s

P

p

.001 w

.86063 0 m

.86063 .00375 L

s

P

p

.001 w

.91834 0 m

.91834 .00375 L

s

P

p

.001 w

.9472 0 m

.9472 .00375 L

s

P

p

.001 w

.97606 0 m

.97606 .00375 L

s

P

[(Time)] .5 0 0 2 0 0 -1 Mouter Mrotshowa

p

.002 w

0 0 m

1 0 L

s

P

p

.002 w

0 .05667 m

.00625 .05667 L

s

P

[(15)] -0.0125 .05667 1 0 0 Minner Mrotshowa

p

.002 w

0 .1537 m

.00625 .1537 L

s

P

[(20)] -0.0125 .1537 1 0 0 Minner Mrotshowa

p

.002 w

0 .25074 m

.00625 .25074 L

s

P

[(25)] -0.0125 .25074 1 0 0 Minner Mrotshowa

p

.002 w

0 .34778 m

.00625 .34778 L

s

P

[(30)] -0.0125 .34778 1 0 0 Minner Mrotshowa

p

.002 w

0 .44482 m

.00625 .44482 L

s

P

[(35)] -0.0125 .44482 1 0 0 Minner Mrotshowa

p

.002 w

0 .54186 m

.00625 .54186 L

s

P

[(40)] -0.0125 .54186 1 0 0 Minner Mrotshowa

p

.001 w

0 .07607 m

.00375 .07607 L

s

P

p

.001 w

0 .09548 m

.00375 .09548 L

s

P

p

.001 w

0 .11489 m

.00375 .11489 L

s

P

p

.001 w

0 .1343 m

.00375 .1343 L

s

P

p

.001 w

0 .17311 m

.00375 .17311 L

s

P

p

.001 w

0 .19252 m

.00375 .19252 L

s

P

p

.001 w

0 .21193 m

.00375 .21193 L

s

P

p

.001 w

0 .23133 m

.00375 .23133 L

s

P

p

.001 w

0 .27015 m

.00375 .27015 L

s

P

p

.001 w

0 .28956 m

.00375 .28956 L

s

P

p

.001 w

0 .30897 m

.00375 .30897 L

s

P

p

.001 w

0 .32837 m

.00375 .32837 L

s

P

p

.001 w

0 .36719 m

.00375 .36719 L

s

P

p

.001 w

0 .3866 m

.00375 .3866 L

s

P

p

.001 w

0 .406 m

.00375 .406 L

s

P

p

.001 w

0 .42541 m

.00375 .42541 L

s

P

p

.001 w

0 .46423 m

.00375 .46423 L

s

P

p

.001 w

0 .48363 m

.00375 .48363 L

s

P

p

.001 w

0 .50304 m

.00375 .50304 L

s

P

p

.001 w

0 .52245 m

.00375 .52245 L

s

P

p

.001 w

0 .03726 m

.00375 .03726 L

s

P

p

.001 w

0 .01785 m

.00375 .01785 L

s

P

p

.001 w

0 .56127 m

.00375 .56127 L

s

P

p

.001 w

0 .58067 m

.00375 .58067 L

s

P

p

.001 w

0 .60008 m

.00375 .60008 L

s

P

[(Tension)] -0.0125 .30902 1 0 90 -1 0 Mouter Mrotshowa

p

.002 w

0 0 m

0 .61803 L

s

P

P

p

p

.002 w

.02381 .61178 m

.02381 .61803 L

s

P

p

.002 w

.16809 .61178 m

.16809 .61803 L

s

P

p

.002 w

.31237 .61178 m

.31237 .61803 L

s

P

p

.002 w

.45665 .61178 m

.45665 .61803 L

s

P

p

.002 w

.60093 .61178 m

.60093 .61803 L

s

P

p

.002 w

.74521 .61178 m

.74521 .61803 L

s

P

p

.002 w

.88949 .61178 m

.88949 .61803 L

s

P

p

.001 w

.05267 .61428 m

.05267 .61803 L

s

P

p

.001 w

.08152 .61428 m

.08152 .61803 L

s

P

p

.001 w

.11038 .61428 m

.11038 .61803 L

s

P

p

.001 w

.13923 .61428 m

.13923 .61803 L

s

P

p

.001 w

.19695 .61428 m

.19695 .61803 L

s

P

p

.001 w

.2258 .61428 m

.2258 .61803 L

s

P

p

.001 w

.25466 .61428 m

.25466 .61803 L

s

P

p

.001 w

.28351 .61428 m

.28351 .61803 L

s

P

p

.001 w

.34122 .61428 m

.34122 .61803 L

s

P

p

.001 w

.37008 .61428 m

.37008 .61803 L

s

P

p

.001 w

.39894 .61428 m

.39894 .61803 L

s

P

p

.001 w

.42779 .61428 m

.42779 .61803 L

s

P

p

.001 w

.4855 .61428 m

.4855 .61803 L

s

P

p

.001 w

.51436 .61428 m

.51436 .61803 L

s

P

p

.001 w

.54322 .61428 m

.54322 .61803 L

s

P

p

.001 w

.57207 .61428 m

.57207 .61803 L

s

P

p

.001 w

.62978 .61428 m

.62978 .61803 L

s

P

p

.001 w

.65864 .61428 m

.65864 .61803 L

s

P

p

.001 w

.6875 .61428 m

.6875 .61803 L

s

P

p

.001 w

.71635 .61428 m

.71635 .61803 L

s

P

p

.001 w

.77406 .61428 m

.77406 .61803 L

s

P

p

.001 w

.80292 .61428 m

.80292 .61803 L

s

P

p

.001 w

.83178 .61428 m

.83178 .61803 L

s

P

p

.001 w

.86063 .61428 m

.86063 .61803 L

s

P

p

.001 w

.91834 .61428 m

.91834 .61803 L

s

P

p

.001 w

.9472 .61428 m

.9472 .61803 L

s

P

p

.001 w

.97606 .61428 m

.97606 .61803 L

s

P

p

.002 w

0 .61803 m

1 .61803 L

s

P

p

.002 w

.99375 .05667 m

1 .05667 L

s

P

p

.002 w

.99375 .1537 m

1 .1537 L

s

P

p

.002 w

.99375 .25074 m

1 .25074 L

s

P

p

.002 w

.99375 .34778 m

1 .34778 L

s

P

p

.002 w

.99375 .44482 m

1 .44482 L

s

P

p

.002 w

.99375 .54186 m

1 .54186 L

s

P

p

.001 w

.99625 .07607 m

1 .07607 L

s

P

p

.001 w

.99625 .09548 m

1 .09548 L

s

P

p

.001 w

.99625 .11489 m

1 .11489 L

s

P

p

.001 w

.99625 .1343 m

1 .1343 L

s

P

p

.001 w

.99625 .17311 m

1 .17311 L

s

P

p

.001 w

.99625 .19252 m

1 .19252 L

s

P

p

.001 w

.99625 .21193 m

1 .21193 L

s

P

p

.001 w

.99625 .23133 m

1 .23133 L

s

P

p

.001 w

.99625 .27015 m

1 .27015 L

s

P

p

.001 w

.99625 .28956 m

1 .28956 L

s

P

p

.001 w

.99625 .30897 m

1 .30897 L

s

P

p

.001 w

.99625 .32837 m

1 .32837 L

s

P

p

.001 w

.99625 .36719 m

1 .36719 L

s

P

p

.001 w

.99625 .3866 m

1 .3866 L

s

P

p

.001 w

.99625 .406 m

1 .406 L

s

P

p

.001 w

.99625 .42541 m

1 .42541 L

s

P

p

.001 w

.99625 .46423 m

1 .46423 L

s

P

p

.001 w

.99625 .48363 m

1 .48363 L

s

P

p

.001 w

.99625 .50304 m

1 .50304 L

s

P

p

.001 w

.99625 .52245 m

1 .52245 L

s

P

p

.001 w

.99625 .03726 m

1 .03726 L

s

P

p

.001 w

.99625 .01785 m

1 .01785 L

s

P

p

.001 w

.99625 .56127 m

1 .56127 L

s

P

p

.001 w

.99625 .58067 m

1 .58067 L

s

P

p

.001 w

.99625 .60008 m

1 .60008 L

s

P

p

.002 w

1 0 m

1 .61803 L

s

P

P

p

P

0 0 m

1 0 L

1 .61803 L

0 .61803 L

closepath

clip

newpath

p

p

.004 w

.02381 .60332 m

.06349 .57352 L

.10317 .54366 L

.14286 .51384 L

.18254 .48416 L

.22222 .45473 L

.2619 .42562 L

.30159 .39692 L

.34127 .36869 L

.38095 .34101 L

.42063 .31392 L

.46032 .28748 L

.5 .26173 L

.53968 .2367 L

.57937 .21244 L

.61905 .18895 L

.65873 .16627 L

.69841 .14441 L

.7381 .12337 L

.77778 .10317 L

.81746 .08381 L

.85714 .06529 L

.89683 .0476 L

.93651 .03075 L

.97619 .01472 L

s

P

P

% End of Graphics

MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  Evaluatable->False,
  ImageSize->{299, 185},
  ImageMargins->{{100, Inherited}, {Inherited, 0}},
  ImageCacheValid->False]}, Open]],

Cell[TextData[
"\nIt gets close to zero near the end so check it out specifically.\n"], 
  "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData[
"\n((((Tension[t]/.fixedder)/.\n\n\
{alpha'[t]->alphadot[t]})/.fixedsol))/.t->release//N\n"], "Input",
  PageWidth->Infinity],

Cell[OutputFormData["\<\

{{12.83845889441031}}






\
\>", "\<\

{{12.8385}}
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False]}, Open]],

Cell[TextData["\nFind the speed of the projectile at the release.\n"], "Text",
  Evaluatable->False],

Cell[CellGroupData[{Cell[TextData["\n(fixedsol/.t->release)[[1]]//N\n"], "Input",
  PageWidth->Infinity],

Cell[OutputFormData["\<\

{alpha[2.660093261442335] -> 

   -(2.914335439641036*10^-16), 

  alphadot[2.660093261442335] -> 

   -1.406242383725165}






\
\>", "\<\

                              -16

{alpha[2.66009] -> -2.91434 10   , 

 

 alphadot[2.66009] -> -1.40624}
\
\>"], "Output",
  PageWidth->Infinity,
  Evaluatable->False]}, Open]]
},
FrontEndVersion->"NeXT 3.0",
ScreenRectangle->{{0, 1085}, {0, 864}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{520, 600},
WindowMargins->{{Automatic, 260}, {Automatic, 14}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1711, 51, 306, 10, 70, "Title"],
Cell[2020, 63, 58, 1, 70, "Input"],
Cell[2081, 66, 66, 1, 70, "Input"],
Cell[2150, 69, 385, 13, 70, "Text"],
Cell[2538, 84, 299, 8, 70, "Input"],
Cell[2840, 94, 894, 19, 70, "Text"],
Cell[3737, 115, 288, 5, 70, "Input"],
Cell[4028, 122, 93, 1, 70, "Text"],
Cell[4124, 125, 331, 9, 70, "Input"],
Cell[4458, 136, 143, 3, 70, "Text"],
Cell[4604, 141, 316, 11, 70, "Text"],
Cell[4923, 154, 308, 8, 70, "Input"],
Cell[5234, 164, 222, 6, 70, "Input"],
Cell[5459, 172, 145, 3, 70, "Text"],
Cell[5607, 177, 184, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[5814, 182, 140, 3, 70, "Input"],
Cell[5957, 187, 8084, 1619, 70, 7936, 1614, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[14053, 1808, 242, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[14318, 1814, 118, 3, 70, "Input"],
Cell[14439, 1819, 134, 16, 70, "Output"]
}, Open  ]],
Cell[14585, 1837, 135, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[14743, 1842, 285, 8, 70, "Input"],
Cell[15031, 1852, 133, 16, 70, "Output"],
Cell[15167, 1870, 135, 16, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15334, 1888, 158, 3, 70, "Input"],
Cell[15495, 1893, 8956, 1769, 70, 8808, 1764, "GraphicsData", 
"PostScript", "Graphics"],
Cell[24454, 3664, 155, 3, 70, "Text"]
}, Open  ]],
Cell[24621, 3669, 104, 2, 70, "Text"],
Cell[24728, 3673, 303, 8, 70, "Input"],
Cell[25034, 3683, 84, 1, 70, "Text"],
Cell[25121, 3686, 312, 8, 70, "Input"],
Cell[25436, 3696, 84, 1, 70, "Text"],
Cell[25523, 3699, 231, 7, 70, "Input"],
Cell[25757, 3708, 78, 1, 70, "Text"],
Cell[25838, 3711, 357, 10, 70, "Input"],
Cell[26198, 3723, 88, 1, 70, "Text"],
Cell[26289, 3726, 285, 8, 70, "Input"],

Cell[CellGroupData[{
Cell[26597, 3736, 311, 8, 70, "Input"],
Cell[26911, 3746, 8951, 1873, 70, 8803, 1868, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[35874, 5621, 95, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[36001, 5624, 88, 1, 70, "Input"],
Cell[36092, 5627, 137, 16, 70, "Output"],
Cell[36232, 5645, 99, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36363, 5648, 326, 9, 70, "Input"],
Cell[36692, 5659, 7911, 1571, 70, 7763, 1566, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[44615, 7232, 135, 3, 70, "Text"],
Cell[44753, 7237, 147, 3, 70, "Input"],
Cell[44903, 7242, 71, 1, 70, "Text"],
Cell[44977, 7245, 199, 6, 70, "Input"],
Cell[45179, 7253, 117, 3, 70, "Text"],
Cell[45299, 7258, 231, 7, 70, "Input"],
Cell[45533, 7267, 338, 11, 70, "Text"],
Cell[45874, 7280, 354, 9, 70, "Input"],
Cell[46231, 7291, 331, 11, 70, "Text"],
Cell[46565, 7304, 289, 8, 70, "Input"],
Cell[46857, 7314, 78, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[46958, 7317, 163, 3, 70, "Input"],
Cell[47124, 7322, 8217, 1693, 70, 8069, 1688, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[55353, 9017, 74, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[55450, 9020, 134, 3, 70, "Input"],
Cell[55587, 9025, 133, 16, 70, "Output"]
}, Open  ]],
Cell[55732, 9043, 89, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[55844, 9046, 330, 9, 70, "Input"],
Cell[56177, 9057, 8664, 1801, 70, 8516, 1796, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[64853, 10860, 120, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[64996, 10865, 140, 3, 70, "Input"],
Cell[65139, 10870, 141, 16, 70, "Output"]
}, Open  ]],
Cell[65292, 10888, 100, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[65415, 10891, 84, 1, 70, "Input"],
Cell[65502, 10894, 337, 28, 70, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
