(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     98327,       1877]
NotebookOptionsPosition[     96662,       1814]
NotebookOutlinePosition[     97218,       1836]
CellTagsIndexPosition[     97175,       1833]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

Finding the Work Put Into a Mass.
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

The solution when F is ignored.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"-", "k"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "-", "L"}], ")"}]}], " ", "==", " ", 
        
        RowBox[{"m", " ", 
         RowBox[{
          RowBox[{"v", "'"}], "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], " ", "==", " ", 
        RowBox[{"v", "[", "t", "]"}]}], ",", "\n", "\n", "\t", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], " ", "==", " ", "L"}], ",", " ", 
       RowBox[{
        RowBox[{"v", "[", "0", "]"}], " ", "==", " ", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802071896*^9, 3.5181802071916*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"L", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["k"], " ", "t"}], 
          SqrtBox["m"]], "]"}], "2"]}], "+", 
      RowBox[{"L", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{
           SqrtBox["k"], " ", "t"}], 
          SqrtBox["m"]], "]"}], "2"]}]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181802261406*^9}]
}, Open  ]],

Cell["\<\

The solution when F is present. Often the solution is easiest to find using 

complex numbers. The complexexpand statement simply converts from 

complex to real after the solution is obtained.
\
\>", "Text",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"sol", " ", "=", " ", 
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", "a"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"omega", " ", "t"}], "]"}]}], " ", "-", 
           RowBox[{"k", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "-", "L"}], ")"}]}]}], " ", "==", 
          " ", "\n", "\n", "\t\t", 
          RowBox[{"m", " ", 
           RowBox[{
            RowBox[{"v", "'"}], "[", "t", "]"}]}]}], ",", "\n", "\n", "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "'"}], "[", "t", "]"}], " ", "==", " ", 
          RowBox[{"v", "[", "t", "]"}]}], ",", " ", 
         RowBox[{
          RowBox[{"x", "[", "0", "]"}], " ", "==", " ", "L"}], ",", " ", 
         RowBox[{
          RowBox[{"v", "[", "0", "]"}], " ", "==", " ", "0"}]}], "}"}], ",", 
       "\n", "\n", "\t", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], ",", 
         RowBox[{"v", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{
    RowBox[{"complexans", " ", "=", " ", 
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "/.", "sol"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"realans", " ", "=", " ", 
     RowBox[{"ComplexExpand", "[", "complexans", "]"}]}], ";"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802087756*^9, 3.5181802087776003`*^9}},
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["\<\

Simplify the answer and use some numbers so the reader can follow easier.

Note that complex exponents are equivalent to sines and cosines.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"simpans", " ", "=", " ", 
    RowBox[{"Simplify", "[", 
     RowBox[{"realans", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"m", "->", "1"}], ",", 
        RowBox[{"k", "->", "1"}], ",", 
        RowBox[{"a", "->", "1"}]}], "}"}]}], "]"}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802111786003`*^9, 3.5181802111816*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    RowBox[{"L", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["omega", "2"]}], ")"}]}], "-", 
    RowBox[{"omega", " ", 
     RowBox[{"Sin", "[", "t", "]"}]}], "+", 
    RowBox[{"Sin", "[", 
     RowBox[{"omega", " ", "t"}], "]"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    SuperscriptBox["omega", "2"]}]], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181802307906*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"pos", "[", "t_", "]"}], " ", "=", " ", 
     RowBox[{"simpans", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802138246*^9, 3.5181802138266*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"energy", " ", "=", " ", 
     RowBox[{"Integrate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"omega", " ", "t"}], "]"}]}], " ", 
        RowBox[{
         RowBox[{"pos", "'"}], "[", "t", "]"}]}], ",", "t"}], "]"}]}], ";"}], 
   "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802144546003`*^9, 3.5181802144566*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{"simpener", " ", "=", " ", 
    RowBox[{"Simplify", "[", "energy", "]"}]}], "\n"}]}]], "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5181802149526*^9, 3.5181802149546003`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox["omega", "2"], " ", 
    RowBox[{"Cos", "[", "t", "]"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"omega", " ", "t"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["omega", "2"]}], ")"}], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "omega", " ", "t"}], "]"}]}], "-", 
   RowBox[{"4", " ", "omega", " ", 
    RowBox[{"Sin", "[", "t", "]"}], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"omega", " ", "t"}], "]"}]}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["omega", "2"]}], ")"}], "2"]}]]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5181802343716*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\

Generate a plot of the energy input when omega is far from 1.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"simpener", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{"omega", "\[Rule]", "0.1`"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Omega = 0.1\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time in Seconds\>\"", ",", "\"\<Energy Input\>\""}], 
     "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3k81F8XxyWkSLKVLNn37Pt2j20MRUpJfiharBVCEUUpkiQkSVT2fR9Z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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Energy Input\"", TraditionalForm]},
  PlotLabel->FormBox["\"Omega = 0.1\"", TraditionalForm],
  PlotRange->{{0, 100}, {-0.26272829303132333`, 0.3420533061317696}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181802365076*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"simpener", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{"omega", "\[Rule]", "10"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Omega = 10\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time in Seconds\>\"", ",", "\"\<Energy Input\>\""}], 
     "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUVnc81W8bPgeVhFQaRAqhX5IiVLiPLSN7j2zZ21F2dkgyohAqITKyw6MS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Energy Input\"", TraditionalForm]},
  PlotLabel->FormBox["\"Omega = 10\"", TraditionalForm],
  PlotRange->{{0, 4}, {-0.0076777879808182835`, 0.01272815584317947}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181802382956*^9}]
}, Open  ]],

Cell["\<\

Now let omega get closer to 1.  Note the energy is still building.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"simpener", "/.", "\[InvisibleSpace]", 
    RowBox[{"{", 
     RowBox[{"omega", "\[Rule]", "0.9`"}], "}"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Omega = 0.9\>\""}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Time in Seconds\>\"", ",", "\"\<Energy Input\>\""}], 
     "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1],
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1nk41FsYB3C00GYpaUGlKN0iuTGX0iskiVvELSktopBSSpKSLEm2LolQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, -23.740000000000002`},
  Frame->True,
  FrameLabel->{
    FormBox["\"Time in Seconds\"", TraditionalForm], 
    FormBox["\"Energy Input\"", TraditionalForm]},
  PlotLabel->FormBox["\"Omega = 0.9\"", TraditionalForm],
  PlotRange->{{0, 1}, {-23.753462603878127`, -23.669930541438102`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5181802398296003`*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 138, 7, 191, "Title",
 Evaluatable->False],
Cell[698, 29, 78, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[801, 38, 999, 31, 112, "Input"],
Cell[1803, 71, 714, 25, 54, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[2532, 99, 240, 9, 137, "Text",
 Evaluatable->False],
Cell[2775, 110, 1704, 51, 272, "Input"],
Cell[4482, 163, 186, 7, 101, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4693, 174, 417, 12, 72, "Input"],
Cell[5113, 188, 520, 18, 53, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[5648, 209, 300, 9, 72, "Input"],
Cell[CellGroupData[{
Cell[5973, 222, 466, 15, 72, "Input"],
Cell[CellGroupData[{
Cell[6464, 241, 235, 6, 72, "Input"],
Cell[6702, 249, 848, 28, 57, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[7577, 281, 108, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7710, 290, 551, 14, 31, "Input"],
Cell[8264, 306, 43581, 722, 260, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51882, 1033, 663, 19, 31, "Input"],
Cell[52548, 1054, 38042, 631, 254, "Output"]
}, Open  ]],
Cell[90605, 1688, 113, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[90743, 1697, 666, 19, 31, "Input"],
Cell[91412, 1718, 5234, 93, 254, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

