(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     56331,       1469]
NotebookOptionsPosition[     53543,       1368]
NotebookOutlinePosition[     54124,       1390]
CellTagsIndexPosition[     54081,       1387]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Some preliminary definintions that make typing easier.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
i = {1,0,0};
j = {0,1,0};
k = {0,0,1};
position[length_,angle_] := length ( Cos[angle] i + 
      Sin[angle] j );

l1 = L;
l2 = 2L;
l3 = 2L;
l4 = 1.5 L;\
\>", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
v1 = position[l1,theta];
v2 = position[l2,gamma];
v3 = position[l3,beta];
v4 = l4 i;
eqn = v1 + v2 - v3 - v4 \
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "1.5`"}], " ", "L"}], "-", 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "+", 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"Cos", "[", "gamma", "]"}]}], "+", 
    RowBox[{"L", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}]}], ",", 
   RowBox[{"0.`", "\[VeryThinSpace]", "-", 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}], "+", 
    RowBox[{"2", " ", "L", " ", 
     RowBox[{"Sin", "[", "gamma", "]"}]}], "+", 
    RowBox[{"L", " ", 
     RowBox[{"Sin", "[", "theta", "]"}]}]}], ",", "0.`"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.518437145678*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
Notice that L factors out so it doesn't matter what it is. Set it to 1 just \
to get rid of it.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["L = 1;", "Input",
 AspectRatioFixed->True],

Cell["The next few lines were copied from NonLin2", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
The following is used to solve 2 nonlinear equations.  You call it as \
follows:
Solve2NonLinear[{eqn1==something, eqn2==other},NameOfIndependentVariable, 
{Initial value of Independent variable, Final value of indep. var. , \
increment of indep. variable}, \
{FirstVariableToFind,SecondVariableToFind},{GuessAtFirstVariable,\
GuessAtSecondVariable}]\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Solve2NonLinear[eqns_,iVar_,iVarStuff_,dVars_,dVarInits_]:=
Module[{iStart,iFinish,iInc,iVarTable,npts,sol,solTable},
SetAttributes[Solve2NonLinear,HoldAll];
iStart=iVarStuff[[1]];
iFinish=iVarStuff[[2]];
iInc=iVarStuff[[3]];
iVarTable=Table[i,{i,iStart,iFinish,iInc}];
npts=Length[iVarTable];
sol=dVarInits;
solTable=Flatten[Table[{
\tsol=dVars/.
\tFindRoot[Evaluate[eqns/.iVar->iVarTable[[i]]],
\tEvaluate[{dVars[[1]],sol[[1]]},{dVars[[2]],sol[[2]]}]]},
{i,1,npts}],1];
{Interpolation[Table[{iVarTable[[i]],solTable[[i]][[1]]},
      {i,1,npts}]],
 Interpolation[Table[{iVarTable[[i]],solTable[[i]][[2]]},
      {i,1,npts}]]}]
\
\>", "Input",
 AspectRatioFixed->True],

Cell["Now for some things specific to this problem.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["eqs := {eqn[[1]] == 0, eqn[[2]] == 0}", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
{GAMMA,BETA} = Solve2NonLinear[eqs,theta,{0,2 Pi, 2 Pi/500},
                 {gamma,beta},{1,0}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
      ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], ",", 
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "6.283185307179586`"}], "}"}], "}"}], 
      ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False]}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371674088*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["Now to simplify the typing.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
gam[theta_] := {GAMMA[theta]}[[1]]
bet[theta_] := {BETA[theta]}[[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell["Here are the velocity equations.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
veleqn = L (-Sin[theta] i + Cos[theta] j)thetadot + 
2L (-Sin[gamma] i + Cos[gamma] j)gammadot -
(2L (-Sin[beta] i + Cos[beta] j)betadot )\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", "betadot", " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
    RowBox[{"2", " ", "gammadot", " ", 
     RowBox[{"Sin", "[", "gamma", "]"}]}], "-", 
    RowBox[{"thetadot", " ", 
     RowBox[{"Sin", "[", "theta", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "betadot", " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "+", 
    RowBox[{"2", " ", "gammadot", " ", 
     RowBox[{"Cos", "[", "gamma", "]"}]}], "+", 
    RowBox[{"thetadot", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}]}], ",", "0"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371714024*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
velsol = Solve[{veleqn[[1]]==0,veleqn[[2]]==0},
    {gammadot,betadot}][[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"gammadot", "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"thetadot", " ", 
        RowBox[{"Cos", "[", "theta", "]"}], " ", 
        RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
       RowBox[{"thetadot", " ", 
        RowBox[{"Cos", "[", "beta", "]"}], " ", 
        RowBox[{"Sin", "[", "theta", "]"}]}]}], 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", "gamma", "]"}], " ", 
          RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
         RowBox[{
          RowBox[{"Cos", "[", "beta", "]"}], " ", 
          RowBox[{"Sin", "[", "gamma", "]"}]}]}], ")"}]}]]}]}], ",", 
   RowBox[{"betadot", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", "thetadot"}], " ", 
       RowBox[{"Cos", "[", "theta", "]"}], " ", 
       RowBox[{"Sin", "[", "gamma", "]"}]}], "+", 
      RowBox[{"thetadot", " ", 
       RowBox[{"Cos", "[", "gamma", "]"}], " ", 
       RowBox[{"Sin", "[", "theta", "]"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", "gamma", "]"}], " ", 
         RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", "beta", "]"}], " ", 
         RowBox[{"Sin", "[", "gamma", "]"}]}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371737892*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["Here are the acceleration equations.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
acceqn = L(-Sin[theta] i + Cos[theta] j)thetaddot + 
2L(-Sin[gamma] i + Cos[gamma] j)gammaddot + 
L(-Cos[theta] i - Sin[theta] j)thetadot^2 + 
2L(-Cos[gamma] i - Sin[gamma] j)gammadot^2 - 
( 2L(-Sin[beta] i + Cos[beta] j)betaddot + 
2L(-Cos[beta] i - Sin[beta] j)betadot^2)\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["betadot", "2"], " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["gammadot", "2"], " ", 
     RowBox[{"Cos", "[", "gamma", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["thetadot", "2"], " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}], "+", 
    RowBox[{"2", " ", "betaddot", " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
    RowBox[{"2", " ", "gammaddot", " ", 
     RowBox[{"Sin", "[", "gamma", "]"}]}], "-", 
    RowBox[{"thetaddot", " ", 
     RowBox[{"Sin", "[", "theta", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", "betaddot", " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "+", 
    RowBox[{"2", " ", "gammaddot", " ", 
     RowBox[{"Cos", "[", "gamma", "]"}]}], "+", 
    RowBox[{"thetaddot", " ", 
     RowBox[{"Cos", "[", "theta", "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["betadot", "2"], " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["gammadot", "2"], " ", 
     RowBox[{"Sin", "[", "gamma", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["thetadot", "2"], " ", 
     RowBox[{"Sin", "[", "theta", "]"}]}]}], ",", "0"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371754584*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
accsol = Solve[{acceqn[[1]]==0,acceqn[[2]]==0},
         {gammaddot,betaddot}][[1]]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"gammaddot", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", "beta", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["betadot", "2"], " ", 
            RowBox[{"Cos", "[", "beta", "]"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["gammadot", "2"], " ", 
            RowBox[{"Cos", "[", "gamma", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["thetadot", "2"], " ", 
            RowBox[{"Cos", "[", "theta", "]"}]}], "-", 
           RowBox[{"thetaddot", " ", 
            RowBox[{"Sin", "[", "theta", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Sin", "[", "beta", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"thetaddot", " ", 
            RowBox[{"Cos", "[", "theta", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["betadot", "2"], " ", 
            RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["gammadot", "2"], " ", 
            RowBox[{"Sin", "[", "gamma", "]"}]}], "-", 
           RowBox[{
            SuperscriptBox["thetadot", "2"], " ", 
            RowBox[{"Sin", "[", "theta", "]"}]}]}], ")"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         RowBox[{"Cos", "[", "gamma", "]"}], " ", 
         RowBox[{"Sin", "[", "beta", "]"}]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"Cos", "[", "beta", "]"}], " ", 
         RowBox[{"Sin", "[", "gamma", "]"}]}]}], ")"}]}]}]}], ",", 
   RowBox[{"betaddot", "\[Rule]", 
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["betadot", "2"], " ", 
         RowBox[{"Cos", "[", "beta", "]"}], " ", 
         RowBox[{"Cos", "[", "gamma", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["gammadot", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "gamma", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["thetadot", "2"], " ", 
         RowBox[{"Cos", "[", "gamma", "]"}], " ", 
         RowBox[{"Cos", "[", "theta", "]"}]}], "-", 
        RowBox[{"thetaddot", " ", 
         RowBox[{"Cos", "[", "theta", "]"}], " ", 
         RowBox[{"Sin", "[", "gamma", "]"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["betadot", "2"], " ", 
         RowBox[{"Sin", "[", "beta", "]"}], " ", 
         RowBox[{"Sin", "[", "gamma", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["gammadot", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "gamma", "]"}], "2"]}], "+", 
        RowBox[{"thetaddot", " ", 
         RowBox[{"Cos", "[", "gamma", "]"}], " ", 
         RowBox[{"Sin", "[", "theta", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["thetadot", "2"], " ", 
         RowBox[{"Sin", "[", "gamma", "]"}], " ", 
         RowBox[{"Sin", "[", "theta", "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Cos", "[", "gamma", "]"}]}], " ", 
           RowBox[{"Sin", "[", "beta", "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", "beta", "]"}], " ", 
           RowBox[{"Sin", "[", "gamma", "]"}]}]}], ")"}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371770964003`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["accels = accsol/.velsol;", "Input",
 AspectRatioFixed->True],

Cell["\<\
accels gives us gammaddot and betaddot in terms of theta, its derivatives, \
gamma, and beta.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
accc = 2L(-Sin[beta] i + Cos[beta] j)betaddot + 
       L(-Cos[beta] i - Sin[beta] j)betadot^2 \
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["betadot", "2"]}], " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "-", 
    RowBox[{"2", " ", "betaddot", " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", "betaddot", " ", 
     RowBox[{"Cos", "[", "beta", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["betadot", "2"], " ", 
     RowBox[{"Sin", "[", "beta", "]"}]}]}], ",", "0"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371838199997`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["Eliminate betaddot and betadot", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
accofc[the_,thedot_,theddot_] :=
      Module[{xbeta,xgamma,xvelsol,xaccels},
      xbeta = bet[the];
      xgamma = gam[the];
      xvelsol = velsol/.{theta->the,thetadot->thedot,
                         thetaddot->theddot,beta->xbeta,
                         gamma->xgamma};
      xaccels = accels/.{theta->the,thetadot->thedot,
                         thetaddot->theddot,beta->xbeta,
                         gamma->xgamma};
      accc/.{theta->the,thetadot->thedot,thetaddot->theddot,
             beta->xbeta,xvelsol[[2]],xaccels[[2]],
             gamma->xgamma,xvelsol[[1]],xaccels[[1]]}]
\
\>", "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
acc1 = Table[accofc[theta,1,0]//N,{theta,0,360 Degree,5 Degree}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9999999999999922`"}], ",", 
     RowBox[{"-", "4.157609203101504`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6.330635645563986`"}], ",", 
     RowBox[{"-", "3.0655573200039994`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.881294483142105`"}], ",", 
     RowBox[{"-", "0.5746175929485664`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "8.672925115436167`"}], ",", "1.416617743486345`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.201771211431959`"}], ",", "2.2928848565349997`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.580148606835091`"}], ",", "2.3668713931718477`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.233475722054173`"}], ",", "2.0665687613630848`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.2208546572826915`"}], ",", "1.6571704379352825`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.4830095353639385`"}], ",", "1.2594717669349562`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.9453697055340053`"}], ",", "0.9155323959054418`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.5473319244490078`"}], ",", "0.6326815454837961`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2454838472383805`"}], ",", "0.40542891402032555`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.0101322962912331`"}], ",", "0.22490797868791326`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.8212695279726843`"}], ",", "0.08247335243148476`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.665430073612604`"}], ",", 
     RowBox[{"-", "0.029186377371789668`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5335094780583285`"}], ",", 
     RowBox[{"-", "0.11590392183109066`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.4193135931300678`"}], ",", 
     RowBox[{"-", "0.18221718973897982`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.3186064002085854`"}], ",", 
     RowBox[{"-", "0.23162843196547767`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.2284844765870551`"}], ",", 
     RowBox[{"-", "0.26684752631714725`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.14696252210601218`"}], ",", 
     RowBox[{"-", "0.28999346612996174`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.07269506900781816`"}], ",", 
     RowBox[{"-", "0.30275247240427805`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.004786472090261131`"}], ",", 
     RowBox[{"-", "0.30649890934788687`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.05734144209096495`", ",", 
     RowBox[{"-", "0.30238653711612423`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.11404374437730694`", ",", 
     RowBox[{"-", "0.29141677692354806`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.16552152054333574`", ",", 
     RowBox[{"-", "0.2744892490961295`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.21187401620638`", ",", 
     RowBox[{"-", "0.25243848690626336`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.25313918811404085`", ",", 
     RowBox[{"-", "0.22605961927950513`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.28932610977019374`", ",", 
     RowBox[{"-", "0.19612498739590828`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.32044136234483234`", ",", 
     RowBox[{"-", "0.1633930948954577`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.34651062692579077`", ",", 
     RowBox[{"-", "0.12861095595148397`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.36759605968632275`", ",", 
     RowBox[{"-", "0.09251076363296468`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3838096118100919`", ",", 
     RowBox[{"-", "0.055801812698970416`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.39532221786754984`", ",", 
     RowBox[{"-", "0.019158729232707755`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "0.40236870140631503`", ",", "0.016792771359765007`", ",", "0.`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"0.4052483175450801`", ",", "0.051491218599386795`", ",", "0.`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4043210434972408`", ",", "0.0844543490757727`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.4000000000000001`", ",", "0.11529227073966272`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3927406880965489`", ",", "0.14371759428497366`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.38302799954311884`", ",", "0.16955163773315324`", ",", "0.`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.37136215297400804`", ",", "0.19272626705859203`", ",", "0.`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3582447858794196`", ",", "0.21328145056364872`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3441663820818729`", ",", "0.23135910366511367`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.329596050510141`", ",", "0.24719421923891344`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3149744307122401`", ",", "0.26110456925117986`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.300710234791145`", ",", "0.2734804095869551`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.28718069866208423`", ",", "0.2847756361875213`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2747360566548556`", ",", "0.29550176700744546`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2637081115825364`", ",", "0.3062260171341178`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2544230778052182`", ",", "0.3175746557579543`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.24721915584248488`", ",", "0.33024284383200014`", ",", "0.`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.24246979178095657`", ",", "0.34501230519766973`", ",", "0.`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2406143477841256`", ",", "0.3627785317383599`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.24219907654681455`", ",", "0.3845898121796923`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.24793305304650698`", ",", "0.411701249269027`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2587664118463658`", ",", "0.4456481228300856`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2760024353711833`", ",", "0.488344446142732`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3014616761672155`", ",", "0.5422141720548445`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3377268939205649`", ",", "0.6103636239385859`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.3885145688780494`", ",", "0.6968026790828195`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.45924571957120003`", ",", "0.8067147176254048`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.5579303639111508`", ",", "0.9467508490471728`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.6965395653245804`", ",", "1.1252572910342633`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.8931082337237191`", ",", "1.3521772148370141`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1748334845166055`", ",", "1.6379667330889556`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5821815378886137`", ",", "1.9899458909681655`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.1727416530020074`", ",", "2.402553984288465`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.0190795711860634`", ",", "2.8344665400182056`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.181876067976279`", ",", "3.162011641489202`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.611064750456538`", ",", "3.107704065014787`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.902401265743172`", ",", "2.2119376078842183`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.974200728390863`", ",", "0.1044376683168653`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.350371826364187`", ",", 
     RowBox[{"-", "2.657985615055933`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9999999999999996`"}], ",", 
     RowBox[{"-", "4.157609203101503`"}], ",", "0.`"}], "}"}]}], 
  "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371880476*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
acc2 = Table[accofc[theta,2,0]//N,{theta,0,360 Degree,5 Degree}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.999999999999969`"}], ",", 
     RowBox[{"-", "16.630436812406018`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "25.322542582255945`"}], ",", 
     RowBox[{"-", "12.262229280015998`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "35.52517793256842`"}], ",", 
     RowBox[{"-", "2.2984703717942656`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "34.69170046174467`"}], ",", "5.66647097394538`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "28.807084845727836`"}], ",", "9.171539426139999`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "22.320594427340364`"}], ",", "9.46748557268739`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "16.933902888216693`"}], ",", "8.266275045452339`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "12.883418629130766`"}], ",", "6.62868175174113`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "9.932038141455754`"}], ",", "5.037887067739825`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "7.781478822136021`"}], ",", "3.662129583621767`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "6.189327697796031`"}], ",", "2.5307261819351843`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.981935388953522`"}], ",", "1.6217156560813022`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "4.0405291851649325`"}], ",", "0.899631914751653`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.285078111890737`"}], ",", "0.32989340972593906`", ",", 
     "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.661720294450416`"}], ",", 
     RowBox[{"-", "0.11674550948715867`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.134037912233314`"}], ",", 
     RowBox[{"-", "0.46361568732436265`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.677254372520271`"}], ",", 
     RowBox[{"-", "0.7288687589559193`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2744256008343415`"}], ",", 
     RowBox[{"-", "0.9265137278619107`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.9139379063482204`"}], ",", 
     RowBox[{"-", "1.067390105268589`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.5878500884240487`"}], ",", 
     RowBox[{"-", "1.159973864519847`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.29078027603127266`"}], ",", 
     RowBox[{"-", "1.2110098896171122`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "0.019145888361044524`"}], ",", 
     RowBox[{"-", "1.2259956373915475`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.2293657683638598`", ",", 
     RowBox[{"-", "1.209546148464497`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.45617497750922775`", ",", 
     RowBox[{"-", "1.1656671076941922`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.662086082173343`", ",", 
     RowBox[{"-", "1.097956996384518`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.84749606482552`", ",", 
     RowBox[{"-", "1.0097539476250534`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0125567524561634`", ",", 
     RowBox[{"-", "0.9042384771180205`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.157304439080775`", ",", 
     RowBox[{"-", "0.7844999495836331`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2817654493793293`", ",", 
     RowBox[{"-", "0.6535723795818308`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.386042507703163`", ",", 
     RowBox[{"-", "0.5144438238059359`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.470384238745291`", ",", 
     RowBox[{"-", "0.3700430545318587`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5352384472403675`", ",", 
     RowBox[{"-", "0.22320725079588166`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5812888714701994`", ",", 
     RowBox[{"-", "0.07663491693083102`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6094748056252601`", ",", "0.06717108543906003`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6209932701803205`", ",", "0.20596487439754718`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6172841739889632`", ",", "0.3378173963030908`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.6000000000000003`", ",", "0.4611690829586509`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5709627523861955`", ",", "0.5748703771398946`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5321119981724753`", ",", "0.678206550932613`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4854486118960322`", ",", "0.7709050682343681`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.4329791435176784`", ",", "0.8531258022545949`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3766655283274916`", ",", "0.9254364146604547`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.318384202040564`", ",", "0.9887768769556537`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.2598977228489605`", ",", "1.0444182770047195`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.20284093916458`", ",", "1.0939216383478203`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.148722794648337`", ",", "1.139102544750085`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0989442266194225`", ",", "1.1820070680297818`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0548324463301455`", ",", "1.2249040685364712`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.017692311220873`", ",", "1.2702986230318172`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9888766233699395`", ",", "1.3209713753280006`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9698791671238263`", ",", "1.380049220790679`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9624573911365024`", ",", "1.4511141269534396`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9687963061872582`", ",", "1.5383592487187692`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.9917322121860279`", ",", "1.646804997076108`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.0350656473854631`", ",", "1.7825924913203424`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.1040097414847332`", ",", "1.953377784570928`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.205846704668862`", ",", "2.168856688219378`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.3509075756822595`", ",", "2.4414544957543436`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.5540582755121977`", ",", "2.787210716331278`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.8369828782848001`", ",", "3.2268588705016192`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.2317214556446032`", ",", "3.787003396188691`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.7861582612983216`", ",", "4.501029164137053`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.5724329348948762`", ",", "5.408708859348057`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.699333938066422`", ",", "6.551866932355822`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.328726151554455`", ",", "7.959783563872662`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8.69096661200803`", ",", "9.61021593715386`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12.076318284744254`", ",", "11.337866160072823`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"16.727504271905115`", ",", "12.648046565956808`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22.44425900182615`", ",", "12.430816260059148`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27.609605062972687`", ",", "8.847750431536873`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"27.89680291356345`", ",", "0.4177506732674612`", ",", "0.`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"17.401487305456747`", ",", 
     RowBox[{"-", "10.631942460223732`"}], ",", "0.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3.9999999999999982`"}], ",", 
     RowBox[{"-", "16.63043681240601`"}], ",", "0.`"}], "}"}]}], 
  "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371899040003`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"SpreadSheetForm", "[", "x_", "]"}], ":=", 
  RowBox[{"StringReplace", "[", 
   RowBox[{
    RowBox[{"StringReplace", "[", 
     RowBox[{
      RowBox[{"ToString", "[", 
       RowBox[{"Column", "[", "x", "]"}], "]"}], ",", 
      RowBox[{"\"\<{\>\"", "\[Rule]", "\"\< \>\""}]}], "]"}], ",", 
    RowBox[{"\"\<}\>\"", "\[Rule]", "\"\< \>\""}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
gam[0]/Degree//N
bet[0]/Degree//N
Plot[{gam[theta Degree]/Degree,bet[theta Degree]/Degree},
     {theta,0,360}]\
\>", "Input",
 AspectRatioFixed->True],

Cell[BoxData["82.81924421854173`"], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371957384*^9},
 AspectRatioFixed->True],

Cell[BoxData["97.18075578145829`"], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371957539997`*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xk4VG8bB3BbJWtKJKUNpUVl32bma9+3mbHOjJCyJGLOTFqQZIkSRWlD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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xk4VN8fB3BRESlbSaREVCr7vr3tuxlbyDYzhJTlzowhS4siSYpoU1GI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 40.},
  PlotRange->{{0, 360}, {28.95502514592429, 151.04497176802258`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184371958008003`*^9},
 AspectRatioFixed->True]
}, Open  ]]
},
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 116, 2, 29, "Text",
 Evaluatable->False],
Cell[676, 24, 202, 12, 184, "Input"],
Cell[CellGroupData[{
Cell[903, 40, 159, 7, 99, "Input"],
Cell[1065, 49, 739, 21, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1819, 73, 165, 5, 29, "Text",
 Evaluatable->False],
Cell[1987, 80, 48, 1, 31, "Input"],
Cell[2038, 83, 105, 2, 29, "Text",
 Evaluatable->False],
Cell[2146, 87, 420, 10, 65, "Text",
 Evaluatable->False],
Cell[2569, 99, 679, 21, 337, "Input"],
Cell[3251, 122, 107, 2, 29, "Text",
 Evaluatable->False],
Cell[3361, 126, 79, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[3465, 131, 147, 4, 48, "Input"],
Cell[3615, 137, 637, 23, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[4267, 163, 89, 2, 29, "Text",
 Evaluatable->False],
Cell[4359, 167, 118, 4, 48, "Input"],
Cell[4480, 173, 94, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4599, 179, 188, 5, 65, "Input"],
Cell[4790, 186, 708, 20, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[5535, 211, 126, 4, 48, "Input"],
Cell[5664, 217, 1481, 44, 49, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[7160, 264, 98, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7283, 270, 323, 8, 116, "Input"],
Cell[7609, 280, 1386, 38, 55, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[9032, 323, 133, 4, 48, "Input"],
Cell[9168, 329, 3633, 96, 99, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[12816, 428, 66, 1, 31, "Input"],
Cell[12885, 431, 163, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[13073, 440, 145, 4, 48, "Input"],
Cell[13221, 446, 587, 18, 33, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[13823, 467, 92, 2, 29, "Text",
 Evaluatable->False],
Cell[13918, 471, 649, 16, 252, "Input"],
Cell[CellGroupData[{
Cell[14592, 491, 114, 3, 31, "Input"],
Cell[14709, 496, 9235, 249, 240, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[23981, 750, 114, 3, 31, "Input"],
Cell[24098, 755, 9151, 248, 221, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[33264, 1006, 423, 11, 31, "Input"],
Cell[CellGroupData[{
Cell[33712, 1021, 161, 6, 82, "Input"],
Cell[33876, 1029, 131, 3, 30, "Output",
 Evaluatable->False],
Cell[34010, 1034, 135, 3, 30, "Output",
 Evaluatable->False],
Cell[34148, 1039, 19379, 326, 231, "Output",
 Evaluatable->False]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

