(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     43480,        958]
NotebookOptionsPosition[     41806,        897]
NotebookOutlinePosition[     42362,        919]
CellTagsIndexPosition[     42319,        916]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

Swinging the Trebuchet Projectile.
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

The following input defines some constants.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell["\<\

L = 1;

DD = 2;

g = 9.81;

thetadot = 10;

thetanot = -30 Degree;

thetaend = 180 Degree;
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell["\<\

The following the the equation for Theta versus time.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell["\<\

theta[t_] := thetadot t + thetanot
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell["\<\

The following is time given Theta.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\

tt[theta_] := (theta-thetanot)/thetadot

tend = tt[thetaend];

tend//N
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell[BoxData["0.3665191429188092`"], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184372941696*^9}]
}, Open  ]],

Cell["\<\

The following two equations are from the equations of motion.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell["\<\

gamma[beta_,t_] := 90 Degree + theta[t] - beta

foverm[beta_,betadot_,t_] := 

      thetadot^2 DD Cos[beta] + 

      (betadot-thetadot)^2 L + 

      g Cos[gamma[beta,t]];
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell["\<\

The following is integrating the equation for Beta.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell["\<\

sol=NDSolve[{u'[t]==g Sin[gamma[beta[t],t]]/L - 

   thetadot^2 DD/L Sin[beta[t]],beta'[t] == u[t],

   beta[0]==-thetanot,u[0]==-thetadot},

   {beta,u},{t,0,tend},MaxSteps->1000];
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell["\<\

The first plot is theta versus time.

The second is beta versus time

Third is beta versus theta.

Last is F/m versus theta.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\

Plot[theta[t] 180/Pi,{t,0,tend}]

Plot[foverm[Evaluate[beta[t]/.sol],

        Evaluate[u[t]/.sol],t],

\t{t,0,tend}]

Plot[Evaluate[180/Pi beta[tt[thet Pi/180]]/.sol],

\t{thet,thetanot 180/Pi,thetaend 180/Pi}]

Plot[foverm[Evaluate[beta[tt[thet Pi/180]]/.sol],

\tEvaluate[u[tt[thet Pi/180]]/.sol],

        tt[thet Pi/180]],

\t{thet,thetanot 180/Pi,thetaend 180/Pi}]
\
\>", "Input",
 PageWidth->Infinity,
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVznk4lAkcwHFUOtb9sMgVKxk6SJZpmn6/JemikiNpHoaZt1FKtBrEot2y
rUT7lNgI2UWUGsdkJfMicjSTmfDK0ehAxyaxNaLMtn98n8+/X8vQSB+umoqK
itfX/lc/KWWKpoMbdyqNapVKJmkVOhK4MdYMflwibD35jkmaXmAaz/FXQY7B
np4FciZpfOPV9BCfCaP26ZPfNDDJ7L9FL8V8L/hpr+oqowQmSYnKhlv4LCgX
vCp0mN5AKtwKBhv5h2Expy6NPcEgU+df7hfxE6GpLSi4eZhOVk2/l8yrOQdB
so+e93jOZO596b6sh1kQVqF158IGR1I8fHfaxeIKPFF7fLFymx3Zxy5f1KBe
BG40D1fhQUvS24Thb1lXDNqv/OSCTXpkHt3yaU99GWRpFQzrM6pFz+d2qUqv
V8AlDXrLop26aKgeKji9UgCyEpV+uXwZ2olak73sqkBja7WEbKchmoon1qnX
gNDKJUBVyxGlO2LLRX1CeErztltt5YySm5L5U7JaGJ3QqDfLoKNE2Dq3ubwO
4ke8m5m3mMiYCL/kXl4P/+7I3aRj8AN+90UQ/7ywAcrsV+ekerrjQspLuZtB
gm1hiq2hrwdWbsnOPE1vhIyPtoaL0j0x+KxTdKdNEzQ9O4+6BVvRLdy66MWK
ZpBXeLefkG/H5zcPxO20vgdJSaXuEfreeKptNr9DuwWiptgJdbq7kBU/YrBU
uxWWXso5HblmN7rMWQzGfWkFG/W1FQ7rfVDy5rqn/dh9OKbIllTDHsyNzlAT
vGiD6r5rV8KDfPFQZ5Omp7Qd9p8yOWvH8cOjd7fzBNIOUFi60Ex/9kcn4xW8
w+JO6EZLUVduACo276ml1z4APfuI6PNFe3FSsyegXyiGbQvYPSfJQBwvLvFM
+1MCI2VCv+SOfVh67cFgevpDEMn6JfgwCB9cLQpZ69EF516XKhxf78eWwMWz
y+90QbOYYq6ZZGHgkPHdeQwpjBfccmLpBON4u09JeKUURBYxRZ2aIRj6Zh0n
doUMbBziaB2ZIRj1uHFLVLEMzrj6LHxqzsYUB77fpOkjyCsemEosYuNKX+oM
K+8RVGisd3VyCkXh9eHMKJNueFKlnN5KhiIe0SM1z3dDAxnTNuoehtzP499e
0OmBP1rId5dlYZg2NXXxamoP0Bzql1MBHMy0uDoW+LkHqAHzvmP9HHQwmg2Z
je+FlCT/Z7Y8LkrjEtSWv++FwV83zob9w8VdOTaF66Z6gX551aHKcS5Kartg
04deyLphOqDynosdCuvEsE+94CWbqcv7wMXmGLGiUJWCBpPb8dQcF2uizN+a
61GQX7FmZpsugTnhJGXkREFY97JPjt8TaHTm4HFbZwoaR7XDk10JzCrVN3B1
ocDs01yfZD2Bv4/xfAIYFDwyG6o9BASmcXXFF90p8DiQE/vXFgIT2aFNer4U
2MzoThsFEfg5WYNt5U/BLxqqvAMsAuMLhErHvRTIzSeommACj8uXMHfvpyDb
XXLbh0NgJKvqdgaHgsXpv/HPHiZwPIHln09QQOTHjfVHEhiRu/BDBe/rn4AX
QIsmkDcQtFYSQUF872aX1uMEjs4skA4doaD3pXOJfhyBnKW3It8epcBx1tow
7ASBz+j7tL5EU5CuqZ8qSCSQHTj/hkYMBW8s5imUSQT+B80fWBc=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{0, 21 Degree}, {-29.999995714285713`, 179.99999571428575`}}, {{
     0, 0.3665191429188092}, {-29.999995714285713`, 179.99999571428575`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184373020632*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Hk41N8XB3BJqBCSsgshe1GSdG5S2UKSEEpms6WUaLEbKVuyRfY9yZKS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 200.},
  PlotRange->
   NCache[{{0, 21 Degree}, {159.2583683241105, 688.3231347157935}}, {{
     0, 0.3665191429188092}, {159.2583683241105, 688.3231347157935}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184373021099997`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1nk4Vd33AHAzRQNRIgmVMfPMzeIO57iXOxkTZby8UUqDSCqVuVSGQplJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{(-5400) Degree/Pi, 32400 Degree/Pi}, {-48.452952558499334`, 
     41.595703308089966`}}, {{-30.000000000000004`, 
    180.}, {-48.452952558499334`, 41.595703308089966`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184373021256*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Hc8Ve8fAHA72WTvPbOJEj4iCdmuzeWec+/NSoooZV5pSEMZIVmJkhUV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 200.},
  PlotRange->
   NCache[{{(-5400) Degree/Pi, 32400 Degree/Pi}, {159.25836832411048`, 
     688.3231347157935}}, {{-30.000000000000004`, 180.}, {159.25836832411048`,
     688.3231347157935}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184373021879997`*^9}]
}, Open  ]],

Cell["\<\

The following produces a column of numbers which will be imported to a \
spreadsheet for 

plotting.  First column is theta in degrees, second is F/m third is beta in \
degrees.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 AspectRatioFixed->True],

Cell["\<\

Note that the output is suppressed. There is no reason to print a bunch of \
numbers unless you plan to copy them somewhere.
\
\>", "Text",
 Evaluatable->False,
 CellHorizontalScrolling->False],

Cell[CellGroupData[{

Cell["\<\

MatrixForm[Table[{

  180/Pi theta[tt[thet Pi/180]]//N,

  (foverm[Evaluate[beta[tt[thet Pi/180]]/.sol],

    Evaluate[u[tt[thet Pi/180]]/.sol],tt[thet Pi/180]]//N)[[1]],

  (Evaluate[180/Pi beta[tt[thet Pi/180]]/.sol]//N)[[1]]

    },{thet,thetanot 180/Pi,thetaend 180/Pi}]];
\
\>", "Input",
 PageWidth->Infinity,
 CellChangeTimes->{{3.5184374821184*^9, 3.5184374928044*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"Table", "::", "itflrw"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Warning: In evaluating \[NoBreak]\\!\\(Floor[\\(\\(1 + \
\\(37800\\\\ \[Degree]\\)\\/\[Pi]\\)\\)]\\)\[NoBreak] to find the number of \
iterations to use for \[NoBreak]\\!\\(Table\\)\[NoBreak], $MaxExtraPrecision \
= \[NoBreak]\\!\\(50.`\\)\[NoBreak] was encountered. An upper estimate will \
be used for the number of iterations. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\
\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/itflrw\\\", ButtonNote -> \
\\\"Table::itflrw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.5184373060256*^9, 3.5184374403416*^9, {3.5184374824927998`*^9, 
   3.5184374942552*^9}}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 139, 7, 191, "Title",
 Evaluatable->False],
Cell[699, 29, 148, 7, 65, "Text",
 Evaluatable->False],
Cell[850, 38, 164, 16, 235, "Input"],
Cell[1017, 56, 158, 7, 65, "Text",
 Evaluatable->False],
Cell[1178, 65, 108, 6, 65, "Input"],
Cell[1289, 73, 139, 7, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1453, 84, 144, 10, 133, "Input"],
Cell[1600, 96, 129, 3, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[1744, 102, 166, 7, 65, "Text",
 Evaluatable->False],
Cell[1913, 111, 247, 14, 201, "Input"],
Cell[2163, 127, 156, 7, 65, "Text",
 Evaluatable->False],
Cell[2322, 136, 255, 12, 167, "Input"],
Cell[2580, 150, 229, 13, 173, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2834, 167, 444, 24, 371, "Input"],
Cell[3281, 193, 2245, 44, 231, "Output",
 Evaluatable->False],
Cell[5529, 239, 14329, 243, 237, "Output",
 Evaluatable->False],
Cell[19861, 484, 5925, 105, 238, "Output",
 Evaluatable->False],
Cell[25789, 591, 14275, 242, 244, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[40079, 836, 282, 11, 101, "Text",
 Evaluatable->False],
Cell[40364, 849, 204, 7, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[40593, 860, 412, 17, 235, "Input"],
Cell[41008, 879, 782, 15, 40, "Message"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

