(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     10876,        365]
NotebookOptionsPosition[      9374,        308]
NotebookOutlinePosition[      9930,        330]
CellTagsIndexPosition[      9887,        327]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\

A Rotating Mass and Spring.
\
\>", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 TextAlignment->Center],

Cell["\<\

Here are the two equations.
\
\>", "Text",
 Evaluatable->False],

Cell["\<\

e1:=-k(L[t]-lo)-m g Sin[157 t + thetao] == 

        m(L''[t]-157^2 L[t])

e2:=n[t]-m g Cos[157 t + thetao] == m 2 L'[t] 157
\
\>", "Input",
 PageWidth->Infinity],

Cell["\<\

Let's choose some values for the parameters.
\
\>", "Text",
 Evaluatable->False],

Cell["\<\

par:={m->1,k->157,lo->1,g->9.81,thetao->0};
\
\>", "Input",
 PageWidth->Infinity],

Cell["\<\

Numerically solve the equation for L[t].
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\

sol = NDSolve[{e1/.par,L[0]==1,L'[0]==0},

           L[t],{t,0,.01}]
\
\>", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"L", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "0.01`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False], "[", "t", "]"}]}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184376654091997`*^9}],

Cell["\<\

Define a convenient function for L and L'.
\
\>", "Text",
 Evaluatable->False]
}, Open  ]],

Cell["\<\

el[tau_] := (L[t]/.sol[[1]])/.t->tau

eldot[tau_] := el'[t]/.t->tau
\
\>", "Input",
 PageWidth->Infinity],

Cell["\<\

Plot L versus t.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"el", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "0.01`"}], "}"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Hk41NsfB/AZX9mSLGMfkaWibiGRpfl8K+tMZIspF8k+Cl371mC+t1K0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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 1.},
  PlotRange->{{0, 0.01}, {1.0000000000000007`, 2.505193760585787}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5184376694184*^9}]
}, Open  ]],

Cell["\<\

Solve for n[t].
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\

nans = Solve[(e2/.{L'[t]->eldot[t]}),n[t]]/.par
\
\>", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"n", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"9.81`", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"157", " ", "t"}], "]"}]}], "+", 
     RowBox[{"314", " ", 
      RowBox[{
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"0.`", ",", "0.01`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
         "]"}],
        False,
        Editable->False], "[", "t", "]"}]}]}]}], "}"}], "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184376716492*^9}]
}, Open  ]],

Cell["\<\

nforce[tau_] := (n[t]/.nans)/.t->tau
\
\>", "Input",
 PageWidth->Infinity],

Cell["\<\

Plot n[t] versus t.
\
\>", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"nforce", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "0.01`"}], "}"}]}], "]"}]], "Input",
 PageWidth->DirectedInfinity[1]],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxX08kwkcAHCqK0IvREeykqSuK6SUst+vq2Pe4qIIKZZi3uZtmQ0bz+fy
Eh2io5cTlxASlbaUHC11K5TsXF6GGCKRl/J46e6P7+e73ivosPcCOTk5u//8
v+nByWGO8pC5VuX81xU5G3C56cOsSuFz6uDyiRp7EaKuWy0vRthKVaAKyh/9
aYtbAyzD6MIBqs6c4rzY0BWNWIqBR4RfqduzLvBaJn2wInKQcUioCFK99vGe
YxE4PuM6YC3UBOkdf5PflOJRnZpuYCXcDMQapcvyvZdQIN+TQmswg2MmRXt+
bi5AVwOutt/gAVCjtk+2MsvxhSCiO8bWGrq17BQqjz9ArxSZd+IVBwjUdM7O
b3qMY8Jgi9sSR6D0HHqdEPQXWjYW7F7l4gzNYp8h46qnmPGvy4Z19a7QrXcp
OXK+Hic7ZezFs8dh/LDD1MsVYlSRrQzOfHgSRpKUrOX8G7DQjfJOw80Lkrty
Ny+1acIaa98axhgd/oDJvXvbXuO+0oQyj2Jv4EOeU/rFZsQLWW+raWfAK6Tt
RrZJC958H7OwZokvbK3R18yflWDi3dySjMcMuNZ3lf6lrhWn5O8lS5z9weF0
qOVU6DsU1V5lCdQC4bMozF5yqB0pC1kZCuVBYGwU2chd2YkBbmkdHAETfjFz
3mbEl2LC2DnD9oxg0NQZiBewu5BBC18bTg+BqVC3RyPe3cj95+Wy4z+FQpHT
YL6KXw86btK5zFENg7rbeT6v6O/Rp+J8b1xHGFxTS99xwb0XS9mnTdoehsOR
4moLA2YfCuZMdfwSWcBfNB8xy5LhxKMwZWvGWWhOuyW1y+7HIGHDA1WLCDCf
0e3VrR7A0nBdOVU1NvgpORL5LYOo4ye18RxlQ07VszwllSF0pGQay55EwvA7
XtGHncMoWsGQHD3PAR9uRnz/iY/I2FfI0/DlQup+H/0Tt0bwjb60Ttk0CprI
k+ctwz5hgE2siqNGNGyfdHe6qzeK4m3aow190aCs/2yf5OUo+to3p+2qiAEB
ZVvF6Nkx1H7LucKi8eB6WalN0M7P2OepaD58mwffpfar6n34jM+TxJ1K6/gg
drpennRvHG2ar3lSUvhgPFzIVIydwO0zQ4avxvnQoh5St9FiErfWMBdsPBUL
8SmvU1rXTWGSN3P9anEsqHWYhw2PTWGCQQxlzigOGms2/pot+oI58bWU5Jw4
cDeiFcjKv6JmfVxA5RICOH4HMtsypvHVqcZVhCIB19fYRkuzppGQX1vloETA
/Vp12fur0/jJ7P7SwWUEFEv27B25MY2ikv6b2hoEHM3rG1G8P40h6XbdfD0C
2DLZZeeWaRR7rHa23U/AqVzBOafVJMaS9LnvDxBQebO+xGcNiaa/l93oPUiA
arCycxSFxNwmq/FoGgFMFn9HwSYS2Qe5qXfsCZAbtNFYtJtE/S1df2t4EJDR
WX2x2YXENtGPoT0nCHghf2bqkzuJqfRIrTJPAgpLeB0qniTOXFHztfImwDDQ
zczKl8Q3yy0Wc/0JiLrXvkXEJjG+OK2EFkiA8i5aRV8UiVSrTid1JgGzWk+f
LIklsSg2Iq80lIDThhZ+NokknqQ8teaEE5DEClEITCFRvWrlmOVZAjxt5X9I
TSPxhYtH1io2Aca1i9/czSSRN1GEXZEEdH3MlGvNJvEbThlaOA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.01}, {0., 113069.56264394104`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5184376764072*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 132, 7, 191, "Title",
 Evaluatable->False],
Cell[692, 29, 74, 5, 65, "Text",
 Evaluatable->False],
Cell[769, 36, 173, 9, 133, "Input"],
Cell[945, 47, 91, 5, 65, "Text",
 Evaluatable->False],
Cell[1039, 54, 92, 5, 65, "Input"],
Cell[1134, 61, 87, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1246, 70, 118, 7, 99, "Input"],
Cell[1367, 79, 493, 17, 30, "Output",
 Evaluatable->False],
Cell[1863, 98, 89, 5, 65, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[1967, 106, 116, 7, 99, "Input"],
Cell[2086, 115, 63, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2174, 124, 206, 6, 31, "Input"],
Cell[2383, 132, 3622, 65, 240, "Output"]
}, Open  ]],
Cell[6020, 200, 62, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[6107, 209, 96, 5, 65, "Input"],
Cell[6206, 216, 656, 22, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[6877, 241, 85, 5, 65, "Input"],
Cell[6965, 248, 66, 5, 65, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[7056, 257, 210, 6, 31, "Input"],
Cell[7269, 265, 2089, 40, 228, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

