(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[      7808,        298]
NotebookOptionsPosition[      5999,        230]
NotebookOutlinePosition[      6555,        252]
CellTagsIndexPosition[      6512,        249]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Two Blocks Sliding Down an Incline.", "Title",
 Evaluatable->False,
 CellHorizontalScrolling->False,
 CellChangeTimes->{3.5184377621604*^9},
 TextAlignment->Center],

Cell["The following are the equations.", "Text",
 Evaluatable->False],

Cell["\<\
eq1 := fb Cos[theta] - nb Sin[theta] - nt Sin[beta] +
           ft Cos[beta] == 0;
eq2 := fb Sin[theta] + nb Cos[theta] - mb g - 
           nt Cos[beta] - ft Sin[beta] == 0;
eq3 := -ft Cos[beta] + nt Sin[beta] == 0;
eq4 := ft Sin[beta] + nt Cos[beta] - mt g == 0;\
\>", "Input",
 PageWidth->Infinity],

Cell["Here are some parameters.", "Text",
 Evaluatable->False],

Cell["\<\
ut = 1/10;ub = 1/10; g = 981/100; mb = 10; mt = 2; 
theta= 30 Degree; beta=15 Degree;\
\>", "Input",
 PageWidth->Infinity],

Cell["This is the solution.", "Text",
 Evaluatable->False],

Cell[CellGroupData[{

Cell["ans = Solve[{eq1,eq2,eq3,eq4},{fb,nb,nt,ft}]//N", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"fb", "\[Rule]", "58.86`"}], ",", 
    RowBox[{"nb", "\[Rule]", "101.9485105335041`"}], ",", 
    RowBox[{"nt", "\[Rule]", "18.95146471179152`"}], ",", 
    RowBox[{"ft", "\[Rule]", "5.0780296649114565`"}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377432532*^9}],

Cell["\<\
Check our assumptions. Is Nt positive, yep. What is maximum frictions?\
\>", "Text",
 Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
ftmax = ut nt/.ans
fbmax = ub nb/.ans\
\>", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", "1.8951464711791521`", "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377445792*^9}],

Cell[BoxData[
 RowBox[{"{", "10.194851053350412`", "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377445792*^9}],

Cell["\<\
Both frictions are violated. Start over. Bottom slides, top sticks?\
\>", "Text",
 Evaluatable->False]
}, Open  ]],

Cell["\<\
eq1 := mubk nb Cos[theta] - nb Sin[theta] - 
           nt Sin[beta] + ft Cos[beta] == 
           mb dddot Cos[theta];
eq2 := mubk nb Sin[theta] + nb Cos[theta] - 
\t   mb g - nt Cos[beta] - ft Sin[beta] ==
           mb dddot Sin[theta];
eq3 := -ft Cos[beta] + nt Sin[beta] == 
           mt dddot Cos[theta];
eq4 := ft Sin[beta] + nt Cos[beta] - mt g == 
           mt dddot Sin[theta];\
\>", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["mubk = 1/10;", "Input",
 PageWidth->Infinity],

Cell[CellGroupData[{

Cell["ans = Solve[{eq1,eq2,eq3,eq4},{dddot,nb,nt,ft}]//N", "Input",
 PageWidth->Infinity],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dddot", "\[Rule]", 
     RowBox[{"-", "4.055429078887466`"}]}], ",", 
    RowBox[{"nb", "\[Rule]", "101.9485105335041`"}], ",", 
    RowBox[{"nt", "\[Rule]", "13.216221907186636`"}], ",", 
    RowBox[{"ft", "\[Rule]", "10.81327246951634`"}]}], "}"}], "}"}]], "Output",\

 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377485727997`*^9}]
}, Open  ]],

Cell["\<\
Check our assumptions. Is Nt positive, yep. What is maximum friction?\
\>", "Text",
 Evaluatable->False,
 FontFamily->"Arial",
 FontSize->12,
 FontWeight->"Plain",
 FontSlant->"Plain",
 FontTracking->"Plain",
 FontVariations->{"Outline"->False,
 "Shadow"->False,
 "Underline"->False},
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell["ftmax = ut nt/.ans", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"{", "1.3216221907186636`", "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377504136*^9}]
}, Open  ]],

Cell["Another violation. Start over. Assume top and bottom slip.", "Text",
 Evaluatable->False],

Cell["\<\
eq1 := mubk nb Cos[theta] - nb Sin[theta] - 
           nt Sin[beta] + mutk nt Cos[beta] == 
           mb dddot Cos[theta];
eq2 := mubk nb Sin[theta] + nb Cos[theta] - 
\t   mb g - nt Cos[beta] - mutk nt Sin[beta] ==
           mb dddot Sin[theta];
eq3 := -mutk nt Cos[beta] + nt Sin[beta] == 
           mt dddot Cos[theta] + mt xddot Cos[beta];
eq4 := mutk nt Sin[beta] + nt Cos[beta] - mt g == 
           mt dddot Sin[theta] - mt xddot Sin[beta];\
\>", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell["mutk = 1/10;", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[CellGroupData[{

Cell["ans = Solve[{eq1,eq2,eq3,eq4},{dddot,nb,nt,xddot}]//N", "Input",
 PageWidth->Infinity,
 FontFamily->"Courier New",
 FontSize->12,
 FontWeight->"Bold",
 FontColor->GrayLevel[0],
 Background->GrayLevel[1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"dddot", "\[Rule]", 
     RowBox[{"-", "4.739652554741768`"}]}], ",", 
    RowBox[{"nb", "\[Rule]", "94.48425443327537`"}], ",", 
    RowBox[{"nt", "\[Rule]", "12.248583787939424`"}], ",", 
    RowBox[{"xddot", "\[Rule]", "5.278026104984805`"}]}], "}"}], 
  "}"}]], "Output",
 PageWidth->Infinity,
 Evaluatable->False,
 CellChangeTimes->{3.5184377531904*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 170, 4, 83, "Title",
 Evaluatable->False],
Cell[730, 26, 69, 1, 29, "Text",
 Evaluatable->False],
Cell[802, 29, 312, 8, 116, "Input"],
Cell[1117, 39, 62, 1, 29, "Text",
 Evaluatable->False],
Cell[1182, 42, 132, 4, 48, "Input"],
Cell[1317, 48, 58, 1, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1400, 53, 86, 1, 31, "Input"],
Cell[1489, 56, 388, 11, 30, "Output",
 Evaluatable->False],
Cell[1880, 69, 115, 3, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[2032, 77, 84, 4, 48, "Input"],
Cell[2119, 83, 151, 4, 30, "Output",
 Evaluatable->False],
Cell[2273, 89, 151, 4, 30, "Output",
 Evaluatable->False],
Cell[2427, 95, 112, 3, 29, "Text",
 Evaluatable->False]
}, Open  ]],
Cell[2554, 101, 553, 17, 184, "Input"],
Cell[3110, 120, 51, 1, 31, "Input"],
Cell[CellGroupData[{
Cell[3186, 125, 89, 1, 31, "Input"],
Cell[3278, 128, 427, 12, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[3720, 143, 347, 13, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[4092, 160, 174, 6, 31, "Input"],
Cell[4269, 168, 151, 4, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[4435, 175, 95, 1, 29, "Text",
 Evaluatable->False],
Cell[4533, 178, 615, 17, 184, "Input"],
Cell[5151, 197, 168, 6, 31, "Input"],
Cell[CellGroupData[{
Cell[5344, 207, 209, 6, 31, "Input"],
Cell[5556, 215, 427, 12, 30, "Output",
 Evaluatable->False]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

