(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    335737,       5955]
NotebookOptionsPosition[    332732,       5846]
NotebookOutlinePosition[    333336,       5869]
CellTagsIndexPosition[    333293,       5866]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Bungee Jumping Simulation",
 FontFamily->"Times",
 FontWeight->"Plain"]], "Subtitle",
 AspectRatioFixed->True],

Cell[TextData[StyleBox["First case: Linear Spring.",
 FontFamily->"Times",
 FontWeight->"Plain"]], "Subsubtitle",
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lu", "=", "25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"H", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", "32.2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m", "=", 
   FractionBox["200", "g"]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c", "=", ".2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"k", "=", "4"}], ";"}]}], "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"v", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["v", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{
        FractionBox["1", "m"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "m"}], " ", "g"}], "-", 
          RowBox[{
           RowBox[{"Sign", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], " ", "c", " ", 
           SuperscriptBox[
            RowBox[{"v", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], ">", 
             RowBox[{"H", "-", "Lu"}]}], ",", "0", ",", 
            RowBox[{"k", " ", 
             RowBox[{"(", 
              RowBox[{"H", "-", "Lu", "-", 
               RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], "]"}]}], ")"}]}]}], 
      ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], "==", "H"}], ",", 
      RowBox[{
       RowBox[{"v", "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "v"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "60"}], "}"}], ",", 
    RowBox[{"MaxSteps", "\[Rule]", "4000"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"v", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397053227997`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"yplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "\n", 
 RowBox[{"vplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWnc41e8bLoQiZUuUvedx9nBux6GMjLIrSklSRqFEVsMohSSpqG/aUVJk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 20.},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.518439706758*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8lf8X59p77z2zx8W1Pee6LpEiIkRpIJSVECoZmYVSSRJlRVkNQp4n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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397068048*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"yplot", ",", "vplot", ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWnc41e8bLoQiZUuUvedx9nBux6GMjLIrSklSRqFEVsMohSSpqG/aUVJk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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8lf8X59p77z2zx8W1Pee6LpEiIkRpIJSVECoZmYVSSRJlRVkNQp4n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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 20.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397088952*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Next case: Stiffening Spring.", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lu", "=", "25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"H", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", "32.2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m", "=", 
   FractionBox["200", "g"]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c", "=", ".2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"k", "=", ".1"}], ";"}]}], "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"v", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["v", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{
        FractionBox["1", "m"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "m"}], " ", "g"}], "-", 
          RowBox[{
           RowBox[{"Sign", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], " ", "c", " ", 
           SuperscriptBox[
            RowBox[{"v", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], ">", 
             RowBox[{"H", "-", "Lu"}]}], ",", "0", ",", 
            RowBox[{"k", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"H", "-", "Lu", "-", 
                RowBox[{"y", "[", "t", "]"}]}], ")"}], "2"]}]}], "]"}]}], 
         ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], "==", "H"}], ",", 
      RowBox[{
       RowBox[{"v", "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "v"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "60"}], "}"}], ",", 
    RowBox[{"MaxSteps", "\[Rule]", "4000"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"v", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397124519997`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"yplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "\n", 
 RowBox[{"vplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c81e8bxosKFRkZ2ZvsY559rnOMCl8Z2RIqCSHJioyiMkKLVFIaokGF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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 20.},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397140744*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81e8Xv+61957Ze+99r8+5MjJCVkRGGYlQSYqyRRRFS6KiEiGUWd0n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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397141212*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"yplot", ",", "vplot", ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c81e8bxosKFRkZ2ZvsY559rnOMCl8Z2RIqCSHJioyiMkKLVFIaokGF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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81e8Xv+61957Ze+99r8+5MjJCVkRGGYlQSYqyRRRFS6KiEiGUWd0n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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 20.},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397164611998`*^9},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Next case: Softening Spring.", "Subsubtitle",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lu", "=", "25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"H", "=", "100"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", "32.2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m", "=", 
   FractionBox["200", "g"]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c", "=", ".2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"k", "=", "1323.5"}], ";"}]}], "Input",
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"v", "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["v", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{
        FractionBox["1", "m"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "m"}], " ", "g"}], "-", 
          RowBox[{
           RowBox[{"Sign", "[", 
            RowBox[{"v", "[", "t", "]"}], "]"}], " ", "c", " ", 
           SuperscriptBox[
            RowBox[{"v", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], ">", 
              RowBox[{"H", "-", "Lu"}]}], "||", 
             RowBox[{
              RowBox[{"y", "[", "t", "]"}], "<", 
              RowBox[{"H", "-", "Lu", "-", "59.1"}]}]}], ",", "0", ",", 
            RowBox[{
             FractionBox[
              RowBox[{"k", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"H", "-", "Lu", "-", 
                  RowBox[{"y", "[", "t", "]"}]}], ")"}], "2"], " ", 
               SqrtBox[
                FractionBox[
                 RowBox[{"H", "-", "Lu", "-", 
                  RowBox[{"y", "[", "t", "]"}]}], "H"]]}], 
              SuperscriptBox["H", "2"]], "-", 
             FractionBox[
              RowBox[{"1.3", " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"H", "-", "Lu", "-", 
                  RowBox[{"y", "[", "t", "]"}]}], ")"}], "3"]}], 
              SuperscriptBox["H", "3"]]}]}], "]"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"y", "[", "0", "]"}], "==", "H"}], ",", 
      RowBox[{
       RowBox[{"v", "[", "0", "]"}], "==", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "v"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "60"}], "}"}], ",", 
    RowBox[{"MaxSteps", "\[Rule]", "4000"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"v", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "60.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{{3.5184397197684*^9, 3.5184397209695997`*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"yplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"y", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "\n", 
 RowBox[{"vplot", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"v", "[", "t", "]"}], "/.", "sol"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "60"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkHk01P0fxce+hTH2JUtJsswMWUPfN2MJDVowPJWQIlt2yb6kRCGKIU8J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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397227167997`*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13c8ld8fAHArGZHszeW6Ntnr3vt8zAohRVSkIhnZKRFCJTMlRGlHiawG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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397227324*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"yplot", ",", "vplot", ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVkHk01P0fxce+hTH2JUtJsswMWUPfN2MJDVowPJWQIlt2yb6kRCGKIU8J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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13c8ld8fAHArGZHszeW6Ntnr3vt8zAohRVSkIhnZKRFCJTMlRGlHiawG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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  GridLines->Automatic,
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397246512003`*^9},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of spring functions", "Subsubtitle"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soft", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"k", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], " ", 
         SqrtBox[
          FractionBox["x", "100"]]}], 
        SuperscriptBox["100", "2"]], "-", 
       FractionBox[
        RowBox[{"1.3", " ", 
         SuperscriptBox["x", "3"]}], 
        SuperscriptBox["100", "3"]]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "59.1"}], "}"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0VV8bB3DzVFKGyJQpUZm5Rxn2495zrytuZShTKDKGDJHkp5QpiUSR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 59.1}, {0., 23.875344217518837`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397275372*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"linear", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{".5", " ", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "60"}], "}"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtzG9M1HUAx3EGD4Q2HIKMk0CHHETIcRzgHXfcl9/nPDy60y8zCxtNU/5c
+QB1+QeLzRDmBJU5BTVi5fR2sxJFZGhKJuxsFW3lQPQuWlhabZnJXfzHOcTd
58F7r2fvpPId652hISEhcr4XTo70f6s+0l0Q1F0wdFr1ocXXrAStVxB7u1zl
c9FmpXrdeW+Yr4u6lEVP4ppnvB7apdy/Ubxj3DtIPYpN/ei3gPcBHVRmvIaT
fu//9IFyy/q5e8AVhqBjSsL963+XZ0Qi6DNlcdXm8wusMQgahmad7eviEhUN
xy+tWX2BqEQaiSPu2tuhS5LoIsSdeHio5bNkGoOGN+0Fg5MpNBa7jGc399en
URUKR2drtj9Mp/GoM79eFp+noYkwdXzS/VGvli5D1XRg/w+ROpqEmRVRI5qS
bLoc5vYLZ06dyqHJCEQ7tmzw5FI1/mzasmHnAj1NhX10r/0vvYG+gscV4bu6
a/NoGmzquNAGj5G+iuifUo92jppoOhIaL63T6800A60rjFEx7wmqwY/xlpVj
xwtoJkwJnmPaewrVYmGYa3dZPWgWltYtM5emWqgOESkbr67/3kJ1yBRLLu3d
tIpmY+dI9C1HiJXmYHSsqcTeaqU5KNJ+12bXFNJc3BzLfzr1cyHNxfaM7OEB
52q6EuJJ5VBphI3qsVqtkpEuG9Ujbf/hDzyGImpAutPYmzJcRA1w3tx6oPv9
12gees8MVQZi7dSI8S/mprRf2akRFSntEW3SQU0IpLfou/wOasI199M/JhrX
0Hy8XZiM/KVrqRkvb2u4ntm3lpoR+1LVZfmWpAJu674af6mkAtn7jlpbNkoq
UOzvvOsrk1Tg4L2JmYoqSQWmXbWrauokFRjOb7lzrl1Sga173J/aOyQVmOy4
4nzcKalA9HLflO6qpAJrwhMTvumTVODG0LnKO3clFXAsvKap9kkq4Cvqn1T9
KqnAeM+/je/8LqmA5mzWxX8eSTr/G7ZUN/0n6fxv8RuK1i+pwLsNewZ2T0g6
/+s72BY3LalA/ezHFT2zkgpE5X6ZsemZpAKnt/VMzM1JKvAcEg0tFw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 60}, {0., 29.999999387755103`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397293780003`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlinear", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{".01", " ", 
     SuperscriptBox["x", "2"]}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "60"}], "}"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzHk81IkbwHHSFJUWkxyRraXDTTEIzzNu8rVTi9CBUCpXOZNjHEvlqCgx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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 60}, {0., 35.99999853061227}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397305324*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"soft", ",", "linear", ",", "nlinear"}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0VV8bB3DzVFKGyJQpUZm5Rxn2495zrytuZShTKDKGDJHkp5QpiUSR
yFCGJCREKFSmRCTKPIUmhEiG3vP+dddnrbPO2s/e3+fZ50o7njFzZmFiYgpk
ZmL6/++xVN18A90y/dr77TmzDkG6RlBpMRF/E0lkqIZFM+7rv5/VHKiOz0YM
d+0JPZG3+hde8sZF9D5Cqlu+9UvGj+knGi5k5MWXopF0z/TJxXl9t+LhoFiN
Z4jeveVabggT0hduM/XtrUYQMH95eoobxaDjQo/06pC2uvTj0BV+FODfFZYe
34DKwTmmyVUUncijz8SPvkafxb03vy+QRgf7X9hc1mhCsR30E6I/5JEWn1bT
2YgWxHTAbzWfWQlJUR5puPa+RaZ0CW6Xv2po0znpTGvFdmQ+2riiMKWFLnw0
5sjVe4/qXghcMTY+gHxmI3UzXDqR0D6SfcsehFy4G/xS4rtQR21nfCVORsdl
1/MTKj8giVetR89qUZGpnvZwzGg36qnd+5+VOx3RLP2Fwnl60DE++XzBMWOk
61tk/J9GL1pysWYxyjqM1K59DQs8/gkNTP1+Tuk2RfI5cpVnIj6j0RMqdgVr
5mjb51Q5x95+ZPIjiafqhRXiWPhoY8s0iLTu+dU1W9uitc3bEiwUh5DMSsTU
GXF75J/5KvS+3gjacsN2PI7XEXkrje6Q6hpB7r7ukhqFTsjt+UZZmssosn3P
s/mLgzOy797//Vb8GGp8N7n/Hqc7sj5pGckvN45iotTUsDUPZDFzVjq+chzR
eu/6M3N6ISOuEsvo0QmkpbqrS6LEB+G33s2zBX5BdrO73FJ6fZG+zPfrYTyT
SIZX9FcJjz/S1JV/HawxhVQ6HpbuTwpAyi0Uh+WmKdQkJXdw6lsgUjx28q//
8Wn0wl//3mNGEJL0SVP1iviKrtepTv7BLiDuB/zpDr3fEcf6cCOj8xJiU1PV
Hjj9A7GXFVjcLApDG7WMD1ZMP9Gyg7Ok6c3LaLE3mttMcQa1ezjMn/EKR7MR
/w5k682hlRbRnVf9o5GnSVz0SNQcKuDzSlmOuIq+8Uv0SHbNoZj6oEOQEYMm
Mg743nX5hapiLNdiJ2NRX1VAXlL8PAqSMuTJmriBJOLEC7aNzKO1HdqN08kJ
6ITjq8I41QU09demy/3wTTTJs600unMBXamMEVR7m4jmbQtrQgR+o7Gi67kX
l24T+2b+csXpNzqbu/FXry0ZBbH9rQ8s+422KErXOOemoI1Cwyafo0uodXB0
mdMtFfFsjHWeSl5GuRViyqrS9xCj62r36NQy+vHMzPyDaAa6kavaa6/9B0Xz
rZ+O2JyJth8OHbD6/AfJmt2Kz9mWhWQyd0yZiP1FdiD3ow27j3TIR9Y0M9bQ
r9zQ8YbfeSh0+/LGk9k1lHmXudwiJR81fEtnVoF1xCl7zeOo3kNET/zOoTi6
jraJvS9/FFeALCYit0nI/kOHZq/3jh96jEiv7BMvf2CCpymrp5PvP0FWSqWC
9atMoJB5Tr2NqxSdT2a//U+WGfiCi4IMz5SimtOFKSFnmWEQFKYE4SkiC/5N
DxRiAVNms7Myv8rQIedb+R6WrMB91ORpVUIlMlmSPbMRwgpKnVbcyaxVyCiq
VOtmNit8LbYYuBtYhfCHHQ1VP1lB4L40LnniOdL5yT3IFc4Ge7oMOoUMapBC
QOi2vBJ24Kv1Mn8gUYfkOXg/Hehhh5Ny9OezDnVILvnuvfZVdjBvV9j5IbsO
7ayq3LtE4wClElKf4556tH19nkod5ICfSseeFkIDYo1wDR7n5gIbg8oW8ZjX
iGn7EpxT4QIn67Fy1p7XaCM3nHPTUS4o3HpTI1LmDfrbnJWknskFqWpHn9rX
vkFzmweKwkjcgD9IMnf624iGko6M73TigdaJiFdfElpQ5YP9JsdrNsPtSOYA
bu0O9M1U0kFjdDOMpP9m7r/VgcT+sfjxcPACVpFmZ7jYgUKt25IrD/NCpoBl
eJD1e0TZ4jAuOM4LusIxk2/EOlH7ufDgd9x8YJU46LBe1IX8clwtMh5thaSD
TgL41h60ae3zIM+LreDejbMs03vQAzMT18D3W8HazU9sJawHffynGsz4vRWy
Le1Wvi32IG2bvxmr+tsgzlAmMXKoF61vuf7dsmsbGJ2/jOXWfUbRQaWXt67w
g/d5a6GmukF0s8ujahOvADheSyaLcw+htH2ycxzSApCwa3Wiw3QIlYwk2q3T
BaBzp0CB2cQQ+kwP0P6WIgAv+oujxzlG0J4d2jOvtAXBbOXvO+39o6itqtb6
XJAQnLeYd7hQP474VptVh5aF4bbOhnD9ia8oelqSJ5xHBK77Lzfcvv4VMfWc
HVeUEIGCrpTJW8+/orkSqdsBZBEIi+a/tVXoG3rvErS6+boIVG50By2//Uas
d3ejjswOeO3heDnG4AcSKoi0vWMiCj1eL6xqjGeRmDUeaZElDobajMzZn/OI
7eDI5phycWB3itv2YdMCmjkQkviyRRy+Cn273q64gBrEyzL3zItDuJV4Bq/L
AnIbka1mokgAc9yuiUfDC6jMlXWucEICBrP/TLv0LqJDgQ3W7Ao7oSWlhffN
pyVUb5S53bZXCt4lqipflFlFqnsuFYOZLJA7To8+YrDAySD+tODsXXA2hE88
wJwTXmo6qxXIKQAl9l7tyileGLH3EFUO2QNnvR5J673bBromnc2TTftATpBd
SUVQCBrz/uy8RVWBabUZq49DInBV2/2LcZsqpBoLj91IFQeaBYmveYs6fO4a
rknykIJM07K79sYaoHtRPsMqQQYGIjaZZfhpgjMtOcs2Uw6UfzUM9JVqgRyr
GohMyoNjonlC3SAJHJeb0HEeRSj0xEWzpLWhKPrd10N2eyFp9yR7msN+YPlj
GUnKUgK7HSfFDKIPQMBr1rPt5SqgR9ZlH23RgT9VynKBi6qwkTUnsndJF3R1
hs6ozquB3fjR+HhxfQjP0GJsGlGHLluxvhlbBCfr+yspHzQgid1u9xoZYH7v
HY2POZrwNmjAOHQCgNVVuc80QAs6j5dl8V4xANk+Rw5pRRK0ezto2EUYgPXG
a3r8XhK0XeJ5UxhlAH+f3xFeUyJB84MT08axBlAgo2LVqU6Cuh+bVWJuGYDp
XiELD10SFIU413DkG8BNmkDx0cMkiE3b3vuvzQDoerdKec+SwHAgaPP8djJ4
FIgOj1SSoKyoLdF/BxkqBTVKdlSTQCpMSuy3GBnS0s/dO1JLgj+7mhX/SJFB
p825o7KeBPlnhA039pDBf3zF06+VBFysFWE8iAxCoutTV/uJ9SkuLMm4kmHX
oq8TvkYCzTVa6AN3MvwnjY6hDRJktqeyy3uSoVVQiaHNhEGQP1lQ0ZcMu8MN
cTk2DBRqE9RULpBBgT/YYGITBtFHVD114smwf727iVUMA/o5r1HzZ2T49y/q
cjWGgcyaYG1BFRmcmNskrfZjsHapJoW5hgyC/anf5g9gUByz6UhxHRmEHxtu
kdXHYPu9hy94Wskw5jvm74VjMPH6y936ATIcW96rUHAEgzB++2MqLBRwXlct
e+GKgU0yu3okGwUm58dZpNwx0BR/zDvIQQGz0aueFz0wmN619jpmEwW+L+2I
0/bC4Mj+VI1JQQq01Wr/SfTDQPJEz9b03RTQNGzpnQnB4PnjQ295GBT42Zev
p3oDA8uk6v6jhylwO7zvFyMBg8VghR+ZphTw7uauc7+JgTKdhRc7RgHWpdm8
u0kYZI+VH3JyoIDYlxdJ0ykYxAhLdFX7UsDK57y1fBYGuzeujnGcpUCKpvKp
XdkYvJ5YmjcNpACztshFmfsYbDx5LzAdTAEL4R3j23Mw8DMJPyoYTgGJknyz
6Xyi3rDvnzxvE/WL19GUSjBYdrX6+iyFAh3stE28TzBIOvRmheUuBSrW1Hu+
EW4XyxC9k0GB4tp3IZlPMSBXmB1/k0+B0MWe1YUKDPZ8rxqWqCZcl4/p1GLQ
1Ck/51ZLgWf5v0RWCZ+qTGQqe0kB+9J3S5UvMLgX4SV98DUFFl1bcpTrMOCX
knYKfEeBc523XjK/wmDVInqyfZgCd+ruW9GaMeBYS/9hPEaBCBF1tQXC/Pef
zjdPUGBQTysjvYXI06+hjYavFLgX7q/9vRUDi+taws8WKMCwqTdyf4eBg6ax
hOYSBUQKp56xtGPg0X9C9skfYj8VtcrvEA5TjFV5tE6B42RJm7oODIrejBlm
cOJw6rIANteJQZXnH4Y4Dw72f+24AruI/RbYYnFnMw6XeC85rhDuP7n/ROI2
HP4UyBT9+YAB10Z8UJQYDpLpb2I/f8RAICcnlE0Sh8cbJXHGPUReTKrDw6Rw
SLgoI1BNWDN18saFXTjo3PDOvNmLwUmS3sMzKjjcFo6ukP2MgeegWfEPNRwE
usMqwggHhbuVu2vicNG4SH2QcFxXYr3TfhxICgFpsX0Y3Dn/sGlEBwfcOjh6
hPADqZfv7PRxyBqI+qnWT+TT+9tnSwoONMmEne8IvxFiGumm4vD69PK37QMY
vK8RmjSl49CpqLPPnvAUj8G8MQOHjw0qvF8Izz859qf5MA6FcwcfyQ0SebPy
3KCaEevVFKk5SVgwL5kHLHG4bJqu3k1456HHW2utceA3eHmbe4jIy++G7QeO
4/DT39VDlzAp7ZP4M3sczo61FnoSNqDMyGiexKH+P0m7VMIm31gVnzjh4KyS
HPyGsFXCDhVlFxyon93ZZgh7D+M6CqdxqAyas8aGMTgfaWOQ44VD1+YtclaE
w5V8DGV8cMjssbIMJBzfHcHI8MOh7Cb7QgLh1At3zcUDcGAs0ZcKCOfIPLG+
cw4HmWLLE/WES1oaHbYH45Do5KL6kXCNz4BzYgix3tKHzpOEm4TnT2+9iMNe
jWP/FgmDr22jYxgO4tRZCtMIBpWtr6XKr+DAsbKJzE1YTU75AmckDgWcnCt8
hAv+S/5oHY3DQTkdN0HCsr1MqoUxOPitscRvJ5ym6hGzEYvDNu0qz/9bKObD
xJF4HELOVzL9//m4cV10P4HIk53twf+/j1Mv987vRKKeC2t0LsKXbvMtGt7G
gX5qaXWDWN/KbNCh1BQckh/cd1wg7Gc0lv8jFYfQBvuQL4S/ZxuzonQcWvQv
0/9f76m1MruEDBzuJrk1NhAePCpZOZ6FQ81+z9+PCR8rjuInPSDO995U923C
HVy/PKNzcZDfp3XqP8J0R5umvnwcZujF2ScJ11e/klZ6hEO5eUk8hfABIaWQ
i49x0Mu9uUeW8FPv2z2dxTiMJ5X4MRHe1/xPVa4UByXvU679xHlLXuj60lyB
w9y/JfMYwsndOiBWhQPzgZiD9oS3KuekelXjwOUo/l2FMMvoucP8dTicI+fu
biPyeOHA6MNTDThoHTFruE14MfEg27PXOJQsObM5EJ6kSVTZtuDQcGFfyDSR
d4fMSIGitzhcv5JY8pDwp5VZL6Z2HM4Htl51I9xa2CCT04VDhMZWhWGin4r4
3WJn+ol8nOliLiH6b7dn5yQM4VBre+OgPeHMNwcMEkdwWO/4qc5D+GYQ7xL2
BYeAiplhG6KfA4ZKHcJmcGgS7E8ZJubBDCb+/MMcDlJMbm3BhF0SIgTlF4j+
eOKYKkDYCrdqaV0m+n0nF6s+MU90C9bVBZmpILo8shjQjQFbIJ0jT4AKfa67
W3zfE+cbb3Ns73Yq8PkevdRHzLuuh565xSJUqLPdYwOEMwdv0ColqCATe86P
lZiPetTPkS27qVBbcUrS9S0GgYIenD90qNDSmvbw/hsM7JRDLH30qXB3IXv3
0GsMcHpc3iJQQTyEs1qIMH9IqeE6lQqCV1MkQxqI+3r8b9SWI1RgY0ms3/WS
uF9Lr3GpnaKCQ3dSzfdnRH7a0q3KXahAL3i6b5m4Xyomi/P3u1OBhXn0wb9y
op9Fu+lkbyqY7ecv4CzDQPqy+FXzICrYBgfPLRQT95vpY+7AWCoU3swr1c3D
oG22nae6jApa7rJaVxOJ52s0iwWfUYGcNVV1kLh/A6NTzb2riHpedNzgJu5n
KWmXNOkXVPiLm6lfjMPA32xdKbqJCtExvGoHr2IgWr7X9GgfFYZyn4bbh2Lg
FhydPPuPeJ+y9YsLLhjU0mZ0jFhooIK7ak2eIuoXsBjJZqPBQPeraYYTMT8e
7VQ8xk0DdfNCZqETGPANVjyv4adBkIDQ1zBrol70ZfDqLhrUveL4/dEYA3Z2
spycMQ0wTQeSozKRfw2vdV8GDfj5fDND9hHz82RKz8vDNDi+Q4+RtIfIR+1M
tK0FDSLivDyr5TFoDLj786YdDbweCRRPS2IQNblYwexDg+KQy2UvtmDA3Zxn
NJxEg3VVe8ziBwlklrpklJJp0G2a/kzoGwkOyG2sBt+hgZnwgHP3FAk8LlkU
bb9Hg2amOiOjcRK0ajMLHMqjwbTNovi2PhJce2gzUFNFg4O7UxxEmkjAe433
TOoQDcQ4JVuYMkiQdH5UT3SUBro753SU00gg6la+OXWcBm70atzqDgnkqXYF
d6ZpIFz8VTA7kQTwr/BLyjwN1K45pGyOJoGfv8nxZA5DUA094avrQ4Ie22tG
ScqGUOrxK5lZn/j+3MctFxdqCC4snmwL7VqQ9E7VcPySIUBEc3noWy2I9rby
0L5iCIYutoizWQt8SvJKxqIMoVbn9Kct9VoAmjQ9LMEQHNdl+P4Q/zNGda4c
G7lvCCMDJ5fUbmuBjPF6tHqLIQRmZ03q22jBA/dfP3sE6EDVVxdI/qQJHG/r
Oey308EuLWN5+YMmuO27ufOLCB1ON29etOjQBKVZddMFCTqYFrqrsTZqQsXZ
s2V8CnRY0WrIUX2qCc0Xl4PpunRwTAt90h6rCT9urXM+P0UH+Tgn7W16mqDR
wC2TXk6HE52vuC8maIBVRMYZkUo6fJdNs1i5pgGhdK3axOd0IHXcyzkTqQHN
7SesYl7SofvS+2NHLmiAff+zuHMtdFhlZA2NntKAmEXnVdNBOly1bmzBMQ0Y
k2/o5mA3giSz0zpsn9Uh4VpwlI+FETA4UiYObFUHh7le5jvTRsD0ZfLcHU9V
qPJxntS/ehAspUm/TOr3wZXY4eH9O42B3u3z4KKrAojvKOUhlxoDZ17PpYV7
smBQX5bRZGoCoTWiXlx5YtDD9sAoe9IEqnmqEt8f5gM/leiFA19NIBxd/W4z
vAX4bDzTP3w3gV2rBl/LvbcAvVjzF9svExDpa60YjOWF59ZvUlxXTaDpbX3N
QuMmyCianNq3lQHivctR6upc4GalGPlsPwPyTeJKXk0wAdsVXtUjugw4H/72
jLk3E2Q9/vV5Wp8BZ4Olip1n/6E+ludKojgDKpzmmesFNpDJ44MfQw4xIIMa
+vyH5V+kyuIpR3ZiQKlp1C2e9nnUtu9Ie58zA/aqO5UL9/9C7paaQf5uDBCu
91F4NTWHsgvX3j7wYgDbPd2Er/9+IkHL6/6cQQxIa9R3v2w5iUrCfCUygxkw
x9fuGHp6AjEKjzZp/8eAxrc5bBWhYyiSWVLM4zIDcLU94cXUQSS7j+UNSwQD
vl/Q1b3i+hnVHZv0vhvFAC7Ipb2L+oiOh7WKaMYwQK77o9P13E608qiooS2W
Ab1vfPIjo96i/wG7Xn9l
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtzG9M1HUAx3EGD4Q2HIKMk0CHHETIcRzgHXfcl9/nPDy60y8zCxtNU/5c
+QB1+QeLzRDmBJU5BTVi5fR2sxJFZGhKJuxsFW3lQPQuWlhabZnJXfzHOcTd
58F7r2fvpPId652hISEhcr4XTo70f6s+0l0Q1F0wdFr1ocXXrAStVxB7u1zl
c9FmpXrdeW+Yr4u6lEVP4ppnvB7apdy/Ubxj3DtIPYpN/ei3gPcBHVRmvIaT
fu//9IFyy/q5e8AVhqBjSsL963+XZ0Qi6DNlcdXm8wusMQgahmad7eviEhUN
xy+tWX2BqEQaiSPu2tuhS5LoIsSdeHio5bNkGoOGN+0Fg5MpNBa7jGc399en
URUKR2drtj9Mp/GoM79eFp+noYkwdXzS/VGvli5D1XRg/w+ROpqEmRVRI5qS
bLoc5vYLZ06dyqHJCEQ7tmzw5FI1/mzasmHnAj1NhX10r/0vvYG+gscV4bu6
a/NoGmzquNAGj5G+iuifUo92jppoOhIaL63T6800A60rjFEx7wmqwY/xlpVj
xwtoJkwJnmPaewrVYmGYa3dZPWgWltYtM5emWqgOESkbr67/3kJ1yBRLLu3d
tIpmY+dI9C1HiJXmYHSsqcTeaqU5KNJ+12bXFNJc3BzLfzr1cyHNxfaM7OEB
52q6EuJJ5VBphI3qsVqtkpEuG9Ujbf/hDzyGImpAutPYmzJcRA1w3tx6oPv9
12gees8MVQZi7dSI8S/mprRf2akRFSntEW3SQU0IpLfou/wOasI199M/JhrX
0Hy8XZiM/KVrqRkvb2u4ntm3lpoR+1LVZfmWpAJu674af6mkAtn7jlpbNkoq
UOzvvOsrk1Tg4L2JmYoqSQWmXbWrauokFRjOb7lzrl1Sga173J/aOyQVmOy4
4nzcKalA9HLflO6qpAJrwhMTvumTVODG0LnKO3clFXAsvKap9kkq4Cvqn1T9
KqnAeM+/je/8LqmA5mzWxX8eSTr/G7ZUN/0n6fxv8RuK1i+pwLsNewZ2T0g6
/+s72BY3LalA/ezHFT2zkgpE5X6ZsemZpAKnt/VMzM1JKvAcEg0tFw==
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzHk81IkbwHHSFJUWkxyRraXDTTEIzzNu8rVTi9CBUCpXOZNjHEvlqCgx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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 59.1}, {0., 23.875344217518837`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184397322483997`*^9},
 AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 134, 3, 49, "Subtitle"],
Cell[716, 27, 138, 3, 29, "Subsubtitle"],
Cell[857, 32, 381, 14, 150, "Input"],
Cell[CellGroupData[{
Cell[1263, 50, 1502, 45, 47, "Input"],
Cell[2768, 97, 733, 26, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[3538, 128, 649, 19, 52, "Input"],
Cell[4190, 149, 29847, 495, 231, "Output",
 Evaluatable->False],
Cell[34040, 646, 30277, 502, 235, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[64354, 1153, 169, 4, 31, "Input"],
Cell[64526, 1159, 59838, 988, 230, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[124401, 2152, 98, 2, 28, "Subsubtitle",
 Evaluatable->False],
Cell[124502, 2156, 382, 14, 150, "Input"],
Cell[CellGroupData[{
Cell[124909, 2174, 1543, 46, 47, "Input"],
Cell[126455, 2222, 733, 26, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[127225, 2253, 649, 19, 52, "Input"],
Cell[127877, 2274, 35525, 588, 233, "Output",
 Evaluatable->False],
Cell[163405, 2864, 36349, 602, 230, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[199791, 3471, 169, 4, 31, "Input"],
Cell[199963, 3477, 71591, 1181, 230, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[271603, 4664, 97, 2, 28, "Subsubtitle",
 Evaluatable->False],
Cell[271703, 4668, 386, 14, 150, "Input"],
Cell[CellGroupData[{
Cell[272114, 4686, 2239, 63, 128, "Input"],
Cell[274356, 4751, 755, 26, 30, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[275148, 4782, 649, 19, 52, "Input"],
Cell[275800, 4803, 4718, 83, 224, "Output",
 Evaluatable->False],
Cell[280521, 4888, 9964, 169, 230, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[290522, 5062, 169, 4, 31, "Input"],
Cell[290694, 5068, 14395, 243, 224, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[305138, 5317, 48, 0, 28, "Subsubtitle"],
Cell[CellGroupData[{
Cell[305211, 5321, 562, 19, 94, "Input"],
Cell[305776, 5342, 8142, 141, 243, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[313955, 5488, 222, 7, 31, "Input"],
Cell[314180, 5497, 1531, 32, 246, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[315748, 5534, 251, 8, 33, "Input"],
Cell[316002, 5544, 3778, 69, 245, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[CellGroupData[{
Cell[319817, 5618, 129, 3, 31, "Input"],
Cell[319949, 5623, 12743, 218, 243, "Output",
 Evaluatable->False]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

