(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    173752,       4061]
NotebookOptionsPosition[    169729,       3924]
NotebookOutlinePosition[    170088,       3940]
CellTagsIndexPosition[    170045,       3937]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Utilizing Vector Notation in Mathematica\[Dash]Momentum Example 1\
\>", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Input the definitions for the vector operations", "Subsection"],

Cell["\<\
Input the vector definition with the command that follows.  The path will \
depend on where  the definitions reside on the local system.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Get[StringJoin[NotebookDirectory[],\"vectors3.m\"]]\
\>", "Input",
 CellChangeTimes->{{3.5184397774572*^9, 3.5184397810452003`*^9}, 
   3.536264450582232*^9},
 AspectRatioFixed->True],

Cell[BoxData["\<\"These Engineering Vector algorithms are copyright Alan A. \
Barhorst\"\>"], "Print",
 CellChangeTimes->{3.5184397821372004`*^9, 3.5184398751912003`*^9, 
  3.536264473894082*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the symbols used for Unit Vectors and Unit Dyads", "Subsection"],

Cell[TextData[{
 "Define Unit Vectors and Unit Dyads for however many frames we need for the \
system. For this example we will use three frames of reference, with the \
frame ",
 StyleBox["N",
  FontWeight->"Bold"],
 " being the Newtonian frame.  The header ",
 StyleBox["unitVector",
  FontWeight->"Bold"],
 " must be included.  The arguments are ",
 StyleBox["[frame, symbol, direction]",
  FontWeight->"Bold"],
 ".  So unit vector ",
 StyleBox["b[1]=unitVector[B,b,1]",
  FontWeight->"Bold"],
 " is the vector in the ",
 StyleBox["B",
  FontWeight->"Bold"],
 " frame in the ",
 StyleBox["1",
  FontWeight->"Bold"],
 " direction.  The unitDyads are double vectors used to describe inertia \
properties."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"B", ",", "b", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"n", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"N", ",", "n", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"bb", "[", 
   RowBox[{"a_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"unitDyad", "[", 
   RowBox[{
    RowBox[{"b", "[", "a", "]"}], ",", 
    RowBox[{"b", "[", "c", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184397914348*^9, 3.5184397914504004`*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["A simple example", "Subsection"],

Cell[CellGroupData[{

Cell["System Extent, Choosing Coordinates, and Define the System", \
"Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 0.580435
200 dict begin
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 56 91 0 0 ]
[ 516 358 0 0 ]
] MathScale
% Start of Graphics
%!PS-Adobe-2.0 EPSF-2.0
%%Title: 
%%Creator: Tailor
%%CreationDate: Sun Aug 24 00:00:35 1997
%%For: alan
%%DocumentFonts: (atend)
%%Pages: 0 0
%%BoundingBox: 56 91 516 358
%%NXNextStepVersion: 3.0
%%EndComments

%%BeginProcSet: /usr/lib/NextStep/printPackage.ps 3.0
%!
% NeXT Printing Package
% Version: 3.1
% Copyright: 1988, NeXT, Inc.

/__NXdef{1 index where{pop pop pop}{def}ifelse}bind def
/__NXbdef{1 index where{pop pop pop}{bind def}ifelse}bind def
/UserObjects 10 array __NXdef
/defineuserobject{
\texch dup 1 add dup UserObjects length gt{
\t\tarray dup 0 UserObjects putinterval
\t\t/UserObjects exch def
\t}{pop}ifelse UserObjects exch 3 -1 roll put
}__NXbdef
/undefineuserobject{UserObjects exch null put}__NXbdef
/execuserobject{UserObjects exch get exec}__NXbdef
/__NXRectPath{4 2 roll moveto 1 index 0 rlineto
0 exch rlineto neg 0 rlineto closepath}__NXbdef
/__NXProcessRectArgs{
\t1 index type /arraytype eq{
\t\texch 0 4 2 index length 1 sub{
\t\t\tdup 3 add 1 exch{1 index exch get exch}for
\t\t\t5 1 roll 5 index exec
\t\t}for pop pop
\t}{exec}ifelse
}__NXbdef
/rectfill{gsave newpath {__NXRectPath fill} __NXProcessRectArgs \
grestore}__NXbdef
/rectclip{newpath {__NXRectPath} __NXProcessRectArgs clip newpath}__NXbdef
/rectstroke{
\tgsave newpath dup type /arraytype eq{dup length 6 eq}{false}ifelse{
\t\t{gsave __NXRectPath null concat stroke grestore}
\t\tdup length array cvx copy dup 2 4 -1 roll put __NXProcessRectArgs
\t}{{__NXRectPath stroke} __NXProcessRectArgs}ifelse grestore
}__NXbdef
/_NXLevel2 systemdict /languagelevel known {languagelevel 2 ge}{false}ifelse \
__NXdef
/xyshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\t3 index 3 index 2 mul 1 add get add exch
\t\t3 index\t3 index 2 mul get add exch moveto pop
\t}for pop pop
}__NXbdef
/xshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\texch 3 index 3 index get add exch moveto pop
\t}for pop pop
}__NXbdef
/yshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\t3 index 3 index get add moveto pop
\t}for pop pop
}__NXbdef
/arct{arcto pop pop pop pop}__NXbdef
/setbbox{pop pop pop pop}__NXbdef
/ucache{}__NXbdef
/ucachestatus{mark 0 0 0 0 0}__NXbdef
/setucacheparams{cleartomark}__NXbdef
/uappend{systemdict begin cvx exec end}__NXbdef
/ueofill{gsave newpath uappend eofill grestore}__NXbdef
/ufill{gsave newpath uappend fill grestore}__NXbdef
/ustroke{
\tgsave newpath dup length 6 eq
\t{exch uappend concat}{uappend}ifelse
\tstroke grestore
}__NXbdef
/__NXustrokepathMatrix dup where {pop pop}{matrix def}ifelse
/ustrokepath{
\tnewpath dup length 6 eq{
\t\texch uappend __NXustrokepathMatrix currentmatrix exch concat
\t\tstrokepath setmatrix
\t}{uappend strokepath}ifelse
} __NXbdef
/upath{
\t[exch {/ucache cvx}if pathbbox /setbbox cvx
\t {/moveto cvx}{/lineto cvx}{/curveto cvx}{/closepath cvx}pathforall]cvx
} __NXbdef
/setstrokeadjust{pop}__NXbdef
/currentstrokeadjust{false}__NXbdef
/selectfont{exch findfont exch
dup type /arraytype eq {makefont}{scalefont}ifelse setfont}__NXbdef
/_NXCombineArrays{
\tcounttomark dup 2 add index dup length 3 -1 roll {
\t\t2 index length sub dup 4 1 roll 1 index exch 4 -1 roll putinterval exch
\t}repeat pop pop pop
}__NXbdef
/flushgraphics{}def
/setwindowtype{pop pop}def
/currentwindowtype{pop 0}def
/setalpha{pop}def
/currentalpha{1.0}def
/hidecursor{}def
/obscurecursor{}def
/revealcursor{}def
/setcursor{4 {pop}repeat}bind def
/showcursor{}def
/NextStepEncoding where not{
/NextStepEncoding StandardEncoding 256 array copy def
0 [129/Agrave/Aacute/Acircumflex/Atilde/Adieresis/Aring/Ccedilla/Egrave
/Eacute/Ecircumflex/Edieresis/Igrave/Iacute/Icircumflex/Idieresis
/Eth/Ntilde/Ograve/Oacute/Ocircumflex/Otilde/Odieresis/Ugrave/Uacute
/Ucircumflex/Udieresis/Yacute/Thorn/mu/multiply/divide/copyright
176/registered 181/brokenbar 190/logicalnot 192/onesuperior 201/twosuperior
204/threesuperior 209/plusminus/onequarter/onehalf/threequarters/agrave
/aacute/acircumflex/atilde/adieresis/aring/ccedilla/egrave/eacute
/ecircumflex/edieresis/igrave 226/iacute 228/icircumflex/idieresis/eth
/ntilde 236/ograve/oacute/ocircumflex/otilde/odieresis 242/ugrave/uacute
/ucircumflex 246/udieresis/yacute 252/thorn/ydieresis]
{dup type /nametype eq
 {NextStepEncoding 2 index 2 index put pop 1 add}{exch pop}ifelse
}forall pop
/NextStepEncoding NextStepEncoding readonly def
/_NXfstr 128 string dup 0 (_NX) putinterval def
/_NXfindfont /findfont load def
/findfont{
 % Because we can never let NextStepEncoding get into
 % SharedFontDirectory, we cannot reencode a font to NextStepEncoding
 % if we are in shared mode.  So if currentshared is true,
 % we call the normal findfont and return that
 /currentshared where {pop currentshared} {false} ifelse
 {_NXfindfont}
 {dup _NXfstr 3 125 getinterval cvs length 3 add _NXfstr 0 3 -1 roll
  getinterval cvn exch FontDirectory 2 index known 
  {pop FontDirectory exch get}
  {_NXfindfont dup /Encoding get StandardEncoding eq
   {\tdup length dict exch
\t{1 index /FID ne {2 index 3 1 roll put}{pop pop}ifelse}forall
\t dup /Encoding NextStepEncoding put definefont
\t}{exch pop} ifelse
   }ifelse
 }ifelse
}bind def
}{pop}ifelse
/_NXImageString {/__NXImageString where{pop}{/__NXImageString 4000 string \
__NXdef}ifelse __NXImageString}__NXbdef
/_NXDoImageOp{
\t3 dict begin /parr 5 array def 1 index{dup}{1}ifelse /chans exch def
\tchans 2 add 2 roll parr 0 chans getinterval astore pop
\t5 index 4 index mul 2 index{1 sub 8 idiv 1 add mul}{mul 1 sub 8 idiv 1 \
add}ifelse
\t4 index mul /totbytes exch def pop exch pop
\tgsave matrix invertmatrix concat 0.5 setgray 0 0 4 2 roll rectfill grestore
\t{0 1 chans 1 sub{parr exch get exec length totbytes exch sub /totbytes exch \
def}for totbytes 0 le{exit}if}loop end
}__NXbdef
/alphaimage{1 add _NXDoImageOp}def
_NXLevel2{ 
\t/NXCalibratedRGBColorSpace where{pop}{
\t\t/NXCalibratedRGBColorSpace
\t\t{mark /NXCalibratedRGB /ColorSpace findresource exch pop}stopped
\t\t{cleartomark /NXCalibratedRGB[/CIEBasedABC 2 dict dup begin 
\t\t/MatrixLMN[.4124 .2126 .0193 .3576 .7152 .1192 .1805 .0722 .9505]def
\t\t/WhitePoint[.9505 1 1.089] def end] /ColorSpace defineresource}if \
def}ifelse
\t/nxsetrgbcolor{NXCalibratedRGBColorSpace setcolorspace setcolor}__NXbdef
\t/nxsetgray{dup dup nxsetrgbcolor}__NXbdef
\t/_NXCalibratedImage{exch{array astore dup length true}{false}ifelse
\t\t8 -1 roll{NXCalibratedRGBColorSpace setcolorspace}if
\t\t8 dict dup 9 1 roll begin /ImageType 1 def /MultipleDataSources exch def
\t\tcurrentcolorspace 0 get /Indexed eq{pop /Decode[0 2 6 index exp 1 \
sub]def}
\t\t{2 mul dup array /Decode exch def 1 sub 0 1 3 -1 roll{Decode exch dup 2 \
mod put}for}ifelse
\t\t/DataSource exch def /ImageMatrix exch def 
\t\t/BitsPerComponent exch def /Height exch def /Width exch def end \
image}__NXbdef
} {
\t/setcmykcolor{
\t\t1.0 exch sub dup dup 6 -1 roll sub dup 0 lt{pop 0}if 5 1 roll
\t\t4 -1 roll sub dup 0 lt{pop 0}if 3 1 roll exch sub dup 0 lt{pop 0}if \
setrgbcolor}__NXbdef
\t/currentcmykcolor{currentrgbcolor 3{1.0 exch sub 3 1 roll}repeat 0}__NXbdef
\t/colorimage{2 copy 3 ne or{_NXDoImageOp}{4 index dup 8 ne exch 4 ne \
and{_NXDoImageOp}{
\t\tpop pop save 6 1 roll 12 dict begin/Proc exch def/Res 0 string def
\t\t/Alloc{2 index length mul 2 add dup 2 index load length gt{1.2 mul round \
cvi string def}{pop pop}ifelse}def
\t\t1 index 8 eq{/Unpack{.34 Alloc}def}{
\t\t\t/Wid 4 index 3 mul def exch pop 8 exch/Str1 0 string def/Lim Wid def
\t\t\t/Unpack{.67 Alloc/Str1 2 Alloc 0 exch Lim exch
\t\t\t\t{dup -4 bitshift 17 mul Str1 exch 4 index exch put 15 and 17 mul Str1 \
exch 3 index 1 add exch put
\t\t\t\t2 sub dup 0 le{0 lt Wid exch{exch 1 sub exch}if}if exch 2 add exch
\t\t\t\t}forall/Lim exch def Str1 exch 0 exch getinterval
\t\t\t}def
\t\t}ifelse
\t\t/Ops[{.3 mul add 1}{.59 mul add 2}{.11 mul add round cvi Res exch 2 index \
exch put 1 add 0.0 0}]def/Val 0.0 def/Phase 0 def
\t\t{0 Val Phase Proc/Res Unpack{exch Ops exch get exec}forall/Phase exch \
def/Val exch def Res exch 0 exch getinterval}
\t\timage end restore}ifelse}ifelse
\t}__NXbdef
\t/nxsetrgbcolor{setrgbcolor}__NXbdef /nxsetgray{setgray}__NXbdef
\t/setpattern{pop .5 setgray}__NXbdef
\t/_NXCalibratedImage{dup 1 eq {pop pop image}{colorimage}ifelse pop}__NXbdef
} ifelse
/_NXSetCMYKOrRGB where{pop}{
\tmark{systemdict /currentwindow get exec}stopped
\t{{pop pop pop setcmykcolor}}{{nxsetrgbcolor pop pop pop pop}}ifelse \
/_NXSetCMYKOrRGB exch def cleartomark
}ifelse
%%EndProcSet

%%BeginResource: procset (Tailor 2.0)
/TailorDict 10 dict def TailorDict begin
/TailorGroupBegin {pop} def /TailorGroupEnd {} def
/TailorBlockBegin {pop pop pop} def /TailorBlockEnd {} def
/TailorSetUniformStroke {pop} def
/setoverprint where {pop} {/setoverprint {pop} def} ifelse
end
%%EndResource

gsave
 /__NXbasematrix matrix currentmatrix def
grestore
%%EndProlog
%%BeginSetup
TailorDict begin
%%EndSetup
0 0 516 358 rectclip
0 0 516 358 rectclip
gsave
0 setgray
1 setlinewidth
(* Group Created by User *) TailorGroupBegin
[1 0 0 1 0 0] matrix invertmatrix concat
[0.509793 -0.616532 0.616532 0.509793 -239.75 183.338989] concat
gsave
newpath
systemdict
begin
381.647003 672.119995 608.646973 689.119995 setbbox
381.647003 680.619995 moveto
381.647003 685.314026 385.451996 689.119995 390.147003 689.119995 curveto
600.146973 689.119995 lineto
604.841003 689.119995 608.646973 685.314026 608.646973 680.619995 curveto
608.646973 675.924988 604.841003 672.119995 600.146973 672.119995 curveto
390.147003 672.119995 lineto
385.451996 672.119995 381.647003 675.924988 381.647003 680.619995 curveto
closepath
end
stroke
grestore
[0.509793 -0.616532 0.616532 0.509793 -239.75 183.338989] matrix invertmatrix \
concat
[-0.007339 -0.799966 0.799966 -0.007339 50.095699 -190.560059] concat
gsave
newpath
systemdict
begin
-389.579987 495.510986 -382.579987 499.510986 setbbox
-388.579987 497.510986 moveto
-389.579987 499.510986 lineto
-382.579987 497.510986 lineto
-389.579987 495.510986 lineto
closepath
end
fill
grestore
[-0.007339 -0.799966 0.799966 -0.007339 50.095699 -190.560059] matrix \
invertmatrix concat
[0.8 0 0 0.8 50.095699 -190.560059] concat
gsave
newpath
systemdict
begin
501.054993 384 502 487 setbbox
502 487 moveto
501.054993 384 lineto
end
stroke
grestore
[0.8 0 0 0.8 50.095699 -190.560059] matrix invertmatrix concat
[0.799941 -0.009753 0.009753 0.799941 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
423.070007 570.286011 430.070007 574.286011 setbbox
424.070007 572.286011 moveto
423.070007 574.286011 lineto
430.070007 572.286011 lineto
423.070007 570.286011 lineto
closepath
end
fill
grestore
[0.799941 -0.009753 0.009753 0.799941 27.095699 -162.560059] matrix \
invertmatrix concat
[0.8 0 0 0.8 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
355 567.072998 431.015991 568 setbbox
355 568 moveto
431.015991 567.072998 lineto
end
stroke
grestore
[0.8 0 0 0.8 27.095699 -162.560059] matrix invertmatrix concat
[0.001254 0.799999 -0.799999 0.001254 672.791992 52.288025] concat
gsave
newpath
systemdict
begin
287.445007 362.462006 294.445007 366.462006 setbbox
288.445007 364.462006 moveto
287.445007 366.462006 lineto
294.445007 364.462006 lineto
287.445007 362.462006 lineto
closepath
end
fill
grestore
[0.001254 0.799999 -0.799999 0.001254 672.791992 52.288025] matrix \
invertmatrix concat
[-3.49691e-08 0.8 -0.8 -3.49691e-08 672.791992 52.288025] concat
gsave
newpath
systemdict
begin
218.440002 364.009003 289.015991 364.119995 setbbox
218.440002 364.119995 moveto
289.015991 364.009003 lineto
end
stroke
grestore
[-3.49691e-08 0.8 -0.8 -3.49691e-08 672.791992 52.288025] matrix invertmatrix \
concat
[0.8 0 0 0.8 187.895996 30.23999] concat
/Times-Italic findfont 1 scalefont [18 0 0 18 0 0] makefont
41
exch
defineuserobject
41 execuserobject setfont
302 113 moveto
(mg ) show
[0.8 0 0 0.8 187.895996 30.23999] matrix invertmatrix concat
[0.8 0 0 0.8 205.496002 52.640015] concat
131 277 moveto
(Rx ) show
[0.8 0 0 0.8 205.496002 52.640015] matrix invertmatrix concat
[0.8 0 0 0.8 200.695999 53.440002] concat
201 225 moveto
(Ry ) show
(* Group Created by User *) TailorGroupBegin
[0.8 0 0 0.8 200.695999 53.440002] matrix invertmatrix concat
[28.251106 0 0 -28.251106 486.251099 158.748901] concat
1 nxsetgray
gsave
newpath
systemdict
begin
-1 -1 1 1 setbbox
1 0 moveto
1 0.552 0.552 1 0 1 curveto
-0.552 1 -1 0.552 -1 0 curveto
-1 -0.552 -0.552 -1 0 -1 curveto
0.552 -1 1 -0.552 1 0 curveto
end
fill
grestore
[28.251106 0 0 -28.251106 486.251099 158.748901] matrix invertmatrix concat
[29.5 0 0 -29.5 485.5 159.5] concat
0 nxsetgray
true setoverprint
0 setlinewidth
true TailorSetUniformStroke
gsave
newpath
systemdict
begin
-1 -1 1 1 setbbox
1 0 moveto
1 0.552 0.552 1 0 1 curveto
-0.552 1 -1 0.552 -1 0 curveto
-1 -0.552 -0.552 -1 0 -1 curveto
0.552 -1 1 -0.552 1 0 curveto
end
[1 0 0 -1 -16.457626 5.40678] concat
stroke
grestore
TailorGroupEnd
[29.5 0 0 -29.5 485.5 159.5] matrix invertmatrix concat
[1.203851 0 0 1.203851 -72.18251 -68.378403] concat
false setoverprint
gsave
newpath
systemdict
begin
359 306 387 314 setbbox
387 313 moveto
377 314 lineto
366 311 lineto
359 306 lineto
end
[1 0 0 1 59.959675 56.799725] concat
stroke
grestore
[1.203851 0 0 1.203851 -72.18251 -68.378403] matrix invertmatrix concat
[0.755 -0.264525 0.264525 0.755 555.009277 -168.767883] concat
gsave
newpath
systemdict
begin
-389.579987 495.510986 -382.579987 499.510986 setbbox
-388.579987 497.510986 moveto
-389.579987 499.510986 lineto
-382.579987 497.510986 lineto
-389.579987 495.510986 lineto
closepath
end
fill
grestore
[0.755 -0.264525 0.264525 0.755 555.009277 -168.767883] matrix invertmatrix \
concat
[0.8 0 0 0.8 239.496002 76.639641] concat
131 277 moveto
(T ) show
[0.8 0 0 0.8 239.496002 76.639641] matrix invertmatrix concat
[1 0 0 1 -107 38] concat
/Times-Italic findfont 1 scalefont [13.400001 0 0 13.400001 0 0] makefont
189
exch
defineuserobject
189 execuserobject setfont
457 254.5 moveto
(d) show
TailorGroupEnd
(* Group Created by User *) TailorGroupBegin
[1 0 0 1 -107 38] matrix invertmatrix concat
[0.509793 -0.616532 0.616532 0.509793 -239.75 183.338989] concat
1 setlinewidth
false TailorSetUniformStroke
gsave
newpath
systemdict
begin
170.009003 402.04599 397.009003 419.046997 setbbox
170.009003 410.546997 moveto
170.009003 415.240997 173.815002 419.046997 178.509003 419.04599 curveto
388.509003 419.046997 lineto
393.203003 419.046997 397.009003 415.240997 397.009003 410.546997 curveto
397.009003 405.85199 393.203003 402.04599 388.509003 402.046997 curveto
178.509003 402.046997 lineto
173.815002 402.04599 170.009003 405.85199 170.009003 410.546997 curveto
closepath
end
stroke
grestore
[0.509793 -0.616532 0.616532 0.509793 -239.75 183.338989] matrix invertmatrix \
concat
[0.8 0 0 0.8 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
67 537 120.982002 573.5 setbbox
120.982002 572.151001 moveto
120.445 552.531006 108.523003 537 94 537 curveto
79.096001 537 67 553.35199 67 573.5 curveto
end
stroke
grestore
gsave
newpath
systemdict
begin
38 574 147 574 setbbox
38 574 moveto
147 574 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
70 575 79 592 setbbox
79 592 moveto
70 575 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
79 574 88 591 setbbox
88 591 moveto
79 574 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
88 574 97 591 setbbox
97 591 moveto
88 574 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
98 574 107 591 setbbox
107 591 moveto
98 574 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
107 574 116 591 setbbox
116 591 moveto
107 574 lineto
end
stroke
grestore
gsave
newpath
systemdict
begin
116 576 125 593 setbbox
125 593 moveto
116 576 lineto
end
stroke
grestore
[0.8 0 0 0.8 27.095699 -162.560059] matrix invertmatrix concat
[1 0 0 1 -35 -263.219971] concat
gsave
newpath
systemdict
begin
135.382004 540.598022 143.617996 548.833984 setbbox
143.617996 544.716003 moveto
143.617996 542.442993 141.772995 540.598022 139.5 540.598022 curveto
137.227005 540.598022 135.382004 542.442993 135.382004 544.716003 curveto
135.382004 546.989014 137.227005 548.833984 139.5 548.833984 curveto
141.772995 548.833984 143.617996 546.989014 143.617996 544.716003 curveto
closepath
end
fill
grestore
[1 0 0 1 -35 -263.219971] matrix invertmatrix concat
[0.8 0 0 0.8 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
91.607597 549.927002 101.903 560.223022 setbbox
101.903 555.075012 moveto
101.903 552.232971 99.597 549.927002 96.755402 549.927002 curveto
93.913803 549.927002 91.607597 552.232971 91.607597 555.075012 curveto
91.607597 557.916992 93.913803 560.223022 96.755402 560.223022 curveto
99.597 560.223022 101.903 557.916992 101.903 555.075012 curveto
closepath
end
stroke
grestore
gsave
newpath
systemdict
begin
97 373.924988 97 540 setbbox
97 540 moveto
97 373.924988 lineto
end
stroke
grestore
[0.8 0 0 0.8 27.095699 -162.560059] matrix invertmatrix concat
[-0.799588 0.02568 -0.02568 -0.799588 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
-91.497902 -393.220001 -84.497902 -389.220001 setbbox
-90.497902 -391.220001 moveto
-91.497902 -389.220001 lineto
-84.497902 -391.220001 lineto
-91.497902 -393.220001 lineto
closepath
end
fill
grestore
[-0.799588 0.02568 -0.02568 -0.799588 27.095699 -162.560059] matrix \
invertmatrix concat
[0.564798 0.566572 -0.566572 0.564798 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
437.183014 154.526001 444.183014 158.526001 setbbox
438.183014 156.526001 moveto
437.183014 158.526001 lineto
444.183014 156.526001 lineto
437.183014 154.526001 lineto
closepath
end
fill
grestore
[0.564798 0.566572 -0.566572 0.564798 27.095699 -162.560059] matrix \
invertmatrix concat
[0.8 0 0 0.8 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
103.009003 388 198.501999 420.834015 setbbox
103.009003 388.114014 moveto
104.996002 388.037994 106.985001 388 108.974998 388 curveto
144.867996 388 178.416 400.303986 198.501999 420.834015 curveto
end
stroke
grestore
[0.8 0 0 0.8 27.095699 -162.560059] matrix invertmatrix concat
[0.506115 -0.619554 0.619554 0.506115 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
-79.306801 426.36499 -72.306702 430.36499 setbbox
-78.306702 428.36499 moveto
-79.306702 430.36499 lineto
-72.306702 428.36499 lineto
-79.306801 426.36499 lineto
closepath
end
fill
grestore
[0.506115 -0.619554 0.619554 0.506115 27.095699 -162.560059] matrix \
invertmatrix concat
[0.619554 0.506115 -0.506115 0.619554 592.728027 -172.930054] concat
gsave
newpath
systemdict
begin
-24.0809 618.84198 -17.0809 622.84198 setbbox
-23.0809 620.84198 moveto
-24.0809 622.84198 lineto
-17.0809 620.84198 lineto
-24.0809 618.84198 lineto
closepath
end
fill
grestore
[0.619554 0.506115 -0.506115 0.619554 592.728027 -172.930054] matrix \
invertmatrix concat
[0.8 0 0 0.8 4.095699 -161.560059] concat
gsave
newpath
systemdict
begin
224.016006 554 231.016006 558 setbbox
225.016006 556 moveto
224.016006 558 lineto
231.016006 556 lineto
224.016006 554 lineto
closepath
end
fill
grestore
[0.8 0 0 0.8 4.095699 -161.560059] matrix invertmatrix concat
[0.5787 0 0 -0.5787 54.002281 604.308105] concat
gsave
newpath
systemdict
begin
104 556 225.016006 556 setbbox
104 556 moveto
225.016006 556 lineto
end
stroke
grestore
[0.5787 0 0 -0.5787 54.002281 604.308105] matrix invertmatrix concat
[-4.38455e-07 0.8 -0.8 -4.38455e-07 671.791992 20.288025] concat
gsave
newpath
systemdict
begin
412.015991 708 419.015991 712 setbbox
413.015991 710 moveto
412.015991 712 lineto
419.015991 710 lineto
412.015991 708 lineto
closepath
end
fill
grestore
[-4.38455e-07 0.8 -0.8 -4.38455e-07 671.791992 20.288025] matrix invertmatrix \
concat
[-3.49691e-08 0.488566 -0.8 -2.13558e-08 671.791992 149.071152] concat
gsave
newpath
systemdict
begin
292 710 413.015991 710 setbbox
292 710 moveto
413.015991 710 lineto
end
stroke
grestore
[-3.49691e-08 0.488566 -0.8 -2.13558e-08 671.791992 149.071152] matrix \
invertmatrix concat
[0.8 0 0 0.8 78.2957 -134.559998] concat
/Times-BoldItalic findfont 1 scalefont [14 0 0 14 0 0] makefont
39
exch
defineuserobject
39 execuserobject setfont
229 288 moveto
(b) show
/Times-BoldItalic findfont 1 scalefont [12 0 0 12 0 0] makefont
40
exch
defineuserobject
40 execuserobject setfont
236 283.200012 moveto
(1 ) show
[0.8 0 0 0.8 78.2957 -134.559998] matrix invertmatrix concat
[0.8 0 0 0.8 89.495697 -36.960022] concat
39 execuserobject setfont
229 288 moveto
(b) show
40 execuserobject setfont
236 283.200012 moveto
(2 ) show
[0.8 0 0 0.8 89.495697 -36.960022] matrix invertmatrix concat
[0.8 0 0 0.8 155.895691 -20.960022] concat
39 execuserobject setfont
132 154.399994 moveto
(^ ) show
[0.8 0 0 0.8 155.895691 -20.960022] matrix invertmatrix concat
[0.8 0 0 0.8 167.895996 75.840027] concat
132 154.399994 moveto
(^ ) show
[0.8 0 0 0.8 167.895996 75.840027] matrix invertmatrix concat
[0.8 0 0 0.8 60.895699 71.23999] concat
169 258 moveto
(i ) show
[0.8 0 0 0.8 60.895699 71.23999] matrix invertmatrix concat
[0.8 0 0 0.8 15.695702 122.23999] concat
122 278 moveto
(j ) show
[0.8 0 0 0.8 15.695702 122.23999] matrix invertmatrix concat
[0.8 0 0 0.8 53.295681 101.440002] concat
75 309 moveto
(^ ) show
[0.8 0 0 0.8 53.295681 101.440002] matrix invertmatrix concat
[0.8 0 0 0.8 136.096008 34.440002] concat
75 309 moveto
(^ ) show
[0.8 0 0 0.8 136.096008 34.440002] matrix invertmatrix concat
[0.8 0 0 0.8 -42.504303 -148.959961] concat
/Symbol findfont 1 scalefont [17.5 0 0 17.5 0 0] makefont
147
exch
defineuserobject
147 execuserobject setfont
240 362 moveto
(q ) show
[0.8 0 0 0.8 -42.504303 -148.959961] matrix invertmatrix concat
[0.8 0 0 0.8 -32.504303 -53.960022] concat
41 execuserobject setfont
240 362 moveto
(d ) show
[0.8 0 0 0.8 -32.504303 -53.960022] matrix invertmatrix concat
[0.8 0 0 0.8 -52.903999 -247.359985] concat
175 665 moveto
(o ) show
[0.8 0 0 0.8 -52.903999 -247.359985] matrix invertmatrix concat
[1 0 0 1 -16 -286.219971] concat
gsave
newpath
systemdict
begin
186.882004 478.597992 195.117996 486.834015 setbbox
195.117996 482.716003 moveto
195.117996 480.442993 193.272995 478.597992 191 478.597992 curveto
188.727005 478.597992 186.882004 480.442993 186.882004 482.716003 curveto
186.882004 484.989014 188.727005 486.834015 191 486.834015 curveto
193.272995 486.834015 195.117996 484.989014 195.117996 482.716003 curveto
closepath
end
fill
grestore
[1 0 0 1 -16 -286.219971] matrix invertmatrix concat
[0.8 0 0 0.8 46.095699 -185.560059] concat
gsave
newpath
systemdict
begin
155.983002 472.427002 166.278 482.722992 setbbox
166.278 477.575012 moveto
166.278 474.733002 163.972 472.427002 161.130005 472.427002 curveto
158.289001 472.427002 155.983002 474.733002 155.983002 477.575012 curveto
155.983002 480.416992 158.289001 482.722992 161.130005 482.722992 curveto
163.972 482.722992 166.278 480.416992 166.278 477.575012 curveto
closepath
end
stroke
grestore
[0.8 0 0 0.8 46.095699 -185.560059] matrix invertmatrix concat
[0.8 0 0 0.8 15.695702 -167.959961] concat
174 462 moveto
(cm ) show
(* Group Created by User *) TailorGroupBegin
[0.8 0 0 0.8 15.695702 -167.959961] matrix invertmatrix concat
[28.251106 0 0 -28.251106 211.251099 150.748901] concat
1 nxsetgray
gsave
newpath
systemdict
begin
-1 -1 1 1 setbbox
1 0 moveto
1 0.552 0.552 1 0 1 curveto
-0.552 1 -1 0.552 -1 0 curveto
-1 -0.552 -0.552 -1 0 -1 curveto
0.552 -1 1 -0.552 1 0 curveto
end
fill
grestore
[28.251106 0 0 -28.251106 211.251099 150.748901] matrix invertmatrix concat
[29.5 0 0 -29.5 210.5 151.5] concat
0 nxsetgray
true setoverprint
0 setlinewidth
true TailorSetUniformStroke
gsave
newpath
systemdict
begin
-1 -1 1 1 setbbox
1 0 moveto
1 0.552 0.552 1 0 1 curveto
-0.552 1 -1 0.552 -1 0 curveto
-1 -0.552 -0.552 -1 0 -1 curveto
0.552 -1 1 -0.552 1 0 curveto
end
[1 0 0 -1 -7.135593 5.135593] concat
stroke
grestore
TailorGroupEnd
[29.5 0 0 -29.5 210.5 151.5] matrix invertmatrix concat
[-3.49691e-08 0.8 -0.8 -3.49691e-08 592.728027 -172.930054] concat
false setoverprint
1 setlinewidth
false TailorSetUniformStroke
gsave
newpath
systemdict
begin
412 410.647003 466.20401 477 setbbox
412 477 moveto
466.20401 410.647003 lineto
end
stroke
grestore
[-3.49691e-08 0.8 -0.8 -3.49691e-08 592.728027 -172.930054] matrix \
invertmatrix concat
[0.8 0 0 0.8 27.095699 -162.560059] concat
gsave
newpath
systemdict
begin
228 331.647003 282.20401 398 setbbox
228 398 moveto
282.20401 331.647003 lineto
end
stroke
grestore
TailorGroupEnd
grestore
gsave
[1 0 0 -1 0 358] concat
grestore
%%Trailer
end
showpage
%%DocumentFonts: Symbol
%%+ Times-Italic
%%+ Times-BoldItalic

%End of Graphics
MathPictureEnd
end
\
\>"], "Graphics",
 ImageSize->{460, 267},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["\<\
Let's write the equations of motion for this system and solve the equations \
and animate the results.  This is a single degree of freedom system with the \
coordinate and freebody diagram as shown.  We will use angular momentum to \
derive the equations of motion.\
\>", "Text"],

Cell["\<\
Define fixed relationships between the frames of reference.  This step is not \
manditory but it helps reduce the results considerbly.  If this step is \
skipped the transformations we will apply later will have to include these \
definitions.  Note: these are different for different base orientations of \
the frames. \
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "Dot", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", "k"}], " ", ":=", " ", "1"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", ".", "i"}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", ".", "j"}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{"k", ".", 
   RowBox[{"b", "[", "1", "]"}]}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{"k", ".", 
   RowBox[{"b", "[", "2", "]"}]}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Dot", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Unprotect", "[", "Cross", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "1", "]"}]}], " ", ":=", " ", 
  RowBox[{"b", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "2", "]"}]}], " ", ":=", " ", 
  RowBox[{"-", 
   RowBox[{"b", "[", "1", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "3", "]"}]}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", "\[Cross]", " ", "i"}], " ", ":=", " ", 
  "j"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", "\[Cross]", " ", "j"}], " ", ":=", " ", 
  
  RowBox[{"-", "i"}]}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Cross", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5184397987980003`*^9, 3.5184398000928*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["FMR\[Dash]Angular Momentum", "Subsubsection"],

Cell["The force vector on the rod is given by:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F1", "=", 
   RowBox[{
    RowBox[{"-", "m"}], " ", "g", " ", "j"}]}], " "}], "\n", 
 RowBox[{"F2", " ", "=", " ", 
  RowBox[{
   RowBox[{"Rx", " ", "i"}], " ", "+", 
   RowBox[{"Ry", " ", "j"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "g"}], " ", "m", " ", 
  OverscriptBox["\<\"j\"\>", "^"]}]], "Output",
 CellChangeTimes->{3.518439804336*^9, 3.5184398795592003`*^9, 
  3.536264474042488*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rx", " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"Ry", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.518439804336*^9, 3.5184398795592003`*^9, 
  3.536264474044284*^9}]
}, Open  ]],

Cell[TextData[{
 "The position to the point of application of the forces is 0 and ",
 StyleBox["l",
  FontSlant->"Italic"],
 "/2 ",
 StyleBox["b[1].",
  FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Or1", " ", "=", " ", 
  RowBox[{
   RowBox[{"l", "/", "2"}], " ", 
   RowBox[{"b", "[", "1", "]"}]}]}], "\n", 
 RowBox[{"Or2", " ", "=", " ", "0"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"l", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}], "2"]], "Output",
 CellChangeTimes->{3.5184398054748*^9, 3.51843988101*^9, 3.536264474089769*^9}
  ],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184398054748*^9, 3.51843988101*^9, 3.536264474091758*^9}
  ]
}, Open  ]],

Cell["The net moment about o is given as:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mo", " ", "=", " ", 
  RowBox[{
   RowBox[{"Or1", " ", "\[Cross]", " ", "F1"}], " ", "+", " ", 
   RowBox[{"Or2", " ", "\[Cross]", " ", "F2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[Cross]", 
   OverscriptBox["\<\"j\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.5184398070816*^9, 3.518439882258*^9, 
  3.536264474126563*^9}]
}, Open  ]],

Cell[TextData[{
 "The full inertia Dyadic about point  ",
 StyleBox["o",
  FontSlant->"Italic"],
 " is given by:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Io", " ", "=", " ", 
  RowBox[{
   RowBox[{"I11", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I12", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I13", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "3"}], "]"}]}]}]}], "\n", 
 RowBox[{"\t\t", 
  RowBox[{
   RowBox[{
    RowBox[{"+", "  ", "I21"}], " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I22", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I23", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}]}]}], "\n", 
 RowBox[{"\t\t", 
  RowBox[{
   RowBox[{
    RowBox[{"+", "  ", "I31"}], " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I32", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I33", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "3"}], "]"}]}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"I11", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I12", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I13", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{3.518439807924*^9, 3.5184398833344*^9, 
  3.536264474159738*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I21", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I22", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I23", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{3.518439807924*^9, 3.5184398833344*^9, 
  3.5362644741618557`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I31", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I32", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I33", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{3.518439807924*^9, 3.5184398833344*^9, 
  3.536264474163506*^9}]
}, Open  ]],

Cell["Making the I's constants.", "Text"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "I11", ",", "I12", ",", "I13", ",", "I21", ",", "I22", ",", "I23", ",", 
     "I31", ",", "I32", ",", "I33"}], "}"}], ",", "Constant"}], 
  "]"}]], "Input"],

Cell[TextData[{
 "The angular velocity of frame ",
 StyleBox["B",
  FontWeight->"Bold"],
 " is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NwB", " ", "=", " ", 
  RowBox[{
   RowBox[{"omega", "[", 
    RowBox[{"N", ",", "B"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "'"}], "[", "t", "]"}], " ", 
    RowBox[{"b", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "3"], " ", 
  RowBox[{
   SuperscriptBox["q", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.5184398106228*^9, 3.5184398858772*^9, 
  3.5362644742253942`*^9}]
}, Open  ]],

Cell[TextData[{
 "The angular momentum is given by ",
 StyleBox["Ho = Io . NwB",
  FontWeight->"Bold"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ho", "=", 
  RowBox[{"Io", " ", ".", " ", "NwB"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"I13", " ", 
  SubscriptBox[
   OverscriptBox["b", "^"], "1"], " ", 
  RowBox[{
   SuperscriptBox["q", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.5184398119175997`*^9, 3.5184398865324*^9, 
  3.5362644742437468`*^9}]
}, Open  ]],

Cell[TextData[{
 "The equation of motion is given by",
 StyleBox[" Mo - DvDt[N,Ho]==0",
  FontWeight->"Bold"],
 " we will drop the",
 StyleBox[" == 0 ",
  FontWeight->"Bold"],
 "until we get to the solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", "=", 
  RowBox[{
   RowBox[{"Mo", " ", "-", " ", 
    RowBox[{"DvDt", "[", 
     RowBox[{"N", ",", "Ho"}], "]"}]}], "//", 
   "distributeScalars"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "1"], "\[Cross]", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "-", 
  RowBox[{"I13", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["q", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"I13", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184398126976*^9, 3.5184398878428*^9, 
  3.536264474276812*^9}]
}, Open  ]],

Cell[TextData[{
 "Now lets take the ",
 StyleBox["b[3]",
  FontWeight->"Bold"],
 " component."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", " ", "=", " ", 
  RowBox[{"eom", ".", 
   RowBox[{"b", "[", "3", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], ".", 
   OverscriptBox["\<\"j\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.5184398145072002`*^9, 3.5184398901359997`*^9, 
  3.536264474309663*^9}]
}, Open  ]],

Cell["\<\
The last thing we need to do is transform the unresolved Dot product.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"transform", "[", "x_", "]"}], ":=", 
  RowBox[{"x", "//.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b", "[", "1", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"q", "[", "t", "]"}], "]"}]}], " ", "j"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], "i"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"b", "[", "2", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], "i"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], " ", "j"}]}]}]}], 
    "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", "=", 
  RowBox[{"eom", "//", "transform"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"q", "[", "t", "]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.518439817752*^9, 3.536264474376153*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"q", "[", "t", "]"}], "]"}]}], "-", 
   RowBox[{"I33", " ", 
    RowBox[{
     SuperscriptBox["q", "\[DoublePrime]",
      MultilineFunction->None], "[", "t", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"q", "[", "t", "]"}], "]"}]}], "-", 
  RowBox[{"I33", " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184398389835997`*^9, 3.5184398930844*^9, 
  3.5362644743933277`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve and Interpret", "Subsubsection"],

Cell["Define the constants.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"l", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", "9.81"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"I33", " ", "=", " ", 
    RowBox[{"m", " ", 
     RowBox[{
      RowBox[{"l", "^", "2"}], " ", "/", " ", "3"}]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Appendix", " ", "C"}], " ", "*)"}]}]}], "Input"],

Cell["Initial conditions and final time.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Wo", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Qo", "=", 
   RowBox[{"Pi", "/", "4"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tf", "=", "7"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eom", "==", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "'"}], "[", "0", "]"}], "==", "Wo"}], ",", 
       RowBox[{
        RowBox[{"q", "[", "0", "]"}], "==", "Qo"}]}], "}"}], ",", "q", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"P1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", "t", "]"}], "/.", "sol"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184401005176*^9, 3.518440117038*^9}, {
  3.518440151514*^9, 3.5184401739312*^9}, {3.5184404844863997`*^9, 
  3.51844048926*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc8lV8cx62UdY24VzYRUpKKjPqeZKVSRkqolEQiK0pIpZSWTRooFSKR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 7}, {-0.7853978921984491, 0.7853981633974264}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5184398510424*^9, 3.5184398995896*^9, {3.5184401043864*^9, 
   3.5184401203764*^9}, {3.5184401681280003`*^9, 3.5184401766612*^9}, 
   3.5184402509328003`*^9, {3.5184404431152*^9, 3.5184404903208*^9}, 
   3.5362644745761423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Qo", "=", 
   RowBox[{"Pi", "/", "8"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eom", "==", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "'"}], "[", "0", "]"}], "==", "Wo"}], ",", 
       RowBox[{
        RowBox[{"q", "[", "0", "]"}], "==", "Qo"}]}], "}"}], ",", "q", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"P2", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", "t", "]"}], "/.", "sol"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184402536472*^9, 3.5184402542088003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc8Vf8fx+19L3LvJXuUNChSRLw/lSikrDRIVEq2hEolGtJAJKMkDZJZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 7}, {-0.3926990866481384, 0.39269909246423473`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5184402302316*^9, 3.5184402545832*^9}, {
   3.5184404373120003`*^9, 3.5184404417268*^9}, 3.518440492068*^9, 
   3.536264474598136*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Qo", "=", 
   RowBox[{"Pi", "/", "32"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eom", "==", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "'"}], "[", "0", "]"}], "==", "Wo"}], ",", 
       RowBox[{
        RowBox[{"q", "[", "0", "]"}], "==", "Qo"}]}], "}"}], ",", "q", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"P3", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", "t", "]"}], "/.", "sol"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184402354108*^9, 3.5184402585456*^9}, {
  3.5184404082024*^9, 3.5184404256275997`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHdczd8fxyukcW9D3VtaKqE0VN8I0ftICmmKRKEo0U4iNFREUUYbiWhp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 7}, {-0.0981745993166847, 0.09817477042467808}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5184402373608*^9, 3.5184402589356003`*^9}, {
   3.518440408998*^9, 3.5184404352216*^9}, 3.5184404934407997`*^9, 
   3.536264474617342*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Qo", "=", 
   RowBox[{"Pi", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eom", "==", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "'"}], "[", "0", "]"}], "==", "Wo"}], ",", 
       RowBox[{
        RowBox[{"q", "[", "0", "]"}], "==", "Qo"}]}], "}"}], ",", "q", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"P4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "[", "t", "]"}], "/.", "sol"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184402422279997`*^9, 3.5184402618528*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHlYTO8bxmfaVFpm2mdataAiJC2o90FFRRtKSCSlRdpDkUoLSiJJJdkS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 7}, {-1.5707962640584283`, 1.5707963267948652`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5184402431328*^9, 3.518440262196*^9}, {
   3.5184404164236*^9, 3.5184404328036003`*^9}, 3.5184404949072*^9, 
   3.5362644746442413`*^9}]
}, Open  ]],

Cell["\<\
This shows several runs of the simulation.  The numbers in the brackets may \
not correspond to the results you have at this point.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"P1", ",", "P2", ",", "P3", ",", "P4", ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5184402664392*^9, 3.5184402705108*^9}, {
  3.5184403537272*^9, 3.5184403965179996`*^9}, {3.5184404526468*^9, 
  3.518440455174*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc8lV8cx62UdY24VzYRUpKKjPqeZKVSRkqolEQiK0pIpZSWTRooFSKR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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHc8Vf8fx+19L3LvJXuUNChSRLw/lSikrDRIVEq2hEolGtJAJKMkDZJZ
UkZ9iIyMXOueS1YZFX3tvX7n94/7eD6c1+d9Pq/3OJ9zlJy9rE5xcXBwnCH/
/P/32aE3H8I2hBoabzCymVdiw4s5RsjzWCdwpaw5PULyvju8ay/H+sBgh+Hn
7yTviV+OTHO6CJFDX/bHk5zSFLTgGnsN/jpPSO8jObntQs7y/A14W96lNKjI
hic9/icfOoXDvY7hE+dITvh9Tmp95X1gZd7s6VNgQ22Arsvx2CgY6JdK3Emy
2fxWtL46Gii3NkTdlmfDtytbpKfmH0LD1cPlhXJkfC7tiRKNOCjI3LulVZYN
lTe06u84JUBM3cfedhk2GAtqph2MeQzjF/2aaqTZUH53Y4hSZRKsU7bnerWS
DT17GYlHY5/BpOvNVSslyfu9QxcozU4BG6uelW/pbDheRzuvWv0c7pfEWW+h
saHzgMT+0fmXcOrGivg5MTYkPVhRfJCeCh+2BqVuF2WDQ7P42mKNNLitELV8
hsKGH3Zi3Lec0sGg9PuDYEE2PI4X9R66+Aas32xkuvGz4Wg7tcMyJgNur091
3MHLhrZjlA+ylVnQ6EPxe8PBhiGtG1sOx+aC/fB/OZemCKht4hkSVnkLXvTK
lwXjBGT4XU/5nP0W+ngH5npGCHDLDxVdVf0OLPjOfh/9S8DfbSF//pt/D3GL
tqepnQR8a+NMfhaWD9Q7Vc+fthHw+tK1gzb0D8BMXGsrwyLgzKfgsgKNj3Bs
4qhy43cCBtDVJ9edCsFndXeRQQkBFT1L1jr/FcLDkvQJ5WICXoVcEfp7sQiy
T1wsGvtAgEv55YD9McUg9pWP0yqbgF6TIEvpys+QEVndIPqEAJ/UYq5DsaXQ
sJTWe8ePACP5qzqPf5aC0ses3JeeBEg93OHerfEFBL2OPXx1hoCSkIqWM5Vf
AHZLfnSwJ4B6rCHtwkwZlBz/KpGyk9w/rdci8UgFJJfbFIYJERB851Vo16sK
0Kpa6GZwE2DN5fpRZbwCTGKKbt6dZ8Hc8D+ljDuVIDz5x11jiAV7a6Yniour
wK5iT8C+Whb0XxNO7JSvAb3aN+7Lt1hQOFP3XdmtBky8t6wVvMqC+16RPKc/
1IDGfde+ufMs2OJA9xzeXwuF2DA49gQLrusq7OC4VgceBQ3bsw1YoDSsNaD0
6zvYKKYIeP1rBQ2NzPi31o1gV6Z4xVO/FXyRUPW+gEZ4Pepy0XZTK+RbnZ75
ndAI/+k6paqtbgXDACU7hZ+NcHWeWRBNbQWLkoe0u95N4GElwbzc3UL+Xok4
da8ZfuUk3kgPboEM//03pCpbYYG+OjD7bTOMhGXkvfvbSta/uOuml82gnSjY
a0FlgYJFemfSo2YoxmU7b9iy4B2FddMoqBlqBXQ5xn6xoN7timSeUTMMJShe
qiHrsHYqp0mjsQnW41HvK3rtkHlSpu9vVyO4BN1tdHFoB1PrNL/QhkZI2bZG
e39wOwSdSK8ULm0EqTz7aYWKdkj7PjU4+KwR+F5XXi61/AF+8zqPB50bofvB
k3Ae1w74NfjCcKKHCbEue1+EP+qC2bXe98KbG4DzVoOb2VwPvJwI8huRq4PX
MVY6vPn9cDDAwZy6VAqxl/en9CgOQqDtXN/37emAa/1fuv0dhq9qpb+ce9Ow
26e1M3UWY1Dtf6Yv0ukLlgqx9Zi+OgETpnwGn3Nr8fSNI54Xbk/A5L7jZi7t
tbj1tqPX/IMJeFlk/2SEpw4/jHL1WX45AVVDjJNv7OrwimeXz/PXToCaS//f
vPk6LFzy8rKk1CSU6l4oGTf4jpcWJ+/p5EwCLISe4G5pwB2c8/cLCibh5VOs
2TzQgIt5OSL1yyahoiQoJXquAV+kCD2A1knY5mKn2KnAxNOy8rEmC5Ng8V9h
6FNXJh7RN06y2zMFF6xS2GWzTPzrQmxWQPcUvD7IbcoQacKB59om7P5MwXN7
W4NgmSZM9ZDX1x2bghvOXSrsdU1Y7/iryhnuaZD/GPbQbm8TjjTO776wZhre
a6kk3rjRhA0lWlcEeU4D7fLBXwlzTTghgx4QvDANt9TdD1qzmvGmV4c/Heed
gbCBxHWhvc244ukT7h3UGTCTW30mebQZjz5YHcmpOAPhoTZjKcIteM+FLa9D
ds1ApYCpSKVhC57cbdt+PXwG3u83Y1171oIPdMXAbalZiAMeiwuHWvGLXWca
tyvNgkObSqbwiVY8nap/amTtLAjt6J0I92jFSd4/w+30ZwHzc8keCGnFQ5yb
WlcfI6/HB3+Mp7fi26tq3L88n4U5vanp+JlW/CMsafl8xizEer5amuJk4U3/
fB6sfT8L3fo73JEwCxPvpT5GVsyCWzv3sTg5FlY1ceF2/DMLyYn/1RzdwcJf
XDkT5jXmYN/V2rB1N1iYUd+8IVtnDi4HasSa3mNhV6007IzmwOejcvzBhyws
Nm/RV205B8f8s05pvWThY3cfb4rzmwO5Tg+XmTIWnsvSqdQunIMcJfVXHxdZ
2EJC+MjvL3PAiBtRfMhD4GcBnUOJNXNQzxe2yUGYwHvQjRXcHXOwTdd8JluK
wLHMRgfm8hz8oofFOGoRePOEx4TH7nnQ2zd0+6cTgW0yfX52WsxDbZ6e0X+n
Cezncr5h/6F5UOneH9vjQeA8IihD020eLnLuGrxygcDan+6cnIychwvyT3B0
BKn3j7BySZiHQ571Se0xpH5jNGI9nwfNKPFBoQRS/yxBtiB/Hk4Ya35QeEHq
b75uDvoxD3xVH+KVPpB6yPzyr28epNbm2b8oIvUzOTnHhudhlu+/09QSUn/2
413EtQC/S7yM46pI/f5KIx61Bcj/sz4vhCD1AjVa5zUXIKBqeA/8IPWl9Yr9
egsgsYaL/1cXqd/culC5bwGmGo6OdvWTeqm+vDvnFkByrfiq7HFSz/ydshC0
ANZ/mKkvpkh9+FCkx80FWBRs1782S+oXxt33xy/AHnHe8OElAje/nz5SkrIA
09c44BonG094zu/RzFiABtfZ2VluNtbu4VotgRfA5tiTwGQBNrZJ4JO4XrUA
kRHdOvVCbOxnLcQ5yVyAklDLiZ8ibJz3VbyjtXcB+ipH7UvF2Lj5Cr3G5L8F
eJXqz3tnBbm+zsqCj9MLcCSy+bk+jVw/XfFhgtAiDDbXFFlKkuufWBUqTFsE
vuZArQ9S5Pqyaj5Bcosgo6Qazy3NxjEt6x3/qS5CDGf8f1tlyHj3N+47tmkR
Aq5laVrKkvFMNut/37YIL32POlnJkfE4dNaiXYuw2j0jSE+ejWmFepK55ovg
XP01RFCBjH/OkFf54CKce/3LF5Nss2Hn+APHRTj232Fze0Uyft/uHm7XRXDc
HkPtJjkmae93P99FUJulF5gqkfHt9n3qu7QI68wumj0muVnM8s3BG4vQKuX3
tZnkiWqb+Mr7i/CLv151gmRa6KFbunGLEB101muO5C3b7c+/frYIk3G7ng6Q
LDKYlBaYvgjFQ+u9MMk/43vaTd4tgsHGqFPXSC7Ys0pUsngRpm+8ClEnOXLa
ZWd/+SK4SORWlJH35/Lq9fn3dYsQMsWvZUSyge1Q2vXWRdA2pX3NIvdH49n4
w7prEVpWWQZzk/z3rY+oyu9FePPI7ORO0p8Sp7ydYyOL4JSV4uNG+vdIbPp8
6ewigDv/6yukv5542+tIriXyPLNdOIj038gz6Iej8BJ0v5WMP0HmR1oOi26k
LcEZg6vWW1ay8WgN564l2SW4GeiuP0rmN2ntrdePNUgOZcStoZP+EtU/3HSW
QCJdQTRFgo3NbomI6aMlCFpv8pGPrJeZ3ih/tuUS6KgdeHWfysb10c2v044s
gYA89b9cst5e7pTsCDixBM+PP/fAZD1aJT/exTi/BO8LGqXj+dhYbX+Xf9/l
JThrwDY7xcPGy4tK6Xk3l8CqL6JIhouNM46milnHLYGeZsYxk0UC80u+7Ygo
WoLs3b1D8WME7vw6IeZYvgTizzXNPw6T/eOnY6RRtwRo3nC+ZIjAzo3F6bWd
SzC1x98qiuzH4nuVAYJcy7CW10xDg03gB9uF3hBCy7BwimrztIXAroPmnakS
y8CMlO2aYxKYsbfRyHj1MqTYaGn6fCOwN0+HeOieZWiX7pY7Wkhg43cKu60s
l4EzTapCIZ/Acs7OgUpHloH2OvlffS6Bv+GBTuy2DEo/J6uG0gi86tLYm4X7
y3DNeUlqTSyB2aP8xv4ty3DB4lhivDuBgyYvNnN1LcP+6z1OES4EVpz95xzx
exkEFtma7scJ7MLRfDVtfhlc81X52q0JfIG/wf6fGAcam3BTv7+NwLyMx7EK
OhxoQ3zKpgMcBG591NLRp8+BpNQeRBbMsHDaStHVGYgDneuePik0ysJmciHv
dE05kOyI/m3nHhaOWnWmwdKBA1kfjHr0r4SF5TZrC10P5UAT+rpt5y+x8H95
HpamYRxIX85M74gvC5dsTY0Tu8eBEr1UHqi6svBJPek1T2I50JrWnfsCDrJw
+g4Oo/zXHGhGfd/47EYW3nqg9vLv7xzoUl2Iw93OVmzhcXLUXJYT/VZ9Haq+
rhVfedHXuaDIiTa77Uu3l2/F2e0utRmrOdEwiv9zfkUrFjN1TRXZyIn2Sl7p
cplrwY2qng61OzjR9sbIv7uqW7Btd0C12WlO9C3yT/OEcwu2t77zzPQtJ3KX
F6DevtmM74aLRMzlc6Lj5z42rghsxp9K7wWlF3GiuHKTXWGuzVh+U6Sd0FdO
JKD003GreTPuFnlI+cbiRCUjcSueiTXjExVJF/YucqIjET6LxQ+b8Nltby33
7OFCubJLnIFRjdh/sNEp1ZwLcR+5Wf/hWiMOeTLuw2fJhUzmG6IGfBpxPOeW
B+WHudCub9xaklaNuKr6QyNy40LiBc6WH8Ub8eojn6y33edCBbC8RLnPxN0X
q2zXNXOhj56ZEa6XGrBdcedhkePc6NZkQ8quQ7W4maBXXYrgQWWylygjjFKs
nLG+8106L3KxP/nCy/oVXpYyP/Kogw/FeQeeO9eTAY86Dp/pFRJAtSd9n6jY
lsH1CE28R1QAvelvT7gUXAa+OwQZmRICKHi3sMOXN2Vg8fJj2XlZAbT6tXCc
DFc58HhIKvBrCCCdmIiKmcxy8F1obllrKYB2tS1uNOCqAHOZA7u8Hgkgvh0B
RwcTq4DjsLH8nIogsrO7clngbh3YbMlX/qQmiAoMbx9QeV8HaeKqa4LVBZFK
7oC3QmcdHPjGu4lPRxAJtp4dL9xYD0/1v+5YYSqI9J+nXrrIrAdDeaNT67wF
0ZcQ/6lL/A0Q9GtHxpFiQWT++98GN10mNODcHLlScn1ppUv9pkxY9VjpffdX
QaQwdHF2vwMTam04P7t8F0Q1bvnb/11jgkxFyXffn4LIcqfUD4tvTChMg/Fw
ASGkon30fZJdI8x4GOgV2Qgh4pdd6tSJJljz1dxJ/bAQ6tqsdJnnXBMclLUP
e+oghAqlsv9yhDRB3reLraEuQkjVQ/3w16dN4LPmo695oBBin6mSudTWBH+7
td50JAoh3+716hHmzfDDWk2W45cQmlgRd5dHpQWE3+js8h0QQjAi4Fq3sQX0
uEzO9g4KIYldGxxCt7dAXM6pj1UTQsh58s/xfNsWsKU8t4niE0ZO/g/TdG61
QH2F3D3ldcJI59Me7qT+FijdJrFk5COMFMJOlr+LbYUDxmdrks8LI/Wg04Os
5FbotCqNW7ggjLbKvM7/nd4Kc25em/NChJGA1qJUw+dW0EqqOaMSI4zOZfOt
e9/XCilc15s4Pwij3XuMHzM3smCTaHuyQ5EwWnHGa1+xLgs+y2h5FmBh9Hdf
jGr0Dha0aXcL+FQJo//CObV5rVmw4vR2w262MNrnbz8568eC0JqJtM8Lwiio
w1pK8T35f8LMX5pTBK38YC38rZgFyb0pu/x5RdCR9CeFjuUsKF480KlOFUF4
q+cWiyYWTGzMlHiiIIJ+tZiMbx1hwcmYU1cu7RRBhW/Nr2mpEjCWXGzGMhZB
C/PdgQ83kO/bmRIrN5uJoKmr7cxfWgQ8rih999daBLkIx0fvBAKaZ+T+HD4l
gu7s5qnhtyNgt0OrtW6YCKJFlg9khBCgF/O1fuyuCBJ0yN+rGUaARk3e3swo
ESRpVSv65B4BjG3RoJwogpROfn+3Lo6A37QD60WyRFDFI7MGuQwCfpjBq4q3
IsjhbmPljxwCGkI0lK59EEEdJ4oWQt4TUDAiIjlVIoKa82mUG58JCK+t5upu
EkF52tjS8TsBV7gLLicQImgp4vYnuyYCfPXSZmw6RJDKhp7dOiwCjqbd/K+6
XwSpWkc9edNJwIGu867XB0WQ8gLzFPpJgBHjVK/hiAjqUvHeXtxHwIbru9re
zYogNY1EftchAhSLtGw9l0SQV0n9ZPwwAfQxpQY1bgpK0srsyx0jYMmRo+KJ
CAVFGnz+HDtDwHf9T7m3FCioJi9HUJubDeW+GRt2rqIgxe20j4952fDxdWLq
ghoFmaZusR7iZ0Oy5MUnPloUlPmTwwSJsCHGwlVqgw4FeRXcSzSisuH2jUPR
/frkeiFJzRvF2OA7vvX20d0UtCFK6l+hBBtc1qnyMEwpyLJNpfoInQ1HnOhX
GywoiEtxOqSHwQaLOJ65cGsK2ietsHK/FBt2fR/3232IgtRPofDnK9mgy/dr
eNmeghyuSbZ0SrNhg0Hj2UInCqpuDpzhkGWDol9pn58LBblePzAuKMcG2puc
4xvdKIg4nlI+S7LAz6ftf7woKGtzuFuDPBsWpCIOvvCjoPQK/YF7CmwY2X+F
eewCBW38yaWjpciGvpse5iuvUFC+2a4jn0hu+2Rf2RRCQXvLAw9sVGJD/YTZ
zvu3KGiWT2dlGMlf1ut/2nOXgmwq1+ZVkpzvvE6XO4qCurJpSv+RnB6/8t2n
hxR0/3iT4/+/dz5tENAITKCgrR6HvYdJjuGfSdN6SkEi9m+tvpEcZjig8u85
BdFecPLfJTnofGtSahoFPXsTck+bZO+MryudMynoa0VYP3k+hZO/8mJk31JQ
3ZarK/RIPiz9QpSVT0EfVP6IPyL3p1arlYmKKEifYYd+k/ufuVxqmo4pqFEu
LlSF5KqNB35LlJP5X7v/xx7Sr7iezhuXqygodbem2SHS3zPRHioDtRRUkMTL
tJRhg87uhZIDTAo6EvTScwuZj9a0lQsqbaT/nvyThZJseHUkLf5eJwW9iWvt
sifze15ER2f6JwVNe9/p/00j8+Nt4/ttkIIEHW+ZY3E29Cr9EtUeoaABI/cs
QbJ+3jX5ZD6ZoCCmv6+mIVlfVjoRv70XKWhwa1/yKSE2KP+Ru9nGSUWFG4Ij
DwmwYTQhQ8WIj4oKNsenbuFjQ+RS9TFJUSritDljncXJhuM5hxaCJajIDzoG
9y4TsMl5IP6vJBW9GNn37vsC2Q9feVo+KVLRgwNnWPHTBCQFRPuuWU1FnobO
up0TBHiuVRaLWktFNLeZBhGyn6j3wOykFhWlxDi9VSP7z9zmYqmQERXd3T11
6WgXAbJ8go5+e6go1UC5a7SdgMEPjxY6zKmI+2jUfV+CnA8y73VybanIafJX
hxaTgKqfw5l2p6mIvX02OruUgLiYK2alblTUfulYVtwnAk4bU/6s8ybZSVPD
vYAAvvR1q5YCqUjbVti9kZxHu31OJbwIpyLFt4O7HycRQFOZ0KFGUBHIPh4h
4gnobQ5pCYimov2SJ+Q5HhJwXTdZzOwxFb1MdJCg3iHgy3LbzdFMKlr9VJhQ
8yfA8P6Bc4ZMKhp/tSPbYQ8BfmcDPvO1UtFZl/qKkh0EpBsnCX5vo6KLUmlT
QvrkvFkefOrYS0Uj/rEFNuoEDHndqg2epiI9J2r4ZzECEi0/ry6TE0VDImei
RxtZ0KDe531HWRSFbPEPrP7GAj4hkWLrNaLoyBnDv2FfWOD75bBV7yZRJMHv
GfM5lwWmmyev8BqJooChrEHeCBbM0DYQJmdF0VEXQ12R3SzQGLVSEfMSRUWw
//dxffJ5UnfBkzgniuZ+sHKfaLLg+41KHtfLomhK4fuH73IseDXlrBkeKYqw
tFgKY7IVbIn48Np8UXRYxbhZ92krsOtCk9I4xZCyOjNX+mcLvGDoP+LkEUPq
6S3jpS0t4Ok4FnGETwzF8UwGW1e3ANfo8WsiwmJo73mZjC05LbCBZnjSmyaG
UofaHk0HtcDVIzNrddeIoTn+3vigFS2wesD9faW5GNJ+qWXSr94MIxtXZSnu
F0O8D0vuDMs3Q2Fg+6sLlmKoQSqspFe0GSyETOPWHxRDF8bbtaNHmyBQfc2l
CEcxFKOY94szrwlqzvUgO18xRLly7PzmLeT5heNgbf8jMbQxyvGQzdpGSOdz
OCiZIIbkkypLVq1shJ8iJ7tNHouhxf4k1z6BRrBa6TuRliyGGFp573R+M0FL
676s22sx1L1kkqX0igljJyrchwvFkN/oYpSkAhN8K7dSZjrEENXvwcMR3gbw
vS9pIbhKHBmcfDh6zLYG9Fw7QziLxZFXiNixmywMbk9jhDv3rkDOMaqzDgee
wYVrOxyGm1cgxR0ikuHSmXh/zrhTq5sEelzwMsj1dBkO3HowQtBTAmls9JOq
f1CGk4s/Fm/3lkCvexiHlT6X4bGqy5LP/STQkM35TdG0chzbw1/ndVkCmXzO
FUsuKcedK2R1BSMkUFjqXIIBvQJ7njeibn8rgT6X9DeGZlfhe3oPC5/NSCCB
rsDnjsl1+G9LmSHPvAQKMU1+FVRdh419xr64LEogI7sTVRfH6vBS6v6a9Vw0
lD28ULLSqB570oV+vBemIYMXbUsdffXYYuTKYrU8DZlcHhzNFG/AYq/OoDEj
Gpriatl+ZycTu+94VG5jQkObqdOPeGyZuOrH1z0f9tJQ6ZpJQffTTBwsoWIZ
ZEFDCm/P/Oa5y8SjwR1OfIdoyNr99V37ZiZuPGoVKu1GQ2+umj2NdmrE0eLb
K3ZG0ZDUhE7AK48mbH+2sD0omoyX7jWQHdSEVct0R/Mf0tCKDG1W6p0mXOi3
RXZ9Ag21bTzOeeJ1E+5mafhKPKeh07fjJXl7m7BGkpJ8bx4N5U/06v+zbcbf
1vH73yBoKFKbuXdmfQuOCb1xB7fRkD3fg6wC3RZ87Af3s9kfNNQppLbizO4W
PHqPo9ajh9z/unXpd461YKnRWaWDf2lILPLJ8FBEC3b5MFSnukBDpkGH4qnD
LZjLqHF1lQIdVQocRWFJrfhSgB91WomOwrUc5FPSWvFEOmN69So6St26Nyzt
bSseED9aFapGRwvbpjsvVrTi2q5fZ0GTjobyZ/K0/7Xih5cms/N30pGGheGq
qa0sTM1+FNdnREexwC/QAiwc9nPbNZoJHc05Ppl/uoeFL+69YuVrRkf3HL0m
Zw+z8DFJ/kl1Gzq6rc7n+Yl8X1Z7J6X38hQdLWf9DgoqYuFn/YXKzafp6PGt
EKWVZSwsLe0gzH2WjuR8Lp999o2FKdee/TjuSUcmS4JMPzYLj1msuyobQEcO
PQ57VKdYuOivfnl0GB0pWda0Zq0nsLZ8Z8aXcDoSOraFh1uLwFmWwQ9H79LR
UZPQSzt1CZz8sdxlfxQdmQtf3RxqRODrN/cJCifQUWf8M0NhewJbKDtahLyh
ozP+K1I1bxF47mzdve5MOsKSxVtf3CXwq3f6dYY5dLRXyVR8KYrAy0ZS5vN5
dCSfl/vg9GMC55xm7vX7TEdjNdsMxHMIbJ8DtxtL6CiHdzD+Ux6BBWczqzaV
kf64rpWxLCCwc3i4yb9Kcv3/Bi6ofyGwROau3S5MOnKjd28uaiRwyWTu9fIm
OjrytgKSWwnsbqhYrtxKRzNeP/a7txG4/PvCzq420q9dGzwLegjsLeUWYtBB
R5INHuf1+ggs58QuTewi68Hjn2/KbwL7j71Hh3rpqL3i0641wwRW1l8VnN9P
R7JzLWJGYwSuD32AaX/o6LdGUaXJJIHX0L0Mmf/oqOtZ6AD3PIEJHbXtptN0
pHjH84UFLxtfD469lDZLR48ep/ml8LPxpmqeIr4FOjJUspDuEGTj20d6tpVx
MNCe1ec6+KhsvPX5/gtK3AzUf2tualKUjX8Ofvp4lZeBdq1e7KgRZ2O9ywk6
24UYKF37LmUDnY37vwoEJIgwkBSz2yqfwcbR1ID8GSoDqS0hxzVSbIzs+iYP
ijPQu0Fzzasr2XjoqfWW9xIMtL2luPKTNBvH/S71k2AwUBCXk9Kv/3//09yU
5yPFQKOVSgbDsmw8ciFp/Ls0A525tbzypxwbP/kisllDjoHu5az4UCTPxqbC
l3zvKjDQ3pI7EkEKbDxl/Sf3rxIDvaK/01BRZOOUx3aje1Yx0M/x3/y5JFv0
fd2UqspAtIqXSauV2HhOXdubdy0DKShfHAsmOdU/JfvEejJ+BZW7jGQbLDZc
qs5AhQmrGgZJ5hC4qqG4iYHWvo45TJ5nccaBfx5XtBjotdKBp6MkH4o/mvlD
m4ESbI8/qyeZ52f1kJ4OA93P73d8QHLuOt0N8dsYKLRZtn07ycfOvXKb1mcg
OXsbiXry/oSKaW9sDRmojzYtYExyPk/o33eIgUK6bha/IPfnvG907YpdDDT5
7onGX3L/QdbZcya7GUjF//je1STHHvaouWzCQCcu3jtlSvqV47j+8bu9DBSb
0xZ6mPTz26k/7n/MSD9MxV5akX73uqUaKFgw0IVigW/keRYv+Zyi2h5gIOuP
OeNcZL60rvRkl9gwEMNK7vBRMr/m158GTx1koAe3GY/6aWzsEu5gueEwA01f
Uus8KsHGCbHssUcODCRtXHWXR4yN8x4/KqtzZKDoUNlpnf9/b02xjeF2ZqC/
RgxvWxE25sxmbvFyYSAe1/0xFgJsLP0+gu/lGQaKa+nfuY6PjbWL9rHazjKQ
KquJb4Sbjc9UVgcae5H5K1Ft3bZM4JC6W3uDfBioSN6/79MCgR837ZZ+e46s
1/5/4hvmCNzQVVokF8hAlsmj3yomCPy37+pd64sM1Nkwc3R8lMA8QwYOt4NI
7paXECL7TXemYGkimIGuGN9anCT7MVns7Y7a2wxEmPAKV7UTuJDhvYLrLgMd
CsM0Y4LAzbIav3TuM1DVqbHDWc0EFlibfv35AzJfi1UpBnVkv+9IqbyYyEBW
t0/etPtE4HCT43E5TxioRi2ibA05X17sk3ftf8pA619KHfxJzh/icIKQ1QsG
etYWfZuRQWDwfbBvbSbp/zvNB5fiCXwo8IC8YzYDff3R1pMUQ2DfK9ThmFwG
2qx24GVGBDn/wsMjOfIZyPfNhrhbNwhMfR7SxPrMQA66QS/1vQnc2eR7+GYD
Ay2ajNgl7yDw+uGF4MFGBsrOqtAe0CNwoNCttAMtZH8OJ8nQtQm8YkfitHQb
AxmPaCirqhLYOKvsYfYvBsq31WiWEyRwdhitkZhiIG0oX3OWfB4sPE+aNZgl
54e6z+KqLyxsitWUns8z0NHgD9aVBSzcO7nd24NDEk29EX/+JY2FpU6conIJ
SSIx56MFMTdYONgg33S9nCSqlxYOyNJj4bpDyDdSQRKNvO9w6dtEPn/8vsVP
Kkmi8fMHXXjWsHBeeudvrCqJ0umWRXMrWPi3JP8tm02SaMnctrn6Tyu2HLMr
u7xLEtm2cVbPPWjFyqmz+g2ukkhvKq51oqkFyz9J3brOnYx35Ef35coWLBNt
q3ndUxLNlyDN0cIWTLuaq6p7ThKdePWiOfZZC+azcxVPDpJEd0xWBnV5tOC/
fOx+rwhJdPvIZmMfrhb81uVjlOh7SbR9k+afMZlmvEs1YMCCQwrtjfX8GS3R
iLPYfueCuaRQxeimVBPuRix1z3c5l0cKDYT75wyOMfHQuIckXVAKBa03rOJp
ZOKY0pMm7eJSqPxz2cOgCCbut7dKPa0ihVQopxQi+Jk4LFr9dLCxFDKyKFw2
Z3/HdRy9/bl3pVBm83bqkkwNVlA7GP931UpUImzadt0MY3b6h6f871aicQGj
O19pydiHLep12FAaPRdq4KO6ZkGDjcdocIs0er+Jd6V2YRmsD6tQfM+SRlIZ
GQZ3+srgZpHCgT9saXLeamc1iJXDduXGLMtOaRSwqNO2+nQ5vB7e6q48II1O
j6hvmVzxFULCOQbKZqRRgbPqEN/pCtAuif7BJyuDqq8azY0uV0Hc+sLKu84y
yP2rzmf+f3VA/PGL4Tolgz5bLUpskawHqbSNToGnZZD5yiHdHTvqIX7Vy7kT
7jJIMui43mRMPSTIRarr+8ugDYiyvlLvOySKukT/uS2DBL4e75mEBkgaF3c0
zpVB4olRytcDmNCZW7u++J0MsuIM0nYIZ4K8960ZzXzy+sa6ReUnTHg6tBAl
VySDTqze6+L3hQnJfQPlE+UyKMeU4rRBpBGesT6te07IIN4bRe1dieT7xMPA
aal2GeSyqK12KbMRlG02l9/vkEGtD8YnOHEjpDSkOVz8KYOCnO6UM3tIro6O
tBwi9Qr7tgaqNsHPWxYOlf/JoCYUdcVDpwmUjQXXGYzKoPd5Knn79jTB8y9X
ytSmyOtD7z6td22C3uBtkUkzMuhgKFPT62ITrIIJe9q8DGo/ZXh2LrwJTi5m
rQ1flEGqu410vBOb4EWR69Tysgw6tHD6VsObJvgfSxnZRA==
      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHdczd8fxyukcW9D3VtaKqE0VN8I0ftICmmKRKEo0U4iNFREUUYbiWhp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      "]]}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHlYTO8bxmfaVFpm2mdataAiJC2o90FFRRtKSCSlRdpDkUoLSiJJJdkS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5184398530236*^9, 3.5184399015708*^9, 3.5184402714624*^9, {
   3.5184403616052*^9, 3.5184404554704*^9}, 3.5184404963112*^9, 
   3.5362644746646023`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsubsection"],

Cell["\<\
For this animation we will draw two circles center at each end of the bar and \
two lines tangent to the circles to repesent the bar and animate according \
the time solution above.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Qo", "=", 
     RowBox[{"Pi", "/", "16"}]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"Change", " ", "this", " ", "for", " ", "amplitude"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sol", "=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"eom", "==", "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"q", "'"}], "[", "0", "]"}], "==", "Wo"}], ",", 
         RowBox[{
          RowBox[{"q", "[", "0", "]"}], "==", "Qo"}]}], "}"}], ",", "q", ",", 
       
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thick", "=", 
     RowBox[{"l", "/", "10"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"circle", " ", "centers"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xc0", "[", "t_", "]"}], "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yc0", "[", "t_", "]"}], "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xc1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{"l", " ", 
         RowBox[{
          RowBox[{"b", "[", "1", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yc1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{"l", " ", 
         RowBox[{
          RowBox[{"b", "[", "1", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"lower", " ", "line", " ", "points"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xl0", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], " ", "thick", " ", 
         RowBox[{
          RowBox[{"b", "[", "2", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yl0", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "2"}], " ", "thick", " ", 
         RowBox[{
          RowBox[{"b", "[", "2", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xl1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"b", "[", "1", "]"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"1", "/", "2"}], " ", "thick", " ", 
            RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "i"}], "]"}], "//.",
        "sol"}], "//", "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yl1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"b", "[", "1", "]"}]}], " ", "-", " ", 
           RowBox[{
            RowBox[{"1", "/", "2"}], " ", "thick", " ", 
            RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "j"}], "]"}], "//.",
        "sol"}], "//", "First"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"upper", " ", "line", " ", "points"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xu0", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "thick", " ", 
         RowBox[{
          RowBox[{"b", "[", "2", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yu0", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"1", "/", "2"}], " ", "thick", " ", 
         RowBox[{
          RowBox[{"b", "[", "2", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
       "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xu1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"1", "/", "2"}], " ", "thick", " ", 
            RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "i"}], "]"}], "//.",
        "sol"}], "//", "First"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yu1", "[", "t_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"transform", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
           RowBox[{
            RowBox[{"1", "/", "2"}], " ", "thick", " ", 
            RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "j"}], "]"}], "//.",
        "sol"}], "//", "First"}]}], ";"}], "\n", "\n", "\n", 
   RowBox[{"Animate", "[", "\n", 
    RowBox[{
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", "\n", "\t\t\t\t\t", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xc0", "[", "t", "]"}], ",", 
              RowBox[{"yc0", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"thick", "/", "2"}]}], "]"}], ",", " ", "\n", 
          "\t\t\t\t      ", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xc1", "[", "t", "]"}], ",", 
              RowBox[{"yc1", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"thick", "/", "2"}]}], "]"}], ",", "  ", "\n", 
          "\t\t\t\t      ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xl0", "[", "t", "]"}], ",", 
               RowBox[{"yl0", "[", "t", "]"}]}], "}"}], ",", "  ", "\n", 
             "\t\t\t\t\t\t     ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xl1", "[", "t", "]"}], ",", 
               RowBox[{"yl1", "[", "t", "]"}]}], "}"}]}], "}"}], "]"}], ",", 
          " ", "\n", "\t\t\t\t      ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xu0", "[", "t", "]"}], ",", 
               RowBox[{"yu0", "[", "t", "]"}]}], "}"}], ",", "\n", 
             "\t\t\t\t\t\t     ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xu1", "[", "t", "]"}], ",", 
               RowBox[{"yu1", "[", "t", "]"}]}], "}"}]}], "}"}], "]"}]}], 
         "\n", "\t\t\t     ", "}"}], "\n", "\t\t     ", "]"}], ",", 
       RowBox[{"Axes", "->", "True"}], ",", 
       RowBox[{"PlotRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "l"}], "-", "1"}], ",", 
            RowBox[{"l", "+", "1"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "l"}], " ", "-", "1"}], ",", 
            RowBox[{"l", " ", "+", "1"}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "->", "1"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5184399153924*^9, 3.5184400158719997`*^9}, {
  3.5184405032532*^9, 3.5184405653724003`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0.9165550231933592, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 7}}, Typeset`size$$ = {360., {179., 184.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`t$160$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$160$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Graphics[{
          Circle[{
            $CellContext`xc0[$CellContext`t$$], 
            $CellContext`yc0[$CellContext`t$$]}, $CellContext`thick/2], 
          Circle[{
            $CellContext`xc1[$CellContext`t$$], 
            $CellContext`yc1[$CellContext`t$$]}, $CellContext`thick/2], 
          Line[{{
             $CellContext`xl0[$CellContext`t$$], 
             $CellContext`yl0[$CellContext`t$$]}, {
             $CellContext`xl1[$CellContext`t$$], 
             $CellContext`yl1[$CellContext`t$$]}}], 
          Line[{{
             $CellContext`xu0[$CellContext`t$$], 
             $CellContext`yu0[$CellContext`t$$]}, {
             $CellContext`xu1[$CellContext`t$$], 
             $CellContext`yu1[$CellContext`t$$]}}]}], Axes -> True, 
        PlotRange -> {{-$CellContext`l - 1, $CellContext`l + 
           1}, {-$CellContext`l - 1, $CellContext`l + 1}}, AspectRatio -> 1], 
      "Specifications" :> {{$CellContext`t$$, 0, 7, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {216., 221.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.5184400163868*^9, {3.5184405050472*^9, 3.5184405547644*^9}, 
   3.5362644747311153`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{200, Automatic}, {Automatic, 15}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 138, 4, 67, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[742, 30, 69, 0, 34, "Subsection"],
Cell[814, 32, 206, 5, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1045, 41, 193, 5, 27, "Input"],
Cell[1241, 48, 195, 3, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1485, 57, 77, 0, 34, "Subsection"],
Cell[1565, 59, 764, 25, 41, "Text",
 Evaluatable->False],
Cell[2332, 86, 585, 17, 58, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2954, 108, 38, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[3017, 112, 85, 1, 24, "Subsubsection"],
Cell[3105, 115, 28814, 991, 275, 24880, 923, "GraphicsData", "PostScript", \
"Graphics"],
Cell[31922, 1108, 289, 5, 41, "Text"],
Cell[32214, 1115, 344, 6, 41, "Text"],
Cell[32561, 1123, 1502, 45, 223, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34100, 1173, 51, 0, 24, "Subsubsection"],
Cell[34154, 1175, 56, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[34235, 1179, 246, 8, 43, "Input"],
Cell[34484, 1189, 197, 5, 31, "Output"],
Cell[34684, 1196, 250, 7, 31, "Output"]
}, Open  ]],
Cell[34949, 1206, 184, 7, 26, "Text"],
Cell[CellGroupData[{
Cell[35158, 1217, 184, 5, 43, "Input"],
Cell[35345, 1224, 202, 6, 50, "Output"],
Cell[35550, 1232, 111, 2, 27, "Output"]
}, Open  ]],
Cell[35676, 1237, 51, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[35752, 1241, 181, 4, 27, "Input"],
Cell[35936, 1247, 314, 9, 46, "Output"]
}, Open  ]],
Cell[36265, 1259, 125, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[36415, 1268, 1082, 35, 58, "Input"],
Cell[37500, 1305, 1338, 39, 34, "Output"],
Cell[38841, 1346, 1340, 39, 34, "Output"],
Cell[40184, 1387, 1338, 39, 34, "Output"]
}, Open  ]],
Cell[41537, 1429, 41, 0, 26, "Text"],
Cell[41581, 1431, 247, 7, 27, "Input"],
Cell[41831, 1440, 108, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[41964, 1449, 247, 8, 27, "Input"],
Cell[42214, 1459, 272, 8, 31, "Output"]
}, Open  ]],
Cell[42501, 1470, 120, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[42646, 1479, 86, 2, 27, "Input"],
Cell[42735, 1483, 288, 8, 31, "Output"]
}, Open  ]],
Cell[43038, 1494, 220, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[43283, 1506, 190, 6, 27, "Input"],
Cell[43476, 1514, 740, 23, 46, "Output"]
}, Open  ]],
Cell[44231, 1540, 106, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[44362, 1549, 115, 3, 27, "Input"],
Cell[44480, 1554, 316, 9, 46, "Output"]
}, Open  ]],
Cell[44811, 1566, 93, 2, 26, "Text"],
Cell[44907, 1570, 775, 25, 27, "Input"],
Cell[CellGroupData[{
Cell[45707, 1599, 85, 2, 27, "Input"],
Cell[45795, 1603, 240, 6, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46072, 1614, 362, 11, 46, "Input"],
Cell[46437, 1627, 422, 12, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46908, 1645, 44, 0, 24, "Subsubsection"],
Cell[46955, 1647, 37, 0, 26, "Text"],
Cell[46995, 1649, 416, 14, 73, "Input"],
Cell[47414, 1665, 50, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[47489, 1669, 995, 31, 88, "Input"],
Cell[48487, 1702, 13714, 231, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[62238, 1938, 842, 26, 58, "Input"],
Cell[63083, 1966, 13319, 224, 235, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76439, 2195, 888, 27, 58, "Input"],
Cell[77330, 2224, 13314, 224, 232, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90681, 2453, 842, 26, 58, "Input"],
Cell[91526, 2481, 13915, 234, 229, "Output"]
}, Open  ]],
Cell[105456, 2718, 155, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[105636, 2725, 309, 6, 27, "Input"],
Cell[105948, 2733, 52802, 876, 229, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158799, 3615, 34, 0, 24, "Subsubsection"],
Cell[158836, 3617, 205, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[159066, 3625, 7828, 233, 523, "Input"],
Cell[166897, 3860, 2780, 58, 454, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
