(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     28877,        700]
NotebookOptionsPosition[     27950,        665]
NotebookOutlinePosition[     28563,        689]
CellTagsIndexPosition[     28520,        686]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Bouncing Trajectory", "Title"],

Cell["\<\
This is the code for the bouncing trajectory.  Be sure to view it with a wide \
browser so that the structure of the Loops and If blocks can be seen.\
\>", "Text"],

Cell[TextData[{
 "In order to do this simulaton in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " it appears that a table of the data has to be maintained after each time \
step so that we can check for collisions and apply the needed momentum change \
and then restart the integration.  There may be a better way; this is what \
came to mind first  and it works.  Refinement can be applied!  Note that the \
time steps and divisors may need adjusting for the problem at hand."
}], "Text"],

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"g", "=", "9.81"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"use", " ", "consistent", " ", "units"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"m", "=", "25"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"c", "=", "0.5"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "drag", " ", "coefficient", " ", "combined", " ", "with", " ", "cross"}],
      "-", 
     RowBox[{"sectional", " ", "area"}]}], "*)"}], "\n", "\n", 
   RowBox[{
    RowBox[{"vxo", "=", ".2"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"initial", " ", "data"}], ",", " ", 
     RowBox[{"speed", " ", "then", " ", "position"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"vyo", "=", ".2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"vzo", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xo", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"yo", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"zo", "=", "0.5"}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"tip1", "=", "0.05"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"time", " ", "divisions", " ", "etc"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"ti", "=", "0.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dt", "=", "0.01"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dts", "=", 
     FractionBox["dt", "10"]}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "division", " ", "when", " ", "near", " ", "a", " ", "collision"}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{"pntdiv", "=", "5"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "number", " ", "of", " ", "point", " ", "at", " ", "each", " ", 
     "integration", " ", "step"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"er", "=", "0.6"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{"coefficient", " ", "of", " ", "restitution"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"eps", "=", "0.05"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "distance", " ", "above", " ", "the", " ", "ground", " ", "to", " ", 
     "say", " ", "we", " ", "are", " ", "near", " ", "collision"}], "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{"sdiv", "=", "10000"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "divisor", " ", "when", " ", "just", " ", "about", " ", "to", " ", 
     "collide"}], "*)"}], "\n", "\n", 
   RowBox[{
    RowBox[{"flag", "=", "0"}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"first", " ", "pass", " ", "flag"}], ",", " ", 
     RowBox[{
     "used", " ", "to", " ", "initiate", " ", "table", " ", "of", " ", 
      "data"}]}], "*)"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "just", " ", "looking", " ", "for", " ", "the", " ", "first", " ", 
     "bounce"}], "*)"}], "\n", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{"ti", "\[LessEqual]", "0.5"}], ",", "\n", "\t", 
     RowBox[{"(*", 
      RowBox[{"main", " ", "integration"}], "*)"}], "\n", "\t", 
     RowBox[{
      RowBox[{"sol1", "=", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["x", "\[DoublePrime]",
               MultilineFunction->None], "[", "t", "]"}], "+", 
             FractionBox[
              RowBox[{
               RowBox[{"Sign", "[", 
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "]"}], " ", "c", 
               " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["x", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "m"]}], "==",
             "0"}], ",", "\n", "         ", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["y", "\[DoublePrime]",
               MultilineFunction->None], "[", "t", "]"}], "+", 
             FractionBox[
              RowBox[{
               RowBox[{"Sign", "[", 
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "]"}], " ", "c", 
               " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "m"]}], "==",
             "0"}], ",", "\n", "\t        ", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["z", "\[DoublePrime]",
               MultilineFunction->None], "[", "t", "]"}], "+", 
             FractionBox[
              RowBox[{
               RowBox[{"Sign", "[", 
                RowBox[{
                 SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "]"}], " ", "c", 
               " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["z", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"]}], "m"], 
             "+", "g"}], "==", "0"}], ",", "\n", "\t        ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "ti", "]"}], "==", "vxo"}], ",", 
           
           RowBox[{
            RowBox[{"x", "[", "ti", "]"}], "==", "xo"}], ",", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "ti", "]"}], "==", "vyo"}], ",", 
           
           RowBox[{
            RowBox[{"y", "[", "ti", "]"}], "==", "yo"}], ",", "\n", 
           "         ", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z", "\[Prime]",
              MultilineFunction->None], "[", "ti", "]"}], "==", "vzo"}], ",", 
           
           RowBox[{
            RowBox[{"z", "[", "ti", "]"}], "==", "zo"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", "ti", ",", "tip1"}], "}"}]}], "]"}]}], ";", "\n", 
      "\t", "\n", "\t", 
      RowBox[{
       RowBox[{"xsol", "[", "t_", "]"}], ":=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], "/.", "sol1"}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{
       "build", " ", "solutions", " ", "for", " ", "this", " ", "time", " ", 
        "step"}], "*)"}], "\n", "  ", 
      RowBox[{
       RowBox[{"ysol", "[", "t_", "]"}], ":=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "/.", "sol1"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"zsol", "[", "t_", "]"}], ":=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"z", "[", "t", "]"}], "/.", "sol1"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"flag", "==", "0"}], ",", "\n", "\t\t", 
        RowBox[{"(*", 
         RowBox[{"first", " ", "pass"}], "*)"}], "\n", "\t\t", 
        RowBox[{
         RowBox[{"xtab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"xsol", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"ytab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"ysol", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"ztab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"zsol", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"flag", "=", "1"}], ";"}], ",", "\n", 
        RowBox[{"(*", "else", "*)"}], "\t", "\n", "\t\t", 
        RowBox[{
         RowBox[{"xtab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"xtab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"xsol", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"ytab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"ytab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ysol", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"ztab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"ztab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"zsol", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";"}]}], "]"}], ";", "\n", "\t", "\n", "\t ", 
      RowBox[{"xo", "=", 
       RowBox[{"xsol", "[", "tip1", "]"}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{
       "new", " ", "initial", " ", "data", " ", "for", " ", "next", " ", 
        "integration", " ", "step"}], "*)"}], "\n", "\t ", 
      RowBox[{"yo", "=", 
       RowBox[{"ysol", "[", "tip1", "]"}]}], ";", "\n", "\t ", 
      RowBox[{"zo", "=", 
       RowBox[{"zsol", "[", "tip1", "]"}]}], ";", "\n", "\t ", 
      RowBox[{"vxo", "=", 
       RowBox[{
        SuperscriptBox["xsol", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", "\t ", 
      RowBox[{"vyo", "=", 
       RowBox[{
        SuperscriptBox["ysol", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", "\t", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"we", " ", "set", " ", "the", " ", "z"}], "-", 
        RowBox[{
        "velocity", " ", "initial", " ", "data", " ", "according", " ", "to", 
         " ", "the", " ", "collision"}]}], "*)"}], "\n", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"zsol", "[", "tip1", "]"}], "\[LessEqual]", "eps"}], "&&", 
         RowBox[{
          RowBox[{
           SuperscriptBox["zsol", "\[Prime]",
            MultilineFunction->None], "[", "tip1", "]"}], "<", "0"}]}], ",", 
        "\n", "\t\t", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"zsol", "[", "tip1", "]"}], "\[LessEqual]", 
            FractionBox["eps", "sdiv"]}], "&&", 
           RowBox[{
            RowBox[{
             SuperscriptBox["zsol", "\[Prime]",
              MultilineFunction->None], "[", "tip1", "]"}], "<", "0"}]}], ",",
           " ", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"contact", " ", "made"}], ",", " ", 
            RowBox[{"apply", " ", "momentum"}]}], "*)"}], "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"vzo", "=", 
            RowBox[{
             RowBox[{"-", "er"}], " ", 
             RowBox[{
              SuperscriptBox["zsol", "\[Prime]",
               MultilineFunction->None], "[", "tip1", "]"}]}]}], ";", 
           RowBox[{"(*", 
            RowBox[{"collision", " ", "with", " ", "fixed", " ", "floor"}], 
            "*)"}], "\n", "\t\t\t", 
           RowBox[{"tfinal", "=", "tip1"}], ";", "\n", "\t\t\t", 
           RowBox[{"ti", "=", "tip1"}], ";", "\n", "\t\t\t", 
           RowBox[{"tip1", "=", 
            RowBox[{"tip1", "+", "dt"}]}], ";"}], ",", "\n", "\t\t", 
          RowBox[{"(*", "else", "*)"}], "\t", "\n", "\t\t\t", 
          RowBox[{
           RowBox[{"vzo", "=", 
            RowBox[{
             SuperscriptBox["zsol", "\[Prime]",
              MultilineFunction->None], "[", "tip1", "]"}]}], ";", " ", 
           RowBox[{"(*", 
            RowBox[{
             RowBox[{
              RowBox[{"just", " ", "close", " ", "no", " ", "collsion"}], 
              "..."}], "proceed"}], "*)"}], "\n", "\t\t\t", 
           RowBox[{"tfinal", "=", "tip1"}], ";", "\n", "\t\t\t", 
           RowBox[{"ti", "=", "tip1"}], ";", "\n", "\t\t\t", 
           RowBox[{"tip1", "=", 
            RowBox[{"tip1", "+", "dts"}]}], ";"}]}], "]"}], ",", "\n", "\t", 
        RowBox[{"(*", "else", "*)"}], "\t", "\n", "\t\t", 
        RowBox[{
         RowBox[{"vzo", "=", 
          RowBox[{
           SuperscriptBox["zsol", "\[Prime]",
            MultilineFunction->None], "[", "tip1", "]"}]}], ";", " ", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
            RowBox[{"not", " ", "near", " ", "the", " ", "floor"}], "..."}], 
           "proceed"}], "*)"}], "\n", "\t\t", 
         RowBox[{"tfinal", "=", "tip1"}], ";", "\n", "\t\t", 
         RowBox[{"ti", "=", "tip1"}], ";", "\n", "\t\t", 
         RowBox[{"tip1", "=", 
          RowBox[{"tip1", "+", "dt"}]}], ";"}]}], "]"}]}]}], "]"}], "\n", 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
    "build", " ", "the", " ", "final", " ", "solutions", " ", "as", " ", 
     "functions", " ", "for", " ", "plotting", " ", "etc"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xfinal", "[", "t_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Interpolation", "[", "xtab", "]"}], "[", "t", "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yfinal", "[", "t_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Interpolation", "[", "ytab", "]"}], "[", "t", "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"zfinal", "[", "t_", "]"}], ":=", 
     RowBox[{
      RowBox[{"Interpolation", "[", "ztab", "]"}], "[", "t", "]"}]}], 
    ";"}]}]}]], "Input",
 AspectRatioFixed->True],

Cell["Plotting just the z variable.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"zfinal", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"tfinal", "-", "dt"}]}], "}"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4VO0bB3AlS5aISm+ytEilJLuSr0oiEdnSgiSRpAUhSgiRbL2iBSMp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 0.4980000000000002}, {-0.0012035007370479766`, 
    0.5509165106890314}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5184517317332*^9, 3.5362648341841507`*^9}]
}, Open  ]],

Cell["Three dimensional view of the trajectory.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot3D", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xfinal", "[", "t", "]"}], ",", 
     RowBox[{"yfinal", "[", "t", "]"}], ",", 
     RowBox[{"zfinal", "[", "t", "]"}]}], "}"}], ",", "\n", "\t", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", 
     RowBox[{"tfinal", "-", "dt"}]}], "}"}], ",", 
   RowBox[{"BoxRatios", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1", ",", "2"}], "}"}]}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 Graphics3DBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], Line3DBox[CompressedData["
1:eJxF1nk0VXsbwHFFmYeL4mq4oUFyJXPCQ6lboUkcuUU0mHKlSyEyhDQQZ3Ii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     "]]}},
  Axes->True,
  BoxRatios->{1, 1, 2},
  PlotRange->{{0., 0.09950092789633308}, {0., 
   0.09950092789633308}, {-0.0012035007370479766`, 0.5509165106890314}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5184517353836*^9, 3.5362648343545437`*^9}]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 36, 0, 76, "Title"],
Cell[596, 22, 173, 3, 26, "Text"],
Cell[772, 27, 497, 9, 41, "Text"],
Cell[1272, 38, 14704, 393, 1435, "Input"],
Cell[15979, 433, 45, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[16049, 437, 230, 7, 27, "Input"],
Cell[16282, 446, 6715, 116, 241, "Output"]
}, Open  ]],
Cell[23012, 565, 57, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[23094, 569, 491, 14, 43, "Input"],
Cell[23588, 585, 4346, 77, 447, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
