(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    131371,       2422]
NotebookOptionsPosition[    129478,       2352]
NotebookOutlinePosition[    130082,       2375]
CellTagsIndexPosition[    130039,       2372]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Pressure Pulse for IC Engine Simulation", "Title",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
In this notebook we generate an approximation to the compustion pulse and \
subsequent pressure trains for a 4-stroke IC engine.  Note this is an \
approximation, and real timimg,etc is not really enabled.  Throttling can be \
approximated via multiplying the pressure pulse by a scale factor, the bigger \
the more open the throttle.

First we load in apackage to be able to generate a Fourier series of the \
approximate pressure pulse train.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"<<", "\"\<FourierSeries`\>\""}]], "Input",
 AspectRatioFixed->True],

Cell["\<\
Each pressure pulse is approximately a bell curve centered at some point on \
the crank position.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"x_", ",", "a_", ",", "w_", ",", "ph_"}], "]"}], ":=", 
  RowBox[{"a", " ", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "w"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "ph"}], ")"}], "^", "2"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5184520058252*^9, 3.5184520058252*^9}},
 AspectRatioFixed->True],

Cell[TextData[{
 "Adjusting the values of the parameters can be seen to change the curve.  \
For this approximation, we use amplitude, width, and phase, ",
 StyleBox["a, w>=1,",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "and ",
 StyleBox["ph ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "respectively.\n\nHere is a typical pressure pulse. ",
 StyleBox[" ",
  FontFamily->"Courier",
  FontWeight->"Bold"]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Plot[g[z,1,1,.5],{z,-Pi, Pi},PlotRange->All]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmnc8Vv/7x93cS2RVFCrUR1aiNEj3dUKFykpS2btFZZRVSPYmRFS2soVk
nGMTys7eK+u2s33v3+Px++ecx/PxOO/3dV2v63qf1/nj8BtZaZjS09HRWdMu
/3dXVmKR3+RnxBaCD1VZS5VQLuY5zZOPMGJ6VcrOB2NLKGL80zGc3IyYZuDN
YjHGUgrLes2aJAcjllXPuJ0/UkppTnHNsKBnxGoPvtxneRujaJNXDnUMk7EW
8/PcK3LlFCUb45qRfjLGrVida+1eTpEZbLZZ6CZj6r4fWNqqyym83zN+M7eS
MeH1/uwrKhWUQXOLt/IVZKyJNVMLsaikmNf0zGfFk7F79rU5qvXVFO0zyrGl
H8lYmzPr8H3eGorix+/XG6LJmL+aTYeTZQ1F5MW7pIlQMqbRXniWibOWMieo
qnPEnYx5RTUqo8/rKHYe5TW+JmTMmJ/3eodpA8V8UcL2vQEZ25Q/OjFX10DR
1vsokKxDxlzKG47eO9VIkTnn5FyuScZyL/D5SO80UrbHzp5ZVyBjp86P8kSk
/aa4X0mNNfuPjNGvpjtMJjdTMF8HtaP8ZOykHpt/y1QzZav5On0nLxm7tPd8
S6Z4C8Vab85UaT8Z28OkLape2EIxenHmpBgDbX3r4IZ/dysFUkuKFgZJWKzp
WTNmtQ6KAzXgyZdeEkb+2KbdGN9ByT9rcNS4k4RN0DV7Fa11UMTL6d+0/SZh
Id3Jv04l/aHw9lxTLiglYaPclzlnWLsoG8wtnU4fSFiXvgfmKtBLOXcr3uds
JAnrdlBnO+jbS3n+3kZ2LpSEHfDkfi+w0kv5+x/XJ31fEnZafJErpbGP0knR
MZdzIGFWnhnh9MEDlPyn4yskbRLm9XeYuzFniLKYX5CM3SJhwUZ8JktLQxTx
ba+79qokTOp61v7ds8OURG/RkqmrJOwWT8C3luJhSljcU/fGsyRsiSVBoax9
hPKsbYMjdB8JC7gcMxpwfpwSrqF6L4yVhLHwMEcLvBmnFDfFf37HRMKY+M8x
pv0epxAbb0hEMtD0MHakfn00QflQFXszZomIhXmI7HzLnKTU5st5JbcSMU5B
Daech9OUOamI3ym/idho3GrRwZppyr7cac4v9URMTA/uphyfoehlhiWmVRCx
E4qvx9RHZihLyePl2blELOmCAbuU1RzlyHuf7aJQIrY1/nFDbnieosA1oFAS
SMRKHlbJf+ZeoDx4d8av1JeIuT51PpR7a4HyLbiXu+wNEVsXqZ9Yr1mgKPmI
X6i2JmKKX9p/qRUuUmwcW5433SJiI0RW+SNly5SodcEfzapELFtoohMjrFDQ
F4641utE7E+exM+L11coe2yOB7XLEzGeKrOeys4VysfHdundZ4hY2oVm5sc7
q5SfutyTo/uI2PeUSosHdusU1Y+ysMFKxL50lP0WqV2ntA3qhbMyEzGuJtcz
49wblD7jeAUZPBG72Ggmp1WxQZl/IPY5cJmAVZOjTR7zbVG47Cj3ZNoJWPRV
dIedZZfyocAgW7WZgAXxEQh/nu5S+NbdyKaNBIyl3WK6um2XIuJUkx9YRcBu
9Ize51ajA4qb2r6xPAJ2eoB9vlUAByYBRg2B4QTMYsQ+lWGCHv7+dj+WGELA
2M+dVQgUYABL9mSHHwEEzMnASLhRjwFehE0LjXkQsCfzuDzzLgbwibJ5K/OC
gBFzdwXU/uAhK8mDMnaHgA1fU/Mp/0eEs5Mp7zZuEbC/P0/ceggk+CFcP8Oq
RsAo1n6G454kqEhjjZZRJGC2jLlhJjxk6MiJ/Bd4gYB5T0sHFt1ghO3SL1ky
hwhYHMfdwxvdTNDQfYp5cz8B6x0xOWBwgRk+rH4zL2IjYK0yFpzUcGaQFUeP
yJIJmKLre97wO3vBIabV79I/PBYt8/LHowkWWHXcskDa8dh17hv7pAXYoTrC
tZKuGY/hO6dVWO+zw7tcIl9ZA431volEhrGD1DTbn8uVeGwhLpHhJyMHWN/7
74p8Lh4zd1+m/N3igPkLKvxXg/FYjTyI4cgHANNsdSL64zFkwoKJcPMABD7V
7qz2wmNKjuLSAyEHQDzFKPCaCx47TNxU4OPnhCdcL7YVrfCY5oknc9yKXDC1
8rHr+k08FijSZ3K+/BD8YP/vLLMSHuP6ViHReoAbvE9+CWpQwGO1kbYvrB5y
g5Dpt2s3ZfGYiNrVrW+cPGDWVpunIorHXglLylU78sJIzkKwOiMeS7lj/yHD
4Sh8IG643SPgsaqLLrLLnUdB6x69jTEOjz09tyomwMsHtbh9WrbrDBjulosX
yZkPMtSkuN//ZcAiYq67qVzhh5dzdnGDdQzYq0a5//YtCICk3OvQv1UMWHzc
s3PnhI/B1DtP98UyBuxB8ATfquEx0L0UaYb/wYDFxd2Y0Gg/BnJ+hSJCXxiw
h8fMO9MrjgOzyFaOlQ8Dtnah6qQxJghVzviElx4M2B9G504ehhPwqpn5nasb
A+a8nFnqd/UELLw8/CLUgQFzvLOeFPv7BHTUUC4WPGTAZk1PlhZMCcFnU9eK
HWUG7P0bQwebq6Jw7jOxzZ+JAWPhd6/UVZcAmd/P6i6TGDDJqEYfQXcJoGz3
lq7QM2AnfqR+f1MgAVfv5qbqbtBjTYpvw3F8knCH3eD1yb80vlOgcGFNEl66
Foo0VtNjlToKXYSaM+CUeZzPtZweC1tREO5mkAKXvsADZ0vpMZbnY4O6l6XA
S9qMLiaPHpvQE+h2KJWCyAWOjscJ9JhnyvEzUHYWCg0fuzK70WOxxfKP4qbO
Q2ngHzvMmR7j/8RzW+PMBSgvkXtsY0+PPc2cIDY7XYCfhw7d6X1Kj3GyM8jJ
c0hDd3OVWJo+PSb/eCjj/DUZ2Lh8tPP6JXrMJ11QVKtHFmQFWsR913DYqz72
ySi9y/BpH5PUrWUclj/VUCQefBkYCArSPPM4DO2iW75eeRl+TuTJf53AYYvO
gtQTYnKgnf5eu74Dh1VLr13xo5cHmwuGbkx5OCz46Q8ZuXoF6BSO8mzNwmGD
y7bR+0hX4CJPq190Gg6zNwuTfSt/Beh3FCJEE3BYWryNuWrpFQiqEEq7HorD
TuH5JL8WXYU0lfl232c4TFK313qqQxHYEOGeW09w2EbXu4jXh5XAWtJokOcB
DstwYBb7baIEMvvbpr4a4LB3PQbZCStKUNtVsFuvisNK5F8r3ue7DqMmr4WZ
xWnrj0SKhkXfBF5HFme/KTpMUbdaxiFaHR4k/OSKGafDetgTT23UqkN+o0dO
+jAd9jF9kzixqg7qfLsTv7rpsEDRBjYmTQ3wqKJqsNfTYaORkv3h+24BlbVZ
KPwrHTabS857l6IJstL+FUnJdNg59MB7rT5N8DFS0iuIp8NKjSLowjhuw/G8
stDOaDrM50ziG69Xt0H7Xs4Otx8dpiMZMWWrowXlCaFtHx/TYZzW/8ndltQG
1l+qVlkWdNiH3g+39S21Qecf054yEzrMjkzv8O+rNvxTcodhHTqssB371CF0
F8SoNl+O36TDOq7F+T4TvgfvpLVcUk/SYdceoQIi13Sg6YOktlnfLnoL76Lx
+5UB0CVYhfe17aKpw9rrvV8MQOJreptmwy56OSojW+uPAQQVCqvLF+2iQdWe
LCGShqDWwa/M934X5YkUGpKbNoQmVg7Zbs1dNLDch2RmYwx0XGoO6jd20aOq
w5vJycYgcSTge638Lmq0ZJ5l2mMMQWJ7zhac3kUt/7vkoa1gAmpK9OJhbLto
/v3Nt9K8ptDktnhUpWEHLU9/gvSOmgGdj4ReVcUOGpJQ8vA+nzlIBFt+kC3a
QbdKf02a65hD0Mepg6JfdlALIVPfkx3moFY8zE722kF9Sk76+zVZQNNKC0O5
/A7qN5rllTr0EH5b5E6cLdpGHa+yLai/soKWgX9qlNxttOTaaG5ErRV0aMn+
uPp1GzVP6bxfyvgUehWq/O5Eb6N+mirRYbefwhTfH0l7x230+HJOLufCU8B3
bTgWX9xGR+3WMtbPPweyGoxVntlG8/ipB/SNngNTzRuVRtFtdGLXcvGw/3Pg
yGPm7+fZRrmt0+O+jDyHo8FHqnc3t9B3ybZnOd5Zg4ySHJt88RZ6gjOPNYvR
FiiYh/31b1vojoKZ25a0LVw+Xz98K20L/frE8UL6Q1tQ/E8zz+QD7XmouUJp
tIXbOLN7Hk5bqGZp++7pCDt4WuidUCe7hb6pzpJlgpeQJNx8Qa1kE93pG4xo
HnEEixPZZS55m+jhQ0H1A3xOIPJfsHJ2+iYau8BzzEzPCTL41HU4YjfR76Gm
lv3dTlDA1fy67dUmyiL5nRDW5Qy1hOZqbWQT9c+todTPvQYfhmxV7wubKFtC
SWP/IRe4gQvuLJTYRBcF0PQoWRdo3lKb4ubfRG8dqr/U6+YC3UtNe/twm+jd
uezuEA5XmB5q0jSs2EBZmf0rJcENMgay+oKLNtA9Xw0EmMzc4GlfkFl57gY6
w6KtL+7vBsudai+PJWygtnt2b2v2usHW76boMfcNVPi/tGeir94AS2nT8IOr
G6hTf8aJ503uIBHV9PR53ToaavIwoz/HE7xu2NGvY+toMJvkXc5JTxjc4Ql7
/X0d/cF5bbvgsBcEGpsX+CWvo0SpB/8u+njBnNjOdtLbdZS3SvPmPQtvSENF
fXsur6N8bx/xBEn7Av55M6+R9DqqqcOhWWzrCzrHX2RMSqyj1ANXcHo5vsDk
Xd68cnQdHaKTycef9IOHGncPsu2soZIcRonLJ/yB9jGVqPBjDTXZz3l9z9lA
cIkQO1+fvYbOdn6S/fsyEDqVWmrVU9fQrzoqm0olgeCZcXhGL3INVdw23vPz
WBCMv/h22t5uDT1idDxdIjsIEvYMo+mn19BhlSC2hs5g4Je41M359R/KuXCP
77ReGNzQ+BsuHv8PbVNpHBDzCIOXNu9uXY3+h85kWe08ygiDX99nG2x9/6Gv
Oujbvu+GgcPlWLTt0T+0jplBJSLxHbRp7CaEiP1D1+7UbxfthIOHbZkVS8Yq
2hFlanD373vIjngiJpi0ikp8m4iP4Y6C3sJDfy/FrqLDHNxFp29EwemdZ0ZP
AlbRVtwrsnpWFAx4CNxusFxFU5OF0h44RcOFyDcyPqdWUbdlLxeL4zEw9eMK
gZi9ggpnspZev/8JvgYX/LROWUGj1YcyZhw/wWML4aChjytofJ3LyaoPn2D2
wF6ekoAV9AG+6N/hgU8w/7RNwubxCvqMlFJhZ/YZVgWNdYZPrKCLtiwLBJc4
oA91yS2NXUYvWKHpqYMJUPFg8aVY+DJ6n3phu4GcCO6ICSXKfxn19Q24KSmZ
CIS5a3W2Tsuozm0ukVK3RCArsQ6I3VtGW6y+PVoQSgKW3Zg90QeW0bx4fRUG
t2TgeVRk+MJvCXWsqDhJePAFomprr+51X0JN5fdbbkd+AW7BDtF4xyX081ul
nUt1NB6aX/n1cAkVKZ1WeC/yFQ7eEfQRVFpCdU1Is9j8V9gvH5zTTlhCq/e1
Lhz0TQdmHnMGqdeL6M7iaweycxb4vbSZrLNbRIe7Rgzb32cBU4dro77lInrp
R6l2fX4W7An+EOGru4g6jNVwnFnIAjKpRXTk4iLKO5vIuGqeDYQlWc2QtQV0
z+vHPo91c2DnJ0fi/LMF9JJXscGpB99APVIwj+vhAqpYUu3J7f0NEkxlqihG
C+gh5TMpJ1O/gTKd0ZifxgL69PyBWw1/v0H42ez/hM8soMdD/8PmHufByU+q
SYbL8+hNO1vVEYd80LH1S26xm0dPKz7yNc7/DplynwrWLefRztBigk/Pd6Bn
+1bDZz6PbnSkqvfSFULKl54JyzvzqKKdbjv+RiEsD4gIMV2YR1v+cdZZjBYC
57sQdc9FKqrn/YYYfrgIrIFZ88G/OTSRiBqp5JSAgjz61nh8Di26365aN1gC
nNeeF+i2z6G/Rp+tO7KWwneVTm6N3DmUI916j/eTUtjSTRiSsZpDSefqW6+I
oeDuJGvFPDGLLj5iczhzD4Pwwsc+mR0zqPUkMZhjrQzMS44Wp1bNoJ1rSYem
OcrhQlnLbPy3GZRRZcV66GQ5dNdeUI8MmUE9hHfbTpiUw5FO/EFXlRlU+FZj
FW9LOSSvfkjUqJ5GyTnaIzm5FfD9TCO2kjeFcimS5Mb8q0CCy1+RI2kK/aF/
zcj9SxWkbNxoEg+fQnNvitZQaqogsqxhwNxuCh05UulMwFXDC9WGna5zU2jX
6B+rHttqOPeoXra04C96jdU4INOkBr7F1X33KJxE24ghCsfu1EEme3UWV8k4
utWVs3ooqBE09NiVB7+Oo0y/BtvS8hth9YvOSErUOMqSj5YY9DWCrMLSAZmX
46hhX02yqOgvqLXjc9Q5M45mPbnz/mbtLxjscbjyOXUMDciV9tDHNwF70qlu
kfBRdPnwIVZu9WawlnnPQLEaRhObN9F87jaQeauvOPmwF73VwbYqjXQD1WIr
8LVXGzrTSBQSVRuEN5XRMrBWgw57dzAdWh6BjiLZyi8MWWjLfj6FZPUJ4LU3
6l9kzkQ972802+tNgJ/DdakgjgzU48B5acVHE/DI+fDgz8Np6Nu4jLud7hMg
8qbsPCKVgj6+yXa9smACUgMYJ0QMP6Eg8FG8lHcSmr5J5ZIN7qDvWNDq1uFJ
0Be7uq0ZnAFSlfEvtXSmQDYyKWD1UyYovs2OibOYAmY3BrYb2lnQE1MSNWYz
BX9njT/P0s6VwERwm6r/FMRVHa+U8MwFSGZTzS2Zgv22SYwFVQUw2ZP6PYl3
Grb+av405MeAodMJV9kyDUv4dHFlUwz2Fb+sre2bhqmjhNDTqRiIOYSdK5+c
hs7befcZJMugKWS4MmRnGvLKDswmIOVgMp7aniI8A5bvO1gn9SthjlNVI8p5
BoYUtW9bxtbCmQW2XX7eWaCMORk29tWCdTju2cbxWYhy/fxE7HAdeIYIXqk5
OQsaP6beTkXXwW2S78glmIVyUed8s/c/IbBSMCXGcBbiWOK49MMawPgqts6b
MAunp1ZmTlxpgje3HhPrj86BwQWy9R+TJogoa7h56MQcBHhwr3u4N8Heo4cC
74nPwZQAEMYrmgD3wqMjT3YO4u57HU6Qa4YRrS7dX9pzsK+RW4UPaYGbeR2Z
rwLmYDkTMg9ebINKJyeWaOocNIhe5Hiq2wbisr2p6StzEJ98zrbmdRv4hf+L
zdycA42PJy/aVbZBPGHwiSuJCtkBPDWtN9vhT+Mfr/tHqGD55F9/gEEHJHhz
GgwpUuHq38XL424dYFrlyDZ2kwqHTecSLiV2gFo4/ds/GlRo0Bl7OPO3A+gj
BiO9dKggcqN1Vcn6D/jZs3tyW1FhQiSTheDRCd6hmXmrQVQoTfryTCelE0IH
7ZaHw6gQLpDUlvuzE1q8RV+VRNLiccdEGbF2gerT/dqXPlEhgdFXEIvsgkFl
GxvzDCo4vfXw5irqAm0lM+2qbCrcwrnNWPZ1Qakndps9jwr06y9zDgt0g1KM
kId1ERUMJs0ojl+7oUmwQdCghgoXTIw+tzR2wxYiSRH/SQXWQV28yHw3DObv
vTLVQMvvj+bPTqkeIDI4soi10PK7pXZS4k4PhAnT1Wa30fT5fT3I074HjM3G
9P77Q9OjRk7rXGkPTN3fu7+jhwrLcpRC/8EeqLsjK7Kvn6ZPqTTvGH0vmJIS
9lIGafnnSwyHXusF3ZQbJ3VHqdCdeMRyoakXPB4cs8KmqZBPTNNIWewFI/7z
08azVAg1lz6vv78PFK/FVKzMUeGGsCZd450+cM7Y+3p0gQpCPkOjb+z74KXX
ed3LS1QgTFvWyUT3wV3WJX+/ZVo9ad4hKf19sG/qU//sKhWi9nK90KfrB5mg
mA2GNSq8sEy4zynQD/0hiCF5nQqavyWRRvl+eBnXybZJYwkJ9Li7aT+EDzWT
ejeowBx8g/GiZz9c/pun8HWTCpMLXbMLKf1AahStttiiQqWGeUvKz34oOrLm
s3+bCp9zl/P1Z2j7L2wFZ9D41X63aE6WAfjeL919bocK92xZXRpPDQA/ocEo
ncbnOj6YuKsPwArLnAjHLhU4zosoXbQeAOnTa5KmNJ6LKDi5GDYAM6cNXiTR
uH5NgSM1fwDcTQo32mmccrdlVb9zAAS+fitaorH7D/0ezo0BMHXi+7FL4yz/
1YHxvYOwOTC5sk7jI5RLGuVHBqHdistqmMZ+c28qY04NApN263+FNN6M/XnO
HhkEay1D7lc0fqjKnqqpPggDhcduStK4c/cOj4TRIOw1jCptoeV/NSvWn8l6
EK4VGlkZ0fibwdju+JtBSC0+bzBIq1+AXex5edggHJlfCL5B46Cy56MxiYNA
MvQkJNP023lWqGWfPwiBcUzFVJq+TwTo6jRrBiHzZ2a+II17W65elOikxbcs
X71O64fyG/90pr+D8OJTprM+rV+Co9wh5XuGIE5B10z9HxXCwgzxsTxDIMTn
XX+K1n/6Kyl29mJD4K5u9mqLNh8DiWfvS6gMwW+carvBIhVUtJwamfSHwJE1
23ltngrFxAqYsBqC5+7PnF5RqRBprnY8NngIzslue9yeoQLxYES4fdwQCFgz
RiZNUcGmto98O3cISNMrjOOTVFAXfjTL1D4ErHWneSXGqIB1ZetPjA1B7cf0
cpkRKoj7rDWXrw5BhKdux5khKuyZfptvf3AYBmBBY6GXCi+jG4RuCw+D9MxE
eV43Fcav74uWkBmGjpvSGRadVChP+/R64v4wjHGqEaNaqeBoWaR4++MwYMVa
4qJ1VJCDFROWzGH4vGWiFlZN25/tlGtN6TCk+Wyrz1XQ6smOK5TuH4bxBCEG
21La+Vv2FjlyeASujb33b8yhzWtVxdU/YiPgcjKcpzSTClfCt42CZEfglTPu
y8c0KrSdfxZNrzMC6WUnu88mUWHRQZt5ImoE7K4V78mkvc9+XA8R+vRlhOZn
DkeE3lHBlbdB4e6PEbCNGdAOCaYCWyk413eNgPrAVS0ZH5oeuBNzmQdH4SxW
R+5yoM2b58rvl+GjYPfASEbrLhVOa5+akUwaBflmW9VRTSqsCz0gT+eNAuv9
cxPGalTw+tmL6LaPQvJPr+/nr1EhaW9l9uX9Y4C7pxV9WooKQ6EhoXtCxiAk
2vWBIxMVtD+duvPBfxymnsvr+2fS/ITUb5gaOw7Z3LKE1pQ5CLLye5yfOQ6m
DnUoOW4O6ih/XZuaxyHn6pePCmFzINMXl4bnnICaGxzXd1/MAS83J/2T2AmQ
7C6I96H510DoVtqlzElAlKu+q/2YBafNLwXK2CSw7Cl9lZU9CweN75bfaZ4E
Kl/zLC51FtRO5/95tjQJ3cY+u/YRs4A1WdEnnf8LUeZerzFrmr/uHbnDgv2F
S+6D8bnCs2DmWUc/0DQFP+pyBqN9Z0CH9VFB3eAUrGyf1Nx2nQH1CObH3+an
QC3hMPXWyxmQTVZt92abhnc3NJoGTWaAo6Y9WUptGg7b3slzuDQDJcThGz6/
p2EwV7Tzx8w07PfYCD/7awbaGYC1UX4aKtxFRf3q5+DnJP+Le3/+gh77WPn+
uwsQuS0ZvVE6DksyNZQhuyVIkzpS5yU4AplWe9eNnq6A4MjXYtvoAcC/Hnc1
CvsH2Vpz4scaOsH1/TElrrB1uI0T4RU43gpipMSt2eh16LYvifFnbYVOG8Gs
yvh1SDPROkbcbAFxNWGu57nrkLN4UP1ISwt0E0+NNbSsw5XBtV/TLi0gZSPj
6sa+AYlJapW7g80wrqJeOBuwAUFi34+JfG2C6/jXwpXem6Dkd2PesKkBDEpk
2hRCNqHIkOcD89cGsLNbfVUVtQmOTHM+f942QNzkk7bqr5ugVvlB8tfFBlhr
0Hld17gJNrGnIiip9ZDwTqb9F/sWXCKbfRPx+QlbgqsuXe+3IEvnnfBhk1rg
GMwWvRe3BWZiBrcb5GrhxPsnHd1ftuD1qyDDaP5a0GAaE+0t2gIfywP07wdq
IIXa2tHftwXXjrh9Ydetgdvfs8VG+behuWuMsqhbDRlKTzrnUrdB7OzQjtSL
SpgPEdDuz96GjM0mtOp+JZzu/fOnsXAbcq9Nqj1DKiHfUu5PWt02nGDHSg/u
qQQ0lKvj4d9tGPF/V5YcWwFNfWWt40I7MH1qurmkoRyWnnH+7k/egVP1ntYu
smVwrqhe5VfmDpgxbr25c7wMXuJdf5UU7MD20QQWReYy2AqfbvxQswNaEkOG
tr0Y4IuxhnsTO/DceSBp1xkDTuKjnx2CuxA6OyYX6IvChSi06lfiLtxdEIwN
+V0Mo+KZshYZu6CwpdQ2+bkYgitic3EFu1DfZbZuZ1MMUzPOn6Vqd+G4T9Yr
Ge5i+ACyzlFTu6D9S/DpPYsicHmuw53LRYd4n9tzs4/lB4xxdTW/0qFDApZO
io68KQDZYTX/egM6ZCgpgHVOpwBC0moVD5rSIT/05Q+InSsAyuXvaPYTOuQM
qXME+ZsPkQ8j0kdf0SENahbH6tTzQbnktrfyZzpE/2xhlIRYHmQYtSCc43RI
ZHet50VCLiQ+cJpRmaJDoPiS7vJoDnx4KhjpOUeHWLQXvO2qzAGfVw7UtVU6
pMKMTlLobQ6YRgnE9pBwSECfe2QLKQd4W55vfhLGIRbXMrsuHMgGn8v78kWf
4JDrrzWuWMRmgKtiiaHJMxwiMZRuqWmRAS9VzffG2OIQz/2WSoGnM8BMt8iE
5RUOUaa73E6tSYfL9sb7FgJwyAV2z4hbq2mwlpX7ND8Lh/RVjjgYGH4FMz5N
0cvLOMRkUyffwjIFrKkOlyXXcMisA2U1RCEFXEo/3+HfwiHz6oki69wpEK1D
fYPD0yN55wrsXtYmQ1OkT2/ZPnqk84Rj7UXBZJBmL/OXO0OPPPMZ3o2dSQRm
evF5+ef0yP6BHzwi8fFwqFmTKGVHjwh0fzW97xIPgp8ceY870CNFe9/uYrrx
cJlSp4h3o0f29Dw7K3QoHuwcTD5XBtMjRkL6pw1C4mBgMUrjSjY9wmDnzSUf
8BlyRkh5V+fpETXKt2YXzY9g01lf7btMj0S2vd2Q4/wI5xsDO5vW6JG1vpvn
rTpjoTifa+sejgHRnlguZNCLhSrvE/JWHAyI688j4XstY6Dz1LXmCCkG5PF0
l7/o52jYcfSYnXzJgLxnSeftU40E7Kny7klnBqSmk/V35+FIeGPKwm7tyoAU
zbpXn5yJALJquNS2NwPSLv+f55B3BLALJDmyRzMgHyvE7Y3qwuF4bRWjTAkD
cpPj36CO9jtQ3k8Q9MXhEeV8YBnKCYFjzVfiPAl4hOe8IKnQPwS2/D2OuDPi
EdEnotnNFiGQTiJzObPjkSkxJKXiaAiwbe4hW/Hjkd/ZYcc+BQVD+xDblMZl
PJLP+/PFjHMQGGTyZnC74hF5KeG2HrI/SD/WFeF6i0dYL6/KGDT6AYdwbNI+
bzwyevWiilqIH1TEHf3IHIxHiul0Fp4e9gPBcIGgnU94JJRHOyTugi9MOwk9
H8bwyN2Qf0Wybt5gpyx17gsdAalPmF/g0fMAqnxyXAiegMScW+NqP+UBFpe4
WR3JBGQ60NJxBOcB9yXoJq+zEZC56smJ7aS3gHA2vJ89SkDSDUNWuFfcgWnY
eFsCCMjFMNdf7p/egHtPx4ND8gSk/0V1h+aLN7DTptSBu0ZAfkl3cj5XeQPz
NacyW1QISPBypnrItht0pG8a2OgRkEs123d19N3gk31oZYEzATmtpNydLuEK
h6yJkp9cCYjPa96Og8yuEPLYPsbrLQEJOMYRVTfhAm/19e3u+hMQd4HXORsf
XeDhFVGhzQ8ExNbQtTFgnwtIsVf4UooJiKKo1ZuLLK+gLmVRo2qDgCSH373Y
Ke0AazX0RfS7BESjLl/+86Y9CE5wHEMYiMjSqbnH1BJ7cPvvzNIPJiJy7ubk
VS4Fe5CNsw7N4iUi8z7hjxy0XkJW9HJrNIWIxNekpZaE2EH/D7xslxwRGeDM
prPQsYO93fsTOK8RkVnC9UwvQTt4ePCsTbAqEfnsfyRYuNgWjr+z3e9pQETQ
TO9jzTM2EBmwqvncjYh8n4pB142soTqdWJLpQUT+PdvDHn/GGlYaOP+b9SEi
nWE7ynl4a5r/nF8xDyUiyuEcyuwpz4HZ68U73QQi0pESZBe89AxcXNfaFauJ
SPvQyBdizFOwsNnQOrqHhCjczrqj/OAxpN/3FN7PQkJuRjL3Zwk+hkW5/Vtk
DhIidP5zX+LoI3BkF/+8eIiEKM8bc5w3egQBGYbTVcIkJNW4X6rL+CHkTda+
fqxEQugL5ZovuFjAxu/bGoY3SYgFNrfJdNUCKAXDx7XUScjm0JK7LrMF1L7d
qoO7JCQ49ODIiyhz6BWQ2L/vAQkxUM50tio2A3rdiJRCLxIyFUh4/4HTFK4p
HHfM8CMhbGLnQsZHTMBPNPtmfBAJGWqb0/2UbQIHNn4u+kWSkO8CVdv6KiYg
FLEja5BCQp4XFib88zMGlWbTZmItCVnNEtD5fdgIoq9IbdwikZG3FjG7suz6
8CX9TkQpExlx4MtG6or04PsBRylhNjKSmdbHIG6uBx1jZZY7B8nIYoennj2m
C2weqiMpImTkvMzi3WEnHfCoftiwfZOM8CfTiRry3IN34gEPLDTIiIHWfv3w
lruQEJ5NbNUiI8etK/95+NyFMrM1JEWfjDwp5fcL3dKGLaJHnsYzMmJ9qt1a
9O8deH7tc2xyGBlpr+f/NTV8G1wzKy9yvCcjf3AaDuyJtyGIa7LTKYYWb6p7
qMv8NqRPiO/TSCIjA8KUv0pUTZj0LPbcKiAjZcX+2c4ETdCr/fNUvYeMbGRb
NS7f1IAnEpt7iwfICGNUvITPIQ1wijzyVXCUjATuPKz8MqYO7y1MxzZnyIhL
qyHi9Vod2shLd5N2yIgIi/eLoEI1GHnK+Y+NgRE5LHVa+r63Gix2Soc5khiR
PVlH15LuqgFrqssvNTZGZHzfBxb7f6pwhD3hUdF+Gl+tbSdFq4KYfQ1Z8BAj
suSMjgaAKlwcmkoMOsyIuN9o7mEaU4H//z8OSY57YuDkqwL/A5gAW2w=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184517813412*^9, 3.5184520085552*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
Next we must build a train of them.  The first pulse is the combustion pulse \
and peaks slightly after the pistion is at top-dead-center.  The other pulses \
complete the 4-stroke cycle and occur at top-dead-center.  This pulse train \
is good for only the first cycle.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ps", "[", 
   RowBox[{"x_", ",", "ph_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"x", ",", "1", ",", "2", ",", "ph"}], "]"}], " ", "+", " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", ".6", ",", "3", ",", 
     RowBox[{"2", " ", "Pi"}]}], "]"}], " ", "+", "\n", " ", 
   RowBox[{"g", "[", 
    RowBox[{"x", ",", ".6", ",", "3", ",", 
     RowBox[{"4", " ", "Pi"}]}], "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.5184518075179996`*^9, 3.5184518075179996`*^9}, {
  3.5184520660256*^9, 3.5184520812356*^9}},
 AspectRatioFixed->True],

Cell["\<\
Here is the plot of the first cycle.  The initial phase is .5 radians after \
top-dead-center.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"ps", "[", 
    RowBox[{"z", ",", ".5"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", 
     RowBox[{"-", "Pi"}], ",", " ", 
     RowBox[{"7", " ", "Pi"}]}], "}"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.518451805646*^9, 3.5184518056616*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUVnc8198Xtsnee5NsZSXxPlcZlYbsVWRmr5SshDIikk0UkoivlVR4f8qK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{{3.5184517850696*^9, 3.518451811262*^9}, 
   3.5184520145768003`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
Now we must make this pulse train repeat for arbitrary angles, so we use the \
Fourier series expansion of the above waveform\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "[", "x_", "]"}], "=", 
  RowBox[{"NFourierTrigSeries", "[", 
   RowBox[{
    RowBox[{"ps", "[", 
     RowBox[{"x", ",", ".5"}], "]"}], ",", "x", ",", "20"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.5184518014496*^9, 3.5184518014496*^9}, 
   3.5184519289016*^9, {3.5184520949168*^9, 3.5184520977872*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"0.19947112753860488`", "\[VeryThinSpace]", "+", 
  RowBox[{"0.308966416545902`", " ", 
   RowBox[{"Cos", "[", "x", "]"}]}], "+", 
  RowBox[{"0.13073731584226578`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.009161735962813474`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.022468192443980746`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.014042664841003165`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"5", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.004387516417592179`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"6", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0008172112902056566`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"7", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00008749405379896016`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"8", " ", "x"}], "]"}]}], "-", 
  RowBox[{"3.3539447468305426`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"9", " ", "x"}], "]"}]}], "+", 
  RowBox[{"4.077026928986138`*^-7", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"10", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.910605959958866`*^-8", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"5.815324102288118`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"12", " ", "x"}], "]"}]}], "+", 
  RowBox[{"1.08797426188748`*^-8", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"13", " ", "x"}], "]"}]}], "-", 
  RowBox[{"9.682560955961095`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"14", " ", "x"}], "]"}]}], "+", 
  RowBox[{"8.853946956269642`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"15", " ", "x"}], "]"}]}], "-", 
  RowBox[{"8.104448444577185`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"16", " ", "x"}], "]"}]}], "+", 
  RowBox[{"7.4330219486037645`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"17", " ", "x"}], "]"}]}], "-", 
  RowBox[{"6.831498387655648`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"18", " ", "x"}], "]"}]}], "+", 
  RowBox[{"6.292265867007936`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"19", " ", "x"}], "]"}]}], "-", 
  RowBox[{"5.808352473789289`*^-9", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"20", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.16878911114114478`", " ", 
   RowBox[{"Sin", "[", "x", "]"}]}], "+", 
  RowBox[{"0.2036113394841855`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.12919315868565479`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.04909383887016689`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"4", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.010490209074638955`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"5", " ", "x"}], "]"}]}], "+", 
  RowBox[{"0.0006254118319781505`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"6", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.0003061109228763175`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"7", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00010129520356501872`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"8", " ", "x"}], "]"}]}], "-", 
  RowBox[{"0.00001561202791544627`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"9", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.4384347151632215`*^-6", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"10", " ", "x"}], "]"}]}], "-", 
  RowBox[{"6.312597693869026`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"11", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.4517737844662807`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"12", " ", "x"}], "]"}]}], "+", 
  RowBox[{"1.275155619605689`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"13", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.2498398712754548`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"14", " ", "x"}], "]"}]}], "+", 
  RowBox[{"1.2269577918360934`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"15", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.2003568082502279`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"16", " ", "x"}], "]"}]}], "+", 
  RowBox[{"1.1718302254330617`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"17", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.1422041246140328`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"18", " ", "x"}], "]"}]}], "+", 
  RowBox[{"1.112118495004494`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"19", " ", "x"}], "]"}]}], "-", 
  RowBox[{"1.0820398185513199`*^-8", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"20", " ", "x"}], "]"}]}]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{{3.5184517865360003`*^9, 3.5184518123227997`*^9}, 
   3.5184518891996*^9, {3.5184519301028*^9, 3.518451941054*^9}, 
   3.5184520173068*^9, {3.5184520715480003`*^9, 3.5184521008136*^9}},
 AspectRatioFixed->True]
}, Open  ]],

Cell["Here is a plot for the crank angle between -14 Pi and 14 Pi.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Plot[p[x],{x,-14 Pi,14 Pi},PlotRange->All]", "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwc2nk0Vd8XAHCVFMpYklRCpgzPPMTdPJ6hkIRkiGQsIXwRQkiSJE0ylMwh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{{3.5184517890008*^9, 3.5184518145848*^9}, 
   3.5184521076619997`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
 "In order to use this function in an engine simulation, use the following \
pressure function, where the parameter ",
 StyleBox["a ",
  FontWeight->"Bold"],
 "is the pressure amplitude, the approximate throttle, and ",
 StyleBox["th ",
  FontWeight->"Bold"],
 "is the crank angle in the equations of motion.  Don't forget to use ",
 StyleBox["th[t] ",
  FontWeight->"Bold"],
 "when the function is actually used.  Remember this is a pressure; force \
requires the pistion area to be used."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Press", "[", 
   RowBox[{"a_", ",", "th_"}], "]"}], "=", 
  RowBox[{"a", " ", 
   RowBox[{"p", "[", "th", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5184521396731997`*^9, 3.5184521396731997`*^9}},
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"a", " ", 
  RowBox[{"(", 
   RowBox[{"0.19947112753860488`", "\[VeryThinSpace]", "+", 
    RowBox[{"0.308966416545902`", " ", 
     RowBox[{"Cos", "[", "th", "]"}]}], "+", 
    RowBox[{"0.13073731584226578`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.009161735962813474`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.022468192443980746`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"4", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.014042664841003165`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"5", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.004387516417592179`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"6", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.0008172112902056566`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"7", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.00008749405379896016`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"8", " ", "th"}], "]"}]}], "-", 
    RowBox[{"3.3539447468305426`*^-6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"9", " ", "th"}], "]"}]}], "+", 
    RowBox[{"4.077026928986138`*^-7", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"10", " ", "th"}], "]"}]}], "+", 
    RowBox[{"8.910605959958866`*^-8", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"11", " ", "th"}], "]"}]}], "-", 
    RowBox[{"5.815324102288118`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"12", " ", "th"}], "]"}]}], "+", 
    RowBox[{"1.08797426188748`*^-8", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"13", " ", "th"}], "]"}]}], "-", 
    RowBox[{"9.682560955961095`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"14", " ", "th"}], "]"}]}], "+", 
    RowBox[{"8.853946956269642`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"15", " ", "th"}], "]"}]}], "-", 
    RowBox[{"8.104448444577185`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"16", " ", "th"}], "]"}]}], "+", 
    RowBox[{"7.4330219486037645`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"17", " ", "th"}], "]"}]}], "-", 
    RowBox[{"6.831498387655648`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"18", " ", "th"}], "]"}]}], "+", 
    RowBox[{"6.292265867007936`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"19", " ", "th"}], "]"}]}], "-", 
    RowBox[{"5.808352473789289`*^-9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"20", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.16878911114114478`", " ", 
     RowBox[{"Sin", "[", "th", "]"}]}], "+", 
    RowBox[{"0.2036113394841855`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.12919315868565479`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.04909383887016689`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"4", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.010490209074638955`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"5", " ", "th"}], "]"}]}], "+", 
    RowBox[{"0.0006254118319781505`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"6", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.0003061109228763175`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"7", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.00010129520356501872`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"8", " ", "th"}], "]"}]}], "-", 
    RowBox[{"0.00001561202791544627`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"9", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.4384347151632215`*^-6", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"10", " ", "th"}], "]"}]}], "-", 
    RowBox[{"6.312597693869026`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"11", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.4517737844662807`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"12", " ", "th"}], "]"}]}], "+", 
    RowBox[{"1.275155619605689`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"13", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.2498398712754548`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"14", " ", "th"}], "]"}]}], "+", 
    RowBox[{"1.2269577918360934`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"15", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.2003568082502279`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"16", " ", "th"}], "]"}]}], "+", 
    RowBox[{"1.1718302254330617`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"17", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.1422041246140328`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"18", " ", "th"}], "]"}]}], "+", 
    RowBox[{"1.112118495004494`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"19", " ", "th"}], "]"}]}], "-", 
    RowBox[{"1.0820398185513199`*^-8", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"20", " ", "th"}], "]"}]}]}], ")"}]}]], "Output",
 Evaluatable->False,
 CellChangeTimes->{3.5184521403752003`*^9},
 AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
If the timing or any other parameter needs to be adjusted, then the above \
steps must re-done at every time step, or a more general pulse train must be \
devised.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 102, 2, 83, "Title",
 Evaluatable->False],
Cell[684, 26, 514, 11, 83, "Text",
 Evaluatable->False],
Cell[1201, 39, 91, 2, 31, "Input"],
Cell[1295, 43, 167, 5, 29, "Text",
 Evaluatable->False],
Cell[1465, 50, 391, 12, 31, "Input"],
Cell[1859, 64, 475, 16, 67, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2359, 84, 86, 1, 31, "Input"],
Cell[2448, 87, 13583, 228, 246, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[16046, 318, 340, 7, 29, "Text",
 Evaluatable->False],
Cell[16389, 327, 589, 15, 52, "Input"],
Cell[16981, 344, 164, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[17170, 353, 380, 11, 31, "Input"],
Cell[17553, 366, 39985, 662, 246, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[57553, 1031, 195, 5, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[57773, 1040, 371, 10, 31, "Input"],
Cell[58147, 1052, 4694, 124, 126, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[62856, 1179, 122, 2, 29, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[63003, 1185, 84, 1, 31, "Input"],
Cell[63090, 1188, 60405, 997, 246, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[123510, 2188, 564, 15, 47, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[124099, 2207, 256, 7, 31, "Input"],
Cell[124358, 2216, 4856, 124, 130, "Output",
 Evaluatable->False]
}, Open  ]],
Cell[129229, 2343, 233, 6, 29, "Text",
 Evaluatable->False]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

