(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     36634,        889]
NotebookOptionsPosition[     34606,        818]
NotebookOutlinePosition[     35210,        841]
CellTagsIndexPosition[     35167,        838]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Trajectory", "Title"],

Cell["This notebook is for the Trebuchet trajectory calculation. ", "Text"],

Cell[TextData[{
 "The air drag force is implemented with the Sign function, the imput \"",
 StyleBox["v_",
  FontWeight->"Bold"],
 "\" and \"",
 StyleBox["c_",
  FontWeight->"Bold"],
 "\"imply any value, ",
 StyleBox["v",
  FontWeight->"Bold"],
 " is the speed, ",
 StyleBox["c",
  FontWeight->"Bold"],
 " is the constant."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"v_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"c", " ", 
   RowBox[{"Sign", "[", "v", "]"}], " ", 
   SuperscriptBox["v", "2"]}]}]], "Input",
 AspectRatioFixed->True],

Cell["This is how the function works.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{"y", ",", "2"}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"2", " ", 
  SuperscriptBox["y", "2"], " ", 
  RowBox[{"Sign", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.5184521713747997`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f", "[", 
  RowBox[{
   RowBox[{
    SuperscriptBox["x", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], ",", "c"}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"c", " ", 
  RowBox[{"Sign", "[", 
   RowBox[{
    SuperscriptBox["x", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["x", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.5184521720456*^9}]
}, Open  ]],

Cell[TextData[{
 "The function sol[...] of the parameters and trajectory data (initial or \
otherwise) returns a solution to the differentional equations between times  ",
 StyleBox["to",
  FontWeight->"Bold"],
 " and ",
 StyleBox["tf",
  FontWeight->"Bold"],
 ".  Time ",
 StyleBox["td",
  FontWeight->"Bold"],
 " is the time the trajectory data is known.  Mathematica can use  ",
 StyleBox["td",
  FontWeight->"Bold"],
 " outside the range  of solution."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "[", 
   RowBox[{
   "A_", ",", "c_", ",", "m_", ",", "g_", ",", "to_", ",", "tf_", ",", "td_", 
    ",", "yd_", ",", "zd_", ",", "vyd_", ",", "vzd_"}], "]"}], ":=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["z", "\[DoublePrime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{"f", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["z", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], ",", 
            RowBox[{"c", " ", "A"}]}], "]"}], "m"]}], "-", "g"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[DoublePrime]",
         MultilineFunction->None], "[", "t", "]"}], "==", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"f", "[", 
          RowBox[{
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], ",", 
           RowBox[{"c", " ", "A"}]}], "]"}], "m"]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["z", "\[Prime]",
         MultilineFunction->None], "[", "td", "]"}], "==", "vzd"}], ",", 
      RowBox[{
       RowBox[{"z", "[", "td", "]"}], "==", "zd"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "td", "]"}], "==", "vyd"}], ",", 
      RowBox[{
       RowBox[{"y", "[", "td", "]"}], "==", "yd"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "z"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "to", ",", "tf"}], "}"}]}], "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell["\<\
The first solution is generated with the following data and parameters.  \
Initial position is (0,0) and initial speeds are (20,20).  Don't forget \
consistent units,we are using MKS here.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol1", "=", 
  RowBox[{"sol", "[", 
   RowBox[{"4", ",", ".1", ",", "10", ",", "9.81", ",", 
    RowBox[{"to", "=", "0"}], ",", 
    RowBox[{"tf", "=", "5"}], ",", 
    RowBox[{"td", "=", "0"}], ",", "0", ",", "0", ",", "20", ",", "20"}], 
   "]"}]}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "5.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"z", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "5.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.51845217398*^9}]
}, Open  ]],

Cell["Enter the wall location, its thickness, and height.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Wally", "=", "25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Wallthick", "=", "2"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Wallz", "=", "5"}], ";"}]}], "Input"],

Cell[TextData[{
 "Plotting the solution of ",
 StyleBox["z",
  FontWeight->"Bold"],
 " versus ",
 StyleBox["y",
  FontWeight->"Bold"],
 " is as follows."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TrajPlot1", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], ",", 
         RowBox[{"z", "[", "t", "]"}]}], "}"}], "/.", "sol1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "to", ",", "tf"}], "}"}], ",", 
     RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", " ", 
  RowBox[{"TrajPlot1", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Rectangle", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Wally", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Wally", "+", "Wallthick"}], ",", "Wallz"}], "}"}]}], "]"}], 
    "]"}], ",", 
   RowBox[{"DisplayFunction", "->", "$DisplayFunction"}]}], " ", 
  "]"}], "\n"}], "Input",
 CellChangeTimes->{3.518452191686*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxd1nk8VPv/B3BC2bIvFco2c6asM2fMMJV5aUYXRYiUqCjlEinaJFIUoaSQ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      "]]}}, RectangleBox[{25, 0}, {27, 5}]},
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  PlotRange->{{0., 40.235947984102864`}, {-26.509217533342383`, 
   12.09199415222475}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5184521772404003`*^9, 3.5184521920292*^9}}]
}, Open  ]],

Cell["\<\
Now we will work backwards.  We will start from the point of impact and see \
the conditions needed to get to that point in some time.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol2", "=", 
  RowBox[{"sol", "[", 
   RowBox[{"4", ",", ".1", ",", "10", ",", "9.81", ",", 
    RowBox[{"to", "=", "0"}], ",", 
    RowBox[{"tf", "=", "6"}], ",", 
    RowBox[{"td", "=", "5"}], ",", "30", ",", "20", ",", "4", ",", 
    RowBox[{"-", "15"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "6.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"z", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "6.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.518452197848*^9}]
}, Open  ]],

Cell["Enter the wall location, its thickness, and height.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Wally", "=", "25"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Wallthick", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Wallz", "=", "20"}], ";"}]}], "Input"],

Cell["Plotting again.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"TrajPlot2", "=", 
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], ",", 
         RowBox[{"z", "[", "t", "]"}]}], "}"}], "/.", "sol2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "to", ",", "tf"}], "}"}], ",", 
     RowBox[{"DisplayFunction", "->", "Identity"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", " ", 
  RowBox[{"TrajPlot2", ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Rectangle", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Wally", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Wally", "+", "Wallthick"}], ",", "Wallz"}], "}"}]}], "]"}], 
    "]"}], ",", 
   RowBox[{"DisplayFunction", "->", "$DisplayFunction"}], ",", 
   RowBox[{"PlotRange", "->", "All"}]}], " ", "]"}], "\n"}], "Input",
 CellChangeTimes->{3.5184522155383997`*^9},
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81fsfB3AkIbIyUtnrLOcY2fTK6nyRCN2mZISkFKJLZqJQSRTKL4TK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      "]]}}, 
   RectangleBox[{25, 0}, {30, 20}]},
  Axes->True,
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5184522133543997`*^9, 3.5184522160688*^9}}]
}, Open  ]],

Cell["\<\
The values of the position and speeds at the initial time can be found as \
follows.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "[", "0", "]"}], ",", 
    RowBox[{"z", "[", "0", "]"}], ",", 
    RowBox[{
     RowBox[{"y", "'"}], "[", "0", "]"}], ",", 
    RowBox[{
     RowBox[{"z", "'"}], "[", "0", "]"}]}], "}"}], "/.", "sol2"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "10.235949157898427`"}], ",", "24.932995293796587`", ",", 
    "20.00000151600601`", ",", "41.91026748799809`"}], "}"}], "}"}]], "Output",\

 CellChangeTimes->{3.5184522182995996`*^9}]
}, Open  ]],

Cell["\<\
They can also be plotted versus time.  Each graph can be identified by the \
initial values.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"y", "[", "t", "]"}], ",", 
       RowBox[{"z", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"y", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"z", "'"}], "[", "t", "]"}]}], "}"}], "/.", "sol2"}], "]"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "to", ",", "tf"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjHk41HkAh8eRsVOEmN8iGkyTlAjJlJnvp1K6HB3OmM092Ul4tkt0KFEZ
OfKURNiQo4tNq8LY0HhiVOiw0SYUkpEiWdn2j/d5n/ef18h/z9YgRRqN5vSD
//11U1iW656jfLeWJgXZAbbkZOAC0xaOgLCy8rIngtiS5o89oWJOGBEmsFwX
b2NL5OVrEkWcw0SS2/53gTlbEsscnevDSSJNf/ypKO82kTx6uLF3GyebnJzJ
UZE5m0j25OxrdOFcJym1Ho3pi4wltYmJ95w41aRDeH17hnyeZIZKJL0/tIU8
+aD36pMSJdlwxC/utvtzkuR8Pr7+prrkzsGgzvwnXeRCVJ1ZTgVN8tL7V4vI
/W/JO6OWou9X2mo0HcXBtXhH4uQyg+z4UaLRFlS2fMcg+ddb4DDppgITlqgo
zn+Y1JHXiZrfNGDXufvRqtQRErrrUp9Qn4nab0c3t2WOkshxsebmAH0Ia6TS
6tgvJCnCkKXAYCEjoFBPZ+c46W9WUxLZG8Pc883Y96AJsrZONeLjcTa6Rl1k
2DBJZt1+4xAi5uDTa11LptsUSRmLv19QYorkkqgQD49pwpWOJSQUm4EzW9Xp
QCYNrspOZ9fvXYyK8KMlSZcVkN465Tu8fQna5qfRt6QqQmntoH+0oiXYx1tN
fTOUsKln+3hmjyW4rq9tLmcqI9DHqlrv3lJ0hsfxxYkz8FF33Hko2gplXC+1
+hQVbKsaar6y3hpM94cvr8bRYW7eIzJTsAHppqX89ZsqprLb2xm3bJDBFKpx
DvyE4qdOsvjQZYjN3hW/LJSBRj45917LFlmyCw1J4TNhXZCjk1Bni5iwNLlB
5Cxc698Vyw9bjkE/05+9/NWwV8DQTVe1w5mpAeWuYHU8yOvmd5TY4e4Hx2F1
79lQsfPtOw8uns23617B1oBi0rPeeS1cCBcGWKTla6B6p2fXuuAVqHXfcWiV
oSaOGHwZWiBfAWvPgSLtXE2o8xQYnrErITq+7jlPXwtfY1q9+uj2SAhW/aaQ
poWIUxdqLBLsUWXgNz2gPQcXWTt7YjR4qPx+UsksaQ5q3YYqTcQ8yMrXDIg1
tVHcK34Qr8lHPSu4ITFVG++3pF/vTebjxB233DcMHTzqvXli/wwCH+NXgh1i
HYhfheyOPUYwWWGhv4jOxMr7N1dbjBJEK/U3pR9m4nGzUaSXJcBkc/3m0yhU
2+SfuRMK7A9z/8w4SCGvMfuJfQ4w1zZQyjlEofQt7eHCXEAyFXFpdQwFB88X
xcw8gCEWO0QdozCzfIQn/x3ILqk713+Kguc9ZmpeIdDw3mqZ9CIFn6uiz0o3
AO2A2fvi7lOwzuCXV1YBlWYGG3OrKRiWrY++Ug0IPpkZVkkoFMzTszlbA1w9
tq7hcx2FSi2D8MBaYGVODDOwmcKq4X5d9XrAv3OwYnUXhQrXp7aCJoCeP3Fa
8A+FjrQjQ47NQKmI/ktUN4XCrXPTlsqAsUljelkfhQ/cJSXKj4HTet4eRsMU
HF0m1ItbAYvukEW8EQrX5gh5aW1AW9Heac/RHz+rDu/odsCQm1KYPE4hN/ip
v/Nz4AHt8qHSCQqBIl+n5S8AobTURTpJgX/jC4f1EpiVfNekZ4qCoCBrWLUD
uOUhHZ+ephAs9Sgc+dH/ARIPJ6M=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VO0XAPBrp5JtGBTZQpZXltRUeo5sc6Wo11KE7ESSspV9S5YpS1JJ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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk4lAkAB+ARNfINZpiZz32NxllkitRT309Zoq0huaOQo5Kwukgx0uZM
dLipFjlSaZeoSLk6sBub6kGxqUWlUEZWs7t/vM+r679/a+ACGo3m8p//F28K
K3DaH7fuTUaGWCIR4OQuA8Nuvi8V5NO95ohYgM6Pb/ak8cMocoRpIP4kwKeb
G1JD+ceovc+1+xcNCyDiTmls56dTLr97MYNbBHjc7jjiwi+k/nHqx9JkAfYX
H3wo5FdTVS7xSWWqAjSnpt7ezG+kdHqss/TtLdA49uIJUd5IZZtbzrrAAnc2
Ggw+NGmiwsstI09ZW8B7gR/tsso9SigsO0kztYBr45yetlYzlTAtW2DKsoCj
5fIQ0ugBpdmuUr+/fzkE/PxJOtVOnZKylRw9uBwLF0XSR/d0U6Ir18ZL6szh
cNwv8Te3PuqDv33CtpllqDsSOFDyxyA1ZpKrs/a1KV547TWLPPQX9bI98f3b
d8Zg2acFNeMdlcfqDj6/yQjM3sAaK+9x6o71kway2QA8ndDyRP8JqsZOOml0
Nx+rBvY9tsn8TIVe2JIx47gEzd/ifuzNm6K6q/pPn7XQR0hTR0ej6Au1WVlq
fcUPPOQElKlxds5QMt/VVp6N0MNSj6Gv3wNnqdWd3qkmRboYnBJ2wWGOcs5p
VmGP62Dylao513WeanWOvB9mpYOMyuhgd3cJVXlf5gDNWBt8RdnNh/NoWHfO
9yc9lhZqw+Mq04ukENDHm178VQO9S7LozpkLkJef5yiWqEM/ocfQJ0caOrpq
UXp0dVg7vVpRlCcDlWeBfhyeGgbCE9elpS6Ep+zduhhvVdRYe8q3nlmEFr3J
FvUMFXDd2l9cSaTDVHioOmiABDVMO3M/ShY+03Z9j61I5HBD5PmHF0PX80Uh
LZ0LUeHun1fukcOKTrG2spiDgq7stvRwAvHJDu91fTmIDcv6pBnJQESU0oe5
LjbG/QxVPP3l0WkTJlFwYiNlfkxmMEgBpYdtvyh3KqPhvf2EgpciGlKT0os9
lPFsyarh1fpMMBy3xKaOKyHEKMAsq4QJ0S1n9vFoJTS7ecfYaLFQvPV6cRVH
CQKPsXL2RRZOS4/4aF9lITTBrm+tuhK2OV44Vylk4VSQ7DepLCU8itohXT/D
xF1NP8kYWxlXJ3qSzPOZqP9+Uto4XRkzuSmlpo5MdN3cMJbGYmNDHrIvjCqi
VSeoLTWTjWjnpuSCjYo4Ued6cUiOgySRhirrlgK26/X7eqdxECAuzdfUVcBc
rZm6CZ2Lxgn7Sy458jgqPfrk3DEu1l8+QbSqyIOrb+23hEbio1kFjZfJwKEw
t2m5IySaCkRDT1UY0LDc1cGPIbF962rXRi4D9+Yj8tfHkgipaCMr2AzIpaXZ
RseTeF3OSRIxGSisbDk7mkTCZl22mpUsA21/W6zsyCVRe/n2WPUMAXaA4sHE
OyTKnfpanj8jUG+s6XixkYQrq+xzZy8B30ljrbv3SCxNM9r74CmBK/F2bdMt
JAxv0G2vdRFYUxzL3dVJ4iVPNSW5jYD/wHjt+kESDOm3O4S1BOgls8m+r0lM
rRgSOvxKoCqUviN6mETiTlHKhhoCX+f06DVvSeyMiBpZVU0gWc3LXXeCxFOe
nZ5BKQGz4WCTtZ9J9MgV7+P9QqC3/IDEY4rE4iI1GZ1LBLSsz5RlzJB4F7dM
Sa2QwANaUUzVLAkPVmkSmU8gpKNK2DFH4lzvt02cXAKMjAbem3kS43+qeypn
E7jh3jEjkZB4RIqvs84T+BeMHTBs
     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzXs81Pkex/FBGZTkNr+SsSFjJD/lfp3vx8wcitp2s6mwWrdBKbqsIiS5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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 6}, {-15.468885224114151`, 51.176545298081706`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.518452221092*^9}]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"NeXTAutomaticEncoding",
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 27, 0, 83, "Title"],
Cell[609, 24, 75, 0, 29, "Text"],
Cell[687, 26, 335, 14, 29, "Text"],
Cell[1025, 42, 219, 7, 31, "Input"],
Cell[1247, 51, 47, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[1319, 55, 102, 3, 31, "Input"],
Cell[1424, 60, 159, 4, 30, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1620, 69, 194, 6, 31, "Input"],
Cell[1817, 77, 339, 10, 30, "Output"]
}, Open  ]],
Cell[2171, 90, 468, 15, 29, "Text"],
Cell[2642, 107, 1757, 51, 67, "Input"],
Cell[4402, 160, 212, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[4639, 168, 310, 8, 31, "Input"],
Cell[4952, 178, 679, 24, 30, "Output"]
}, Open  ]],
Cell[5646, 205, 67, 0, 29, "Text"],
Cell[5716, 207, 188, 6, 72, "Input"],
Cell[5907, 215, 165, 8, 29, "Text"],
Cell[CellGroupData[{
Cell[6097, 227, 946, 28, 72, "Input"],
Cell[7046, 257, 5828, 102, 348, "Output"]
}, Open  ]],
Cell[12889, 362, 158, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[13072, 369, 302, 7, 31, "Input"],
Cell[13377, 378, 680, 24, 30, "Output"]
}, Open  ]],
Cell[14072, 405, 67, 0, 29, "Text"],
Cell[14142, 407, 189, 6, 72, "Input"],
Cell[14334, 415, 31, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[14390, 419, 993, 28, 72, "Input"],
Cell[15386, 449, 5615, 99, 441, "Output"]
}, Open  ]],
Cell[21016, 551, 108, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[21149, 558, 282, 9, 31, "Input"],
Cell[21434, 569, 258, 7, 30, "Output"]
}, Open  ]],
Cell[21707, 579, 116, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[21848, 586, 463, 15, 31, "Input"],
Cell[22314, 603, 12264, 211, 230, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

