(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   3345302,      61434]
NotebookOptionsPosition[   3335865,      61179]
NotebookOutlinePosition[   3336243,      61196]
CellTagsIndexPosition[   3336200,      61193]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Run this first", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
This is just the needed equations with no other stuff.  Run this first.  Then \
proceed by running the solve interpret section over and over again.  First \
I'll turm off spelling warnings.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}]}], "Input"],

Cell[CellGroupData[{

Cell["Input the definitions for the vector operations", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Input the vector definition with the command that follows.  The path will \
depend on where  the definitions reside on the local system.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", 
  "\"\</Users/alan/Book2010/Rev2010/dynmath/math3/vectors3.m\>\""}]], "Input",\

 CellChangeTimes->{3.512418846635106*^9, 3.512418902200667*^9},
 AspectRatioFixed->True],

Cell[BoxData["\<\"These Engineering Vector algorithms are copyright Alan A. \
Barhorst\"\>"], "Print",
 CellChangeTimes->{3.512418915537998*^9}]
}, Open  ]],

Cell["\<\
Define Unit Vectors and Unit Dyads for however many frames we need for the \
system. For this example we will use five frames of reference as shown.  \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a", "[", "x_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"A", ",", "a", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"b", "[", "x_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"B", ",", "b", ",", "x"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"c", "[", "x_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"C", ",", "c", ",", "x"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"d", "[", "x_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"D", ",", "d", ",", "x"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"n", "[", "x_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"N", ",", "n", ",", "x"}], "]"}]}]}], "Input",
 AspectRatioFixed->True],

Cell["\<\
Define fixed relationships between the frames of reference.   Note: these are \
different for different base orientations of the frames. \
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Unprotect", "[", "Dot", "]"}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], ".", 
    RowBox[{"n", "[", "3", "]"}]}], ":=", 
   RowBox[{"-", "1"}]}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"b", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], ".", 
    RowBox[{"b", "[", "3", "]"}]}], ":=", "1"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"c", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], ".", 
    RowBox[{"c", "[", "3", "]"}]}], ":=", "1"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], ".", 
    RowBox[{"d", "[", "3", "]"}]}], ":=", "1"}], "\[IndentingNewLine]", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], ".", 
    RowBox[{"n", "[", "3", "]"}]}], ":=", 
   RowBox[{"-", "1"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], ".", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"c", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], ".", 
    RowBox[{"c", "[", "3", "]"}]}], ":=", "1"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], ".", 
    RowBox[{"d", "[", "3", "]"}]}], ":=", "1"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], ".", 
    RowBox[{"n", "[", "3", "]"}]}], ":=", 
   RowBox[{"-", "1"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], ".", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], ".", 
    RowBox[{"b", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], ".", 
    RowBox[{"d", "[", "3", "]"}]}], ":=", "1"}], "\[IndentingNewLine]", 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], ".", 
   RowBox[{"n", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "3", "]"}], ".", 
    RowBox[{"n", "[", "3", "]"}]}], ":=", 
   RowBox[{"-", "1"}]}], "\n", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], ".", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], ".", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], ".", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], ".", 
    RowBox[{"b", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], ".", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], ".", 
    RowBox[{"c", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], ".", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], ".", 
    RowBox[{"d", "[", "2", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", "Dot", "]"}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Unprotect", "[", "Cross", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", 
  RowBox[{"b", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"b", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"b", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", 
  RowBox[{"c", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"c", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"c", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", 
  RowBox[{"d", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"d", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"d", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"n", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"a", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"n", "[", "2", "]"}]}], ":=", 
   RowBox[{"n", "[", "1", "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", 
  RowBox[{"a", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"a", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", 
  RowBox[{"c", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"c", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"c", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", 
  RowBox[{"d", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"d", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"d", "[", "1", "]"}]}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"n", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"b", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"n", "[", "2", "]"}]}], ":=", 
   RowBox[{"n", "[", "1", "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", 
  RowBox[{"a", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"a", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", 
  RowBox[{"b", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"b", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"b", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", 
  RowBox[{"d", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"d", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"d", "[", "1", "]"}]}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"n", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"c", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"n", "[", "2", "]"}]}], ":=", 
   RowBox[{"n", "[", "1", "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", 
  RowBox[{"a", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"a", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"a", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", 
  RowBox[{"b", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"b", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"b", "[", "1", "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", 
  RowBox[{"c", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"c", "[", "2", "]"}]}], ":=", 
   RowBox[{"-", 
    RowBox[{"c", "[", "1", "]"}]}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"n", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"n", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"d", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"n", "[", "2", "]"}]}], ":=", 
   RowBox[{"n", "[", "1", "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"a", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"a", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"a", "[", "2", "]"}]}], ":=", 
  RowBox[{"a", "[", "1", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"a", "[", "3", "]"}]}], ":=", "0"}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"b", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "2", "]"}]}], ":=", 
  RowBox[{"b", "[", "1", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"b", "[", "3", "]"}]}], ":=", "0"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"c", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "2", "]"}]}], ":=", 
  RowBox[{"c", "[", "1", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"c", "[", "3", "]"}]}], ":=", "0"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"d", "[", "1", "]"}]}], ":=", 
  RowBox[{"-", 
   RowBox[{"d", "[", "2", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
   RowBox[{"d", "[", "2", "]"}]}], ":=", 
  RowBox[{"d", "[", "1", "]"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
    RowBox[{"d", "[", "3", "]"}]}], ":=", "0"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", "Cross", "]"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"transform", "[", "x_", "]"}], ":=", 
  RowBox[{"x", "//.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"d", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"c", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"d", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"q3", "[", "t", "]"}], "]"}]}], " ", 
        RowBox[{"c", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"c", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"c", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"q2", "[", "t", "]"}], "]"}]}], " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"q4", "[", "t", "]"}], "]"}]}], " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"b", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"q1", "[", "t", "]"}], "]"}]}], " ", 
        RowBox[{"n", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"n", "[", "2", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"n", "[", "1", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
        RowBox[{"n", "[", "2", "]"}]}]}]}]}], "}"}]}]}]], "Input",
 AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constraints", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"solq4x", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["H", "2"]}], "+", 
                SuperscriptBox["l2", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["l3", "2"]}], "-", 
                RowBox[{
                 SuperscriptBox["l2", "2"], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "+", 
                RowBox[{"4", " ", "H", " ", "l2", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{"H", "+", 
                RowBox[{"l2", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"y", "[", "t", "]"}]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{"q4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"ArcCos", "[", 
          RowBox[{
           FractionBox["1", "l3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "H"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
             RowBox[{"l2", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"q1", "[", "t", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
              RowBox[{"y", "[", "t", "]"}]}], "+", 
             RowBox[{
              FractionBox["1", 
               SqrtBox["2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
                RowBox[{"\[Sqrt]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["H", "2"]}], "-", 
                   SuperscriptBox["l2", "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["l3", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["l2", "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
                   RowBox[{"4", " ", "H", " ", "l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                   RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{"H", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"y", "[", "t", "]"}]}], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}], "]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"\[Sqrt]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 SuperscriptBox["H", "2"]}], "+", 
                SuperscriptBox["l2", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["l3", "2"]}], "-", 
                RowBox[{
                 SuperscriptBox["l2", "2"], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "+", 
                RowBox[{"4", " ", "H", " ", "l2", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
             RowBox[{"8", " ", 
              RowBox[{"(", 
               RowBox[{"H", "+", 
                RowBox[{"l2", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"y", "[", "t", "]"}]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{"q4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"ArcCos", "[", 
         RowBox[{
          FractionBox["1", "l3"], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "H"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
            RowBox[{"l2", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
             RowBox[{"y", "[", "t", "]"}]}], "+", 
            RowBox[{
             FractionBox["1", 
              SqrtBox["2"]], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Cos", "[", 
                RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
               RowBox[{"\[Sqrt]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["H", "2"]}], "-", 
                  SuperscriptBox["l2", "2"], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["l3", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["l2", "2"], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
                  RowBox[{"4", " ", "H", " ", "l2", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"(", 
                    RowBox[{"H", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                   RowBox[{"y", "[", "t", "]"}]}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox[
                    RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["H", "2"]}], "-", 
            FractionBox[
             SuperscriptBox["l2", "2"], "2"], "+", 
            SuperscriptBox["l3", "2"], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox["l2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{"2", " ", "H", " ", "l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"H", "+", 
               RowBox[{"l2", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"y", "[", "t", "]"}]}], "-", 
            SuperscriptBox[
             RowBox[{"y", "[", "t", "]"}], "2"]}], ")"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"q4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"ArcCos", "[", 
          RowBox[{"-", 
           RowBox[{
            FractionBox["1", "l3"], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"H", " ", 
               RowBox[{"Sin", "[", 
                RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
              RowBox[{"l2", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"Sin", "[", 
                RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
               RowBox[{"y", "[", "t", "]"}]}], "+", 
              RowBox[{
               FractionBox["1", 
                SqrtBox["2"]], 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"\[Sqrt]", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["H", "2"]}], "-", 
                    SuperscriptBox["l2", "2"], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["l3", "2"]}], "+", 
                    RowBox[{
                    SuperscriptBox["l2", "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
                    RowBox[{"4", " ", "H", " ", "l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{"H", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"y", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], "]"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["H", "2"]}], "-", 
            FractionBox[
             SuperscriptBox["l2", "2"], "2"], "+", 
            SuperscriptBox["l3", "2"], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SuperscriptBox["l2", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
            RowBox[{"2", " ", "H", " ", "l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"H", "+", 
               RowBox[{"l2", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"y", "[", "t", "]"}]}], "-", 
            SuperscriptBox[
             RowBox[{"y", "[", "t", "]"}], "2"]}], ")"}]}]}]}], ",", 
       RowBox[{
        RowBox[{"q4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"ArcCos", "[", 
         RowBox[{"-", 
          RowBox[{
           FractionBox["1", "l3"], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"H", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
             RowBox[{"l2", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"q1", "[", "t", "]"}], "]"}], "2"]}], "-", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
              RowBox[{"y", "[", "t", "]"}]}], "+", 
             RowBox[{
              FractionBox["1", 
               SqrtBox["2"]], 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"Cos", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
                RowBox[{"\[Sqrt]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    SuperscriptBox["H", "2"]}], "-", 
                   SuperscriptBox["l2", "2"], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["l3", "2"]}], "+", 
                   RowBox[{
                    SuperscriptBox["l2", "2"], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "]"}]}], "-", 
                   RowBox[{"4", " ", "H", " ", "l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                   RowBox[{"4", " ", 
                    RowBox[{"(", 
                    RowBox[{"H", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"y", "[", "t", "]"}]}], "-", 
                   RowBox[{"2", " ", 
                    SuperscriptBox[
                    RowBox[{"y", "[", "t", "]"}], "2"]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], "]"}]}]}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solDq4x", "=", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "l2"}], " ", 
         RowBox[{"Sec", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"Tan", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["q4", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        FractionBox["1", "l3"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sec", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"l2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                RowBox[{"l3", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{
              SuperscriptBox["q1", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], 
         ")"}]}]}]}], "}"}], "}"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dragging sets of equations of motion", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom1d", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d1", " ", "g", " ", "mb", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"g", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"g", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"d1", " ", "g", " ", "mb", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "+", 
      RowBox[{"g", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "+", 
      RowBox[{"g", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "+", 
      RowBox[{"2", " ", "l1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d2", " ", "mc"}], "+", 
            RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", "dB", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", "dC", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q3", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q3", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"4", " ", "l1", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d2", " ", "mc"}], "+", 
               RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", "B33", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d1", "2"], " ", "mb", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["l1", "2"], " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["l1", "2"], " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "-", 
         RowBox[{"q2", "[", "t", "]"}], "-", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", "d1", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "l2", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", "d1", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "l2", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "d1", " ", "g", " ", "ma", " ", "\[Mu]", 
          " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "g", " ", "l2", " ", "ma", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"2", " ", "d1", " ", "g", " ", "mh", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "g", " ", "l2", " ", "mh", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"q1", "[", "t", "]"}]}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"q1", "[", "t", "]"}]}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"q1", "[", "t", "]"}]}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{"2", " ", "l1", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d2", " ", "mc"}], "+", 
               RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q1", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "l1", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d2", " ", "mc"}], "+", 
               RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q2", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "dC", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "-", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q3", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q3", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"4", " ", "l1", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"d2", " ", "mc"}], "+", 
                  RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"d3", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["q2", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["q3", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"dB", "-", 
            RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["q3", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", "d1", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", "l2", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["x", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", "d1", " ", "\[Mu]", " ", 
          RowBox[{"Sign", "[", 
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", "l2", " ", "\[Mu]", " ", 
          RowBox[{"Sign", "[", 
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["y", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "-", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", "B33", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "-", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "-", 
            RowBox[{"q2", "[", "t", "]"}], "-", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"2", " ", "d1", " ", "ma", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", "l2", " ", "ma", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"2", " ", "d1", " ", "mh", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", "l2", " ", "mh", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"Sign", "[", 
          RowBox[{
           SuperscriptBox["x", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom2d", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{"g", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d2", " ", "mc"}], "+", 
          RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"d3", " ", "l4", " ", "md", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dC", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "+", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l1", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom3d", "=", 
   RowBox[{
    RowBox[{"d3", " ", "g", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{"d3", " ", "md", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q2", "[", "t", "]"}], "+", 
          RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{"l4", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l1", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom4d", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "l3"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sec", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q1", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q4", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"l2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "-", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], ")"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom5d", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      SuperscriptBox["x", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sec", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"l3", "+", 
          RowBox[{"l2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", "l3", " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"l2", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom6d", "=", 
   RowBox[{
    SuperscriptBox["y", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Swinging sets of equations of motion", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom1s", "=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d1", " ", "g", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"g", " ", "l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "d1", " ", "g", " ", "mb", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "g", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"2", " ", "g", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"d1", " ", "g", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"g", " ", "l2", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"d1", " ", "g", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "+", 
      RowBox[{"g", " ", "l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "-", 
      RowBox[{"d1", " ", "g", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "+", 
      RowBox[{"g", " ", "l2", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "+", 
      RowBox[{"2", " ", "l1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d2", " ", "mc"}], "+", 
            RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", "l1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d2", " ", "mc"}], "+", 
            RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", "dC", " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q3", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"4", " ", "l1", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d2", " ", "mc"}], "+", 
               RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"dB", "-", 
         RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", "B33", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["d1", "2"], " ", "mb", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["l1", "2"], " ", "mc", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["l1", "2"], " ", "md", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d1", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l2", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d1", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l2", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d1", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l2", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d1", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l2", " ", "mh", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d1", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"d1", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"l2", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d1", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"d1", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"l2", " ", "mh", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom2s", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{"g", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d2", " ", "mc"}], "+", 
          RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"d3", " ", "l4", " ", "md", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dC", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "+", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l1", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom3s", "=", 
   RowBox[{
    RowBox[{"d3", " ", "g", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{"d3", " ", "md", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q2", "[", "t", "]"}], "+", 
          RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{"l4", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l1", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom4s", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Aa"}], " ", "Cd", " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"Aa", " ", "Cd", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"ma", "+", "mh"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"g", "+", 
          RowBox[{
           SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}], 
      ")"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom5s", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "l3", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l3", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q4", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"l2", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l3", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l3", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["x", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom6s", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"l2", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
        RowBox[{"l3", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", "l3", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"l3", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q4", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"l2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l3", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l3", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["y", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Free flying sets of equations of motion", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom1f", "=", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "d1", " ", "g", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"4", " ", "g", " ", "l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"8", " ", "d1", " ", "g", " ", "mb", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"8", " ", "g", " ", "l1", " ", "mc", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
      RowBox[{"8", " ", "g", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"4", " ", "d1", " ", "g", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "+", 
      RowBox[{"4", " ", "g", " ", "l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "d2", " ", "l1", " ", "mc", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "l1", " ", "l4", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{"2", " ", "d1", " ", "l3", " ", "ma", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", "l2", " ", "l3", " ", "ma", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"d1", " ", "l2", " ", "ma", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["l2", "2"], " ", "ma", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "+", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", 
          RowBox[{"(", 
           RowBox[{"d1", "-", "l2"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"l2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
             RowBox[{"l3", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{
                RowBox[{"q1", "[", "t", "]"}], "+", 
                RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"], " ", 
          
          RowBox[{"Sign", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l3", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["q1", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["q4", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "-", 
         RowBox[{"2", " ", "Aa", " ", "Cd", " ", 
          RowBox[{"(", 
           RowBox[{"d1", "-", "l2"}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{"Sign", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l2", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l3", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["q1", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["q4", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"l2", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
             RowBox[{"l3", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{
                RowBox[{"q1", "[", "t", "]"}], "+", 
                RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], "2"]}]}], 
        ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"8", " ", "l1", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"d2", " ", "mc"}], "+", 
            RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{"d3", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q2", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"8", " ", "dC", " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q3", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"8", " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"dB", "-", 
         RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"8", " ", "d1", " ", "l3", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"8", " ", "l2", " ", "l3", " ", "ma", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
       SuperscriptBox["l3", "2"], " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"l2", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"l3", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               RowBox[{"q1", "[", "t", "]"}], "+", 
               RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q1", "[", "t", "]"}], "+", 
            RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"3", " ", 
          RowBox[{"q1", "[", "t", "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"q4", "[", "t", "]"}]}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "l1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d2", " ", "mc"}], "+", 
               RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
            RowBox[{"d3", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{
               RowBox[{"q2", "[", "t", "]"}], "+", 
               RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"8", " ", "d3", " ", "l1", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["q3", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"d1", "-", "l2"}], ")"}], " ", "l3", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Aa", " ", "Cd", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"l2", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l3", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"Sign", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l2", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                  RowBox[{"l3", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"l3", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"q1", "[", "t", "]"}], "+", 
                 RowBox[{"q4", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "ma"}], "+", 
               RowBox[{"Aa", " ", "Cd", " ", 
                RowBox[{"Sign", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                  RowBox[{"l3", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l2", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
                  RowBox[{"l3", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], 
              ")"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"8", " ", "B33", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", "d1", " ", "l2", " ", "ma", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["l2", "2"], " ", "ma", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["d1", "2"], " ", "mb", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["l1", "2"], " ", "mc", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["l1", "2"], " ", "md", " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"4", " ", "d1", " ", "l2", " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["l2", "2"], " ", "ma", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d2", " ", "l1", " ", "mc", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "l1", " ", "l4", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"8", " ", "d3", " ", "l1", " ", "md", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "+", 
         RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom2f", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{"g", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"d2", " ", "mc"}], "+", 
          RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"d3", " ", "l4", " ", "md", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dC", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "+", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"l1", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q2", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"C33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["d2", "2"], " ", "mc", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["l4", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom3f", "=", 
   RowBox[{
    RowBox[{"d3", " ", "g", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
    RowBox[{"d3", " ", "md", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"l1", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q2", "[", "t", "]"}], "+", 
          RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
       RowBox[{"l4", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q1", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"dD", " ", 
     RowBox[{
      SuperscriptBox["q4", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"d3", " ", "l1", " ", "md", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q2", "[", "t", "]"}], "+", 
       RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"d3", " ", "l4", " ", "md", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["q2", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"D33", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["d3", "2"], " ", "md", " ", 
     RowBox[{
      SuperscriptBox["q3", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom4f", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "g"}], " ", "ma", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], "-", 
    RowBox[{"Aa", " ", "Cd", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{"l3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"q1", "[", "t", "]"}], "+", 
             RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l2", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
           RowBox[{"l3", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"q1", "[", "t", "]"}], "+", 
              RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{"l3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "2"]}], "-", 
    
    RowBox[{"Aa", " ", "Cd", " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{"l3", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"q1", "[", "t", "]"}], "+", 
             RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l2", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
           RowBox[{"l3", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{
              RowBox[{"q1", "[", "t", "]"}], "+", 
              RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{"l3", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "2"]}], "+", 
    
    RowBox[{"ma", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l2", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{"l3", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{
             RowBox[{"q1", "[", "t", "]"}], "+", 
             RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", "l3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"l2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "-", 
       RowBox[{"l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "-", 
       RowBox[{"l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
    RowBox[{"ma", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"q1", "[", "t", "]"}], "+", 
       RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
          RowBox[{"l3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{
             RowBox[{"q1", "[", "t", "]"}], "+", 
             RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", "l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q1", "[", "t", "]"}], "+", 
          RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["q4", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom5f", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Aa"}], " ", "Cd", " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["x", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"mh", " ", 
     RowBox[{
      SuperscriptBox["x", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eom6f", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "Aa"}], " ", "Cd", " ", 
     RowBox[{"Sign", "[", 
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"mh", " ", 
     RowBox[{"(", 
      RowBox[{"g", "+", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]}]}], 
  ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Switching info", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Na", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"g", " ", "ma", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"g", " ", "mh", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{"ma", " ", 
       RowBox[{"Sec", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"q1DD", "[", "t", "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l3", "+", 
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q1", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "l3", " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q4", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{"mh", " ", 
       RowBox[{"Sec", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "+", 
         RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "l2"}], " ", 
          RowBox[{"q1DD", "[", "t", "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l3", "+", 
            RowBox[{"l2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q1", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "l3", " ", 
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], " ", 
          RowBox[{
           SuperscriptBox["q4", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "+", 
         RowBox[{"l3", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["q4", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{"Aa", " ", "Cd", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"Aa", " ", "Cd", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"q4", "[", "t", "]"}], "]"}]}], "-", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Sign", "[", 
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"q1", "[", "t", "]"}], "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"q1DD", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"d3", " ", "g", " ", "md", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"q1", "[", "t", "]"}], "+", 
           RowBox[{"q2", "[", "t", "]"}], "+", 
           RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
        RowBox[{"d3", " ", "md", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l1", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{
              RowBox[{"q2", "[", "t", "]"}], "+", 
              RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
           RowBox[{"l4", " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["q1", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["q1", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["q2", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}], "+", 
        RowBox[{"d3", " ", "l4", " ", "md", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["q2", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
        RowBox[{"dD", " ", 
         RowBox[{
          SuperscriptBox["q4", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "D33"}], "+", 
        RowBox[{
         SuperscriptBox["d3", "2"], " ", "md"}], "+", 
        RowBox[{"d3", " ", "l4", " ", "md", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
        RowBox[{"d3", " ", "l1", " ", "md", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{
           RowBox[{"q2", "[", "t", "]"}], "+", 
           RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "D33"}], "+", 
         RowBox[{
          SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
               ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"B33", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["d1", "2"], " ", "mb", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "mc", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"B33", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
               ")"}]}]}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C33"}], "-", 
                RowBox[{
                 SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                RowBox[{
                 SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d3", " ", "g", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{"d3", " ", "md", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l1", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                  RowBox[{"l4", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
               RowBox[{"dD", " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
               RowBox[{"g", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
                  RowBox[{"d3", " ", "l4", " ", "md", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
               RowBox[{"dC", " ", 
                RowBox[{
                 SuperscriptBox["q3", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q3", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
               RowBox[{"dD", " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
           ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l1", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"B33", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["d1", "2"], " ", "mb", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "mc", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"B33", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
               ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d3", " ", "g", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{"d3", " ", "md", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l1", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                  RowBox[{"l4", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
               RowBox[{"dD", " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "mb", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "mb", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "ma", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l2", " ", "ma", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "mh", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"g", " ", "l2", " ", "mh", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"l1", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"l1", " ", "\[Mu]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
               
               FractionBox[
                RowBox[{"dB", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"l1", " ", "\[Mu]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
               
               FractionBox[
                RowBox[{"dC", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"dC", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", " ", "l1", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", " ", "l1", " ", "\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"dB", "-", 
                    RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
               
               FractionBox[
                RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"Aa", " ", "Cd", " ", "d1", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{"Aa", " ", "Cd", " ", "l2", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"d1", " ", "ma", " ", 
                  RowBox[{"Sec", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"l2", " ", "ma", " ", 
                  RowBox[{"Sec", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"d1", " ", "mh", " ", 
                  RowBox[{"Sec", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
               
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"l2", " ", "mh", " ", 
                  RowBox[{"Sec", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 ")"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "D33"}], "+", 
         RowBox[{
          SuperscriptBox["d3", "2"], " ", "md"}], "+", 
         RowBox[{"d3", " ", "l4", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
         RowBox[{"d3", " ", "l1", " ", "md", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{
            RowBox[{"q2", "[", "t", "]"}], "+", 
            RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l1", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
               "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
              ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"B33", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["d1", "2"], " ", "mb", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"B33", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l1", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "-", 
            RowBox[{"d3", " ", "l4", " ", "md", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
               "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
              ")"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"B33", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                 RowBox[{
                  RowBox[{"Cos", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["d1", "2"], " ", "mb", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "mc", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"B33", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
               FractionBox[
                RowBox[{
                 SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                 RowBox[{"Sign", "[", 
                  RowBox[{
                   SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{
                 RowBox[{"Cos", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                 RowBox[{"\[Mu]", " ", 
                  RowBox[{"Sign", "[", 
                   RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "-", 
                   RowBox[{"q2", "[", "t", "]"}], "-", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
               FractionBox[
                RowBox[{"d3", " ", "l1", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{
                   RowBox[{"q1", "[", "t", "]"}], "+", 
                   RowBox[{"q2", "[", "t", "]"}], "+", 
                   RowBox[{"q3", "[", "t", "]"}], "+", 
                   RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                   RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
              ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "D33"}], "+", 
         RowBox[{
          SuperscriptBox["d3", "2"], " ", "md"}], "+", 
         RowBox[{"d3", " ", "l4", " ", "md", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "C33"}], "-", 
                RowBox[{
                 SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                RowBox[{
                 SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                RowBox[{"l1", " ", "l4", " ", "md", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d3", " ", "g", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
               RowBox[{"d3", " ", "md", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l1", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                  RowBox[{"l4", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
               RowBox[{"dD", " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
               RowBox[{"g", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q1", "[", "t", "]"}], "+", 
                  RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"l1", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
                  RowBox[{"d3", " ", "l4", " ", "md", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q1", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q2", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
               RowBox[{"dC", " ", 
                RowBox[{
                 SuperscriptBox["q3", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q2", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q3", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["q3", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                RowBox[{
                 SuperscriptBox["q1", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                  RowBox[{
                   SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
               RowBox[{"dD", " ", 
                RowBox[{
                 SuperscriptBox["q4", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
           ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D33"}], "+", 
                RowBox[{
                 SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                RowBox[{"d3", " ", "l4", " ", "md", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
               RowBox[{"l1", " ", "l4", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "C33"}], "-", 
               RowBox[{
                SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
               RowBox[{
                SuperscriptBox["l4", "2"], " ", "md"}], "-", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D33"}], "+", 
               RowBox[{
                SuperscriptBox["d3", "2"], " ", "md"}], "+", 
               RowBox[{"d3", " ", "l4", " ", "md", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
               RowBox[{"d3", " ", "l1", " ", "md", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{
                  RowBox[{"q2", "[", "t", "]"}], "+", 
                  RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
           ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "D33"}], "+", 
                  RowBox[{
                   SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C33"}], "-", 
                 RowBox[{
                  SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                 RowBox[{
                  SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "-", 
              RowBox[{"d3", " ", "l4", " ", "md", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "D33"}], "+", 
                 RowBox[{
                  SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    ")"}]}], "-", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"B33", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"B33", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    ")"}]}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"d3", " ", "g", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l1", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                    RowBox[{"l4", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"dD", " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "d2"}], " ", "g", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
                    RowBox[{"g", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}]}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"dC", " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "+", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
                    RowBox[{"dD", " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
                ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"B33", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"B33", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"d3", " ", "g", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"l1", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}], "+", 
                    RowBox[{"l4", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"dD", " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "ma", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l2", " ", "ma", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "mh", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"g", " ", "l2", " ", "mh", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d1", " ", "g", " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"g", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"q1", "[", "t", "]"}]}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l1", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                    "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l1", " ", "\[Mu]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                    "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
                    
                    FractionBox[
                    RowBox[{"dB", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l1", " ", "\[Mu]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}], 
                    "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
                    
                    FractionBox[
                    RowBox[{"dC", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"dC", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"2", " ", "l1", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"2", " ", "l1", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"d2", " ", "mc"}], "+", 
                    RowBox[{"l4", " ", "md"}]}], ")"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"d3", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q2", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{"dB", "-", 
                    RowBox[{"2", " ", "d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q3", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
                    
                    FractionBox[
                    RowBox[{"Aa", " ", "Cd", " ", "d1", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"Aa", " ", "Cd", " ", "l2", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"Aa", " ", "Cd", " ", "d1", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{"Aa", " ", "Cd", " ", "l2", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"d1", " ", "ma", " ", 
                    RowBox[{"Sec", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l2", " ", "ma", " ", 
                    RowBox[{"Sec", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "-", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"d1", " ", "mh", " ", 
                    RowBox[{"Sec", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}], "+", 
                    
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l2", " ", "mh", " ", 
                    RowBox[{"Sec", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"l3", "+", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "l3", " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"l3", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["q4", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"l2", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q4", "[", "t", "]"}], "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["q1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "D33"}], "+", 
                  RowBox[{
                   SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                  RowBox[{"d3", " ", "l4", " ", "md", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C33"}], "-", 
                 RowBox[{
                  SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                 RowBox[{
                  SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                 RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                 RowBox[{"l1", " ", "l4", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "C33"}], "-", 
                 RowBox[{
                  SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                 RowBox[{
                  SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "D33"}], "+", 
                 RowBox[{
                  SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                 RowBox[{"d3", " ", "l1", " ", "md", " ", 
                  RowBox[{"Sin", "[", 
                   RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
             ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
                ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                   ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"B33", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"B33", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                   ")"}]}]}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}]}], ")"}]}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "C33"}], "-", 
                    RowBox[{
                    SuperscriptBox["d2", "2"], " ", "mc"}], "-", 
                    RowBox[{
                    SuperscriptBox["l4", "2"], " ", "md"}], "-", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}], "+", 
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{"q2", "[", "t", "]"}], "]"}]}]}], ")"}]}], "-", 
                 RowBox[{"d3", " ", "l4", " ", "md", " ", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"q3", "[", "t", "]"}], "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}], 
                ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                    "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                   ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "D33"}], "+", 
                    RowBox[{
                    SuperscriptBox["d3", "2"], " ", "md"}], "+", 
                    RowBox[{"d3", " ", "l4", " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"q3", "[", "t", "]"}], "]"}]}]}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", 
                    FractionBox[
                    RowBox[{"B33", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]]}], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"B33", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["d1", "2"], " ", "mb", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "mc", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "+", 
                    FractionBox[
                    RowBox[{
                    SuperscriptBox["l1", "2"], " ", "md", " ", "\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}]], "-", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d2", " ", "l1", " ", "mc", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"l1", " ", "l4", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "-", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "-", 
                    RowBox[{"q2", "[", "t", "]"}], "-", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]], "+", 
                    FractionBox[
                    RowBox[{"d3", " ", "l1", " ", "md", " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q2", "[", "t", "]"}], "+", 
                    RowBox[{"q3", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}], 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Cos", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}], "-", 
                    RowBox[{"\[Mu]", " ", 
                    RowBox[{"Sign", "[", 
                    RowBox[{
                    SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "]"}], " ", 
                    RowBox[{"Sin", "[", 
                    RowBox[{
                    RowBox[{"q1", "[", "t", "]"}], "+", 
                    RowBox[{"q4", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "D33"}], "+", 
       RowBox[{
        SuperscriptBox["d3", "2"], " ", "md"}], "+", 
       RowBox[{"d3", " ", "l4", " ", "md", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"q3", "[", "t", "]"}], "]"}]}], "-", 
       RowBox[{"d3", " ", "l1", " ", "md", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{
          RowBox[{"q2", "[", "t", "]"}], "+", 
          RowBox[{"q3", "[", "t", "]"}]}], "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve and Interpret", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 StyleBox["********NOTE********",
  FontColor->RGBColor[1, 0, 0]],
 "\nWhen running this simulation make changes in this section and execute \
this section as many times as needed to get the results. The steps above need \
only be executed during the first pass through the notebook. "
}], "Text"],

Cell[TextData[{
 "Define the constants.  ",
 StyleBox["Use consistent units",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}],
 StyleBox[".",
  FontSlant->"Italic",
  FontVariations->{"Underline"->True}]
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 4 4 377 279
%%HiResBoundingBox: 4 4 377 279
%%Creator: (Mathematica 4.2 for Macintosh)
%%CreationDate: (Friday, April 29, 2005) (19:00:15)
%%Title: Clipboard
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 283 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def

%%MathematicaCell
%Cell[GraphicsData[\"PICT\", \\
%\"\\<\\
%000000000A<1M@0A0_l<0?on0000B00004P0000000014`\\
%5e0000000N00402P00
%00014`5e038000000A<1M@0OP0200800PP000==H00000@000000000000000000
%00400000000000000000040000000000000000000000@00000014`5e00030000
%00X02P0000014`5e0000OWAYIVH0000000000000001QL71/000000001001M@4C
%04P0001800000=:<004:E4U6AR0XC5YG:@00000000000000000000000000000H
%ool0000<LgAbL00001d0000<JFiTN0000040000<M6UVH`0000D00000CDd0:P00
%dHB0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@B6AB>BBFCBND
%BVEB^FBfGBnHC6IC>JCFKCNLCVMC^NCfOCnPD6QD>RDFSDNTDVUD^VDfWDnXE6YE
%>ZEF[EN/EV]E^^Ef_En`F6aF>bFFcFNdFVeF^fFfgFnhG6iG>jGFkGNlGVmG^nGf
%oGo0H71H?2HG3HO4HV=_g6@=oHmli63?c:H[;IO<IW=I^i?K?@Ikj61iikIcCJOD
%JWEJ^P__G@W:?cFK?JKGKKOLAK7_kB@?6?gG?_OkWRLGSLOTGimL^4l7TloXM7YM
%>djC8_UXMT0M_ZMg_Mo`N6NL]m@UCNO]P37HoaNggNohO5o_j9k7Mk56oT1O]]Og
%i?o040`4_[j?VPD2X90/48;1D3@M1<3WjnKO`TP[b33300`dG/>=fgd:@[1;M_I0
%LBa=4lD:G0[I7o5R2@[4<7`ZnTFAM0/IWfPAm/O5alAlPHIB2m9?B8RD@AS5<TbD
%P3oPD3PT5Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMP[nPClT<6TCoTDPO/UT
%d2O[oOL2O<3T3oU[oOd_Ud/OLkPKgW`:X00XAHXSmXcnY59Q=9XdeSe?Z5AZECZU
%EZeG[5I[EK[UM[eO/5Q/ES/UUSTcVLRV/]T/WUeZUL[W4aPDcYdhW5>PKE_U01@3
%`0I`D3Y]=YEVa69aF;aV=af?b6AbFCbVEbeU]5eVT/^=>ODPUlU]T2W4fcFTdSjO
%ChPKeebPf0>f@1fP8fccg4bY65XfGgfoh71hG3hW5hg7i79[nIPMhcNVVcjdU8Td
%Pc;mVO@Ode_;lkd38OQXGS009lbSm5;jT8`o:mg_n7anGcnWengg/EYdldUlgk:d
%^TOYm[XeR?YBe2jYJVjK7jO<77O23006lRQ0=2`M@`eC?_FPSf_a3l@A34DAa94/
%CA>[;m>PoSn9:k9m^TOQm`:NjI<h^JI@DWIl`:Oi=anf`40U8Ka`U2AhBA1bj88g
%RmAA9lXBS:DYbY:/[?c1227^N/F_fNajWTM1cW6MQhaZdjGY`NZFafVcnYBkdQPT
%lHJC[2`30K?<kSQ?RV^JWRF:?3T[d9@]3D?A54dDn[//8OIn7/NQk9m?dI1L4XC1
%l8XTW]6d5Wbd22`77Y:e:0UCRYE:T_6JmFPYEkaWCFD=Cnd[2=kAMLeeGMNEkGeO
%ZPOd79XU[NZ<EQCUBBi:T`BI:4`DQCUHTYmY0]]0ZM9CaRAKRTZB0]`8791h0QLX
%dg>kbE:KFUPGKMeggQN=iBSMT4WneIh7DM0J1V6c/YJ50CQHMai7bNdf94O65E^Y
%aTHLPLU:JlJ1gC9A^H_FZ4bENN>HkSf?i1T;laTUSo[HNi@4`BYRV:IIlY>O9mVN
%IYW4@Ai;`:k5k92_F=]9@1oP5XEdZJNfS87Xe>Y3M>V9ETFWjQ:Z0X0oh50h91H=
%1hA2HE2hI3HM3hQ4HU4hY5H]5ha6He6hi7Hm3Wk0Wg0Wjmg`nWjnghogjmYHn7k8
%GhoX4oWfoWhngc0W[8IXog`mgW0io<I3=Gm?gnljH0:M2GYDHOAXoEJ]EjaFJeFj
%iGJmGk1HK5Hk9IK=IkAJKEJi8nge;WloKS=H4o7Ro7^kiHogZmH6nY5=gnlG^ojD
%ogg9WaQh8m/M1ZL086nLXml]1/XnGgVh=E;IWm1XM5Xm9YM=YmAZMEZmI[HYLgkP
%<i=7k:l<lVVcV8GRdJ4ZSTjaEj^080@0`fBeGa?9dngkbiYKYI]X;Vi70/Ro>e1^
%e<jCgh7A/mIioS89AoA98Ki_30/1R<=M8;Ah9iH9el5LZ9l_I[_lol0@30D1`90/
%3@>ZZH/@TIm<hOjMWnOAm7J`ak3^=i12D7PXU4AY51J3`<UZGYT7RPCU`NOJG=/f
%bJ?0P[_P36D1::mCh/<Xkl>S7JF?]6lOA^n31/fMbT/<j9l_NjkH^/^ZmWnUaoWY
%1T8BNUJLb>YC^^jPLV`A;l`C3<Dac9</c@?7:DWXNkl894al7R3H;1D3H8QBOii7
%X5X=PbIiZW0NRAB4U2AY`^TG_ZY<I036TK:>l/L_LVQm>R^BhaLoSmb2`1o;e:Al
%96Tjj7bO1j:BkL7bLXlXbW2<ZZ?5/8`TXTS8:c<ceaG=MEgGUNemGkhW^Ne2[XT]
%0WfMYeVhJZW0TJQ/7NLa^W02h6PHOS0<XTQjW`NIfWTWLDAKF]4WmAM6bOAkfb4`
%Cld/YDOGSB9oDXOYlW]1Yl_e@JE^UE33_a5R4@Tmk1WS4c0^^PV2F1Q^7HOR68hU
%RJ<da8:R^FNidUVDQ>R>9@//FOiDU4E8V228IO5jHBg7jIAPUd6`HQF0030LLQfW
%aLKcAS6L2B1MLL]YN==Alf[3BD_JM9VnAi7QQ1ogkBS1Ao7^[J[MJ5H8Xe4HY[f_
%k1/>aK7M2@jFOT5?POAgRT98R5nGiTWd`YATVCH8080ac7BMYk:BKi`6dT@m3j@A
%K5bH3bg9FUcIm<KdbO65<a^kJKA?Y6ZWmOBm[VOCZAcPCh/5BV[j0URHWae;_^][
%W5k9eoHMSfGImXSBO_c2:hYVWIo>Ff:ijR`agf?NbiBRfWDW/=`gSWYjoAMed/g?
%<?8LQC?P?A5e2dh^5>7nF9G5X=0_S0=8a3B6hN2PM4:?Pim@8522JAA55mamFoJo
%coGmoio_o4YDhOXWa8EB50KlGE1CJ48U^<fKHNhmAk2?4J8hL8iAc;hJXedY3SE6
%85NZSIbB=eH:2JRKA@[_RQV95X;@G`5P90LBT>`F`[QF0Q1F48NY?c2W`A@HDmjP
%BP96EReUA3n7CSm;jGiodBhVA=RM4m01?g?3i;RC/f:3c04iGd?a:Z=DL:T7X:hD
%XYUUSH7:>/MKlX=T6Ik1e0T7g8We?Ti19I97^8?7LZDN04@80N6/=8L1R1j2B4B8
%@?HRQ?S^=/RPWL>e0U7MlY@VSC604a;LQ8;LVBXZVE>ZR8lD9@BQU5:>DQEROX@H
%DkeZ:PEkV87dQ29@mBEU57d?<B0Q`o0L0L0/6X;@ERS5F:f7K>hf::LLP>>1m8i@
%R<<MLfaj30A8<<?<IXbARP@0N1lOAOQm3Z7F0LY`aa[STB:@8Ni>bg3]7^?hNA8V
%A4[9<?aWAnS18@GN5JO0W9m466I?dD/oiBd1X5@>PU0YCY>86BhO/:DEX=W<o54k
%8RP4/7T?hNHjbF8>G56]64aXgC8DM22ILGSKBB<eAT`abal3^5f;LFP2@40H?PW@
%3`6080>757V9A;1m1X2l5`000@4R94T9m:bAgLWa?NoDj`]JW0iZPDIe8n0MeE5S
%ENP]FJ]EKZhk5XSUdXEPPc5hYD?b19A7f?QOB]GX<lXlV:I<LWP7f9BB^:jm2F3e
%6d=EIP0070V1234AXQA11V325^FBZAoS[7<>Q5@mQcS/7P3/8@B9h[2>LXDfR:Ao
%A:GNMH2]XAcFS61JD4mYj^fY]EJ^eR_ee7A9Fiha5VdJSl7/Ch_HnRH@7M9IUReK
%IR`LC;724=Gc^ShRDkhU9QJl1`3H6TD0Wa=`9Dd@8HPaaV2E4`9eMiPJT=3<@GdX
%I1AgGU<L?H:=jA;G[]KNfmekkhAAVFj5N2=RiZG?TcZ:SW3iDLG:m=0KYUdTR_0e
%QU[F6SehOL?dLHhAa0@0R1F_Pfbm]7CH?PK@gQ^R>4L9IKC]cHTVM8D1cMM6dSo7
%5RTB>:`:H]_:>jn><LIHcaXFHna?cK4SJ?KQ9lEAlVFMB`:0B=cW7aPdm:HioX_;
%ZA/SZfKYdG]7?SU9B1>AkSa7J>TCPVQ<RK4m?lE0[e=SO78=dChYA@SX7D?@kI>B
%RaK>XKBf8nAn2Mc/4c?03lm0hch77?a0d^Hed5X?@VQB8i;b8HQL98bAhiX@/EOY
%8akSd7/?1h:@[PDM^4P7A2?e8e9]kEn7C>V/55G/BH`A]S:;97H=X1H301112:48
%58<0L3a:7:Yh9ed83=el60;`GLm0?2E/DDVaagk90Q//IncC`hWd=]4P3oPD3PT5
%Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMSdOQ[nPCmTKoTCoOSoOKkOkhU</U
%<ZU3iPShOCgO;nUd]TCjU42UTVTcnTl4XSn0=9T5;QdTOm>Tm5YckTEDYlWO;jOS
%kOU4X4YTmKXm4OTTZ//Z;nN;mOc/PCfTCmO<T[/2V<dK3ML9A;9I3@J32=AR8L[U
%LL6Bf97^;46=O>?YVAbFCbVEbfGc6IcFKcVMcfOd6QdFHZ=6ZnW/dUXD6^=aT^UP
%M7eU4Y81Sn`QN]e6j]Vkgd2f6hQCm/5@U3l//aPCjiT3i7:O;hX?7O5/O50aki/^
%[M3VM9a=ib2@C2Z0@:1N_Y/W<We0UHYn31n@bnRoneSo43UOCPKmocA`10<1@70T
%2`=0l4@C1D5`HdCI8:XkJ]^h2@]lg/;]i3;F@XeKP`hd[WXFYbW7nmR1_I4:A_nh
%2R3Y5`9aP=TI7E6SoA95;SWhGdMQG7/K4C80cB4Pcma/oBEaa8d6bG9TVbM9lXBS
%:DYbY:[LZm23J:Dc/=@`gl?8M<3BW^NbJ84k<7XDk<C;/i4K:>K4hQS>H^CZKTkX
%BNlmA]9AoU5?iWD2PIgd8==37aA23D@jlfZk;2WaG:e9DWBU:d]Bm<DcCC=cBf<]
%=];T;@e3/?XU3ao><Pdm7_8TT>A=<L86DMIPaFY:E_AKW>Ni3mX<ilnDRPM5cC=T
%LckCbRdgIEUfII]WFOJ5XdiAmT@U1<a8C4KEA8PdK?fXlLDGH[n_mHYeg><UdPoM
%IXGKGB]YFQ=LXFimNX;AKWcC?[meSJEoGoP60h5PN2BIC/F:A;L2f`eJ3fdYm]XI
%>i^2IR[/eli4oU4F6>>NL6?Q9T8ci6NfBgO?]Eg`i6<>EEKIWmRj4COAlnf?P^Ki
%aW>MIgWVNhAUm[8hgV8`gDVSHIQfRHOYK7W^Xh`JP7PMQlMig7SE4:1;[ASjh`Yb
%Pk/1;k5NaoiRPTKAaF6EXA9;o>NC6h5k^B1c@o:2gkWflke_NnKk_d2H>XN4e1XC
%DJ925Bj?a=TX;YNU96/SE7nm9jST>8j2V:@ZZ4Ki_722o@6]dG@0^C?CFAH]Rf8i
%[UmHPUaX5bR35KfPPm]LU^G_A>omig_OMoh7PXQ`<8hDSL^]MX]CYRdYnZhdjAKK
%4Rb>@[An?KYM>Y4CY>4o[1<4^CF:RIFX<5?lmF^W/R:Z??ZSb;H3/POnIco[I6G`
%1/gLIIhGnolon040GS[DH@d5hjXV8?::Nl`U0nSDU27lE^1KcSU527dMYVA8bETi
%PRi8ijI2J6ULb5D3<9F==TCBh4S1ngeT;B46HA4<HE42ILJ1H[nSg7lP53/QQ0B0
%?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@@=oB>3B=o06DAio?
%mnb^FbbG@BE_nIbimb^J`:I_en_mm_RJ?^J?ek_IlcAo_bQDRABIo?b1CfF?Ej_>
%X`>UCRM?l5PX6XF`;Za@UmFFC?^dB6NBfAfQmfEmBIRg<UGEbgLhgUjG^3?boB67
%bJ1g21fj3?W4H35H_6Hg7Ho8I79I?:IG;IO<IW=IC1@FCBP0bZHJ>Ge^VCWCe6LC
%en_ZTd1oFEl_FFBbXJVTF_>e;NEOJ`:g_eQ/9RS@ISIflT>L]<lfcfV@HB2gkK`[
%Z1?/9G]5;^HGXI^Vc>6ig`NGcNOdNWeN_fNggNohI3bN7@J:GjGaJSmCAnCal=PX
%CHX4O3FWRLYb6nDA?U<HAP6FOSG7jfkEYXTJe[:O4<:S33Y7n?PmSl?8l3fPI/A<
%54D4m5C`Z`_j;[Fl;iX:^2g316`Za`=<M86a1l/<c<H>W5ao[Q7[hb?94TbE9LVB
%K9dWbPT4I@ZTjDXjUd/=<g3D9NObNWm0;G7hfQoW/PAj7VMiePn3PATnCYE:NZl9
%:7;B1`U23O:TWbd1L5XH60GiQB:a1gd<;m48<Nm5XljSb;M8b45;BH@dZAE;^XPK
%oWa:K8bVTe<b4j/Xe9D]CE?E5DeEEMBDnTKjb^dSDBfdbJbo<9n7bN2F7TVQj7dN
%ai143hC6jKId=neT9ZfgJXdFNZo=LPAfFX2P9P/O9l:FPRgDFNm@X98:<`j`JbX<
%]befld1@gI>jNAKDK9Y=LC`[LJ]keIO=mGgOUngmOn0AHceGb/SckeVoKLCXWl1Z
%WGaoWbMa^VbJX7PN2l<YlebBGNVK2BlfdjfBPIYI:DiDCRQ5`>lOIWiLMfH8gUKP
%>nN>K5cW0bId7NN0KWa5j0gBB?K7ioUmXhRJCVJ:cfg26?gQ>0jUZNZJ[Zc;hBlF
%AjgE3b?8jP2k3YLG]lVEJeZTV@C0OalZ/OdcEdUQiTXB163X?Y1:]R217bWZSYlT
%EKYI0:K]RWZX9bfnnj6ZTbFh]2eW5b@ClX^ibj;L]YBX_/QWWcaEM0;gAIl1XNM<
%A_D79e@7MH:?G:MXJTb6bZEW^N/cAVO9n4bC1=Rh;X_UVFQK3R>@i?kYZXWjYL_]
%jWbHjc>jV=_JBElFZ4j=J]6]J_k__Nol7`k=FWYJgi=BmPOe=X<07fgPS>eO?j=`
%[NWbP=JUTc7fZam7T5P9PARm6><`NRIcG5;7T?/O[Odj_;L6C@^;ccJ`:7d?Q7a`
%21?88<XHMihCZ2>Q01V4@jhB437]2LPbhQd`[512d:T;`2@a2I3<B<=A``g?2cHN
%81hN0AQldEc3F4k3`R8DP@PPa31H2b5/2h60=3XQFFb4k^7b_;FbGhX2A3E4RK>n
%>1C44952:F[n2Y/F?;VO56V=DJhf<1NLliP1L8N07GXAQn99H^TeKBh9G8oAjZk7
%j?HNhk1b0A0F0PMXm1l>h:FCLOhmh3:LCTV21i[An=[=ZE8UKe9=[_84hdQQJaCb
%S2W:F81J1abYAD9h7d[F;0?2a;4Cl/aeBe8B^0IL^@GbkUh<6Gb?Beae<TSeAc/3
%Z1?V@0JI@bYV;T9dk5D9DRU[BL:DU;AZ3KSkOdG4ULFH4]/PbWU`3g8fcUW=>NM1
%khg]UE>n^IihU=_]00YdR/Mc?AiWNH<O4T5LT/C4?LFX[1BQ92:44F8]QLb@TNJi
%TXf0;PO12<HIPc33;_HjmTO1BQn/IT^ajC[bc_W?9nOmP@oaVdW6eBTAU:`Kd]0G
%Bl<=<AHdcIP>iURkTl7E9=5<FU?IBQC;08D=m@cg;PQeBl1HIZUC2DfMBHY>co`5
%RdlnCLGJM3o7F=LI`]aARN5F:dFhlBNeBRbL0XT1F@CY[EF^]UKJg4DFlnam/m2:
%Ag[Bn@VIoI7Z<L2?`O1]3FRJ4X942P406S<6P=5cDVbQ1D2d5XNKfdkU?7dhE>De
%Tm?S8C5=3Z?AXfO3aJ45EX`=fU3KJN5XX7<T<DfFiXZhQ7faZD6HJU]CUPLJ4V0k
%iU4;UUJ:dT8P2;QBa2`:fha9T>YC>TE:;<eFQUJ7oE8jXlAcPc0X0lChXAEdf7n[
%^j<6JoT/O^nN]miKcGW_@eMM=O23[PDRAN^ccH^Eh8:]i21Ai:4o7Z?@N3b8;577
%d?`K`g1_Q[;b?DWS7WM6iVjB<j/2Y0V87_AU8IKU`36``lH>@8<>0O`l7G44c1UC
%^7n;g4`O<DF[855>8:hI?4/aN@H36<jDSJV4NEW@I0Phk0CSdKV?kKfa4NS`a:0j
%B459i=<h3JBLTcC8MDMHh@M0M0^=hL0jQdU@^lgYnaBBSha_CV7<FHfY_cc<WIEE
%CdNg_a_?FnDmWaTc7g9MPi27hgg:^b0WPVa;2H5^;/GQBl5Tc<BhZ31_T9Vl;f?C
%4`_DM1Y0UY46>T`mjEI:=8QSSBg0edh6SCa36RXMJ;JdkiN@he1?:?T/YK1=j]1C
%ZlK>/HA0I:6>0K`g@E0X1B70=`KjWU8I11I`[e3PCIPbUXgPoAbEJ0b0h13=U/bO
%aFlU]FI=[KGf`Zc<mm6W:UVL@Ym;l<ggbW^`XUMUCBU^^A6PXMn2QB2365d;Xl4d
%B=9a_Nc0mRESf;nCdNhl1iR^5B:T;XF`]7H0V3SQ@RN6HeG>MmLFgh>15hY20Abh
%<BDUDeTMcI0QQlO1Mb7SBlR132hn1GU0fnE2liIL3?2GWK3f26448D<`V:K7S`3H
%2MWV6gFFm:R`nfj2=3/7@>YB3ofG:FKLo6fNWM?jQ>Zj1>l7@;`VKE22GfcSjd6E
%^H<WXhKPc@_nn9@jW5nHCGZ_C2D^]YS4?PF`[1Ek>0@=lLHh^U/d@[18LXkAgRX5
%L:h9HAPU0D0J108X@0P2I4^9Hi8kN<ciH7KYKJh[gj;4]iVW73li^c8;Rd]H4?A3
%Xm8f<Rj=;M]lb:?lKN?`=FUI`;TjPXQA2P/N5Q>[lBZSb3?kgCP=A_SN73c/dKOL
%0Ved9>626LeNY41>2<5XbQS3DjbUiaJW2FB:L0DcZ?gO_OO</F`oZ440]W7@><LX
%jAcSZTYeaTES6f;J8Af4Q:/f0?;;RD[g;l]R]/`2=@eD;l=H9FcV?b7dTPO`od9h
%=^gh7h7N7T7/Q87R4^4^4j242:2B0J0Z0^242@2@5F5<5@7J7<7BMT:6fni68Da8
%Y4hf[:DfRVoZ96m@Fffn/N2dQZ4R8fV4G01Q1jLl7VdF1LUf4DJ08<a<5f60605l
%M/[@:8_fPJ7l3o2T18161<6T6V6ZkDd>7^;Njb/a0F7^7R847R7B7D740@0J0l7O
%34FBP:7j7TFb7X7Z:4RbGRo13_3a3b8/JP_l@RTN7U3L7n1J1@1D290^TX_X[^MT
%jH/b=ng:W8J/Y4m=4F=A0:BhX^:2B8S47f6/6d6b4H4T4T24262>0R0P0Z2Z2X2b
%5B5D5L7P7ZXb<6:PdB;@PHLhN@OU1TgHBVgDMS1P84M05D6_66b87bJlMR]L>n5W
%6F2=6J[X8NDPmF9<7=6X0e6/9<Yn343636=^@bFn@P@dKD:4Wk4`Jd5B5@kV0N0V
%I`5nilf>I2:@:DTPKN9l7J5d5R5H1h2R384j5V6@:B9j7R7<TN7Fbl363H3b7JP?
%3e8I8K8L8F?fPZbn/b5>54584d4[0X4T4/5H5B5PPV=LC@@8FFSZWG4LcRJW4V9;
%5lQ@lnXj==02Jd7j6J6F6D4@44441X1N1R0^0f0d2lId5Z5/5`_g7V=73VcVj0:<
%7ffRaP`BMP]blhV4FlJn;l]N9i6X7<UN6A:hlhY^W2>[1nZ2cJ8/@j;V6;1j1PdZ
%3f1/YJN@ilT`bBPZ7/=X_bFdQ@;@726n704k;j5i2@6D6F6N0H0N0X4j505:kb7n
%WfHf@ZHfP:7/7>524`4V000D0j666h7P7`7NEf7bPjT6140h0b2j3<3ZnJFg8O=D
%80oh50h91H=1hA2HE2hI3HM3hQ4HU4hY5H]5h<oX56XM78dnW`nGo7gZmgjn7dlW
%FkQf=1^og`ni>o1F9aRig:kY76gnmWZnYfoJ4o7i@7noH5B:?BH?7XaCjQCgmDgg
%EJ8o:KB7kF7mB:joWhnj_1VCICXMCZ8a890oKCTKCN`Uj_gcFgg6GnnG^nZVo[^o
%jaC<117kDj5QJW3kk0j[Ol9@[kRjC@/IEEgU`[VFKVh7EgeWh=Qh<nM9HjQY951E
%CZai[KJ7g@jGC8GbmGbn8doGTm7S0[o<WbmY7MkmAgjlgRlQ1be/]EdmW^ng0hg@
%7Q29S/O3hmWe8XiBWg^7c_GnkI6mgS6WUPJ4nWFhd6NCJRT<Peja6Tmh5PJSoOlo
%l0@30D1`90/3@?144`E1L2ZLSZN9fOIlZ0YBT4`B9:6bJAZWnOJ=:`IYTVVBA84f
%YJ^Y6[C:?fX[1@Z`B2`M1TIX@bB7:fXin7jOJP:jNijWXI1S6:=<R/b2XDBB?LUV
%BIYV8i2DNWnNIkW/_j[bRX;fZj_RT7hg:28hQRn]4Q3D8bZL/:Ze36/ZaaWCP>Ti
%876c3]<`2[Z8olbAFTJYSK@05D4Hm2@L`;Lbngj]W`hK094OYm7hO3K7^O00P00I
%dW@M[4/2LadWL6cFRd;`^WXNAjWfNe6>:W[09dV1j:0V:V2N90P6fJQV3<<PaV^K
%[I_g6UQf9H]SF?I5TfEIMV@C6Da`PY1l7VNZUWdT/>WlKY[6bDa?U4HQOV6`LM`j
%e:==^a4aAMMRU[`WMVfM238/C6:``TO1I5PEh^2d;8<P^2`G1H5I2T6@A_VjKTD[
%j^Z`86YD?X4NJm:HZ[S:B[4L:e65h8C?S3gESjZ:[<Z6/nXb27;UND8=U/HgZOij
%iVZ<K;jLNL0OW@VIhM^O<@fS^7bg;LahNb^^m7Ym4NAI43T=`eP^2X;2T:8ZAi?5
%//7:LZRT:PXQn7`QWHMCc@kBJM7lNSc`l`2=7ACi@4fCI4T:@@Fk`Ja]7;FF?GS_
%o0L3`G1l9`_3@?XTjGW6:_HiMbUCdXAh7DM@@0b3QP5dH<F/Xa>;/:WS9AOan>l?
%12=A@PYnWDMIeUGehY2P:880L1XPR07Q:4VAibW6LDDn177D[b`[n8e7TLJfdSmA
%A?B_ha;lM9gIlo<RQnGnZd>@gE>n8Nfc/m84KGaX7<lF?i=b<;jaYkOJ7ggPin9;
%oV3gjVWnjWDPZ/dZCXb^Sf305d:PUA927:>?T:@CP/2K4^:E523UJ3h;2H4>8LPk
%0V1>2/Kk2B]_<=`?XhA7bkXkM@?lE`[QF2c5X;@`:QgC@_QQ366D<hJ9QLFgi6<=
%d7@kQ_3YV/?G@5R>:QlXa6QOa7D^00O0mai]K?HA/^ho1k3c7J>X4H70@Sb7M18S
%@mB/6oF53PdD3g6_0M8^i0HY8e9`6L@=k3gRU?I8:mR=iThh_Y:L>DLPigiRE2P5
%89X0P3032F4l9`XQ@2Q7L>`MI0UZZ^S@KhTJ?B_@f:JQ2Bj=Ta/aAXmdSLW242bU
%452DPm9C<^=19mjdMTj;d;k9hOhNII2HUX26FcmaYRVUd1>GP^3V/<AdSHXPn1NR
%n5X3d7`;213UDP>l2H2PCSM6ZXaSB>bQ=]7nDHNQA2oRJ4j:4204@9S8W8l21lfA
%lUL96F6D`lRTWOU13FNDlijCeW/P27T>9;CiWi3eN3e2;CiGLGa3Zl68XM:[4T=h
%KPe;T?dfiAXnaiSA6F<P0P0021P2h6H000P5Ro6><lN1nRja>LDV6</I5f^S:N?R
%UaZ1EDa27C>UbS21<XCJKhZchI/bY7n?NX1QjLT4O<?n3Hga9E91n3`8@2`4P<2n
%5d;PYaDRT7F?4MhkCT2c5R;0DHWa>7W851:<==bAZ?Ta@5=:NCnE/?hbI6TVYF<`
%7lc>;aA0]ei23G]WcIZR6TC@F0XUAG`7lZ:bH1eRAiF;:^X@HiV@9e94Q?nK:f2o
%1T385PAhT0n42789XC@S@5P51>?ho@nj7cI>6ImFQ<21CK7lUHO`]aMRl0X1D2h[
%AER/NVm8SdID>_]7TDPOEa9kg7^ALViEbinXeQmIBj2cj1?ZR0^QB99XWYE<L0l1
%`2P20300?`e9h2_8B7X>h>SD0?PH0n?@N0nQ3R94V54;0H8`=J>hLBWYAWAd/Y>^
%]01Z;4P>LX>Y8hi/443OJL:^UL24F;7T=C2@Sl:0Y`/1S30HL=EL5TRLdQSCDZ?E
%j5`:PCPU]JFUF=Md8E68_N6@ZEeLR2BV7YCEl]P5U<X`MO/Q>2`kho4?T4Q;f1Ri
%54ITL>6BDi1d3ETd@6CfCDe;j>c:P4<[46=X>8L`i@A0V1:74=hL1n3eDHZ/`0nP
%[Q@2@<0G`[A^SQ68YP00E@[1db:>VX8aAR2m1X2`5@3P3P:7F>lN0l1lXBTUCl/@
%d1XSC0d1P38SQ62=@RQ>LeoGS_7^GY_CVWM?>1^K9Nj=ckYgC8_?`YE12a5o:dER
%VXE0YQ?RB9bKbThAa@:>?L3k01a3KMnEPD`ZAH152B52TYPIdcoU1Oe66YR:V=;j
%bPZhHmZHD4N03K6>hh3cfh@?:ADaUKQ3W^<5Ni@CKW`d678XaDg5P7jG[5[6BOSc
%:0?T:XE`Z@X5OJX`N;E6DfaKOZgn<5j46:_P/QUQ70B`SZ@@H?3jJV7MN:/k@O0g
%lG5iaW@Xl2nQ[hlFP>XGnA0ci8WLaXf>D1BiESI25/]1S`YV4<9hB@T/bKFMdB@R
%A203D^7`@0IaBR]51]P38gQ_^P7n=PJXc<cR53l84F@]QKVYET?X_j3Q`MI1R2l6
%0K0e1[90Mia[bjG=7G<N7CoJNeM[kHPCD=e;X@ikSg27IR2SGj;2j4ZHU192A05]
%P283`98Ac<N4KXfAZPB0L0^:SJbTBb3n8TAPTC0URBWSDNBe5XJSkVDnXYOAFnQ1
%Yj<4oYK2a^<o`PPG3aPi=3D1Wf0:_ILE6QkGQ[=YE4W7d;`FP/@c1P2MQX:Vf05S
%WK=2h^hlb/A=;nD3I5JBVcaNe77QA19H8;aU:g07eRR67[j:Sl0LOaI93P;7lbMj
%PFYiX4TLokM_D^6[o4:oladOeafWKkYG8BTK7j6P<P<05X4h4PL`L0K[MiEHNhN0
%P@Mj/IL[A2Jjei/h=`=P=j[ARSA8MiVI@`XSKPNH908`8h:H:8:@MIC@/3EPbJR2
%>k]/5T5/5d5iMkI`R/6D6@RSE2HHXQ:A[2bPE8DhD`0bkl800h?H?:cYRh_`AH@h
%@PAH@`@`YHKcG`181@1cbcZ`OhGhH0HC[P6@2`2h3;0[7JiZ5[]aV;0H74<jXHe2
%5HFP<l=X14=h5l>;88@hKT>Z>3JBWPcbE8OXTZM`XhFhFHGX6H5@5XXhM0BhA`?X
%6`7`:3?1[@X8Ol?a]K4:PZecbd5HRImh7bDC3Z>bXKk91DCiTPa`PKm8MdDhD/E8
%</EH?dEXK<EjXHBTF@ETFRXX;4FlDhMbXARhP[6P=dGj=SkB`Ye;Eb;a7HX`O0C0
%BhB02P2H1`I`IPIJBJei:XgXhQLhj8OHMc2PAXK8K@KP_jQi:jVhVC02VXNXNHNQ
%GP<X6P6@6<4XM15`VAB9E/64NdNlO3CS]kDjObokj2P:7BlQLZ7Q70H4PaW@1j9:
%Y`1A^0LXg`C8C0BP;@;0:i^@Ch;H;0;b?@Li70fhOJXh`h?/T@FdTTObj4<JT`oX
%ZiV`ZHeX7SdH6PeHE;nH:h1TV`7/W0B4WCmXLik3J0`a?Z>0_0e8N8N0N8M;:`4`
%L@K@l`NhLh?H=@;0@HAhCYF0e8`Si`[0Xb;hP@TBPR><D0ha7HaXZ[2`5<>YQJW@
%acjYHY=@aaUHLXBL^Ce`@D^YW0LIU3QXa[:PMSf03<W@B2F@?8LT`SP`XS6@e0B<
%a@DlaSK@l2<8[Y7AE:^XFhG8FL;X2lE8D[5@hXhRV`OhNPD8DHBXKT:0M3@KiXP@
%j9l8SQ2Im4O`A8A8@kf02hJ8J8IhY8Nhh9<4O<NhP820?n1@>2@F3@N4@V5@^6@f
%7@n8A69A>:AF;AN6?j1AYoab>AR>a^A@J?B>@BF@bUo_f1?enBmoBb@_Yl_i`=ma
%0ZM0D1P@2080SlO3ZG?R>_ei_5i?Ag_=o?bCAeoAmneDeEMjEV1bRDE1oej`B2Ee
%F3>Bc:>d1^e06f4^g9bh>Zi@ImgF7eFlC:2GR1DIo^UT/IMPT7RMlDIk=m/Q8001
%X=ad?21Ej>_]oiIo_ZSen=E1me1lAYne?BAnjGEkJT6J/2jekjmlk64jBaAKH_U^
%kU6k/_Ke;KmcL6]e>jiRmeGJA^Y]oV1[W9CX?[Y97Z1W[4o/>?]BBY`=JMm1N61k
%NDiRX?bJGf=?GA_QY=5Z1l?2=07hndMoIR=8E2WP50H00H@4EAE5Plb17dc/47fd
%K9YN_SA<nUim5JEYEPT2@85dGAL=4OAn7bf/AA74TBa=4lDAC5DEaI5/G;4[RXXP
%Z[<9HV:SWjOK=9FdQn>@TJl[8RDHY2^/@ahYkGW^OQmXdSA]6bK`80N2Bf01:`3P
%<0@XRN9b@ac9bFY76jHabOCZ4RL4e?8TIjW/d:A`>Oil]6[cTX8dRn8@MLn4_?`Q
%d01]12S@PMD<2U46SAB1[`d[^`@jCQ]=8Ik<bLA?TbA8T2X=1gZ<4`;103@50FEQ
%IUfN4684N9MUTEH5PB3if7NOik[jbImWXPE:/_Ae9/^^b2RKHH7F:PJGWi>llb4P
%mTF@dkSCeH5XZZIe[3mK0bFdCm^7IKe6B3Ij4>TOEYF>UiPgBgI6TcMX?gN0eh[I
%NH0/J01dg`QQZgf<]nbE1]TWnO3S</O]M7mBYkedZ1dW6MHHQT6@]2l;Yi<>d<4W
%nNJ1Hg9XS1l8iMUdGYl^TSTO;cLBYC:_B369Um40XC^I]VZMT7;W0PieL6FX4hZ3
%FLUlGj7XVRj=XnTJCYFSB9Gj4>;WjEYK<c=YRe=MC6bMV8=LcIjbUBI7j`mN:ZZ1
%lW`OY^6fL4/PCN`104005PD0ejP0DaB5>U:I8h/RlAdDI@U0K72I`L]ca13nCYHN
%akWb/;<c3UM98<h9c4Qc531eN832ocaDm0dSRQcdP^M<>_DJjPmOC^RIo:<OAd70
%K1UP00H71D78V5lFaQP>0025NFAL/XOYf7RLa`3F=Y27IBYjX58j_nPOV3afPSKc
%_=QoTGkX8NoLR1o2Q7]mDh/kbDPedV2>?fSGmiHORN_ilA[V]XAm:2^;LQhOj>3o
%b1[N7HCh0RmSFP5KNg0=42ga:A84o=j2ZahSa2[1DLPiAdScE/NHOQAV46GDZT`b
%iTb_T/2B4l9X=@OPj7F?@MPm1mS[:Z?4[ho`CPM1<=8J0db>3h=R;`GX_A^A38Bb
%XPK5b1SGRD2J9PLXW<ZC^;n:@?hZ:B3_5L5dFH8;:DNEmXCBh`AQS56><TIHc93J
%ndhQ;HFK6_PRIQ9XoDS]R<>BPOB`DlAM8Jdf;aGRI8e9XE0S@gQ^SS0N0h2H2@4P
%502g4eH22M08KJ:lE`/db8n;6ITO@SQ62;0BUT6/XAGBSQlTdU[TTR8B8hQ9BAc1
%_YX1Y;42l/`^be5a;LQ;DAoWF0b;jG`79PA88Ln<RinAoSf<T`PN1QeK4R7dYDe9
%VAkT/7f?HE`YA@2U5J;PNA0Qi@K?dIR3aNSK^ZR6=`ATj@LC[P>VXL2dUTBjDU<8
%hiNUTBn5lnd>;WP__[>;?@kQ7eO>DNRK8Q2M``D9PP@<Je3@4D?G/_IcRl`UDEJ1
%5lQ@JWUS:6J=B?b>GYT[<dSTOPmCcTR7ZfL?`Q@o0E0h18KHgaX:kQZ0/0X33d5i
%1iC/<E?G]a684TZGBdQie51gDL;=BFXAh4[DfWXHSRWl4:2nZSoAh5h:beR?]@8c
%eMZmEn/5HJaAX9BBPS9CiCU?AXchSXnQU396:WhBKQYE<nX`oDQlO8SSh7/E>>hn
%eK4U60;hHiSH200366@;PT18R;Fh9d305`>F67P>nKZh1o6b9LI^PY=F_bULKIj/
%Z2amc^?2886mZ@<F[=j5imMAAi]1A0K5UA]eb@7>:a46@b[NC4WTY1ji5VnT/=RM
%8O1D6aFdA/bLP@m1m1V2n68J`hQ`@d:U2@T;=Z1T26QMd>eg`AgQ>L1X<eiH5QXZ
%X2l?]jb6Fb8<KN2HlD:R]ON6/=mmaRgiDTjfc]12275ZiAMhYb2YS=`<:S13R5b1
%<`H0O1e4L85X57P51aj3Y7T8d8/APT1?RN576i13?Qm3hE/SHoA:Al3j7X:`EhY0
%;PH0L:lF0Z1e3X7B141`5<B3j1kSeOXIKgd6_o7QlaMET6Y7/5O9@=/V@2868C:5
%j`ncY4H2G:bn1dglSc@:?EHl_IOc1V7<B;:m4>SX[b>2C9VSk6H</Hm3`2Ed9QGH
%bUN27EjEnS]7CSb@RG4Z9h0P0`42N4l9XEX[QC0i1d3A<A6QKRf5h=?BA;Am?d;8
%BDNPle:^B<nOUI9GBZ^46`8PA0QV8P`D@18=VZaMj]][T;>d3D4UC7A[DZhJR1eB
%33[]J50CJjM9CAlUPlR=3f:mR@OhlQfSo3:6<>28HkSoHFR4bdMAjU65X;DFhIm^
%Bl1E]l>NhATKS?6K7GHHA0kY19^_FA0l0DH75_4ENl`dke41_N9@eiRK^;ZWNGE_
%dI_gSk[8dTXaGKS6@jXg8g@9l=0O`nGP5^903hX9_Rbb7E4:8d;TFh^0oQo3jBc4
%J8;T4N9H?e7JCVa4^7Z;dGP]@@0P0h7<>PM0MPl1l5SW@D0W1?7fbE;o0W]YgX0@
%QI0N^TA<1=`/;GCGC1L_22=`b_[OAhbeV?[7FN]MKjhE^=:<kS5EB>In`3?Q]SJ6
%]N43kHhkAh_m7_[i:XBi[]63`7@A@:PD0bchMXkQb0A0T0a?PjHA3gf<^0bb=cYD
%TAiJ=8PcaX3B3j]P4/C5gPMON6TGo;RW[DIj@A9Da2lELDK5dKOYn6PCb:LIWQ5I
%Ee1VW2<bj>AmS^:P?A>PoQjZf3h7XAXB@T1E7V?TMY;1gSj7R>XE@Wa@^N3>0L1H
%50O0o268Wjg2g]T3Ob?m@0@aKoOb/2DHGhb3B^53nOFnma0;k6[^EjG[B2kk>D[n
%GGlXnbjWYUXk@h`gOmoP8>7302[f7`F:0LP>jJ2d]Q06m4AXK>9F7h6l6l6h3438
%327J7N7HlB7XmfX4<^j0<bBHJ`7fR66d0LhN101212291FinY6LT8:b@oLgJoVj:
%8>Cl4^0[1bjRUV0^;<78kNIlkL8:nbjk2;2=2?2@JBc:8JK29N;lSPAd7/46443j
%Nj4>U>96I@SFh4MFkR8dCHAfS^G:7Z^L3`3/426`6^6i2LEf2b2d2Xo>4n;/>jQl
%k6JXC8CV7^Pl946:6<6@3b3d3h0j0l101<1>1BOn3P`<6Ja6/2a</hbfhc22><=8
%o]1ZM81b5U4dO/;bon[8:lPL;0Af7`7Z7d:L>D9B71024V4Z4N2@2>240@KR2P2B
%2H4X4V4bOj7/Ad;bbdFT=^1?62XJ6/bTZN4U6>376BL`4Pofo/IZ8nG94T;6;dh1
%1VLV8@XF8:m69O4G6FO@=NULb@Ue1lhX06G/mBeJ5f8BaBBF<^<lB<7Z7V7X342j
%2n766l7092BHDO50CV=0@l>T1f1/1`100f0j7^CM0N]6G8C_0Hlo2jT31T843g8X
%G/Wa7F<>nd=N8<7U8k2C8o919394A92FK2C52`T`[HPn7`fFH@0l121:6H6P6^@J
%FT^69LAn9DSDjl]6BncZIlk57f92K?1N<`7d50524f2L2L2H@J[<JTJTC:<n6J6F
%6H3V3T3Z16141:0n10143`3b3f6P6R6W3dN^=X/f/f9Rljem6d`8oXSa6Rh4;`>P
%4Y0@_l`X8X8e3V8e8@df9L/b=46N6L6V42404:1P1T1N0Z0^0TZB2^5V5R5P7]0g
%8F/l=<M4gjbj882A<joDan_Z7O=56/UF9P>j?b7f7V7L<Z6j747:2Pid9j@21N1@
%6U=/:lYR7@UZ360@<J4N4D483j40486D6R6ba>94[G;F[DY0[BLFln5`5/5Z4H4@
%4::n7bP4/<5T5R5/JTin<Y:Z6H0B9dG/`L0>2NXZ6jk>Aj[H<nmTA/Q83d3V3`5f
%5/5`^b[HQ6VN7j?H:V3d3b3h0f0/0`4F4<4@A`Ae9jJV;dj^^08<l<A32nb459@X
%0S@/TD0BV8^fFVb2NU6M97A1A3A5949;9<Ej<bE_A@Z2VX8lH:fF7/6h7H6l6N0<
%0R167DA2C/=TA^96HbLPKjiD8:<jT2?A9>TdAg2JJ4<jU<:XI/:b7U0;38/2h684
%IN68g23VjRo23cBi67<bmHc0b`@`0T]P@85D6YCA8U6_BXFVIDFAAh8dH^OFlbiR
%101:181>3J3H3N61CjOVHf8b<gCL[^84o6643aD@fh3>5SDI0E@Fh0=6V<EZY0A^
%7fNP7b7F7>6d6R000:0F33Bh6T6X5h2B281H2/bD6/6l7PB^0h3P3V486N5h5B1F
%0d0=Dj0P6d7HfTEfT4_n[J9S2N@n7bSP@@<jd^NR7/6R6>5j3P3>2l2G5ZdT6j1H
%1@1/7H7:Vj^@[F7n3B3R3N0<0@0:9n02KL000J9h2D;L6B6N6Jf>7dVJ88?@BJAl
%K`5:=n4/ndSZlJ7j4MGlgF18242023>R5^DTm:MH8IHA20FV5IHM1h@f5d_6gm25
%6Vm8Jg;fG;4l@@A09HT`BHi@@SI3Gh@H7d6N6R6L]hhC>J9MB;6VAZI]9?A=IWIU
%A7I]I^jf=4=5?bU<;mIl92;l]4Y07`7B<b6d5^5<4X2/383l78<dH30l7h=NB=Ho
%?b7VH79[BF:OBD8fSnk58`;mCHc/>:2?K:h<RT5n3KKE@/0R_CD@3`6OKSHX@I2h
%c7:F2Ld84l]B1^6GKjFG8N^0h0=8=^gV5FZOKH@41PNj4F^j6QHFO8ePEf=BNd=S
%Cj61KD3JanR25jgh@T<YL6b4e4F?JnmU?JHf7`7<3b3B2d1n2/2h7D887>6L6>5F
%3ng^2h383^2L2l3o5:;j745X4l4>0D0V1472:<^/7T<]3dT4lCIlk4@BF2CTX4i>
%:<7j7N584^4H1/1R1Z7T7N7l6N6D6h302h3DMNIF<`B>12141406G[E^N0<J9j08
%0@F:aN0`M@3Z`U6Z84_b6:^n3/Kn;Z4eP;H07?P@GN0nhF[bDM4iHH86PQ7BhT0/
%oILf1mP`86ZcLjUc<dEoCQGTJ2=:9G7IIeQ9GP=4LL7/4l504j1^1b1]8<0e0R6i
%DOFiIKBAI[:QIYQgB=IaQoR0[3Q=A<U=32a3ABmS0lV>7>CV6n3@2/2@3J3h4R6O
%1naB7n6B66621L1B1C@/0N7I0^^>iFmT[<9@?J7]5:VNIlNfnf`5KWL/RX1nG]Rj
%1B4ES_PH8G@g2:Fh4n>`2OKHeZ7@8=1R;k8b8;P@7>GJ4b2=TJ9d0ETJ2<bX;UMQ
%@L`[PhmQGS@N=N>n5Xoj3MOd5iU48=8L8<WMK:2>GWTO7:dD1d7D7L7N7/?BA^7^
%EX7X72180X0:5B5d62<T86Hf7j7J7^7V7P0/0d1:5`686`U<<b7H5B4Z4@2J2/3:
%fF7n7L9IK3AJ7jHD?D7l@o?c7Jmb@U4J/b7R7h7V742^2J223/3J3T1l1^2<6`6Z
%78Nj4Z6V6ToK4V;`6IWlKPN0P:`LP@00040D0B@0`PG/c/nfL/]J7MXPonUZ2jRg
%<fX3@J8?DL89L/hN0N67Xn;aDH5Rj@3dRh8n=_;cCD_R86hn3n_VO?I9I67k7`6k
%423b0b>L2;TJ5V>oDRa0Y4a7ITB=QeQiZ;QmR3ZAZBS5R7IU;gIhndNRF><d7gU/
%721P0n0Z1T1n2P6jQX>j746h6d;6j@3`5R5T5X:l<`7X7^AdlBjmGV[E9?KXNTWY
%8HRjG85c[c6B37KIKfF`3mKICDWR;ZG9[/Eo6TbmXP7M1b0ZP?@j8==/6T47/Vaj
%1jKP04ZB2b5O/g=4EX8;CNRkX`8=/j`@5@g?Y9/R>:MD_LoR>U0272GV/><JLiTN
%KN060;1RKj7/7L6b6<0VP@7>7R7`Zd9N4^4B486F645j=F0HNLHd^>H47T1V120j
%4V4d5EUn7L</B?:4V<A0[J9KW9ZLQZfBZ:@h5^3l3b3R4B3j3J6n6T6>766h7238
%343N:42H2D2H2/KgEm9l7oGD2FB^<JGZ0T0R0X504l53BT8a8j7Te_Kj6G6/IiY<
%bdEm6fI@;dG9LfNn0P6C`nonO?X/oW9]PLX>RjLdnoH=>CF87`5f5j5d2:2>280P
%0T0N3Joj6^L9B1>I6eZ7Qf@WZ9b5Qkb9ZEb=b>J?ZIb:C`@JCW?b<ZfUEf7YT67b
%7T7R8d7G1NAbSXoj3H]2CU[B?>KhAU6WF8K4RP:V;aHRPZ2[C7P`1m6>4TL]T:7o
%cOC=PQSd>9HZj`21cj]F0`FU`n6C4Bo20kd=L`5[dBon;`O:h4ZGKYN_=56F2gdX
%bXW>ejJOHZZh0Gdi7:G/GWXDP>9h080gYaGWJTQX7Z780b0N024d4n567PDZ4>3n
%4D0d0F0P7X7:6m0<005@5L5D^>7f3n3N3P0LN0666D6`^/kX95JTa:lB@Hf07n7F
%7L7T5<5F5L3J3R3T4J4N4HRDQiUZ:n7KAT6V06040:6/6j7:6^6f7<9d0T4@4248
%CVY6H47^I<7n6`6h6jTPnQdh58565=`<0Yh45=6/G8YoD8fT:b]>W`]/lFh5Ko5l
%AYHZUd6=hc1B137BW:j4b4WQhHo/>;SL8;hfULbacRjD1KiH`U6RC/95D[H[Y<`5
%bAi]i_R5GiQlAR8hk6:f</VZ7n7ZEXAeb^fB@FVX7b4X4N4Ngb^Ij4^?iPJb[Dh`
%C1Ghb@M05Bid2a0:U21[TFL/H^MD;`bX_?;Jbg]I2<>:4=kHLhFd391h1IkUYKKR
%6OPf8GYF8;i;6VWLZJ4ZeF3ILG/kLjAkhHF@H_;bC^WaKHG/P8LilJ9lKR02P:00
%0X0N0R@h5ba27f7H4`4R4</<<J0K0<0`6Z6>6T<b7R5F4l4JM]`800100X0jMn0@
%787ESCR@iBJV;67DI`4d4`4f3Z3/3`4T4Z4b6hgRHcaK9DDZ7d7J302T2>4/4d4g
%D07RA2Ch7V6b6L6T3J3236K4HcbLHd=S4`0D0@0B6FXh?N6X0f0d0kKcPNPNOXoV
%nf>:`UcS`WB5a<WZ80oh4nh90X<ofE2@C2e]3H?0Wa4H<oXY3go17g4h[0Wk7Hm5
%XXoX=7h4nI<09@HID4iHEILaYQ1WY<go8Y[=Gjog/mGa=i_7Y35Y91giAH]AjABJ
%EBjICJMCjQDJUDjYEJ]EjaFJeFjU=X?=Yc=i4oIjo9k?GgJ7e>W_5gkKGnkYcAGh
%Ze:YG4gFnj[hnGdnWi0/2og^ngiQY5RL2oWiHGnlWTl58YU6DRXD@QVB;VdiWKhj
%[YC7[Xh/i]<3=AM=EAJ7C:3G=QC]Fo4Q]@9]cg^G3^h=Oge68doY<nMK3mm1VUbD
%=bc5cDociVm7WdmkOh=/h=6>;Aha[h?bd<3_41O9:?<0=^1?<0I@2@60`E]d5li5
%QWhlXPn7ZngHj7/Rj1;JHIGU4Li[64Taf/2OY;4PC@R209alXPPBeYlLY`74BI6T
%J?HjSZCY<4db9iWZNc0<4PBK;6PJ;WVOQc6b5P=PRJi_VjN<0aDVaj7^NicW@;X[
%2fLAbWBWZM94DYB5>mP06lKY`7j`<X702T[/jCR?8lhlMZlY:<6O<@gc8Sb8W`kc
%PY0SIo]6N[T>B1li5g>TdX6PS@X5=b;>1>j<XO<lnWnSajW^NS9U660H1L288PN@
%=8<nWba/75Io/>RR`d/OImBg>bSdnf=AE7DUBe=DmDECEEBD/SUG;5@J<X:]IoET
%W9lY4`<T;PAeN_D00IQR6AGF8Vam7m:LE8WIAg7HMYDU>E0QfWAX8R@9@STlD1>W
%KK[Pe2TZC:BNeb8<7McUiM;GDc;Ing1EMB3YN@LGXAUk96S/n8:Qm18lI5oSkP8c
%H6EN2bjRmmZE?:3h>T;_GJac/hBD>:CT1keP20;gP6l`3Hl0@003Gh6P>0i<TfC2
%<fB]j9;32JdaJB8nSP2:D4dBi73>=Hf0@1096TJQ`A>Oi/VlL924@A8eJFF1EUJN
%YgWNOak[F^L9ePOij7aG5U8m2Io?nNAcPb1H06RK9[_`OiQ6NJIVKJ`QkU4BA9P/
%1X91448C68IIWb@Lae7GSIZ6RJjO/2L_4PcaI7lKO37;XXJ?D4Pg4W:;W<7McCQZ
%5O:T:6JW@fZFGBFoMS7:1=TO;PXn3lNPa]mR?7IPZ2h:2:8hR?V@56PNJ_O^?BUU
%L?IETFEC2O:ACo:GQi_WNOj7XnUjJZXla_T[3BZO8bjbNWj]O[[P`<o`VOYmWckb
%LboMeJYZVaeWHMa>ThChT2>9@:0T2HS288YE?oLd>iBSkCH<;8<O<@@KH54F=lD<
%kc[WW/;;X`mcaGdf4H2Y1T?d6`I@MPXjPSY8CO34Q8724d2PfRdQD^mjQBaU`_?B
%ah0aihJ02Q/0<080P3/I0T0h1H^1NRg7/Ha925QlScO0nhOhn1k8C7Z>LGHZA=1f
%3Z74B8UQ=2g5l<@?0Oa2Qf3h7`FP^1KSa<P@Mk:^BJW4D6lEhJUUg80RF?lO8kQ6
%R03^0<0h1P[1P3:7/@`R1i4A;N?@MHga_A;7j3050<A0244F:<EP[aj;8CnYM59H
%R:3RTh2NC`Fi@7G:<ELT8JIC496D^mb<5CTSB0g:mPXZgGU8PP@MiT]V4TN5c;/:
%4_Ca0>3U<4K@g1/SkNn9`C`V`OQ11l_@73`Hg[:7d?PS9Hc3:CD^KlT;TX:WE@]2
%fL4hIaCSW9>DQi@He?HELH`RiAD9Si<2[BHdCD0?]@FAU[i>B2TR=lT0M0Ua=RJ2
%44<8X306P?2T54:RBaCScS<Cme9Hal3lJ^EV0b0DO3FXd2BSS44eCWM>K6EAAHF5
%>>f3bU0`ZE0LYH=NUa@cXRjYU2H>0KZK;Y5i0iQbGic>O8j62X1i02WVHfaQS9:5
%OPT161mlKEbhDEO6?HR<Ub<Sl7N<dGP/0kQe3`6/>@NQMS46>?DW8lAjSd8jWmbK
%ieJ:_;1=5EYHdF3oO0OPOXm1fS^7P>nJQohj4C;FnLN`jAg1b3D7=ZPoaKS06:70
%?@NGba]7j?Ilhmj9bS7n82c@2k>46C>EPT:i1k6e4PolEA`IJ^[5kJ/KU[GE/;D4
%W/`A[2>fRLNG@hHlKM:m4L22g`<kP2E^5KI[YH`m1l3cLL?8:KV2n^LY`SYRbL[9
%WHCimQQakeW9a;M@QXf5WKYkN6lEhkbGUE0/ZN4kB1gCODm]@MCAjef[LVdNkJRo
%Sh7^>XLXia>2J4f3O003c<QJU0:YP]UTT=M<=Fab9[c1ZTX^?l4F4da3?UZD>FiF
%b@hALNL<gbWl=dTCHL<^ReC?QgaACH=`[lF1UaL7[62oaT9P88`e=UiR>4M=lNVX
%Y:6<Y>00182@40JPc1TA6B]M6[elSV[4a8oAI2h5X7<>XK`o1d3@<lHP_Xf]G[ln
%F^MJUGT?^VmZK1BD__L[]IA7@oaiclD^L8NHnAh3[3h7<>eOc1dC7n5T;hG`6PA0
%P?0M`ki/7C7V5WABRPHBXXnEK4>3iH`8U5PlhI6<>7i`CSJWS23kH?6WZ4<nXcD0
%<2mZLHnZEmBG7bFT/HHPb1Q4V9DBEYPRQ42>/VjddGc?SV[EDT`n1jIS>6M^Sf>=
%TK9fE/]EF_GSIV9ZbZBi=S1Un@/maHiRB13S76>4AhSQ510G?T<28E@YQDUf;Ta/
%8B=Wf<H^ijj[GQ_/V[QY=V4LD1gMV7S=2K:MJM:U/HSY`jBZGWL^8Z8aN52IhI;d
%:06>8>o6ZDTgd]C^dkfHUhS0W^>1:hl1GT0A>A8L4J?TNmOQmVS7RH<MaKA@RY5X
%7C?0Q11Qn6N=HIb^RJWoi<AEZhlRoZb9<O/O@mZdiS?][[NACB_?6iBYNk9>Dgi=
%AH?TNPW19R>7Ro4M0id542WXBP0@BnbIo2n>Aa=6Q[0^kH6?]eWn`;UddEEMk/A]
%m^36@IcQaS[Hi;8A:S3[23>[l6ShPd/@Hn9UN1^c@P;M8iCmg[Q71QnEbD6408@?
%aO2o5n?<N@m@>0K0l<LH`bLcV:OD^hO@maoM59ZQIFPoCQkL76:KfcY1IJ?hck_g
%W_OO5:O==m?jOao7jcT@CE[hm]I^7R?0L@h1_R;4N905P;`IPG0Z1@<e@1MRf5a=
%?<18M[4fJfe`SWbi[6788ZdhV3b/Bekf@PQ8:ojBcEGN3_ceRRlEkk6RKXP@b0NC
%fPAL0S_1aXAhM<18Pc2H4CE8HiRBBkOXaRc3PZL`^S^3CcC8PhM0L`LXDHD@Cb50
%APBHCHKHL@d20RJP`POHOa=hOH]XW8RCbZC2>POHoihaI3o@eT6SYHTHW47jLiII
%Bik`O@NBHcHJ_h^9IX9H8@7X6h5`582l:@K0KXL950D`DPEX1X0P18?`>h?AHhOH
%:@;0:P2I:jh@B[`PY433^Q=QPhS0ML>;A@;9Z8Mj1Z2[B:cbZIQ8kcfP?l?iR`8<
%@@Fl@RFl=CbQ<1kh/H8X8`8`L:CQI8BXBPBh:`:X;1C3GZjamBJY2a90NcThMilh
%WXT@MPMHMa_84PFhF`G9hSYBJ;dlEkglFDFLFQN3GB^Q5Y5D6l92>8OhJXJhL8nH
%A@6P6@6;R02P;h<h<XH0V8/<5@`J>9;hVclKb8nX_b9P]/JBC;J0[ACi;P_h3lL:
%U`JhkK38f0S2FXYRFYd8JR11<P=hCLN;A0Rd33aYYH=@Y8^TM;_d2ZlPgcn8P`gH
%L<0PAH=LPboXCHN<>;>8`KhH/PTA=2^ROSoJR29B]T7h_haSJLKJC;mZ^Ke<82=a
%hIV4D@PD92RZNXokU8giOILX3H2h481P080hA8@LV`A8@X1X2`28>X>`>`DLX3B/
%O:c0[Y=T=S_PO@=4Y@I<YTXBT478aa@APH<aRdMjeXKPYSPAlaQ8kY@IBQe8Vjo0
%O@1h1`28K@K<[15LCHO8N[b4C`O8N`MHR4S@VhM@M8MR?H1<DXM`OBm;9lEj^<`4
%F/`L`T`[3A;HNh`;1hOXNHJHIhHIfH>SjX6P3@384`=@=0>HHhHXHPaXNhN<6b8L
%aDG9kDRi?ALQmJ]<^QhaCCbPnchIhIjZ2XkB2/34Y@=2132<3Bd36k_bEI;I@C6@
%g8?H=ThXEThj0;B/3@g`j<@PFhfK40RSRkY/gZldXhOhKdk8l4P`=HE<kd>[GJ>B
%]CIjOTR0RTUSl`V`a0XPTY1J^0PHTAZiFQk@/<f471hZ^<6d]XWQl`P@NJb`_j_e
%0ClQ=2:X?X1H0//P181X5`5P5H6H786XMXNHMkJ`H=2kO9PieKo0Z0T<322LjXT8
%AE4Ji`GaeJ3l?A=1=R5@FPj;ne3HS/@hPbhTA3<T8KeKJR4<69ZPA`AXB4BX;4[c
%h;J;ek/0]8MY@HNI@HNP@cVP=h=`>82`2X3098909Ih`Vii4`<F5;T`e;e;m<1iA
%C0RPJ@JXK@>`>h?84`4H3@4X4@39N@>@HPHXI9c`/9:LlilZBh`LJ0V[mb2IhJnj
%MJ]8`0gii<[b0TKSB3S3^I?e2hH;006lOID4j[P;om6[Ce4[60?DfjW1<kHhYD?8
%QlgI;d[;MSP2lTMR3H?`>MEYHPEd@jfAIAlilI2ZmSXJOQFk<IjkN97H`:m=?[GZ
%j3JRC:J/nQ5/72m/F0T`^2mZOH`AFXTB8I98W8J`JPKX1@0`20mP0X0P0BXHU04X
%4h4@;P<8;HBhC8B`F=MHKEM/fiK]95DLXPZ8k`T:V@GCAaL<U0P@BMOXJ=OhRe6C
%<TfXR9Ckn3bHh=D0/H^KNABd_I:h2SihL<7keYI0/]9A[9FXN0<0;X:PB`BXB0S`
%:P:@;XC@C0D<RQQ1C];T7/8EE4`Z2ENMC1ChG5VY3h>/[DXK1iPm3QQMWUBlYb^S
%o]WZc5WiR=NEWMXJ2[29@C4UVCAjWKCYQLO[Cd2C6EVh4=[84ULECHI0HhHLG<85
%U/G[Y/F9E5UYDbKJ2XUP2LP@R`^QOZ2/P3_e]jfPaaeMNlhX=RH8>EAlL`ZJR8P`
%F]`H7m`X5U`lhhEU]EXimaQaPjF[2;n<j8[eDUXDURBhH5c;O8?=cPHMcd32Fm43
%P4eZMB=]deNU/`T4`@XCYUFMUI7KK8aIIDCmN8O0M0M0N1>@39T9SPliGmKh0H0@
%1P1H0j6P00P`N5i8U@<8LUiYdaF/?Tj/7DMQJX1EjcDX7]k:R<7DNhL5ka=MbRc4
%LY?5YhZmlKCialW`>e_@SPXZRH]i2XVXNhH0GhG1Lh5hP@N9c@M@2@1h50JPJ@M0
%T@^0NIl`n]RT_ii9FQG5IE@l`e`:Tb2[Q@HX1^2XLn2j4Co[EMNZ2iQ<263P[bFl
%jKAn4CmI=Pkf4/5V4n3ZHbj:c1@DjialOhTebN21@LfKi3bL3BeHG[5@3^7jC`4j
%<8?PK68]P@WC^EC5<8fE^e^XOUiJdR]L29;aChk0QhhI=`E^;C5EmBE5aMb/X/Z0
%DV<Mj`1BX@laWX10Dn=KnelmimW@Y=^J2aQei5i=NmmAP8?XI^?Hkd@l2k`2G6:N
%9L89kHOSU3eN1/K0N85h5h6j6dVEKYT8002h2`3MoX2X>Q<PEhEHE0M8LhLe6N98
%PdhMVXG5WF3:KhRcaJ6`0@m=h`>>F0kMOhJ;5PEk`YeU3Q[eQ4Y0[KPUBXQjCPL@
%e01AK/^DlEn:^P;8;@:AGX@CT`L`D`DXD3@@5Zb`Vl90MXOHNPS8W[EZ>@SI5Ikc
%X`RUAD`N:ea^>;bN2hLn7h3Y>PGHfJKQkkX9Q;H]BlKmbkb@hVNk7FNSEPTd[@ge
%Y^P6OVNNO=OE3QCl09cXadKeBm52fKm`YKcPGlfkDYLh7Ka/MU5>QV<6@MPMaUWE
%MHF;T@8Pd@dQ2^3@Qhd`L`C6Ue_Ca/Zll4YmP;``Zn8h7FW;7k7mhf</fR40acA0
%T>4NR<jmV<aNOYCXS/0<k`E:50@nZ3D8JIai<iMnWn9fSii@PJDLnbK<D@NH:h:h
%:HU00Xmh1H0@0`0h:`;@;8GXGPH:JIUDCJmml1QKSPC`BF_>QSCPSc^cDZXPmhlb
%cP1N=<>^Wn=HDj5hIMdAai<eP^GkbV>@[1@CB>Lj1@=LW`>Q?`^3l0NH;h<0;5c8
%F`LPK`J5gX9`:P=PG@H@JhT@NPK0JPHP?h>H?X1`0X30MPN0OL8b>@W`jeFPT/f>
%9Hj=4X4fhf8=`h5Um@Pb3X6AN@>U`HFX4^jNi>i:VQChQXFbh06LL83knP5K5Fk0
%Q^kNk^knl<j^k>lTL>lbVflFkBh6l[nVlkC^m>n6mNnBVbFkM>AP5jg`405702Gk
%2[S`9Cg6;@E^m@3nh`4finNE4X4O25[84;aN8:Gh6_2l0hD73D1RiP5>klNnSPPD
%ic]P5bSP4VmP=f[=BTZ3B^N`a`g`lfVHPkn9QKfRgP;_70BW7CfSgFT66`f=^0PW
%0050lbXF=;7X067Pgc2>QfT>GVR>FmN73@D6F0>:dUiXLVa^Y8kLODS<j/go5C=6
%[LODn0`hW2Q89YSX0X1@9fe0J8JXJdSHVjJL631m5eY1QN?HI]_EaK30S1Q>oQT]
%h]h`U3DX3G@iB0@?;3_4277_5J3mZQMKC/7BK`T=iXLBcP18jKb4f2^PAHAP@bXh
%A8@@>hDhDHD00H183XKPLZ]3=cHFD1=h78608HM8MXNPN8`7>FKbHcJ^hBWXP820
%?n1@>2@F3@=k`V3>n6=N7=68=J9=n:7j;0J<<^=?:>@i[]F@=2A>NB@=kBMnbUjB
%]UBe`bnA=1bC>CBREBbGC2AC=bCEkBUnb]jBeUBm`c6NCjPD:RDJTCB1BNOcNQcV
%Sc^X?mje^1_2_=V`=Ra=:b6Vc86d2Be=ZfAai=>h=fiFa]DJP@=mgUDG/[Gd;GlF
%h4nh=aHF1_W4??5F9/A1Xb1Z^[9@J4_O5?>H]k==C>>_?@O@J7AJ?BJGCJBPGOC`
%D]Je?jnPGUm`>:=m2kL/kUAk]dkg@d1nL63?[RK:3L7T?cEj?R?[T9_X0OY03ZMG
%ZP7/0c]>c^@=oMn4@Z1MmoMk_hQl`Kd@>N93g77h:3i>gjIF1lSS@GbL?RJRD^Jh
%kQ>G0L2@;0cbWo12D]VOimWdO9jQl7@KP2jP=Pf39/6^KD47dOYo^DOil7^OD4_6
%OYn@NPcE88i21ZfN[=6l</J<lMJl;boQm3=7SZPO7h8B2k00Ta8Z`6c7Pc099H[b
%JIlW]TlTF7a:S:`0P[eb`a438<lTG85;j3_@<@a30A144<klB`JOAmWZl/87XMZX
%WfO9l7XNYoa94aj8XJHM1T7iEU6Fak7bOd6@A4d6X53l47c555BiBM:>FXCo7jG=
%=0[CPNDlH]@=9:l4_0oCbE:OlF?gDeCX7EED?=E]6YCF<^e?AEGdTlMKeMFS@E6f
%CT65HHJf:jZ3BXO5Ea5:QKfL:5X0UJ@RfXAE[77K5T_^h=A]S7=MdDo;A<ZZE:g=
%Ll3G5KL@X>lUTUIN5Z2:Iej47NdJ3:D]m7SOS@_8i]Ue]GB2F30E:^1P`UhDjX1h
%Jj[Y0>0F90;RPQh]746E9PN4GHPJ96/An@[<=9Di:]bP>K5T`haF=AiIL3Ch3M6I
%iXlNK7oB4@WjaAgU>DAA0J10444@8n84OI[V/KJ_7]4<@dDlYl7/Nl4Wjm5;X;LF
%EX5OQhSI[jh6WGYng43fcE0HZd438Y<8HMk;Z1]QEKW<i413^hNkb_ID?3ZSUfG5
%Uce6i]PFnOmj6L38<P^Q<l`K=B1CFianlM3m7?:OIn7TZ9IUNGXSR8:YoDME:2@E
%VmD`GV_EiYMFS[c6G50bHOJ1mfaLM`lT/WoL[@>A5VGMlh?P?jdOOelOoPX?hl?l
%Sh[ANHPOUFdPGMh4iX8ncJ@9G4b^mRUl06o5R`QT]lacO@PN/89SVaiUPW3C3P^>
%c1PgFO_LdF=UefLBfPCJ0e@10G0=N0[2Y?_H`o`i9`D_?fOZ?amke5:W84c1Djd5
%aF`I5g1]R@0X;P0G/8<`koT@@;:0f4@4:@g@[Dd;Tnbh84?EQ8@I63PEI_=OPiV1
%ck3D`hOa3m;R2Sb/MLTlTOhha_3R7j?XMhj1d3N>X0LEh[QMZ@>LPeobSQn:>Qlj
%lOI@70?8?DHPAdIAJAWE6;2=@>8f:gH6NQ/8WHi2=SXHiI<6AF]i1jk:<XSQgAoC
%2LQjd3ecaQRj@MLAi0W1>2HTDBa`Al4Y?BXaaj3FYSg7lV]3jKAhW>7/>0Khk@k1
%e4:ZTlXoSdZAL^ZA4kAe6a0UPP=kY2ERPeSjD09T^AJbk8<n/m4=WC:XMg<1F/<Y
%9^YT?<Eo/aiR<`V<f=Od`XIb48:`1F10PScI0k=]TXZ@WcOP60/9Dhff7d7Je^I2
%jiP>mQb^]jkciPC=US?<djDdZAW5X7FOD:`g;364D2LHBQCd3SLR^<D=j3B7V10e
%nT4cPV@HPMLk0KJ::aKDMDS01SZRoXhChHm7`kdQY4;ZTRhY[<3WM<jH;Xj3c8V1
%>QKc6IjDc@8PR8Bod4XUNK3PN`B`U136P<lJX<`IPk7<>XM9bQnWPElNDhPn4`c0
%PTLe[D33_]kSX8dPHAZ^6_4oBU1YNHW3X3WFDf@bJd0H[E6XF531Ve_BJ5MkHLZj
%<OH`/^@L@I[`UGHD25i1j?S50n1l3[ZW7bITTNF7dVal3i4084?8F`^QHJ88lM8j
%1k=E84?RcDYk5>GA39ZVTm5Ac/866Re4R`W462aJeO@YCB@a]7K>fPo`RFg>Z56g
%@XKNCVWUKFh4b7g`;PPMn<5aRD__X:@EG=NB1ao7L:nj@JkZDR8d</d9ccX1E^i<
%ZgjTkUX]H=BLPco2Y0/_@`aQX:kfB1FhL@7mlDQWE0_OD<MmhDR0K@niFlj;IG1`
%1P5;[Ah6:=JNN=?8naiR`5F:dAPRQ6Y`6Z=LJ@F0]QRPPcRYHnCRDfVBP>QJJSR=
%Q]J5RnX5gm^687>Je0J7iW8BN<m/`7QIheVP@9K0h`lhk0WSfKhCj>2oV0Z>fC^e
%EXXAC6>HjRg<>6=UE`8Qd1<Z=>9IVDdFdCDfEC5/NjMD?FLDHiPlXmW<:;JLZjYd
%[l1<eI@lnfBb`^ia?T:2onJlkBaI6n81Y_AdZHc_?AoSQ7WX6d4V]SDj4`WL7H9c
%AT0@e2;dPf5F=9SR8/dESd2Lk<jde[gF0dTj4H43C86:3k3@1Y7H4D:2XVFQ08X`
%AR[PAT0[/E6V6l>OmLG1bdX]4`n[6X97XZTNHJ@aQZ7hClZ8m1kS^4B8TBHdQZ3P
%c>?eZHnfX;XPT@H<nf`DkM<L@=I>>@nKS^PJ5I9QAa7@4foY`c71:k_1E_45nlm6
%2Le3I]:V/f1?7f/?hi9_cU>SQi3R3H^kf0Y;c9=/RMGBiIU<PfBCI4h9PA<iUgVI
%D4IWDKVWQ^^GFB9E_GoKHIgc2F^?BSSg:EcjS_@2`EO;cT;MYKbYeKkEOe?BXU6i
%4Qggei>K^Q]VXa:M398>LZDj5eb6KkKL8P/NWGUaDY?Va1lfXN9C>SK90VmdIB6a
%@0XY^`7X^Q_FOTOCJRbk@a18L7Kl`SV?K9iG=>iA0@jGU3[aCISjf2?eZT37oKFU
%<NDN/TO08<`>jQ;Tk7MUB0Ehem0i^BQNlTO0>=M0iAj0iiUjF7C_g^XJLf_klcd2
%nm84;ddf`>QkmE>JhWFJn7VIe<0mN^hQn08:2kg46AE[LM<jQ1TV^1L=Q`Pc<1/k
%?B/cDPc3oLkHhRd=TXd=I@i[F4E[OiWed1[baKZ?k6Jm=d9eWGl^QkQ8;hZmWa:E
%bJmW=mMjiDHTOhHUkL^OA4T4ZGOd>`Hi2<U>0EPnX2oP4RWd3Z4W0:mHQf863Q0D
%>ZjleJXn6>[^EhYDnk0XIZefT^UND@EBYdA:7f7`7D7<763632303Y1<3L3N3Vl:
%JR=V]2NJi@=<FFC2FBgD[RID>2aB7fK@>Z]h52VRE`9B<ZFL5^5i2:QjXDN@<h6X
%aJNf=J2dL@kLG4^>IdER?8><mXI/AH^T5N1c2jBXc8hXei0dRFJZ@@l<>l=W38TZ
%TXGHh50dn30ZIRE@?8[n9l?8_b8/3lnK1Q3RkV<21J5k42HPoV84OG3jG?1b^bQ<
%N@FBPTaR494PdL594VKLKjF@gbPNND=TEbNDg@[D0a1^XJ@6j@Q^YRUnYJV01_5D
%>ZPk4ni:7;5PQX:hV<ON1g5/Pn/60nlNa^[h[o594?60=52`[2;b7^f27l/h7j7`
%7H7<780:@Z6h6f@f6d6`0P0R0Z7b>D@H7/f/l13J[e1P?8_H1FaZ5VdlYDe<BF08
%:TYS4888[74n457TkLE6[b;LfJ4B177e2j1bW`=6RFel/<VBmZU>bfCHM8?8gR1D
%WlQdTVGH@L[2hZ/fULEVA13BZF84Klc0hJba3i62ZRQk4_8f:04I9:l/cm62njFP
%2P86SH1`Y85e7LkS9B=:a2U@<@OhoB7j6I9h3e9lI65]:2Y>n/mNBdbF=0YNQfNH
%iK9PVDDX?`jR=:PT=T;X1e:/PnXbm85m957L[0=T[6Ng5HHU2M9VHe:M9Y;@`6Mh
%7^D>C0l0EX`D@B7/2d2X2T4`4T4TYbJ>8X7:7`=V@Hn8=W;lehG<IB9B61<A3ng<
%BY<<Q`Ub2HjllX=2UVKl7n<T7D1Y<b3a<g5h86<^iRNN<ZX65>M/1lMT]DI6hBbX
%elcDH8@lbbL/l>DTST4j_R1nDO32CI8Rc:A58XMBhPMB@A8dELC0M9;B=0XHIN_4
%^:7li:aJH5;?>>iX:0KE0D3P[`VW>T@8=T[bA/63>nl/l]:J8:WI52g^Qc5n?@oZ
%eX>8:<i:2K?PB20P9S3Z_0[fXI:Q0m<H>86A?jmD3g06<63jXR>XXb=^U:Jb;biT
%Q`AI?DZ/7l5M@S@8>/j64XAPd2d7>e>e66@N>28D7l7X7d7V7B0n0/0b706b6h@B
%T`I`?0`bTRTX7N7XZPl@IZa:I24N=>NHjL5R>d0H>Z69B3??>R:0?@g6J<V[@bT@
%L<<P3OBLNb0Rlb0iAlk@5PDJhBljK67hl0U?1O2b>DNHK^1268E0l?=nEY8:DHAA
%CD@n`?3==bM?<8ea6d/DbI32R78=<0MB>@Ea2bhTTX7ngZnhQPdk@diC2/;b<P11
%DFo`]6DLA:M6hb>lI_CACFA1DWC]:@lfd<:TS`BC@5?j6@YPiWBBnNXA7noDH6C2
%<Q4P48UZNfcR2jiN5F:l7PES5n=>i0D@L<FBh;@2<7B268:0ci7d16_D0621FBge
%@B7fKV5E:hEH86l];404Xb[N6K>RnoD=3RDN?j`lA07V7/7R7B0b0T0Z`X6//f6J
%6L6@[@6NCfA2444<4:2@2F2Q6cCT@<PU5P7:lJ0Ddd[fmLj:eN0<0MH<;M5hXGBl
%c4CHRn@LQ`ljAB7j5>5:5@1j1l200`0h0j3d3b3h71I087A`TF2HlkBbhjmjn2/D
%`?BfH79:4H2YIRH73M8@M98`n=><?eA[GbebJXfEA0hJc0f2M:CbA67n7V@KJ@A7
%3<@jhXPQ<7307k4V59ES;;FfnHC3BTdT8:BnYf@6IT=RcD=RM6/b7l7R@J7Z6Z6a
%;k8bKlNJ7hFD7b7VLLLLglLS0bBm<08H7Jk05<XX3J3oL2eAFI<j>FW@L6lhH6AQ
%0NY55cDF10Jn3Hh:V6NACh[g@aE<^4if:U@R5MLS3cJfYF:0O02TPj_X_[Gi3f?8
%B6jBE@Oh:41SMRPn1AMX;M4gL[@O1oL]8mJ^`11U@l?4@L@PC@4>0804062h2h2d
%;@3oHNY^61>n4l4n53Mh>FMgEJaK9djPHbidDE?THN>TGTFFOiCFJ/I/A:7X?B7X
%7F7L7TSX4V6h6l6f3f3d3/0n0`0n241h2<5B5J5X7TgjJ?=Nc67X7WBPj;4BEHi>
%VDC2:4a><P[nNDQO@HN@?@OhOhe`Cb9F7mJ@NJCFhD7oE/7Rf27LEB/hRn7V7_;l
%@@n:DHBff@7hWlDl1hOODKMj]ZXH?8WiEKDf^I=KAdPMK2n58X/h7h7R5J584j>X
%0J6f76l6hfJ>UB7d7[23B_0fI/F`724l4h4f3@3<3:nX:<ERAQ?C>c90QaL@7d[n
%N87eAh2oSNMT1?SU@48mEbk/EA5o2>K6<Z<[JV^X3FK[L688[b?A;`4TPnW37;:k
%E:86>[M^T>Y>PT6gTVd`_V>X2WTaNg2ZigMgQ^nIQ]5kSi<ZGF=Ti6j:^ML<H<<^
%0eUITV6fAHHh]T>@jI7D>[Gla;SBmkD_8P>EAX7/5PjM6/0V000800/T2d6d6T6j
%I`TXf@f^GFl]1<3Y>QE>HeU17`39Vb9l^Pi75o<JbEP`hl?BR^n=32`>/h7V>D/b
%A:7h7Z@4ZQ1JhY1J/hLV7j[6ojgg0ATliCF2U[VYJlH?HRABFhTU0f7H6h6d2l2P
%2N6L6J6P2N2b2l7DJh?6n9C`A07l6l6j764L4R4Z303:2n4d4h4/[7HUQk0VRl=>
%NEMnXJ^PZl^h2ZXb23YXZc5fQ^L:Of?AQcD:HdOV86[6i;>]AaI071FQ68[08mM=
%@:8`l/imLBeWMH=1Yo:<86Vk0HHX>ZeGZX=4WUU1WfYWTkJhPG>Dd:=T]EU@dhDE
%FM=]D@YUYE[73J>oLRPoGl0C[^]E<J?gCB6n70784@4>4DLF0/F:1B4f4j4P1d20
%1h00060>7<7:Lf>DBf?fRFJ]31D^7n@d6d@^0fFCNeVZ[0WTdDjlAT87425k7i>`
%DPNA[LkLVjn^RnFDhjC[1`FA;dh36e8bf>A0@nQdNZhfYH7jXbPU:9[0cF=TFB<Z
%oj;UVFjYQoUBRfK9K4nCKP7Z2j]d6b[NMB3i4PD85dLf/d6d6P6b4>3j3h3N3B3>
%4j50587@:mUj@nJXM?HNK77J84APXbO8IJNOPB[h9iIO5/1gAl]d2ReGT8<@mLo0
%>HWPN@6i`NZbI6In54ch=oE8NCBDJkST1>e<>[5D1_4<=6:UNj2ga;/o0U>FkLT4
%<A07FYF]^g5;`_TgN[^>^1]MZVORN6N@6=ai03J/>FAI:/1e=7FcH34`89EJHPeK
%FXjmQW@L7h5jm82R2Z2/0J0L0T3>383F6b<h847N7:7<6/262>2@3D3P3f2T2/32
%7ZKl]2ZDn<7f7R7T7Xl?=;FLEbdgNjg1b>KDI686ZmNB2icg8fXCGi7T45LO7ian
%cGDZ>1CJ>>A:7^/cdN7n7L9>ZE=o6bA330Ee4nacL;aZ`4PD>2:8gAYfE;X1[E^X
%n4IiI06iRh4/Tb/bf]6H7J2d2h3<3b3f4@322l3N5T5L5`7/7Z7PJRc1d89n7dTj
%7ZUB/eTN8<<^iJ>ZW<VD[n;86U3c3o4nGa2fj`o_aTRlZVNO7HYK2E<f3aSnSa<^
%eVb6>9Mf<_5he6B6e<W2aS4E?Hd<FFNEYIa@8<W=3nHPPj;D18]<PNWSECe3^A:R
%eWTNND[6Sd4_hRMI2ELN>K[5``d=;;T;;aAlPjojKEF:>[7D15i81H1F1L4T4V4_
%CF7i;IR^7l7J]d28;475G`3b40485V5^5]8i^1<8Rnd<VjSe`FHeFeZ@84g@oj9h
%nY06]U9P;j2]?Ti72Q0Xb`F30dTXCK;nTgdNl1f?ALUNA2DBQ^SdWm]1;=hB`2?9
%gP^IMa2YIA1S0Tb@@N7cKL`87g6h7`7J4H4B442@2>2J3P3L3f5n5d6DR=/bL/7l
%JJMiJ@7f7QSD:S;UDbY@?@8lW2>ZBB:0j>>3>n62e78EBTY5ah6=S8odPF^DoGBD
%Ad879h6IBMmP3O:e`EFS:<_mYj=f57ZF>/ZlGFZYhF85kH89H@N5KQb?Sf?489^K
%bFP_ES:C>IkBn^^8o`FCfNNMDh9>iFC8kJ=1B7mZWB85JV>[<NlT2mSN2oESGlAn
%0N_gDWY>Fn7`8T6B4X4V4I^V`b7RD<3B3J3D80ogfoDFQ4Bng`oWRl7ZogloGjo7
%`o7hnW_5`a6Fe6gm7Hloi18I348S5937Wg:I5:c7;Cg;c1<Da<i2ki/T9`9id<Ih
%U9ll:1:gnmZ8nZ=@ZABJEBjICGno7gCgi3X587]57e0gnnWnoGLljkAWdmWXoGnn
%978;<mgaFHLoYFGkTX;Y98o8;_C[eNkiOKmOl1Bh^mjK9:CIZkPHYDlCSGk=WJ/e
%V[cNJS4OcNGe>WDV0004W<m85DgmG:ON93KGflGc8:S3WjmZk/[PoM[S=M:EY^`3
%_@?_`O`FY`e[aIRH0QbAabd?cFOci3A=U:iC[jgAiFn>e7^e4i=QhPnO4^O8L_<M
%o@aoEQ]ce/GH^[NJKeI?7Xk8FSn@Wnmj0Ll00^`2T;Z_4eZE[4T<490/Bl[51BA@
%:nBT^Z/AE`/oh5@boi>@i0ZU@T]jh<34LBA;4dC_JYBk8jTT7ZDN<HA@XAgAXoH9
%WA73^_[4Bc^dnRE_HTA3B6oheb<6DT?nA<Uad_3ka4Tb8:jORh7g:Ze:XO1k7bfb
%Z@FO`h3L>8FQR61cWFM2^[<UDN7nl`i3W>:BB2_;5cXS/VcDa1oXfKDK2;@2O4X=
%520c@`VD@GU5@6UB[:96E8;hUAn8PZK6:hnj7=THaL66;`Z2D=`dRn7HRRHLIgXS
%:4_=[88heNAMH_]C=8e[FeKa<_:?B37jd/KBE6Wo6Qf5>DiBSD=@d48@Q1?bIZ7=
%4OAc64FQDRn=a0WJT1leFOcGa4f:@8V[ZXa5C1m=]KbEW1MPRGL15h05NCnPMNX6
%g^8=lYVC1aGkG/?Xk3bVH4Y2lZ0N1DHB>V5SmQYVhO7N2>ZaK2bTUN:ACKKa:4NV
%>QiSko_n5NAWKT]MEYFLNCWRd@U=UbQ>TXENF3VIm/G8`ei2cejPLK^OIRjUPeaX
%NRJ:YSg^`TFDafT>2AgULm/2AfYRiZZU>[G/@Ejo9XYd4knR[/9MK67fbiLDf9^n
%]DeZhO/[7m::f7`X1g5^FYJ58DAAbbNjcJR@I64:2H=0VN1e7DPCJWo0YclKNh6Y
%AH><CeYT9YBaJ?9J<KnP[cY0LnKo@Z51lkII8>SA>OE;=A2:]gBFAG683P9Q8XIe
%5`Ei?1B6HM7QLCGklg4m/GOHbN<XD@MAiGUa;bJ@lWX2AZaVGC8PMO[Tek8cnfA1
%44=d9^XkBVg=MJ2QW8>HbRd005Pl6`US<78O2NM1b7LZVg:hRD5WdQk64?=J@Q4@
%k1h3a3Q0L1L2CoWmGT08oh1X81JPT?:2SdGA]996baibCTfT[N^>]HXY`f@SFF8@
%Jl9e67FNHD9Ya:cd1gId000L<aX@e;bcD_K:CnXXLVH/aIg@Fa1QV0<ol@@F/M=4
%B]>[JXEa=RM4l_D;BY6hQBB44LEaUAI>RXlUIPd4]97[65/k7`N0GS<G8;h`8e91
%=f;@WP<H=Vi84E4OKoB^`18XFPdXK`fQ`2F4X:2SCJ/fBX?T]0nQDRb5D<DG``CC
%V9RlB1A0C1?BE:4[e?;cb:4T<G1l?TWhc0G21:<olB3DWJRQ4daQY1l[U=<?<X0k
%0=0K1Z<hI0h2]S_4d8X?@NQ12:7RnDOhmb[UDV8PI48/YUBCM?1bE<ciXAOGA1Y]
%AMc4=^F2^`L3Da7@S3H9JL2<1hY=V^BU0aR8jSeFd?<LP6`808428XBhlR@0O103
%0GX^AQV=8O<8OXm2:`Z7f><Khg0]d7<m0f1c>X6Wm?o0doh1J92KXY64Q[JfXTPL
%V`@TS11ddO4IB5h`I5mSIY<lQ5S;9XbW7`B@G5;h806XLIhBE=Ch/XEXT6:DdR@W
%oGnY15HoQYE309DEN023oQQZDAj2c6JEe?ZPdFRcCCaDgAh;J[0=j]DF@Ni4ma51
%cEQVlAT30Ajc2a[@?>]Ce5dWfR<XXGQB2EAe7lF@RK=S4Sn;0?/NXF0/1R5D:dGR
%E4_6i7hF@OXmHj3i7XFRU]0H<Sm<T;<7EUIC=1QEAPS``K>1D/lQT1@K[AE36T>>
%d`7;DDoZRd@d]6Re;URB>`IPcARP90L2]M@oQdST0LIhIHdQ[3ZSXR9:/icH4R6]
%LT55bfXFA]GLmF[TiVTRJPN8Nk?Q]R:^d6FkPZK_<U7JF9>iYAmD]O8HhSYYQm3F
%6V<`5h:`C_B7n4T8XDAJ2`5hA6jQ4:kV4;>B04X90@04<lOh0@0`105]@1a/X?V`
%QE9N7]chP0fhEF@6ZBI`@7da`SB`aJ_KY4@]<><iXQ`ghWQ31n]UK;YbYB2>c62=
%Z7[b[<4NB<Lk<U8B2PaFTVQn@kDQN:UAkA@i5?nKl0ioaEI;AET>j6ClX5>Tc4YF
%QR`XiGGgTdTXo;_2Y2EUmahM/a<n6jiDTB;X>;k2QV]YdoAmV]DZB0FH]AH1^364
%l<PG0XVN0Z>0M;Rb@3d7]<4OQH2QVe7_7EER8A1j=PnF83FTA/JCYfB1`hjZJRB1
%EY/5>WI`2FCbH^^0>MB4Q<6[_9fDC0=`8Ll0Z8o1hSm7`>8b@Z@3P=1:?Dd@=@@0
%S0n0d0i31ldG;D>9W`4P80K6<<DJDoB@eZ7WJ3<cbMEKE;lGT`I963RAfhTH=8[Q
%G2/9/>o5ICRB?0]N?^o`na6R;4H8H@8PB77J7X?42`6@@3K6j>LZPm1i5P;<M/]0
%ob6SnK:3`BKDa`SL6l[m4>8DiiVfP<kRUCLL4Q>6=AQXOVL2]hlPDjANLYXQ^W]B
%9iR`TlYYV01@`6J`SV^LT39f;E73fZ]@L;O8m[iERHB36kVSoa30Cd<KgAHOM7f]
%dWYA@ZYT[>T>GZ3?:[4Qa67gZ`6n/12jd9o[Q@/?^GijB:SIhSYBQ79fM3en]I;T
%5F:lG2I@JSo7P=`C8S@oPb1h5DMaL2bYI:jJ8Oeo[2g4Cdf<GDXATn9dJ8>Y@HBl
%jC6`6KbFT@=1Bl/<;c3V60X5HfB248G_@:miYd^7?Q4e42d<>`KPg1X6N0R243h=
%A5Qk4:5h:@E36L3gV?^F0G@]QXMDFm498K@K@c=jCi1BnVU8Z`;Jd@KYa5Z:<@UF
%TDZ;@]GBE3=khWbU61>1X48ha[SId294CHSPY1V3;^@ZPnQa3J6^1T1X6AZS<6hU
%_@3RedTWKM8JWPYSE2][ZIL@kB;8I@?<134h=jbHX@`IGZeBb942CS/9iQZ1F8AJ
%1j20ohGL3RU1U@R2Zb9Hg2[YFS=14a[;7XUKBh4/5S92V:iH53J11Z33i<6ZJ2>9
%?8?47AQH>PT8Fl7kb`:@1T8IW2i8Jb5PlCTaP23XTB5ikH<jjS>0M`N0MHLH2`3H
%5hL8Khd@O8M`@@>8<X?XAXCQa3o9SYg`ZY:JCHZH[9;[hHT3i[[03L3PGHi821/h
%6/?:D;2K4I7I426hR1j:><6`_I;PRASJJhdbH8OhNKcXZH>X=X?0EXDXEa9hnj`h
%L0J`JP>X>P@8NZ?AEY?H5lDHITD[7d@TE2e@`JUhG3[PClDj>hO8Nj>9YI0i1cPJ
%Jh]Bm9aHO8<09h:XAh@3AX@P?P@8A`@T<ZNPOhNPNXL[_h<8;0=0NHMI;3o1:b`/
%=9e@R/3``K6hX@k[iZG/L@?B^1U95/6S<iY8k[dHSccD9RE9QhIZXj6;SJUPYB><
%4`XCh`UJ2TIA6@k/0:58_8ihIj8KX:6K2X=[dLE4QSTh[2<2<:181JCh?P44R`64
%S0^PD3LJBhU8_8j[TJ[cLXTCUiajl1L@T0M0IHHPG80cG0N8dCFHLX1Xc`IXK`La
%K@dio8NXN8N@NPehO8dRjTGH[XSbR`HLY094Y@oj:h4KS`EYPP/DK`T3iKD`RkT[
%WR:TQZ^@/i:jEH]@fBOhO[HHLPL@LH2X2H3`I0HhJRliBhN`E0C@Bj[0H10dMhOk
%2kC<F4[L6Z:C29[1X@abZTX<2RYdGA^3jI;0Z//IaHN`O0M`MPMbbkPH^0d`L`K@
%JPH@<X=H?8Nh^0OS>10`ZIlPR:obaCMD`HYCBki[b@<b4/PP/CW@Y;/IKT59PXSX
%jZjL@IiJR`3dg`oZXX0RbX7DSPY8n4`;/A]A1liHXd6Hda4KdCE<ZR<8XC8XD:68
%ohETkDfD_TkYiP/A8H@bY:Y@H/lZ:/FbJJS8YId/m@TS6hjXjD9jk@A@[XQXO0Kh
%CPBX@H9X;@=HNHZH4H1P4P3P0h2`D0F8Fa=8OHL`LhJjnP780DU`GXHXJhQ8[Hg3
%PKF8OPNlY0HI08;Yai@P=1k8CB=kD;/90/54^jHHRlMdk`Y`Z<cdaI1H_0f`f8O0
%NXMPC`CXC8CXCXDXEHEXG9;aM0OhMhMX=H;h;a6SV`e1Y@S[CjkP<[hm5kED2@R0
%BM;9?:Vld4FD[43kR:oJljJl41l]3H/8ejoa7Te0OHLPD`D@B@FPG`HhNIL56TaH
%j`dbRk7:ShM:BXC`==@:T8APJM@/KjE4fHRT@4mCol=j:LgBCLjB5KW390oiWQd8
%KlTJjLkUAJlI/iB92:W0OaPQbHjZ_`;2R@0Xok3CX[Q]:]Eii29DK5FJ2lik7dYk
%3DO[TeAL?aFIR/mD4`I5H@3mHPQ2H8OHLhL0K@IP000@1`586090HHFHIJY01HEH
%G8GBH8O0M0L`JXYhN0GXH8I0=H>H@YLJ`QLDb0KX5@584SCX5;KPB:91bH4ENc2K
%RPIdfUF/_JeD9EEiaB_=9bjROa;9;Ro@ZPF39H1PghMHM@MZhP/`_8IMRP5URc[d
%`]F2Z9?8TT>R6XJ17JbH8eTH4eT/Yl9KWLM[dhQiEH[LX8f5H`;P;H:`N0NHNm8[
%]DJk`SkPPC/hLDEc2hAmXEC3V=S@_L2L[@T@kY/lPc0Xg[L0EaPUOi6B7@gZJ91k
%LLg`3eE8oj=mZL2=GeXaG2O[IeAP^3daL5/jea;aom9alK`Q:B`Q]`OXOCfh:8C4
%^@]Bjb6l=UUm/mAUU<_LZ`NiO888E8DhD`QaeCMEQhNEM8eXO5Vcg:e[`91HB0B8
%BHIHI`JLB`THLHL@K`GXGXGM:S70W0B3:h:82UeLSDSXjdZM<De:c5/@P820?n1@
%>2@F3@=n`V3?b6@R5@9ma63A5m_F;0j<?Z=?V>@N?An@B6AB>BBFCBNBaB3@Un`a
%n8NH?>I;2J0VK02L0:MCP0::OAal`>PBbD@=oDNFD2G@>;?FJ;08E5aE>5`f1=Z/
%9:]6N^:2_=b`B:S_jRfFcFNd@>U`F/=X6fnM0:N66jFZ[@AkGVdd2?aYm@>NBZdh
%=ogj1]340?5C`4Hf^6Ne`C8f?3HC;IO<B=o?f8@;>?o?`:bFAojCCJ:1?ZbJYo__
%>hFb?fajS2_al_[KK5I;AHS8J366Go@H;Binb?amdS1f?8gIn@=Fm4Lm?TJ?DIEo
%l7?IkP[QL;IF:aE@Im?UnNGWjC?Bb7mV6F=iO6K0URoDCOM<OV?dCADNB_hc<0`4
%XZlW/PKR:Zij?@05<6VA1l1`S2D9[4ocDXdUR:3I3J1Q_3`3A0WP0a6WP<a<O4D@
%BXbSYLRSIX;04G/T^joATJ<KT778gAfELNWI7j?YLiZ88U2TS@TNTTYLjHLYhWPF
%BQ0/G@/Oikb/c<JbXidAP38jB^`PI:C59bLBhElcX=99jAFmDQbm=l9/o>C]X<dk
%=]:fSI=0jdlCg2amWhOan<hfD;=8g1lPn48?6FIITXBecn_E0im<iBK<b/Nj9XR4
%U>V6HARc`Y/489>AR68HC_5/N=F;6URU^>i<I@?8Z3RoFi2ecEQhS]GZ:CLmR4c0
%PBU;_>5S`4_TH8CIC@?K6BF39JA;FYI5[F^_J>;6C=^7AK`EG1<P009LT^0GLigG
%BUUQ[?H/5B[:mR8ha1X3_N`jg`j9FZKFQm`1>ZT?K3=JfaP[BbXX3R3KQJN0EQec
%PGAYU^9:M;`S:B8[6;N=a@O62[7RR8[l:fB<D0JN0SU9`iFoKfh=Uk2CVd4j8:dk
%Zc_?5;idPE1cjOEo=??[B4FAY52h;P]AHUTIDcXC1Z1FJ2hjPI6JZ:PYR]?Z?FDO
%YO5lGRN2V:HXg`>Z7=2OM:jdOnYi[:QhKPIfi1?^VXWnX2VeMUd;WeYZ2`;V70Y2
%RUVgnPFfX9MQ6lF>76gi`G8B>iR6L0PYgl^[A95;cMb08]h6[RWSkQ<_Zo@a_J2K
%dd:EXC[aOEj>`imTGWJBcRdfDgB<IgO5G8bl/LI;6FWQlj0oS9hBOTX=`[fcLU38
%^a6EfHo:SRAnMP?NcLD?1_/jGAUDWOO5D^J91X;AbdXc2WdO1nkBccKd<R50ijdQ
%l8hM]dPWoMMen^j0735WGHgI0X4`90E6f=XKY0e<_BOHIi5QNDeZB<RBd`YiVc[m
%>LD`RbD0F2kQ11TP@gHB2XQ<@=jJlQlXbL@n=gcNDZ@]8:n4Hl=@F`gMa2j7B0f>
%SVQlF<=D@B1PaR8bQU89HTA96a4^1[jGDU7;lVhn8lQIAE3G5L?lFECS4QBDE_c1
%gK]lGM3]8af1eAWOf1<WSaP3Q<SLS8UbcFk839T?<PdDgaAO<S5]TbG02ao3;85g
%/H8b@jITB6<923AZF=TLPcZMbb8X=VJA@3CTn/T2/8VCBoD0?ORLFIh30Fd4ALN?
%l>HLPjQf3Z7Qj;jD<Yd?HkUYbk3/;/4_;L:<^F>X0:01nG`M9P46LZJdR<Gi2/`H
%B[FC`oUV_Q>LGiQ`2RTTMV?=DTQOQMCIHf5/34gAWcO;6lTBJjAg46KP?0PI?QA<
%Y0REhD48UW4];^iLMjnPdCg4=?TK<niT^jMHJ4YYTD2[=Pf//O/GI[6IF2?dX0A:
%7A[N<1ZRCehLTP8Y04U4]B=@X8e0hhBeef:INH?dB59FC6<<J;FUAHj2D9LRd4cA
%]3C:4<hA8Q@oSGDh7b?M0aI4[54J2oDe:oQUE5@J2VGKZ:<5UQU<BOa7QYeALk7D
%lU7IABU>8/fUXoiB`<GS60RQ568Cd;7:DM]Ij7142CF^;mFbQ^XYL/NY[07PC`87
%1j6Xajhek8m5T?h>[0>;4JE<LCZQdf7/4l69aKE`0Z2cHm=A0hO3V?b9QQHKG<a;
%6aAEg;R4Q;6DTkUJ5L;@W[MGG`b`R;E4lA00HWP`;HBQ?Dn1S<WbdFSURY8De^ga
%EK>LF<8m`IXTl0[LDLUai1fXF]C0/AZ7g5oC^@ZSM>3BSk7`?@N8hA_SN7Z?@eCj
%1oUiD6WbXECZSRo_AEFSmBbcW4]Tji/@Dif;D4]KnDA7kIDE]aNZcS?268k3L7_0
%Eo;C;f3_AEYM][UCFSTDMFhGa?HARjoiMlcRdHF89QQ01f80[/F0/lXiCADhSC49
%@PKR8YT^ARU@/HCLG<M/ECQFZV@/He^:1D:V>L8RNS>>Z;ZKW`hH`FUiibA5IFb7
%lGjKhcjCTi9d83:52hMFbBiT<LnE`>IIA4R<8FGC/AaVY8A`lT/5I39ALbA4S3Rg
%?=1M1]8mXkDh7H>PLX0BL2Z5B:loe=dn?a=8oDXhUM1He2aSl^n@KJee8lF=K`j;
%10QdP2kBF9Hj]fb4P/Q>AIhiWU3E4JJ9P<d5`bA4b>@624NPZlfd6IT1aM;m>9J@
%I7UiQM;MnA;cmEjUeGRM51TCR9^;m5nY9XIjCK0I/O;X@WGH4dgOhlkYc@S[fU[7
%GSkB4i;3c]T<ffaEKM/[A83@W=a9^V==NSNA]F;GEN@b[ITHYPMgPG6?h1DVEcFa
%Ki_QP2LJGV><?ObG5a1bh5Z:9ZP]EklgCOPfQV/e4]7f?USe><TZJ^XKH9`BPSSA
%6N=060;`J3U7:>^WkmQlYj>bYIBB1MSP<[>>gMIb5JR>iTa9S/GF@4Agl<>C6h0^
%lmHU@/bMmb2kUOFNGFSKV;<3b>I@SChE<PhjP:CZA1Z^fUS087[1cV:TD65edFoG
%mJl9@5R[41jQ[MW15fWE=Yb3gi@UQ`m[Q>SW^7i]8MHJNl3OkeAbSi0nkH=7mb0L
%]m:ZISHmdSDChIB/[72fG0gF10S1lU/0SFB`EnG;X66b?B>bCb=]g?XWHT_@`H/M
%QS/fkFa60R>3eT6W1>f@CUG1J;B8T`4>G4^9lhZRbf[?3X>]oAL:KFB5>A6_3d<Y
%hLDhX/1G2]4:8<@BN1W3=6T60<0ISoGUCdXLR:00aoO3in5=Q;;hTl`CjDSB^a8o
%[Q^2fXlVQ4Zk;m<<oU1gfA`/ncU@R2U9T/iZg>T>9:;6DbWD1o0<0g0@l4S`l@84
%@:>`2G0P2=0TV6K>bP40Wb4<GFg>n2CRdbeF;lbb0h;06hK/YHkVSV]^NZEZbT8:
%>`SZDj18Fh4b9Lf2B/W4^22>HPj8edfNXnO2kFB28HP0XFH4kRe>7nN^/N2bR81R
%6_2Lg/ZL[/gA0h@VbneFMDg44hbf02]J5?2m1@O6H`b>Vg2P[R8XfBG4113D/8CH
%VJe8;_312XMBhF94IT@bAH>27^^jR^3FD47j^j7^Ij4F4H4P6R6T6/7^7`=HClD6
%i<ATk>6]0@0f>`V03X;R354`CH;libT23:0U4nT`]P60>8UY0f>h?>ZlDd8:hPYb
%^L>N_HUPZJ;l8Y16o23he10T2<?25HSZkPkH[Y0d7e3hKX1>W><R3S6@]D4@^C3T
%@2kFHdHfafVF[XWn<bmnCH8X>`X^8B`N2m6lWP[Bd8]f5<ljS6QDddlf8>Rn[32>
%94>8l:K^c2>`/ZLn:NH[7BP2lk6J@Xo>]`6[7n8`0L<J0@9hW^3@:4c33RCNNQ0f
%XlgBN/Ao12bJ00[F2B8734eV:2]=7fO=3Xn8UP8S8dClOD7n68666<5052567:7<
%7D7X7Z7^O>PPY`8HGl>47jL^7J861i9h:N2M9n0402080:080>@N6@W>4k:D1O:H
%M76Dk/mLZLGHL@8i5D7k:D4j<NkJYU3X`XAPn<Mb5c;42E;8a_4jkd6o30UJaTD0
%d>njM@4o;RKT6LAT3a;/49;`GHhA8hO<BXo>8<Q<5@27<6_DaS8D;>P330AU0a4T
%Lf5:L@Dc6NaHRLaFh<MhL6dC8b>8@:mXb?6dE[590fA^6RkB14k`3Bem1F?K3;;h
%</_f8:/J9hI=:H1NHjen?Nj4LS7P870F^DkF:0MLh0C83m>98b_`c;7fc@90CT>2
%=S4J=^>@D2=86/6^6f00020:7@7B7F=87/7^?<8Bcn:8D2=0B/7ZIX/ZUl0n]J0>
%0<0B0/0Z0`nn36SBUb2R>l5`>8W9:S6Y0H@bEfa^l4KbYZDZ>ZKBlm1@CT^>78`4
%3g?D1Y@Q;R4n>a7G<bfLIJD:o@=`;_7P9Hh43Ta;8M=J<`kL89@FVj0`W>CI1i5P
%@5=f8:dll^1FI<g0mH70iO22GNXdXo30jg92kV/nGNATjZ8?5l@0CDHZ86N^2eBI
%=Y;@o?27@cA6<`lXXn<Nm`9e87;V[XX@FAAfkiA4[fJHZn9LlPLk2fMX5h>Ll1BV
%dG8lO8CgCROL?NF9@fIhL>=L5R5X5b2H2N2XnhhNXkCTD2>BcJ=/<m926YDDM69b
%06040:bM:4<Nl4WP_HLW<_:U5<IWDf7j@f3I;/3`JLP/I`=>aF7h5R5R5NaZ2]4n
%0UDm=6_EAK2S@_EXE;0lGNjDWP2UEflPCBBCCJ;BO2[N=32I555m>>n09<@16f7j
%/W5l_@5o<JLfSL2HWDX[;f8>CLFJCM1YDdkYC1;lDQ@/c4fKG:mj]<oF4Ra^5MGH
%UUA9CNYW98]V9F<j8DFNL4Tj8Hjn5^M2bL04W4CHd]7JF@]a<[76gBV73L7g0<1n
%;RBi4U:Pj@ga;h=8T><nYbCT;9D:TZX>HbD67<IF3>36303N3L3R9`0H545@5XIn
%TD>6X?HZ:?;JTXhO;`44^69`mB01DO::9bHP1[J0Z:6EFi25?2RM7e?m;0=1@GFX
%?@P/JL7`7^^P7nW>4EJ/kB101/1/1X:d4PSZmnP328eEB4U3H2RQ0fj8>`:14T0_
%KK176_F09<L@K/>a;`48MT3W3[2<hNkWB9BR86dm@JZ>2;L8>L9M8ZMP;6GdBH95
%=BGlk;KR886=LW1PLJ3Q@ZZN;`;dDTFP;98dMeHZD/DSJOB4=@D2l>@=5@^jD?CN
%<90Xj/CMA/0]MW8WEf2U2XbXA6b7Gc>T?D9H77N1MV0]=T<E8Z[Xde8iHZhF>4Hm
%G/C`=`KH=L7g>n^lGB0h0D0<7<6/6>7b7R7H000<0f6P6m4DD/I_J:cn847R7Z7/
%5b5d5hSBA49`0C?J0?:8I@0P0V0204089iC>9`/K:SKYFm2TKHABQW=Dll866CPH
%`O83BH2djj64LPP9Lf8>9H@;4_4`2_PiKJ0^lHHZ@0ZK=OF0O2@:[bZ?Q4AAETe<
%7g7Bi^MddP12`=PH6BM=0foPNi<n7g?E4P:0M]F57UP9KRlI?//01d;JK>f694RR
%L>F998Y_M6@DGO5NET<:B]9d7hHlV:A@DSFB<8;l_HDc<627HLA712XX[iHV>`<3
%H6V?A;?j7n:NBi>400Ab47GL:;SPV]NEDfKI0J>bIX7`=L;e5D7f3?Ph5@4N4D<:
%7@6J645d0>0T1J7H=M?8>@hX_3?<7/7d6j70780V0/0e>^05DL0:?V2P2L2J3^3Z
%3XnH5JR81N4^4/4b7P7R7V;m;AFQ2c=kAb8<HjaP`EFGAnhPA@WLdT1LZ>Eb4;=j
%`gR6F?A`l<8<Db2AVZd8ff3<WLib4eVi05K>e]CJjD_MIU2?A@6gW>8=5/WMA:8X
%Hj9L6IWPK:GXBoFlicPlajDbRoE1:e0IE/=3NA;iMNS0oP0YX::O6IFnb<=9Ln8@
%?F>:=SGVUWD>=J=1Rf7aXGMJ9<oaD`g8Znm/G4Lj[bgBmP8:9LmTc=<[PaP/863e
%YJHJHLLkLV6<K?EUFAC4CX?EMAT3SmIJAB7d?R7L1JgP7J6/6P<:7>1P1:0j3l4@
%527R847Y9R8PYgX^=X20262>0h0n164<4D4F76747:E:?BTHfj5@201n24D1YcP?
%7S94khRRefn9G5Lb9M=7@nHQ5c;45cVVB/LA=HF>80nh4oh91H=1bk2BG2h:GhLW
%HQ1GM4h4nh;5Gi6H:oHi1h<mY17Y58i99I=9iA9We:h:oYM77k5Hm87]2BjV9a;W
%lLIhBIm<X?>X:[j86:<::@O:DlJI<8[>WaDJ51ha6J18Xbo7;F`IGGOGiY98ZnK9
%5h7:KAJKEJkI1:Rn8lb;T5[XN[]Kk<niFnXmFGhoGno88oXg18jogkQ<7Rl@nGjo
%7`/e/^TXUD^ngZlWoV<Dmge;[K;M118[<99FH:aMD0=H0mM[00Q]UHM3]M]JYYCi
%LFmiN=__mo<9QDh=Z8>=^@1^E/0icG?ch;aWo>^9`>]enWQ/Hog]1>kP/AfGgPWe
%5WjlWTl124@TlVjf4ZPSR1mHX5@_FHfWYh7LkGB9hVRLAa7TNlK^<Lcao?0_C09J
%a9n;dO1k/<2@8PXK9]6hScR9P_J[Y8Nl@X:/Ql^Tdb24g58NaF4TFR[5i8aRj:<^
%ZPRm^a71oa2NlC/2SB23Q88OB6VR/S38i?BBTiABHKlW>6dLMA36/LbZf/X<DOlK
%X>gaoTe;h[c2FLaPk<YhC>PYTcDSdMUk=a]CQ6In>97J?B`jBB;g4SY2]?Y7CnSK
%3^hT:2:bfT[DAA:39dNU6X:YQhR7B@MDXiiccU7[YBc@;Y/O@ZF/<V9k7H]a:4`D
%8G1T7LK;MB4/df]LNd31[RanOlcWP3EM03GSG068=PCZ`LXdE:cYBfjLXfAH]4fF
%]BM75J86fVf3H2SJjmeTX=RFIK[/]7;;^^h`=?/9CbHX8NMe1N40@PTeQN5DCHC0
%j2P_S>?9e`W@AmT<@Q2VZJa[<E1K2?0k9jhCC[4<4Od6Wj?0kSd=`gSR_/JBSC=K
%A93M^7o>1]3cT@7I89VC:8Ej:gDNH:iJK>G[cI5]Fld:H:b@nL1OWAeIhdAoC2:i
%?j57/NVQXeM0e=aNa6/[B85VNJJROl^jHO:[ZcB`7jeTP74G[`^K1JH6TK/VKE/P
%/?;?:D9X?UJ?F@d]19?4Q^KZ^P;6K_<@A5ZFnfNUeQ<A@CY8[W13PYa1LLDP^Z@f
%`K0HLj=?/IM1o7NOIl7N?A04LAQ9U6PFf7ZlB;>bflZEW]2EROeP2mLf6]0OWQe>
%9e6o>a]b3_@cGKd@hTmJK7dibRFWRP9hh4NBf3I4<]3ZNOg[P<9F3_N[1^6lVNYl
%[haAj>jm9oWcDQl7PNk2KHaD97V9XURHlJo/8OC0A:cM2Wg;:H[iCf79LOQc3U7@
%N`2RSAj8mM/h8OZcR34`5E0eB@@fkQcPT>62Q>V>473M1T?46ba42NNoQ^COH;][
%8:8b4ac@>3SQDch_HUXG5b6@@E@j?AO@e0W3Ma@^8I:4NRe9Z18gOT[0o4>2@LdE
%Pm4[4TM4Bg6YJ9FWPPT8eI[79HMj7S?R/UGRTRQ58<8_5I9dG^3l?Hb5XA8kDUi7
%1RA[C:1dY@O3DVZKZ=a1AP2>V7<Bi=EiPbh3m7H?XNHj0=0R1X</Jhjec7N@PE=j
%QK4/<M>Y2hBa/04bE=PbQaQDHbWFFA9dUL@BnBK=ZCZ7i8TZ1]U@K1hh105b]QQ6
%1SdY2>@7U4BQCJ3Aj?F>d`AbHo7i9J<8GXa0lAl3c7F?T]cmQo3A6P<`?HN@m6:N
%fPZG[SbP^@V``TNKT@V1=2NT`DBE6c5n98>2L`OYd=81a>/E<kDR]WD:[H]liQ`0
%GW/`TNZVV?BeIl@ET`C01D17I@>OZXAnaWOj[HWAEF3SNXL7NR3<ilClDC5U]A=9
%`1JXdR@<]7DGQEKRC5]CL6e4NRfl:Tc`BB8LD4L@[:?B5Q;3kC=3m1ZJdDIY:1e:
%`d/UI7CCl8E@@Oe3W/1N2PhF5TM7loMQQfgYT6;P?/L`jA_SC020h3hj2h9c8/?i
%dKdc5B==3CL_Hf:c07[@]DeR@@hDkDG?^W4@6<W2EXCXDeMjhU]YM@XUe9gEBQ7n
%LP6eJP00S/=?R1E1Jl[?PFmELK3eT[T<@^JYSYBbSl7VFhNaO9T464Z9@B0cQV3=
%?;DbbB2e@6XOfAbHAhC22a5T;@6E/blf:[X?dFe^@YFkK^6Ng`e;PEo[LAjVlBad
%=YM:[D_m;Jh;NF@d2MH>5L9f[YM@a:DF[c`O3BXPT1;5[6E/7FlAG@617_<:Bm2B
%A?0Y_IM<PkA;ZgO9:YI^hakk=EAkCL_ef[4gbYFU64M2jBU^;O9XPPJ<46`_/<MQ
%Hn9TE;?<mbJQfAiSiKHMdOHj1D2K4P58<8LQgAA9H?h^2iY/6e[95DOk:`Fh]/82
%_62T6;/7RQOh]<7eN01a/XU:QFEXSR0QT4f6>@Yi5AkA<PkPLMbV<FPeLDOC5WP?
%17^dkT2h9JbT@Bd@b`:PD0P<@H@`kBUo/T?PRc1eH>AcEI2YhohD3CcQ;1;8kLj2
%3c/Rd4P<Lm4h4`kVkMWKU6gL30M`SJVIb?_OKM@BMb<S[dL3cB56P]5O7O6Q1Ef/
%Ugn:^FlFFWB/Uk6OZ66h4aYJUCUGnVnVBAjM5TlT16U;5B@KNB];/];iGmPAS>Ti
%Ka@jm9l4T2F`A1R145M]`Ai[TVO7j?POUWC2HH7D3H4h7aLS96`>]>`nQf3[7RN2
%?;YbG<b8iKh<j_YE?7[<=RC>IVeJYeEGi6f:SHK^eDL14Rb1FkiEm@40A/1;koIW
%4gN]HLVc9a8jIPcTn4>C<>jFdbRd6T2VVXD`4_c`K<LQ=MQKTKG>Vc/8>SXIB2Ro
%i8d3H84PaLYe2<lTm]d[5kWdMBhM1/i6W^e1JkPoj73Nca4GVM:=jm1RMH2<A;Rg
%PKj@:kYEOlJgFj4B8<gD@JMCIGYo5A^ZaE_jc_E7^0BG:7[MLJX8@TDRK6gfL8P@
%PQQ;2<4PM3ol8e;?2N4N@nak64`L>LK88P9P<50:hFheQdBi8h<LGX^d`QM2J54;
%6gbfUkk0@@EOTjd7d=I_c/]Om;Jaj5dEjQFLLm?AaSF3lAMcb[09b_Vc`n]eih8j
%HjKg<B^Vbbi@kG/?LHWfJGXk^KL7:N]>Z3R76lf>VMVjh0]k0DP^nHf@A^S]/KaO
%UJ`PGCJN7F7=mUUhfJm/7RK`:N<_RmhZ9ei7XHa_d0AoDd8Ci1LTIoL3n3dE>>GH
%4b^@HR_nMfh3eco<Z30`Oh=l0CZH6RO3j`Pc9@PSmkYkFcoXcJ3b=8OZ>H3d2SY0
%3JXkmaQ8?@?8?P4D3`H0HPH8OCIY7`OHO;<bbI;@LPJXIX10eP@XAhBadJ:<4hoX
%Z@3H3h4ca`jj>If;diX0W@jCnD1[NXg<20O`gP;KnCnH]8]j3hhQgH6l:@f3OP44
%:`]kN3X:GSf0OaoAkSKkfYdbYC:;QC=B[XOHakfHNhZ@dSQ9ZK<S=;4kSSS8a@V1
%=@I8GL?9@l8RPaVL0h]0]hX`337kG3FJ`4@400PY`8DlAQf8H<AkG2k9Pl9T9Q3[
%5BjcV<;;9IVH_J]Rj9gKmjO0hS[4BQKIjPZl18Oi9`Kl2P3cSl@BRbd`N[IPE`F@
%FJN`2XAHAAiXcIQ8N:cIlanXOQ48N8McQ`j8OXHhG`Gh^P3`JHJhKd7IVXSP_IH0
%88f1Gd:`42PHMT0klbDZob:R`2WDDXd<9Kj@PZh0JQf;7:EX1JgH:C6/?keb?@U[
%29C/;LBL<h``aAd[=2>`lXNjG8cJ>ZdZ?;Rd<[SC=JGKg3XJn1FQgL@cG2Uj48fZ
%]RR0>l@aFKP<A;l;V8PYfH9DTCiP5c>0JJVklZ7Q@lCDLZ<P[94PR/E;0Anj_Yh;
%@lR[Yj9[10=40TDRP`Sa;/Lk6bTRi9S@OPJ<Y1UX2[mSmP;<Y`_YnHdPPPLZL`70
%6@60989@8PNXNhN9L`e3SRYPOY49dHO0O@O8N0NH>@>@?@BhCHDDJ@]XRX@4^Sdh
%f0ID_2U94YF`ZlL3nK?`P/R<UY:hSSnA;ZL2`Pf3GXD8V4XBaL;J40a2[/<2YakR
%D;h2cZi;^CIHa0O@N`NXN9KkRS<XR`ac=Y1chTQSeX_<NH[0S8]l_`]94S>PMX1D
%fd1Kjkl;Wi?IFaI0C<gkm@2:=lU1IDBhZSoT`HP`P820?n1@>2@F3@N4@V3?f6@U
%l@mka65@ElaF9aN<AV=A^6?enAn3@ml@<hbD>BMOBUiB^>af1_^HA^IC>J@R:_V4
%c2M?^1YVO1NP:^QAmn62S9bT?jUBn1?N1>mjB=n@9l_LdV`aQ/@1UW/eV?mo?nN?
%ml_em?Uk>mo_fYCbY[EJ[eAZIF_f`cF2<>m02n0RoG`08?1@=kHF4hEk@Ijh^lHg
%7@UmI61i5mI?8dZk_o:Ho>Ig7c[5H_4BnHIPgJL2JW00WF=CG@>RIkIAVke>`KF1
%?fN?jk@;KIUoIEob>ef?RCSLcbfF;R?]o?an_9i_>k_Yn_oKFF`iV1Kb`MO_F^`N
%>bAJ4J3L`bMDBF`c<@j7ik<;7j=3k@=LoUcO^4a6W>jYCd;4V1b@:9D3QO19Y`FP
%bM<fgb@@0OcAX:f;I`_34<YW1kb^@PSo=Q2<1[6PSYWW3DD8c0B1_NPClUbX0;SZ
%>Hj7PMah_6Qk4[F^cN:FPkN_8kS^aBVC<:92c/8n8lV1Y9a/BQ5RU0m:Q/b/Pc/X
%4O3[^`PAm7`/9m5>EQBPX2@8TTB18[74SQW^Mie1B40@Sd>XlTLAa:=]8:JWE?dZ
%0l0=1<09e2YfV<9=94RRAJcC9B;5=6_K;SKWlDe;b58TQ?0gKQ>8b[]]l/B`^_;S
%`DdlT^;_D;b898K>Z93T/A4M]J`B5k0<05EM/FN]8DSDEFe=DcLEJOe>]c;:a86Q
%Zc;0gJcDNlQkWfSmCX@ke/dY5Scd@PRGDBRK<G1556/`4md6kMDSa59<1<XCmhPc
%NHlG[AE6`i1mXc0lBZ<RglFE;CE@^L]MEeoQ64hEQN68bN9gWL<P_S24P=16GQJU
%hPF2WfiZ5^PcBY]eSK]i0Q]B?M7mG:ELU6X_MSK@k0EhTn4VK3OW2A;aPkb7`NbW
%=hSimE8KFRQ]XhXRT:Aj<FimX7fO9mHNN3ai0RmbBC9PS]H1;00e[kmW=LJ6hK/Z
%4e9]63Ahk4NP0081dcO/^:Z]K4W`MSQW6K9YV:KQ^W2Ii[6dN1n7LM1gW>KAY7:K
%YZWHJa^W:hVecHg=Ul_E=DK<XT[6b1_?/00_A3?dSea5AFFiE/eDIiEmFh2km^KS
%COHg5fGEmaIVb88bS<15gi`N2c7QiELSG6Y@XW1WiI]nJNWW`KKb5WfhF2WdZN2l
%^NUS^D]K:n_bin>NOik97JVBMOg?eOGmWLj2NilV>GYS1:3`BSD=8bV/K1Y7Tb9b
%4;?F;:Uljk<CN?D<BAihS`bR4jG8@UBL47MRhPX3:2bCPJ2kPdkYKI=FM7YDXXM4
%PkhB1YQ<1n50eXE=SDXI@SZBEg?B84WPA`1XK60Q/0HnP/H9@MOJ[lO0nQk]Y=j?
%]JPn6A5l04?X/IHAl3e:VW/WRKbe]h7X=X>8JP/5l08:TF@]bW3b72>PK`9P?0e0
%T0/5@^aPS<@lb0OIebaabHfN8^jZWLTR8j:V?RPP0Zi;h::@A1VH469_3nA4RHO[
%TET@844SfRSJIL@DILU@ZBGD0H8@I7I3[HMDNU=Se1jYQSR?XN[DBaTh8l//OY>8
%h737V?LZHmRLBd;2`2AD^IMBk9X?b9PoQlU^7n>lMXl0kQf3TBL30A0SQ;5<:TEb
%eGa:S>6mQ7jU4^72QlAM0DTb2@=D>:NLDU`Z0SW<:FM10i>Y:IRQN1jGUY43Sh:T
%1DmA=cgDDP:Mj?8O3:Wm3T`01j1@V3Bm54TgYN6c;_<5;If5B?HP6fh0JZeC5D;2
%?MG`o1j737DF0M0Wa<R92X5T;Z7QoSd7h?/NP:@CPlW4<69[^Vf9M?6`MJk[V5c[
%?lCX<U?@1doZ13TJ]@e546<A?^Q=BJU6NBBRH65CeiPI@:>A:@oZQSE2aEV507a5
%EM7CElba`Y_TOVlRd/Hm1kSh7Lg:VPn2N5WU7BXZLYQlTSS^N=Z0nak=3F=D^_eO
%i4/77X?>^aTc5Sa5H:/F8?0MQ1CV24?hP@n3R7;9:EQVRY;7C2d:PaR96ZE8^id>
%MX`7fU29JLCEZD>@O]0Idc288@8[Hf]hbRjQ^PX]`5VgA:ai43Ek1b5c^ahG31;L
%Ed@1C00a^E2m4Bn9hf0<Njd]HmAkUA7jnLOPFP]QK[BZ1CEO6AW;7mH@MhgP?PK0
%N:`FH]akBY7N=LIhbVg0D7?F]n2VUVY4MMCMmR9R3G37QLD4YP01H5^D35dc<ImY
%9^QPg1c;bU1k`T1;2SWG>QO``173@S<>H0WG?XmA<<6@P8;BXN`jB1DK8jIE2:G:
%D_N>@Onm/ecM5::VM^?63lMHk@dC2Te5iJ9NHf/i;XcQVS@3H6`=05P;P=0X1D1h
%A`RQ@4684A`_QP2m7H>m/ChbI4g?/=2NMX`iPic<il1X7Le1ncH>?=e[59HQDFjL
%adnco8DMiLnMV60_fh1@<c@4724U43;XFX1P<dBA]U?bY6?2IDY<c@aU1VR`eiGh
%NB^Y^cdSe7NgQ2Hm1f3Q097l<XK0h1N326D?XJ`cPN0P0l60?0UE[KGCAKKUKlGl
%QnB9A^H@7Jo`:08`0H]RH;8oX_AfbIMVDdFldKIP11KA0[]<@^eAhkGZ:@E3V8b5
%8]?0Z2F@oDCVJ7n?DOXSQ0R:3HDH;PE`/Qc3h8LMQUIE5CXKF;LU=:LK:gi_dQ1d
%6DWQFniH]`mYFSfa^I<LXi1`2c5T;P>`MPo0h1d3L1`405PQ121m@6JP>lJ122WT
%B^`ELPfV1G?`CNE27iH<7U`jnH:cWKRC4^8/j6=PL@aG]2>J8SM@@`D7@NCRFj8X
%ff0oaBM9X3@8`4PQAE6<<Q20dWmo>fYZ@8N@m1h]Y7f?4NHl6dUR[8bajRcg_2TY
%04<8@?Aha8UFn@NPH@W1?4@9DDKE3K]eUDcdZU<VC^JK;XeKi39kRKT000_`21DN
%;j>@>eWEO8@o/nCL27U@eNG]ic`Oj9UbK8G2@LWMMD]7HaAi/<@FPcR43`8Xc@n`
%]=94V9lEZ>?=UVg]@`lTZO0NAmiXiH[@d^<M7]:<k/1B9;7LbUfH6UVQ_I>l=kj0
%hOY3RnY/hJGeo/O@6l>ckQSlE[B<XTWcAWYeXQB@^@S/gQ^O[1Gnd;_kkFBA0]o?
%`hG_k4jj<A8P_P_N^l7bhBGdXHP:dZXHN^JR7h>@?10DDL2HBHj84/7bIh7F7H0^
%040:6@6X707BRRklFVm6?BYVEHM`8jdFo:842e1@^><0]:0NTRZZfbok1RH@THcd
%lB]ngni^8dQH[:DJXd;86j6F5f5B0F0N1@7TEl;87f1<0^0P6B6/6h7J84n8;^In
%9P>8=/Ua1U2d^P;^;LI49P?nUJ9`>0R@7^A`U^DlL//f<d=j>0dHMfT8IDPG1hgf
%8^?I3P<jlll6QJcd<`@49^A<o/2lclZ^c<1bM2M4I/18f^mX8`^2Vg2fMZXNWh[^
%7h5:5>54dZdZP:?D<RC0:D7/JHf406706n752`OP6X5f5l0l0D0NY@7n]j7n7^I>
%H4?72@:LDi12[jl2Mg1<[67hA=4Df2<01e6<ca3e4S6D=T/n<`lZ0PE[2R@TVjID
%oa3W3ZQ0?O151l7d6j423L2f3X3f4ZNf7n645Z5d0d0H0>7N[LXfL^7a5XFdSZBD
%OC6G7^UbPDGh<RSR;^7^g`>`aDRA4dkj>:BlSRR@BlF_7`;`BC4NlL?Rof8H:@4h
%lB<0Sl^>6K8e1XRHFlo77`^TZZa/00f54fdXVX8J7i0V7H2d2b2hRh4P4NCd>^6Z
%6P6T0l0F0H0R040>5h5l6D?n7U0@I4e]5V:JGj>Dee6`Udd06HWZ0Dl>=>3LW0CJ
%]VA8f<h14Q8I7`G8Qc1_3NQlJ`F]3`9[2j<B7f781^1:0/585D5`732R;h0D3230
%3:Gj;26h6f6/3J3H3N0@0B167I2R?27hElh5:g<@OF;6AfR4nK7XSZRX7h7`>@7X
%ab7l[L7[5TF[7Y:G<B8>o4jX86lJ84Pd5fX0T04==BlO:/9b=:N97`dbKRC2FTKL
%00N^UU<^O4GhR<;@Ak7lh@JZ908J<TNZV[:<^^7l:LLZ>@96LZknMV[n<`4Y>V<0
%d>;h5W>`o=1:?<@k<m<B<@]H8k:NEj`h4H`0[3:n9^fh9X=[3@Y>7>5:4^4D060>
%0<2b3<3L1l2<2`5P5Z6<blKX7R7<>:121D2>712Rn6[]7O:[>m@LHD=fO:7V7J=/
%Hl7n3X3V3N3^382f382/2V3D3/48mXR@=f96I6O47VTk<k@N8:NO7O;11N84`0oV
%0]8^D4Jn0dclK2PFT<8ZdG8o1RMk</WHD77X[h;;9>=dF/>g4VL]0@YW0RFF:F<B
%;>FFLZmdHhMS92`L9d^f2fl>`d0RoF6hjP7]1j^Ja]1cAJgk:no<86i88j3[CVI`
%3NdFWg5n8f;^[L;4>_7R;F7X7P7X72El7^0/0j1b747@L`7jn66Z6<2L1b1X4N58
%5j718FYDk=CIDfB;>7A>R27i7n;02N2/2h4<464B<d7V2j2T2H4R545Dm:>b7VA`
%_2kNYSDh8fWFVl9d2;El=B08f3AZK2]B4d^>5OFA8KCG7^;3@DNX;/>_BnAd8nDn
%8O<[9>;8N^<TEF>2U4YX=]5b<Z7S629`[Nb4E8[Nd[3DH6`J@47AGNG@1>l?6<1d
%<Xj>oBIHh2d5Ebmh<`WFPR84Zn7C6N7MH;AU>j@^>gE5@Rjf7n7H5N5/5H0<0J1>
%7U>JVV7c2R7J765d5<5:262f3TZXEJ[de[GiI><ln2;07Y5T7F5h5h5N0T0Z18Bn
%Bd7T140f0P6>6b6`7IBL[V7f7ZUXk0j`US7]I@WE>iJBSN8n4OJM68T0ANDJn`Zf
%bB3HEj8k?2?K<@/hNmFg4T;4onYZUKB><Rh<I6FhI1=WJ2;90hL^U_9?G<;8n:[V
%V/S]GH`NG861KfZ1F0Qc:UCNij9_B3J@`KG`>0N8QP8n2_LH4KLL8G;9L8F`:JUJ
%R3>DP:7f:l6@4ZW^4X4j5D6R6`71IF>`;DBn7D747F363T46k`[hk=<?L;MTB=7X
%9R7j783/3J2f3j404RXJ5f5^5X0V0V0>7JJQ5`g6:V>@ElLW;_MV@UJc8RIF7l6;
%NZ0GN_4@0:9:3Ro<^H7hQ87OLH2^ZN1PZW1P[37_IDL`7W2>Dbjn<BXXYB?n>4NZ
%:8n7MN<[7f>6>_33Fc<T7b7R8l:MOY11><O1:D`JBBG90Nl>Z05YPO=GHAASNNfC
%PDMfa07j`07;Pg1Q6]AH8EG0kj>^RHO9A>YX>@E8>`7V3l3N3>2X2P2J4>4H4P6n
%7@dh:U=IPYQe1d<e5X>`9h7R721j1>0b5D5H5/70gV000>0B2n3:33@]3N545[24
%5h64V09`m5;9QfWF]hi41Bl>1gS5AO=JA89^QXZR5ESEL7=36F;=KHDMIZd[2^h9
%K4?2NX7b:R7_<d>nUG2Xg;0S>Db490dd>6NlgbSV>=KZKEK``MH1SR@>2EN^0F<0
%i>nX74^0ce6CQf`L/oCMNP?J/n/n8d;75T]jU^STH4^j;0NnR67S;?Pb7`7BEljR
%RJa`mgTiUcKa<V>67J5F4X4D04020<2l3@3R262D2U?j5b>/8;<^5X;P00080V70
%mXS^PC:eDhQIAl7b:<30l>`X0TLkNk;8fiKf60W<163_WGO?SL:DNZ?DkNaL7n5?
%;JDf=h>AOYOT;FhBJSQ8O0aHm7K4IS<T/`O3P:[i<fCiPo7c;8`B`0AS>/0027XX
%c`Z[TgUdUhWg8iH??F:YJD<L;6g6?oRaCjJPWJ>2>IT@g:7n7P967X;690:FAoXI
%XcI?BLBhRXg47T7L7Fk:160l1L7@79U>>j7b605n5d4b4d4l3D3R4B7QT4?6Ve6E
%6^=hMf<aPSNl86jL<1F0<0W45>GbFUX`86iP7FJeGXK33R>Nf>FmP]VbZDX[VM0F
%SnKPB0L/[ILV=j_hIiBgPA[bChgk6XN695:Jf3XT3c/EGfimY]/LIO7XP=[bT90F
%S`d[K]KaY[/OGh[_Y?UH85;>7Z5V5H5N0R0@0f7k847d5j5h5^3>3@346:6@6H3Z
%3/4QBBR6O8>7QC:g189PWgVf8:N?6O=>00Yj39X/lnljD>ldcH3l9>0h5_^U]lNY
%[9=MZ_[RZECbWP[4<1[;/fiUL>ZZ9_JL4Nl>Qb5e_CGm>iXm_1_M_O_PEn>h[PBd
%6^6V6N4b4X4/5@525P6b6T72?5Z@5d5:5<500T0V0^4`4`5L7PEl7RV29hH;^bgm
%Pl<PFU^Blf>W4<Sl<0i1S8jTj?3lQTm1a8865ka@ZR41aFDK5o^2adMjjX:8Sm_R
%=VG8<@2=abl?N60VnhK`@ULUa[b5b7b88VlNJ2R<>aA>>^>AYR>obJ2X2Z2^7R]k
%Be5VUK/dfC_5VMGc:d:9CV3Zl?F0Z^B@8o5o3^DYC@iW6087O025cOGYH4[3`/lP
%<APmFUNUb;L28ETN7?cl0ad0l?XX27PSced=d?dAVLDea09N=eX27iC>Db8RA<>X
%;2V2[JdQFHjXehID@h8kIN5i8`M4<04Se:8ebg4YbjinDXWG:n3ieNAR65eU;4B@
%`O8LFT^M81dB8AZfika?a@jF0>fPfS_Kegf=f?/LXNknUFIm<<<ZXZaZbl[HEI3K
%<ll5NRLVnT73AZl>2[fme@QH<X/oP`X=94N:Mg=;A[=B4=dibbZF_l8:]ifAWJWi
%H>j?gFl>Sl6AggU7gWgmgoJ@E8[g0SBJFH]V7eC>aN[^:Z>934n8B3/590:E=7g[
%]0<:2IhaXT0Yhf`0j?^nWI:ag:8X8ZVlcL77GYTS[?f:XC[6[5aR<cgkcdl5a6SS
%;9AOcN258/;hAScl7?h1ioj1Gi>7@ZC0M>8IWbSZa^YR[[7NDnDI:fWF@h@4?mLL
%4Jl>Jh9B5lG9PSiYaO8QNJFjA9Tl<HiZ7fhR3/D069kD`NcR9JZZD^5=fACaY08?
%Aj85Pf7;hf0YA^022Ckmj3l1l3f]88AjkcI90ofO[bXY]1lHM_6GkKeb6OlTf3`j
%;i/D3bWgd:XBQgd00`ZjmIbh<cPaeXPhT;_TN9aYl49Y^XiL63JPEb49mSJGS;mE
%m[m//0R:KAh:F50n/;[d?37OAQ>Q2eiF7nCl7Di1Zn;iGXiUi4K=4OiR86N270J>
%1]TSH:eX8`dGg8jT<O^gSR87^ma=m_:Yjn87k?F0SmF1W>PhG9nom_oQoROFk3=T
%92m7Bh87n2nCgLfB80oX4oh8nX=17nIXD08I3@Q3fo4Gk4hY27c5hA6He6hi7Hm7
%hk5Hdo997SK9`i:FG:h<nX4oXA;H@miY97i<iY89e>iK;hg=P3@Ig@j9AJ=AjABJ
%EBY]6i4oa_DHJ1:X7j/jJa>7_CiUBjmGk1HK5Hk9IK=IkABH280oh50h91H=1hA2
%HE2hI3HM3hQ4HU4h8oH8oX567o6X8nX4n8g6I58H4mY;98]98Y:iI;HHnIQ0dU<`
%1=@7=`9>EM>gi?H<mJ11Wk@iM;WWAh7?GhnjI4U[C`QDDKDh6oZ]0geFH7@iC6j_
%1JHnj;27]IK3EWlFkDn;IHkMKkQLKU0kI88;<7bhkd6;i=Kl02EPJ5A;WQL=QlAR
%LERlISLMSlQTHSGI97;4ohmEH5:HiMY16]1T]5GXi0fUY`WZKo=C7[H=BX=HJ[Gm
%72[AFLc1:EB[@i]l=^0C^4kN9J87@7[2Ji/m;5=Q0]ac:aF][eN]5=U1JiaXcEUU
%gkl0_40O8R_=1^ieoEjoIkOMkoQlLKXH5Uh]m7oUmc:97V>Pb[n_T^:l86Nl31Q1
%2KP6W821=1d37^ik<>XOkU^ji[J]a2B4`8/Rb]`=4@Q34IZA;2D9@k2[2<<XiiX<
%NDH@56C9:i3J2`T]0jAdl@1;l1<OV98;GYm6LRb=8lTBC9DU/dUC<[4o2DWfS1n]
%0S2[Xa:Kl`0UDV9H_0eC20daam7iXC>[LE`;0b1^c5C:<Q2b:Z6^Z4_C=<h7nDTm
%PS?Y<CnPJl>RQ4g9G@L9]bg3dd?;e6XU2CLD?@jd:D6m;;m1PBddLm>D;Ae?e1D=
%AE7D;l<_:40/g:T[:lT<ZbfnT<E8QAKeZ_cb02_a:efjKL[:TdKYk>lVX9Dj;Y7F
%:]eEE<k;@fTfZJn]XX>/<96eJl41P9U]dlo:VA/USdZi>Bd5=LeIg@Q=6>Q2S1Wj
%L5h:R23EP0;=k>gImdgeOMnGkObgYBnmV8@o5UH;9UbFLSTi75QX;hONPXHU?2RX
%dnin8bTam7TT:UeK8V<@[=//i3T:;cc@efXA2AjIJ=VGQ1V9[IWG]VeTkBQg0m65
%EaOnO8RYAGj5NRo9VBE0YRQ4iIeWnVjMYnXJS94iGFdRTYj8>/PG[Jo0i[e>7>m>
%V8M:jkEm2^>7lRbDh`OIl/g;/YBhRZGCUV/?F0OjUCfDSDPVC_0Ca^b1AB[Tj[_Y
%:3d>_e^jUO_3]8=_9GX0o:VGbkSZ3YDEk7ag?Lod7@m4UcN=Y5Z343e=j0;eQUMM
%ZinF6RRDkO_B@WfSak6nKa/WXMYh7o5co<^^fC:BRanEO;L^Z;J/R895>kWndiY1
%Gj`_naZ]X7g`IolQG_I:EW_AjN]6FWX6Odc60bo19mafOPPg8;ak_bO]nolOcZ2d
%CM=bU38P0GieP1DN1oP<m8PJ_e`We@Z?HO8malSdH`?P58:@?Q7Jb?mf[Kf@^eI<
%aI]KbV@/g8NoEJ@ne85IDG2XZci`]@_Dd2DK4<gW<VG6R]aY1EOUW:/FX;Kggm:P
%R0@@KTAH1Zg?92l;C/8Pa=RM4n:2o6Z5I:hRd3/EdOP9;l3b;QN5^`:9LAPOS]BD
%/K5D:HC@YQARJ:V8dEPZQNSm<^A`ScJR=<UBJfX]c2R>;PMU3TOhVi1=n5?8EMbg
%D=??DVKAkDDEA`l7l:fBDAcEYo4`@I22kY7BKTi9fCaTDg5L2]:=NRlQdbWHY2L]
%im2;3c7D>48X?@I3f7V>`NQ@0D0[1d>`M[Jc=UR:6AZ3JCBR@T8Jd]iijAHC;APa
%`cJJRBXO@X<bJSkPB9Q3D?2KA2G>T2M>@FI/We7B=CN6VLaOP4CYWD=6MR;dHT2V
%k>:NDlijCc;2m4PB^a:a802n/FTodD^bJ@kDUZFBbRJ4T8dJXcQS=jX8<HI8cA9R
%F4jkJRdMSl/H7k1mPI;W2U35]B49m8g[0[6CBLPb:E^S^YI3h5U;e[SJQ<XQjBRY
%6<ZWZO1L2n2>:o1UCmNP;JQ5hS0VnW=AjTE9W/Da4Xe7:P7@DGi48J9<^4LC:6J1
%;F0Wg9<?a];g6<AhWQF<SJ[amDJXhlb[CW2NS0[L1V^0gZi2S[X`l2hUZl>bCT`T
%OdnP:Eo9f:i@kYF5`g>H^HDeBTRe5CLNVYX2[88lE`5bbR@gSF:/aIVcBC3dUXR7
%@=?1BPGfS;lPZ2X:JRV?=2?XX8naf427J8L@HP791c1L387HQQ42B7f?N/QV1lSk
%7ZGHnd:5_8E</Db_MFG<W984KhL`5[Y2h^X@J^@gU/QD^e:LM:9gWc87h<jlDE`>
%Q__<K]iln4gUhZO?6cJAQ?gaZN_A`0WK_FGYY?1imk[ggm_mOlURgJN?cLB6C0aO
%Wee?ZJKEF9magQT2j4/A8QA0_97n4@90Da?RQ5Jb8Oe`CX>aJBOXO3KbR?:8jEUb
%1BY00^aL8_63fhKab:H6O6d<AQHiCMEE_DbB[C=HT52dH;eh3P>EEUG50/0992_T
%eG23;80:QV=Q>Ej[;9[]mT_;FFl^4;K5Mm5J:IUR`D`CT_`W<dDc<L?ii8o1l3e6
%H<DGX507P59:D<O<E`B^k7Fg>3AFBa3l7d?iE6Q2ACgLCBUa9b21QNdL5SB42Bb[
%^CTMlFCOX31ob>bPPXT=?0Ee0;7DAHB`ZA@XGk;ZBi4Sl]?>RM89mHJ<QdFELEK;
%lJYea[VcJL]B;C;`NTKN`EiBD01MX:VEcJWg7f8D?PMa=RB4F?dO@kaPS35j0/1h
%61j<J7_78NU_Xa4FKNfiK`n8a<3;[N1>ElA?j`1>nNWMQYWkB:b>SN`Aml701/=o
%OQ1ZR^G6F=GPA0h0380o`L?72B4UQ2U`gGBAhJSGhT0cRRm6GQ/Nf^2;bdleL?hm
%anCJKXQUQZ;_P8jm=g3ZiDFSSYRB=3eSUWP:P@@M3B5l;DMXjA^P0080098E``39
%6T=m;Hd1P311S;T183@73I7H>PNRbUHHP_eEi60R>/8Y:ESTH@4^_K16fc]IclRf
%bZQ>NHA@6neISG07W]b35N_`7H4G^RUPKSTkaOcT1lRl2JkmU5NPX_149Z;S?_OQ
%b0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN1_f=?j>@Ilan37jA02BBD2bMSbV
%<aZ1_ZGAR:_j1?V1?an?QA8i2Q6B7Tj6Y7YQ9P04Q5V=E`?mk_ef=U]_mm_a18I2
%Z]O[ed_]mE21E]o_f3ZJa0:bB]n^Nd1Ve;ZfCInFJ4aZ`@^>?ji<:l22m7:n?2oF
%iHH6BZ?2GFj`=2HT>h]Nhf?cBIb2HI?:IG;IO<A>GEj2?_?5o@BFBQ;B=OC@>g@=
%kj^3G;<joHK7IK?JKGKKOLKWMK_N@W3i5ljV1;cR07SF@10?U8;VJkN`bI?nk?Qo
%_ah_mi^En?UiFmo_B`?Vi_^1?OZ_QjW4iVic?9hMB1C9n_JX_ZXcJ1X?mBE/Og=Q
%k012`4hB_YH[ZGX4ib26Y1Rg;Zcck^lOif`X:4;1c33C6^hQN0=3`@a0^3hXhaYN
%]82A0aC23WaI5/G<XN/HX6N<J1E6bB^D0HHag1k?=K0cY8k5lQb98/SB?94TbE9K
%:/NQ<:7J3TY>@TXOB/^:=@8ikW?8OAh>TNR17fNil7`kamYTOch?8BQ9TNJa/6Vl
%SZZjO3b;Vj:JY/8/n0G?aGd0=E12I@TEY[=3D?a<DOCdOQEdN0@006M9cW@UZG>R
%nj1c:O1<Dl2]@4>A140EDX80L1he3@=:j`DPIeeP8MI1IFQae]9UL8bR3XccG:i@
%EEZ=6UHH4f:dBBD4=B3<=8DPekG=XFSJEYfYJ][=kIUW`:OXYFj0U_Y:2ma79LT5
%;M@dS_7<D4X7GT4c@D9?U4KI]Vc6Qg_^j:i7lOR`GLOIlWd0`20:T/;2L4PBQ:Mj
%oH2OSXWXNYlW/Nilge8AnY/OAc7>M8T2>9AXVFJ@/RX;3YI@kn7/Pj;7/NHIR6<2
%`=0b0`3P>0JB0OHYT6<Hl2@8^ZBPgXQPJ<^Ed@QEe5cVPT]8;YMY[]P1l8h[anW`
%NbJCB[kiIBVF7dAOb_[NhBiaIM3=X<B6fBXTTLUI^;O^[AAobMJnlKc_Fmki_^n4
%G`5_P8T[S02E?3d^OFigKI][TSakT1QbAGLYYmWH0]jI58DAAPJ1H6><05_P44HB
%19dXB0X2X;Y80PPR48f;gdSC87j:XY2`K1ZVfOAjW^A134>EaFUU>fk9VP@kSb>`
%L1`6`;0Z32B0415RP2/VLdTTP:0T2MH7FQ=>@l0aKo;L@;T1m=4hOa^VFGI^T<ma
%MZDc>kaYLjSiC@NAk7VlQMVbYMP0ElPR_FXVh@8?:1AZSF452[0m]`006`C6k1Ea
%PoUd=nPe1^3T7H?@O8RPXcJ6P7@U9:0R50JhE46KD@R3;NHF`5FI0`lbJBgQ9Q`B
%H0[fCA03Fnil1`P10R3I@aU^QfakSfC4=HJ8da;2>4fE`P@n1f3b7@74?0P1jUP>
%lOIf`FPZ0T1B2<1h3P8P9060X2`3`9@l02BB=h1D?0RSX>Z>aSfiXi86>R?P@8o1
%1T0>V@BVdb_c7nI]bb_dP;EMVeQ>bS44UPD<deODDTiVY;/AUmY^HGT:DhU1Q@9B
%B^21o:D_`l6PbKQ1:^ET[IGB_BD?>F@:IJ;7003BG0mYM>9KVFi1dZUYX:Dh^PeK
%5C97B;N=DJHeUBP:U]2P0`5@;0F4l9lCk5cZZ8GJN<[@mDj?77o=hc`kSb3d7V@:
%KcM2<UK7bUdOYFao7P5`:/F0D`VQ=0L1@200P5P6U/BELiWRg1AX8R8OhNJ40JXD
%<FQQ0i>T9;M0MnQ6TbX5FFeU0[5QoWd?U99ARLf0>:V>]Xg/<J38:6GBU71bRBd8
%3c@JF5<JIDcYYCDS210bDiYF0=Vh1aYdoYQ94O/QW;;GT<@JH[:0U192I<dTZOP4
%/77L>hMQ6C_;^7bV@OQZao3j?<?ljQgYcS65b<X<XHPWQU3H5P6@A@Z3P>^Xb31i
%1l4d9Y5dPAm2_Sk?0?PCXYaA0R1<2E`A9Hj0RJR/1IYK1M0D/LOZ8Q`5>6KKV]U_
%LVBi9UK^EmRJo2XTe?R?`c`nAl3jRhJemSG4G5bQS9e6Qeb1>?4RSVF`][KFKY]K
%VgE^kNDb53Kn7D>cU2R^8@aOJcIN]eFY@6BQ79OV686=dKPh@6P<0Nm<Th1FhRZG
%N`11=9RI=D>TonN4BRgS85l=H281@;eP7<8dA`O0D0m2P>e4LhAgS/:fVJ0RLicb
%79V?M>lgQm7NO:;Mlh3<5;50C;:ojfhA887n>72R00NZb26>o3BF6c_[Z:]6C=V:
%mWNJAR5/K:HSA6JQA8g>7b2:L7YS5mhoPSHeL:SVJH5Ub3T]kSg7f?lP;D6eT?1@
%34o0;9:5S9D5kV5bTC8Z3LQVU4K8h3<6@=gYPH0^1XJ6GKAg>^L^a/1mX2DFWN?T
%NPkSY3f7TQ@3`6`G3F6N=m^`kA=RC4@8DC8[abhW:n?M/=@k@5LTLaVoPoDiYT?P
%@@BnSG2`C0K@K9hoC7Qgd/GX40bM=HaC2da0V;<@;l>TF0OEHBK[m@TB`/0kiS:j
%7i;Xj9gY<95/ZAaM2iRKH>17[^FdY@Od?b3/7HF`mR6``]144fbJYiZDJ@JC^]i5
%[FTDfNeV4R1]a5H0@0H2090A0YM8Ki_m4GNJj_`OVI4dTPP`EnlYGajSK6^=@1H3
%P>jU84>lM@6`5P96:=DMEmRU3gVl?hNdVAiSfa>WTZ8oS85@TQ;hVcL`[lC<8:<Q
%RW235^5Sa/2?7E?2H/fg?D2d;A[[:d:@C`W09PK0j<@I@bSZSm345`;PaQWSB7P?
%//1;:/YW@??3?a_;LK=A7B@PX_nTH<PR7KYVaNW=k820P3oPD3PT5Pd7Q49QD;QT
%=Qd?R4ARDCRTERd>O/IOTKQQhS`0T4Q0TSIlUPKjU4GUD[UT7SKlQ<_O4cT860X:
%M[/MkoOd4OKkO;nOd`OkmPCmXM6W[lNkgWSkX[jWSfOkhN2`EjZ99A;;lWXf40S3
%851bhHCGLKdXkjL3GJ0B2@LJ3FLE1OkgO[iV3kW]lO=@XdlQE2`Sn0>7U[Na@faQ
%?aceb4_S>1WU2bLWU=7bLIPN4c]2U5BPF4WkkUl3O>YPNWQ6QP[mOSkYfaOklOAO
%<iYF:gFneOZJBRDFboHCa[e5XffXShXD4Oe:U_AR^/Oj5jdQ0OIT:ekT3bN4boBl
%GSlWUlgWm7YmG[mW]mg_QfUPfYO<3GOgT85oF70:4ob1_TPBVW^cch@<QSB/VVIl
%86=L7960Qc7:MAmWdOYjWXYb2<33RS]/Z2NWnOBH<hOL67jYao7/K9]6X0020:4h
%EQTEA:U21H00>D1CUbN[EZXNQgRb;Hd7DZT=7U2jH=4Z2X=[4AlBLPkG84T<0X/U
%k@SO;HCBjH/_/nXJ>85:SJYO<JO9nQ;j8Nd/bYS<JU:<X2V7^Ba=4f;@_2ni0nS`
%?A_7<M3jZ>PBOa2OD@Z>dd3YH`T5c2`PVDVVX30<3]<71CB7^YA]?DoD5@e5DMBE
%;DbEW]E;_8c<YbeL3MH?d0Z@R3F/0CDPCZB_Dkd<9=SG/hPYgf6`CW]6i1nYo@RT
%:6cEPZ>W]S7hn[I:VY1k7HO1iD8Om27VOig7PY2CWXLi[VZ>8kT:LTO7TPD6@I4D
%A:U9bR9jd<2X8Ukn?50K9UAP0;H4Cf2EBZSA^Jn=LGVdB5EnPl1X=;;<f@WT;WWM
%c0YjDYBU6@a348I9T6FE1CUDOR<d@_CH>MI]LcAGR7HSH1nWCV`?i`T;n1mWSj?3
%=<YISXFQj9X^SJ?Y5?hNPHUJJT:@d`3YcjW<ZG_1InT_8Un7/9</5WTN:eDDZZI`
%m3jP>MReX<4i2WZ;Pil7ZObVX71QoAlX]2a4NQB4/BYIUdI2MWnN2RZM3BX:8V1o
%BM/J1h<d[22gbM88_Pf98fKO=1OcP/LmVJ2<PNZGW=dYGM>IgDWYeMlio=KE8:dV
%5]FSUYA8bS@VPIQTRF98T3F=`i7/O:T=Xf4XbO3L:kC[:2M1fDY<8H7YY20G[?h?
%o/mY<kDMQi__o1l?aO7lSf@CIi6oBoSn92Fgg8C<[=jalZ8CNP[ZL[Hk1O/bJnC8
%XM]IPS;[67nQDO8m2NUoA4heaJQ4@[C7n?DN@I`^QL7<]T]D4D15E:6E12cNEY?n
%C8aAO;mRE_b=PVQ0HHhF0UQL=661Q1C`cH41H3<=e9Q<Lh2l0l?HMSJR0a=QYYE>
%T;JF@8O8mbZ4Y8bULL@g1]06<>>m3;3B>A=D<Mh_ZDVD?R>n`UUYcfDU24?6Do9n
%R@S7SDm/NLKGjA_SQ76>DLgVa57n<J?02hm<j<>7F?bnHS[MNljj>Q3hD?MFhP]>
%S;R2TcH?6=U2bB_::9jb`cdHQn;a7d?@O8lRR>`<XF/G@/QH0:0:0M@@lWA[MEbg
%UAJdGm>>856eKi1AiBg9J_TQhXiN@e2A;l5L`A/c3M0Bm0H[IT0:VE30J:]fPT2M
%4cmAkIF4=SA2AY^Q1A0Qk3f=dK0f3V><<jXE9aXX1VD=<DAlC3d[^PH<4>N2/R@P
%?WX>bNdQIlCiWe?^OQj39S`X02NPBUP34Q1_@LjSX9WCBS1?eEIU7X46Oc08_TTY
%9=j7j?=eRQY9baEc92;<1BmSgA<faAATalSjP0gX_J5ZE:<NC08Z@nRm6HHJ_R<4
%9R9DXT6AV@9X@@e1WP4<PdQ23SQZ@B4G5Bi0V5S0iMnjJ4?W8CZ7`?PN0X1@2L<P
%H`bFlZ9@Z/HYID7R;C7j`e]Sm39af8HZhLX5jh7I06O`85MH_bbXMGV_ENjn?TIn
%6:`3Cb@0=/9DPL9m4[V4S]Fb_T^R2YGLR_IoBhiGASA3INSm9UXCGYm9D[b83J`O
%KJKA4D3iFb^G_0UIR7Ja6JXZ//`PYAC2V/aAjTb7Gm46Efc@FM_HKPICLBPjSEid
%<;63LL35bGESdZP@M:i8JgF40J:njTiam3h7^a`D8eec[9UQ9FB/0W5U5_3IQ0<X
%F/[i/DVR8S<212m_PB8TI8F?R6XOGfo5nKmGk>UDIn;lR3Fc5=H9YhY<3GlSSGPQ
%5U<54=>>Ibg1BjE=iCXLMa@nf3Sf>NGHOh00304W:aZ958Jc5<DA;0OmbkM<;=;@
%L6h_<H<o=2eJQ[=46X>45SU<9lg_4Q1ESl5^@D[/o8fXVYae3=fBaXHG9606GbCb
%HVR@nCjW9RWEU=<fD;eiGFOK]3Jck73o47V<k1fG[02^><77J0Y/`5HGV7112KJi
%c]]W@j;EDdIEcSW_13?WiaQ87<<K<NTL4PET5kA3MBIi`ciPVg93;JdnMFWE]YZX
%[U6]I;2LYJbOP00608_2bF4FW:9FMMkRZ>BbQ<JFjD]egA8=COlbTk3BTo4e[N5P
%HfOd:VZQ0T:VQ`>?EEXdRMS256U@F3gIElP2:`0g?HMUmiZT9bm/BcFelkIfUcSG
%;<9F:KFg1?Uo:IF7j^1U^NPULPAK[UY^6Qe]B6fHFBE9Hc:CE6Z8b;/kP62h0490
%5/;8FQaTj@eILV2UP21m3l7h?HP11Qj3j86Ea]RRZ47d7cR?2a2203n8:Z`O<N7d
%7b7CTP4NC1miAamehnI^1k43bmk8OnGlB84=;V`:NL6C3ec/A7?NMQj41d4Mg@`4
%M53CdLPO7nPlLNcbP?ZTH`M>iSc7YgD55MBjV7oZ/eElmHjWe/bYQB1mNjYbSZgH
%nDLa3cf/o`Q<_E6Nf@?J03>jK<2KgMGC2mSK^W7]S>_ObEiKGbI;?oO?3A_Ye]?9
%o;GZ_F[T<cb2IGAN7SU_3B4/GRY=LBkLE<_=o005R:TD`f1US31<283`H`j1k7J[
%VJho`GLhiP7KQHOc[3n7dDkDblbV22468L?W;_PQnc68>@90`kO90Cl/S`N>fYW8
%fUN<XQnFm>iD@8D7f@ZoKk@7gWo<nFeI2PB5O??nUlOn;Uhd_aN?oXc7nXWok?fQ
%loBk=@glLaocoYnonfKQm_i?f_jYW_o@0;j^HR639TbT[T5QL`6R@YU052@WdQ6^
%hUW7<9e=g=/_0=]2::8_525?9_:@A7`;853X`2G`6QL/22@Q9@FSZ>m`AYn[<1kT
%<6e<84;Z00:9j1L;NRRT61lQe1C1@Q;P:PEPK1c_G:@UTRlQjU25^?L3JQk2T1l4
%B6f<A=_:d5W>L0DRBQW]82Q<QUWV3>W?RZ9R2SkQM_6P12://93<W28@fR<@g`g3
%=R4Y5@C32/I8B8`@@R28o0jR@_UP4Zi1Ta2Z9=5`C[g@H]]/6[R>@/R?XA5a97_W
%@:eR=VYQcP?A=<bP1ZQZN5^@:a9]g_<@K3H2VQRWYP7YU1kYL1nT61mQf0o0kPfP
%[Pg0mQdU39:QiRX;/2N1m1jUT_M5gRYUkWKRH9<US]N22;V^?P^aW4baU<_2GQha
%ZA=0?<dR36^RD>C08PYa_487l2IWnRO^h6J=Jab?2acAcab/_UTaeadafacQmaf:
%7/_?1R=`?Af^@S@]U0N/2:10CUQQg`c88S8AA3a]6>`RGWA7laa]Jb3b86RAi943
%j0WB;8cP2]W1eB=R31fb?@B`1b8YlSH=iVe3WQA1@1?PJPIPI1o=kRe5bPB0?P;Q
%@1IQO_FSJT@TW=A4C5276Qm2Z1o9=4ASj`>9W<_9J4^PC9N1A`Gal=^:7R@_[RkR
%VSZ>F`841R@/e]S_n]Z[7b^_n/E`1b_6PBa44B`B@YIXg@?a3Ql:S<`Q^BhP:BiZ
%22@a_0Y/`b2:m?;43b4WX;00a>W:gA/X`BmBAC3T3a;9e>NQ4@ER@;h1N]5@ZA5@
%HC4?:Ti6;1l1k1jQGQFQF04P3P31a1^Q^U^QkPnPj0fP60402QfRX71SSX2QoR/Q
%E2Q>:9F3=2XTb:>=<C<@m66al[^1[R@_TPk3j5lT[b=Qe0RcV@8:L9I321YcY;WR
%@7A6L0?QMC/W8S;Ah:7/Zaj5WC_c^c`ZWC`5TCa;d23Zka`Uh^`bb7FUW/UQICiX
%n00/cQ8Cl=[Bn43B4b71Ocoa0_UQ5d1]GCSbXC;AAA898cd_SR;V7QVd85:P3<c_
%Vd4@>/Sc:<lc^3:3Z8C8kC5=Y66@;R5TD@JC<c=QfQeQe0S0R0QP0R@DGP00H0G0
%HQ`1_Qa9`X721C=Ql038NU4]A:HS0X^bQ4b=D:dR;^QQg370WXMPdDWV21??RP[d
%Z0:d[17D/:072R;R@Phd_0]D`D;3gPhDb3n5I3n?81V:K@4<^b`W`@=284f;<:Y[
%<2TRFYT1FSn>j06:20NDo7CQG:gA7<Wb]c3Da:mZVcKA5<Ze6E6alR1PbE8cj]cP
%I:ke7E;e<E<e=E=e>E>e?E?/ZS@T[XCEB6:39QdED263@TbQ_eFdA]HA@8S3DX/>
%:XUBC2lXU1aDK1e1dQf5E8`2OQn8<[:000100==VfcI82Y:TDZBCM[b>`e?b732@
%DQ<E[E8Pb>B0j<31BCQ?4b5D=<[3@T86XQeec:KE@EdeeEeefEfegE=T1PHEiCjP
%eEjR363:S<E<K>^Egene>;ES;F0e>S_3C2T`JBPZ?@h]096YZ1oQ=f7bj[1>RP4:
%i09f;:jPP?RQAF=QUF>QaF?e3/mWWRQ<28NP3cjc7FD`EZiFD[Y=VFEFHFHfIFIf
%JFJfKFKfL=38d;1FCA>FJ7fDH7eck<cW[B<Cj/c`e2@f9fJF9S3P0FWFDRAfT2@=
%o00P79CP8P3]o??dHVWfRP1UIP0F`P2]oC@eRZ2]?7ZR@01??eSFLa>@8FDfQF^f
%P6WT8=OFMF`TG[ifefRc7FNfgg0g1G1g2G2g2SnG000FU[15I9iC7EkUDfYg3G9g
%:FIDHg;R@:iP104P20301g<dHC7FifHflFEF9f8VWYj07fD;11DgGF@/hRG/_AU2
%E6^@n38AZ1hd@gH:RXVadDBT==hRQ>5PoA[;VT5a]66cRbUD@242Gd]0JgXW9P]R
%34Z:c[[Z<2SWE]G[:851kSABGDMQlQl84210Y7?529eBM;CdRRZTW76SY;VT`VOa
%f<][4@l45e[1<2@b2GJGN2ET[gLYRTdGkTY39V3B6caVSDh=hZ?8TTCZF<D<6S1Z
%WUDf7Q=P8H</25IDmgE0Mh?cl18BV1THBB?1fccGoYl5o5WgTD3eXedY4946OgKE
%oHJhKHKefVO`nde_k/<5D]40_0MHQEc1ehHZXQnE/Do0NHC2IF6W]S51_:h0;^I/
%iC^BMgO6d;:cK6dT@`Z563:GT<AUiETggUXT25^eT5aee<Ua7hFAa<ohf25a<2h0
%9=P=Q63X`hLHmHmhnHKYWBcHNi0682V[4hnhnF03Wf1E<[=<<H8BLTA@ZT?RTc5H
%hf5QoQJI<3nG5P00QI>QHi?hk@;HNhJC:hDY2aU;e:W2FT5Xk4[d6iC?2H`HgXDY
%<RIi>PQ0XiLaU3ZHRCV0RUJPPgi<Z8`8e1S[OQ?iT>[Em<g5UUU<RZ<2D6k2Y1lb
%PZ<RS1gW5/i`U/9dQ55eWZH;93aeA65iMa8/5Wi3j0RIe>fY0iBiC29UlelChic5
%mBWh9eH7`h6?;`[DS>9Qo1_Q]1^I8DTB]`;QRJ3d91:j5IU[V`/GMig[m41ch@ji
%Qeeba7cWL@mi3J=j>EoC]U5IHR1eD1dBU0ijC7A?h1mVK1dei0H470eba<`i?QHd
%[0:jIR1fAj@4hZ<5UEVIZAi]j2Y1nQhTC1hd]Qg41@W5LTV3A66]C4D;E3OCNbCE
%daX<fZ7_X@<IciJ237DQW>Ud>eC<`J>jbJbjc55IGd5IDU5AUE;JchLf1I4E<h7W
%mQjaQ6lQd1aQb_?QIQG1H2P@/^`ceR=T1c0=LW8EPR=V7f5:KJ?j8:m8k@5Dg2;C
%Wa@Z6IkiC8C1[K=P>K>Q6K?XC<]bhQ^8JQ5KC9fj[UW1>KE[TP<1UkGhSBbceG/e
%X5akK3HRZJQRN1kQeRSD]X54WQKQG1GY<YEZHYa@XEU[Lcmj2H6Z:9e2GZi8D<`Z
%S8Q4`]SB4k7R8/V]IW_4h<^5V55IQ7_im7H[K@KST83Ql0Z0WPXQ[8H0GPFPG:01
%k=5][]7S:Y<c=V;9;4?2290T[]SBbK]L2L2`kHW211OL5C[dXbfR3L51OL66224a
%U>IP=L;eFQ_U6RU4@DPQi]j3AVDDHV;9[SV]j/7[`:><]Dk3J8^lGK`lCIn[L;:1
%oSn777XKZH5L3LMS1kJg/[FWT]BSATVTDQmQIQH1K121112SWQk1Y1Z1XPZP^0eB
%g:<8aT@;bSj]C76;CKk[:lNL`L`RFVOQElb]WJKj]R1lbQElci?gZ]_dMUDPblie
%:DUE_Sf;c8?Zl3nK9@1[?L^LOH]2RTBM2EXKcAG2YLQK03j481j38a5>[HDLaLaL
%DlIbC;CUjVGRWQkQiQh0j0gPh[[T=2ISHQ0Q61?1X1/1fYa4c<CRl/<CMaG2RZHM
%<dT30bMm9mLmMHZ/[17mOL;P=J_C2<XQnMO17mPMQ7HgKX99KbkPSmWdU5BUX/A8
%1;;:i21[3C/QMHkloWoKK8D98Y8dPDPD5S>?GRV7R1lL@21R@QW2BkA]GJ2b_bdm
%Ml`M:lD/jjYTiQkJQ3=89AL<DVgT@Vl1hUUS=2RGh2TMIN5mJGf2O@UMjn8mMS9^
%F/OPEHX<m<f=@Qnn:/On<IEN=21hCH?PMP`NCIUgo3gSHh9KlGc0Y0Y63=WCoQO_
%1W63Tm:a/WmDSW7:;TAl_QkM739R@PAPB0BB1@/Lkn9MLmkkU[L]=l^SA2=QEQCQ
%<PNPKPCQU1Q1NQ3Q3160@PEPP1abL5kS8:B8881MHTCn6WTVaggVmNUNhLMjIPLn
%jD]C_2Q7lninjZ0NkbQL41okF`1B]ig3c822N[/:E;A23e/EjPe:5R<RVVl4>97;
%b=jlDngO:S?He?k/g6;8fQhXNP2QKQLQK24kYn@NhmM4>Dh2nTbJjDQVGQkQgQa0
%9@8Pc0]P[QC1@1DG50>QfRW:J5X4WAP:HcIL]nei`Z@mL6HR0X0oh50h91H=1hA2
%HE2hI3HM3hQ4HU4hY5H]5ha6He6hi0TO7gY8H6oI92Gg9hnSi2m979HA9gg0e;<i
%JoGm=h==gm7HVnWbo7o>j30Z51F5A`oBGEBgaCH@oI>nI9<H7@Z]@go@:cA:i1J4
%o:1H:2oCRLCN0;@o7lngeKKM<8CH7i97k?;]MkaNKeNkiOHIEjaEi/ojXog`mW^o
%k[RWdefHa0EJ5<V4Vhfhh@H51>hWOGI]E7[HH5DlI@GgFZYFX;E:YRkm[mQ/MU/m
%Y]M]]khm]e0jJn7__hI^W]_:K_lC1Mk>X7L=7;]a1:^o/G>iQKQEeeCfNHoiGd;[
%d/E@:5RnWF:eijkd>JnI2e6Td@T4PP1@:0Ig[Y[M:[>Yacolol0@30B_:jX1n`<[
%BQ:RPAm:bNJ/WXDa=4d4ChWnOAj4^Ai6Sh@Y:9Hl:^7TZAl84NamY`kl6/8e3dX8
%eSA`76DIaY6/KA_0Bi8<kJ1adPDOANTj3B0V/R8:O<T?lOTD:6l4VY^@dXP9:Jd0
%00D[bZ0<]BZ0Bd02]4^P00JdC60DaP9;h2;A=@0CI=@0c3<80Bn002[A>di[@DAA
%51:[kahQ2M?e752D;@dI>R[T3aI4:]Z6aLBWo1io7/60@Q<GQEUN`ah2D88N4>B1
%=VTKaf?0Maf7J90WRVAi<4jO3_Z[5KCX4ZRR/DaC5YSG53emGmPF3HEQf8RcZ9n`
%9oVcIH9fJ0Sj9/jCWFB[:eBBTZ]AFm45=5Ab[?jXQnTJAI51l7PM]7:H1?_H]fgM
%MjkDCAjPEZZ4OdDPE8WXNih7@4h=0nOIe7POihWF4@<PX<0d3TN:jWbO5N7j?i34
%HJ9/W3FmIe/ZQlaL^ZGEiN6Ai9T^CI?U27/?ScZ7eF@QIPB>IClQ1m7`O9o;WGC2
%9RTQ>4ZC080B21[6PK1EU@E`70J2Ag7NNJ]7YVl4X591lW2Ki`0`2`:VjKI]=nN/
%lgIU>bk=H[0:jnl4G_NInW^]IjDY1im[[Ud;a:O9kdRhM`WXMigRB9XZ7U1[D^W5
%ImHk5cV[6[6clQb?9LWbRo9fOVG9lOQcW<M9LUdGEXP7:KafVWNmERYbBi_2inTH
%@I40>003T^B9<6XJI/:o]Yl;WWB1VBHiT6TJ1XX=:Zi_ab_UnI030:_9TV:Q8CbK
%/N[37SWQoiaSaoWPNjf7/NI/VVJ90MQB;F;DX?4lGajFlMG_VoWnWjo]U3bgV`dT
%=>OP^1M2jg]B9@BK/fIHSm0aMFM506D<4H`5`80G7^?54Y>bQ=g7dM@dL5VZY9E`
%?6401`408OjoN4d9bl`LFC1T`a8d38[>VB`Oa;5j_K84?LTXoQl2B4D8LI0b1W5D
%7]0LXSkFZ^<OR[:54BhVA=RLKPWK=Vj]D<0?T]YP2h;7@JBB7B9G58G7l:DCPX@<
%PB0^?4MPl689<DM3QAKfam?[LL?N8JbD`?bRO7V9ii3e;D@^_TiAEhY42N^?lhKY
%al3nNk1TOXga/3@0b101HaQSS;:Tje]DAXK:>SjfV?DWi@BQU4@/Z478eZ?9^lUV
%k>42aLIdH/]ZS8hS/72><?HLPkPJ0V1PHh`QS2l5f;j:aHS2B0?jJN5D5SbSe7]8
%VDLci?_bAP^52l[8>=e@^hZ=kQHF4a7/>d`T<U_C:R:_UmaZRZ]ZVQ>^MTkHCAl:
%6F``IF7nU2R]2aA@n8]UeKf5l:PEP9P80D?`N8ma<2?4X0`0X2Qd>MMg<F?lm2e4
%nDX?E1[;J9AhWMA]bIh:?CZ=8[ZE<=g3:fY<H=S`oD7SjL:a5I1>3V:AHS4NCTjH
%oDLYaCVWBkW;]gT4BL`2dIk99Y/T8/DEY<@H<8?JRhofmaaY<XiVlK5Z4k=lbj5E
%>j];]TlS6HYh9hCc9Pg17kUbMSf;0cdV;jjDT/7j?HZ1JRM]kW@?ia:1V=84OOE^
%_UOJo>ANO>ZVm=Z^T:EkAZ_mREQWh/;?2Z]PTHU[==9d[ai;2f:/aIVcEVk>FM/m
%Ind5XKAFS]9JF_Y0@0003@4000<000010GD0004100<000010A<0004200<00003
%003B9P4300<0000100D0004600<000010080004A00@0000:003B;04E00<00001
%00<0004F00@0000100007@4G00@0000:003BE04J00D00001003BO04K00D00001
%003BQ04L00<000010040004X00<00001008000000000200800P000080004CP00
%3lD002LV001?Q@00Le800926002V6`00]/L00<^K0004AP002gL001MQ000XG`00
%8ld001dd000EU@004:`001CD0005j00:o80002L@00[lP0009a001`2^07X01`01
%00400`0300@0000=00`0405e0GD1M@5e02P0O@25455eJF=[E6U]IJXPHFiT8640
%02P0R@1]5eA9ATHP:4aJEbTPI6ESKfe`LVEcLfmb02P0U@1M7f5bIB1^IFETIF@P
%M6lPLfEU87AXJG<PL6USM7EbIBh0003o\\>\"], \"Graphics\",
%  ImageSize->{373, 275},
%  ImageMargins->{{0, 0}, {0, 0}},
%  ImageRegion->{{0, 1}, {0, 1}}]
%%EndMathematicaCell
1 setgray
4 279 moveto
377 279 lineto
377 4 lineto
4 4 lineto
closepath
fill
gsave
4 279 translate
373 -275 scale
1 string
373 275 8 [373 0 0 275 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFEFBFFFEFB
FFFFFFFFFEFFFFFEFFFFFFFFFFFEFDFFFFFDFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFFFEFFFFFEFF
FAFBFBFEFFFFFEFFFFFDFEFEFEFFFFF9F9F9FFFFFFFFFEFFFFFBFBFFFCFC
FFF9FAFFFAFDFFFAFDFFFAFFFBF6FAFFFEFFF7F8FAFCFFFFFBFFFFFCFFFF
F8F9FBFEFFFFFFFEFFFFFEFFFFFEFFF8F7FAFDFEFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFEFDFFFDFFFFFDFFFFFDFEFFFFFB
FBFBF7FEFFFFFCFEFFFCFEFFF6FCFCFBFFFDFBFFFCFEFFF9FFFDF4FFFDF6
FDFBFCFEFEFFF7F8FCFFFFFFFFFEFAFFFFFAFCFFFDFBFFFFFEFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFEFFFBFAFD
FEFFFFFEFFFFFBFCFCFEFFFFF9FAFAFEFFFFFFFEFFFDF8FAFFFDFDFFF7F8
5F545613080AFCF1F7988F940C050AE8E6E9FEFFFFFCFFFFFBFFFFFAFFFF
FEFFFFFBFCFEFAF9FEF6F5FAFFFEFFFBFAFFFEFFFFFBFCFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFDFDFB
FFFFFDFDFEFEFCFFFFF7FAFFFBFFFFFBFFFFFBFFFDFEFFF9FFFDF3FFFAF2
FAF8FBF9FCFFFEFEFFFBFBFBFFFFF8FFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFEFFFEFFF9F8FBFFFEFF
FDFEFEFCFDFDF8F9F9FEFFFFFEFFFFFCFDFDFEFCFDFFFDFFFFFAFAFFFBFC
FFFAFCECE1E37B72771A1318C7C2C6BCBBBEF9FAFCFCFFFFFBFFFFF8FEFE
FEFFFFFBFCFEFFFEFFFFFEFFFEFDFFFFFEFFF5F6F8FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFBFFFFFBFFFFFFFEFDFF
FAF9FEFFFEFFFEFFFBFDFFFAFAFBFDFCFFFFF2FAFAFEFFFBFFF6EDFFFBF4
FFFEFFFCFFFFFEFEFFFEFDFFFFFEFAFFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFAF8FBFDFCFFFFFEFF
FEFFFFFEFFFFF9FAFAFEFFFFFEFFFFFBFBFBFFFEFFFBF9FAFFFDFDFEF8F8
FFFAFBFFFAFEA59CA1191217F1ECF0F9F8FBFEFFFFFCFFFFF7FDFDFCFFFF
F9FAFCFEFFFFFEFDFFF7F6F9FFFEFFFFFEFF000002FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFFFAFFFFF8FEFEFEFFFEFF
FFFEFFFAF8FBFFFFF5FFFFF6FFFEFFF9F8FEF9FFFFFAFEFDDFD8D019100B
C6C7CBF9FDFFFAFDFFFFFEFFFFFEFAFFFFFAFBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFDFCFF
F8F9F9FBFCFC5C5D5DF7F8F8FFFFFFFEFEFEFAF8F9FFFEFFFFFCFCFFFDFD
FFFCFDFFFCFFCAC1C6171017F7F1F8FFFEFFFEFFFFFAFDFFFAFEFFFBFFFF
FDFEFFFEFFFFF9F9F9FFFEFFFFFFFFF1F1F1070808FBFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFEFFFFFEFFFFFEFFFAFEFFF8FFFFFFFDFCFF
FDFAFFFFFDFFFFFEF4FFFEF4FFFBFCFFFDFFF9FFFFF7FDFDFFFEF8928A87
C8C8CEFBFFFFF6F9FFFEFFFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFEFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFAF9FCE7E6E9
B9BABAFDFEFE030404FEFFFFFDFDFDFFFFFFFFFEFFF9F7F8FDF8F8FFFDFD
FFF8F9FFFAFD8C8388070007979198D4D3D8FEFFFFFCFFFFFCFFFFF8FCFD
FCFDFFFFFFFFC9C7C8D2D0D1FFFFFFFFFFFF000000FCFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFEFFFBFEFFFDFBFBFB
FFFDFFFFFDFDFFFAF5FFF8F1FFFBFBFFF9FEF9FFFFF0F7FBFAF6F3D9D3D1
808388F8FFFFFBFFFFFBFCFEFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F6F9FFFEFFFBFAFDFFFEFF
424242919191000000FEFFFFFFFFFFFFFFFFFAF8F9FEFCFDFFFDFDFFFBFB
FFFDFD9C9598100910D6D0D8ABA8AE0E0D12EEEFF3FCFFFFF4F8F9FCFFFF
FEFFFFF9F9F9E1DFE0181615DDDBDAF7F7F5000100FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFDFCFFFDFCFFFFFCFFFFFEFFFDFCFDF7
FEFBF4FEF6F3FFFBFDFFFAFDFFFAF8FFF9F7F8FFFFF6FFFFFFFEFDF4EFEF
494D54F2FAFFFBFFFFFCFDFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF9FCFFFEFFFFFEFF
D9D9D9131313040505FDFEFEFDFDFDFFFFFFFFFEFFFFFEFFFFFCFCFEF9F9
FFFDFDFFFCFFFFFAFFFFFCFFFFFCFFFEFFFFFBFCFFFCFFFFFCFFFFFEFFFF
FEFEFEFFFFFFFFFEFD8D8B8A3E3C3BFFFFFD040402FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFBFFFFFCFFFFFEFFFDFFFFF8
FFFFF4F7F0E8271A1FFBEAF0FFF1EB221914606872F1FDFFF9F8FBFFFEFD
7F868CD1D9E1FBFFFFFEFFFFFFFEFAFFFFFBFBFFFFF9FFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFEFDFFFFFEFF
FEFEFE868686040404000000020202000000010101000000020000010000
020000030000030002030004010004000004000004000004000102000002
000000010000050000050000010000A2A2A0000000FEFFFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFCFFFFFCFFFFFEFFFDFFFFF8
FFFFF3FFFEF6302126BCABAFFFF8F04A413C87909BD2DEECFEFDFFEEECED
484F538F989DF8FDFFFEFFFFFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
F8F8F8F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFF8F8F8F7F7F7
FFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFEFDFFFFFEFF
FBFBFBFAFAFA2A2A2AA9A9A9FBFBFBFFFFFFF4F4F4FFFFFFFFFEFDFFFEFD
FFFDFCFFFEFFFFFDFFFFFDFFFFFEFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFF
FFFFFFFFFEFFFFFDFDF9F4F4D4D2D1121210050501FEFFFDFFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFDFCFFFDFCFFFFFEFFFFFBFBF9FFFFFA
FFFCF3FFFCF4A69A9A221212FFFAF4978F8D7C8594F4FFFFFDFCFFFFFEFF
F2F9FDF8FFFFF6FBFEFEFFFDFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FF4F4F4FFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFBFBFB8F8F8FF4F4F4FFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFA5A5A5FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF9FCFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFC2C2C21F1F1FEAEAEAF8F8F8FFFFFFFFFFFFFFFFFDFBFBF9
FDFDFBFFFFFFFFFEFFFFFEFFFFFEFFFEFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFEFFFFFCFCFFFCFCFFFEFD71716F000000FCFEFBFAFAFAFAFAFA
FBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFFFF8F6F7
FFFDFFFFFDFAD7CCC40A0000A69893E3DCE10C1427E2EFFFFFFEFFFFFDFE
FBFFFFF5FCFFFCFFFFFDFDFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB1B1B1393939F0F0F0FFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFB1B1B1393939F0F0F0FFFFFFFDFDFDFEFEFE
F8F8F8FFFFFFFFFFFF181818838383FBFBFBFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFEFFF8F7FAFBFAFD
FFFFFFFFFFFFFFFFFF6464646A6A6AFFFFFFFBFBFBFDFDFDF7F7F5FFFFFD
FFFFFDF8F8F6FFFDFEFEFDFFFDFEFFFDFEFFFBFFFFFBFFFFFDFEFEFEFEFE
FFFDFEFFFEFFFFFBFBFFFBFBFFFEFDF3F3F1070705B7B9B6FFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFBFFFFFAF9F7F8FFFDFF
FFFCFFFFFCFCF7EFE2120A00665B57A6A0A800081DEDF7FFFAF9FFFFFDFE
FBFFFFF5FDFFFCFFFFFFFFFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD7B7B7B2A2A2ADEDEDE
FEFEFEFEFEFEFFFFFFF7F7F7FDFDFD7B7B7B2A2A2ADEDEDEFEFEFEFEFEFE
FFFFFFF7F7F7FFFFFFEDEDED3B3B3B606060F4F4F4FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFF525252F6F6F61B1B1BBFBFBFFEFEFEFFFFFFFCFEFBFDFFFC
FEFFFDFEFFFDFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FDFBFCFFFAFCFFFDFFFFFDFFF6F4F5FDFDFD000000232424EFEFEFFEFEFE
FFFFFFFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFFFBFFFFFAFFFEFFFFFCFF
FFFAFFFFFCFCABA7993D3727CAC2BD87868C212B40E3EDFFFFFEFFFAF5F5
F7FBFCF9FFFFFEFFFDFFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC8F8F8F1A1A1A
CECECEFFFFFFFFFFFFFEFEFEFEFEFEFCFCFC8F8F8F1A1A1ACECECEFFFFFF
FFFFFFFEFEFEFFFFFFF5F5F5F2F2F2535353474747EEEEEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFFFEFFFFFEFF
FDFDFDFEFEFE030303FFFFFFE1E1E1BABABAFFFFFFF6F6F6FEFFFDFCFEFB
FEFFFDFEFFFDFDFDFDFDFDFDFCFDFDFCFDFDFAFEFDFAFEFDFCFDFDFDFDFD
FFFEFFFFFDFFFCF7F9FDF8FAFFFEFFFFFFFF000000CECFCFDCDCDCF2F2F2
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFDFFFDFDFFFDFFFBF6FA
FFFDFFFFFDFDF5F2E9FFFFF4FFFDF6FEFFFFF5FFFFF1F9FFFFFDFFFFFDFD
FCFFFFFBFFFFFEFFFDFEFDF8FFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB
1B1B1BB1B1B1FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB1B1B1BB1B1B1
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6656565323232EEEEEEFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFBFAFDFFFEFF
FFFFFFFFFFFF010101FAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFEFFFDFCFEFB
FEFFFDFEFFFDFFFFFDFFFFFDFEFFFDFCFFFDFCFFFDFCFFFDFEFFFFFFFFFF
FFFEFFFDF8FAFFFCFFFFFDFFFBF9FAF9F9F9040404F4F5F5FCFCFCFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFBFFFFFCFFFFFCFC
FFFEFBF7F3F0746F71FAF8F7FFFFF8F8FCFB818C9ED0D8EDFEFBFFFFFCFC
FEFFFFFAFEFDF9FBF6FFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFDFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
BEBEBE1F1F1F9E9E9EFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFBEBEBE1F1F1F
9E9E9EFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF8181811A1A1ADFDFDF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFBFFFEFDFBFFFFF3FAFF
FEFFFFFEFCFD010000FFFEFDFEFFFFFDFEFEFFFEFDFFFDFCFEFFFDFEFFFD
FEFFFFFBFCFCFEFEFEFEFEFCFDFFFCFBFFFCFDFFFCFDFFFCFDFEFEFEFEFE
FFFEFFFFFAFCFFFDFFFFFDFFFFFDFEFFFFFF010101FEFFFFFFFFFFFEFEFE
FBFBFBFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFCFFFFFDFFFFFEFB
FFFBF7FFFEFBB3B0B6848285FEFDF6D2D4D1555C6AF8FDFFFFFDFFFFFDFD
FDFEFEFBFFFEFEFFFDFFFEF9FFFDFAFFFEFBFEFFFFFCFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF4A4A4A0000000000001D1D1DE7E7E7FAFAFAFFFFFF
FCFCFCFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF9F9F9FFFFFF
FEFEFEFAFAFAFFFFFFF8F8F8F2F1F4FFFEFFFFFFFFF8F8F8FFFFFDFCFCFA
FBFBF9FFFFFFFFFEFFFEFDFFFFFDFEFFFEFFFFFDFDFFFEFBFFFDF6FFFFF8
F5FEF7F7FFFFFFF8FFFEF5FFFFFDFFFFFDFFFFFAF4A49695B3BAC8EFFFFF
F0FFFDF7FFF7FFFFFBFFFCFFFFFCFFFEFBFFFFFEFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFCFCFCDBDBDB2F2F2F585858F7F7F7
FFFFFFFFFFFFF5F5F5FCFCFCE6E6E6AEAEAECECECEF4F4F4FEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFCFCFCFFFEFDFFFCFCFFFDFDFFFFFFFAFAFAD0CCC94B4948
6B6E72F6F9FDFEFCFBFFFDFCF8FBFFFCFFFFFFFFFFFDFBFAFFFFFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFBFBFBFFFFFFFEFEFE
C0C0C00000000202020101017F7F7FFFFFFFFCFCFCFCFCFCFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFF9F9F9FFFFFFBBBBBB000000050505010101848484FFFFFF
FBFBFBFFFFFFF7F7F7FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFDFDFD
F8F8F8FFFFFF6B6B6B040404E6E5EAFBFAFDF5F4F7FFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFCFAFBFFFEFFFFFAFCFFFDFDFFFBF8FFFDF7FFFEF6D9DAD4
000405272B32AA95A10B0007A0A7B9F5FFFFFFFCF6FFF4EF595B68EAF6FF
F7FFFFF2FDF5FCFFFAFFFFFBFFFBFFFFFCFFFAF8FBFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFAFAFA6F6F6F262626C5C5C5FFFFFFFEFEFEFCFCFC
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFDFFFEFDFFFBF9FCF7F7969A9B5A5E5F
FFFDFD7D787ADEE6E8F9FFFFFFFDFFFFFBFBFEFFFFFAFEFFFFFFFFFDFBFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFEFEFEFEFEFE4C4C4C
0000000606061D1D1DE0E0E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D3D3D020202000000262626
EEEEEEFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFDFDFD
FAFAFAFFFFFFFFFFFFACACAC040308121114DDDCDFFEFEFEFFFFFDFBFBF9
FFFFFDFEFEFCFCFAFBFFFEFFFEF9F9FFFEFBFFFDFAFFFEF6FFFDF5DBD7D4
0B0E1DFAF8FFFFEFEA1B0B09C5D5EAEDFFFFF7F7F5FFFEF6FEFDFFF3F6FD
FFFEFFFFFEFFFFFFFBFCFEF9FFFFFFFBFBFBFFFFFFFCFCFCFCFCFCFEFEFE
FFFFFF575757A3A3A3FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
FCFCFCB1B1B1111111989898F9F9F9FFFFFFFEFEFEFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBF9FFFFFBFFFBFAA49E9C131B1DC4CACA
FFFCFD625C5CC6CFD2F0FBFDFFFDFDFFF9F7FCFFFFFBFFFFFAFAFAFFFEFD
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF090909020202
000000767676FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDADADA0C0C0C0B0B0B000000
585858FFFFFFFEFEFEFCFCFCFBFBFBFDFDFDFCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFEFEFE33323700000218171AD0D0D0FBFBF9FEFEFC
FEFEFCFFFFFDFFFEFFFCFAFBFFFDFFFFFDFDFFFDFAF9F4EEFFFEF6F2EDED
1E1B2ED6CFDFFFF9ED9B93888599AFE5FDFFFEFFFFFFFDF7FCFEFBFDFEFF
FFFCFFFFFBFFFDF8F8FDFCF8FCFFFDFBFFFFF7F8F8FFFFFFFFFFFF979797
0101010D0D0DFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDF9F9F9
777777202020C9C9C9F4F4F4FFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFEFDFFFAF8FFFCFCF8FCFDFCFFFF
FFFDFDFFFDFFEFF7F9F9FFFFFFFDFFFCF6F6FEFFFFFCFFFFFCFCFCFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFBFBFBFFFFFFFDFDFDFFFFFFFCFCFCF3F3F3232323000000000000
3F3F3FFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA1A1A1000000050505
030303A2A2A2FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFEFEFE
FCFCFCFEFEFEFEFEFEFFFFFFDDDCE10D0C0F000002050505ACACAAFFFFFD
FBFBF9FFFFFDFAFAFAFFFFFFFFFEFFFBF9F8FFFEFBFFFEFAFFFEF6FFFCFF
C8BED6110517FFF8E68D8E7C283D50EDFFFFFEFEFFF5EFECFAFFF8FCFFFD
FFFBFFFFF3FFFFFAFFFFF9F7FBFFFDF5FFFAFCFFFFB7B7B71717170C0C0C
090909F3F3F3FFFFFFFDFDFDFDFDFDFFFFFFFAFAFAFFFFFFE1E1E13D3D3D
434343EFEFEFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFDFFFDFBFCFFFFFDFDFDFB
FEFDFFFEFDFFFEFFFFFEFFFFFDFCFFFDFCFFFFFFFFFFFFFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F4F4F4FFFFFFFFFFFFFEFEFE464646010101030303161616
E4E4E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF646464000000
030303070707D3D3D3FFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7FFFEFF4A494C0A0A0A0000000B0B0950504E
EEEEECFFFFFFFDFCFFFFFEFFFFFEFFF9F7F8FCF7F7FEFAF7FFFFF8FFFCFF
FFF3FFC6B9CA65624F656C58324554E0F1FFFBFBFFFFFEFBFBFFF8F9FFF9
FFFCFFFFFAFFFFF6FBFFFDFBF4FDF89DA7A2222625040404000000222222
FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFBABABA141414838383
FFFFFFF9F9F9F8F8F8FAFAFAFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFDFDFDF8F8F9F9F9FFFFFFFDF9F6FEFCFB
FCFFFFFCFFFFFEFCFBFBF9F8FAFDFFFCFFFFFFFFFFFFFDFCFEFEFEFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFF
FBFBFBFFFFFFFFFFFFF1F1F1FFFFFF919191030303000000000000B6B6B6
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3292929
000000000000343434F6F6F6FFFFFFFAFAFAFEFEFEFFFFFFFCFCFCFCFCFC
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FBFBFB
FFFFFFF7F7F7F9F9F9FFFFFFFEFCFFD5D3D60A0A0A000000000000080806
1516169E9F9FFEFFFFFDFEFFFCFBFEFFFFFFFFFEFDFFFFFBFBFAF5FFFCFF
FFF9FFFFF5FFFBFBEEFBFFF4F3FFFFF5FFFFFCFCFFFFFFFDFAFFF9FBFFFA
FDFAFFFEF4FDB8ABB0534D4D0E1410020B06000000000000000000FCFCFC
FBFBFBFCFCFC515151FFFFFFFDFDFDFFFFFF7979791A1A1AC5C5C5FFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFDF8F8FFFDFDFFFFFFFFFFFFFEF8F6FFFDFD
F9FEFFF6FBFEFFFDFDFFFBFBFBFFFFFBFFFFFBF9FAFEF9F9FFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFDFFFFFFCBCBCB000000030303000000797979FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAD7D7D7
0E0E0E0000000808086B6B6BFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFF7F7F7FFFEFFFEFCFF494949000000050503000000
0000000304040B0C0E808183FFFEFFFDFCFFFCFCFCF9F7F6FFFFFBD6D1D3
968E9BFFFBFFFFFFF8ECF2E8717880F5FDFFFCFFFFFAFBFD555A54242923
0F0E1109030A160F12030000000100000100050606222222EAEAEAF9F9F9
FEFEFEFFFFFF030303FFFFFFE8E8E8404040414141E9E9E9FFFFFFF8F8F8
FEFEFEFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDFDFDF8F8FBFBFBFFFFFFFFFDFDFFFBFB
FBFFFFFBFFFFFFFEFFFFFDFFFBFFFFFBFFFFFCFCFCFFFEFDFFFFFFFDFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8EDEDED2525250000000404043F3F3FF0F0F0FCFCFC
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8B8B8B040404000000010101A9A9A9FFFFFFFAFAFAFEFEFEFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF919191020202303030AEAEAE
FCFCFCFFFFFFFFFFFFFEFEFEFBF9FCFFFEFFA4A2A30D0B0C010100040402
232424232424141517000004414246FEFFFFFDFEFEFFFFFDFDFDF9FFFFFD
555258D8D5DBFAF5F7888687AEADB2F8FBFFF9FFFFF9FFFF777976383836
161518000002080909010202030000030000141213EBEBEBFFFFFFFFFFFF
FFFFFFF8F8F8060606B7B7B7171717808080FFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFBFBFBFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFBFBFFFDFDFFFFFBFAFAF8FFFEFFFDFBFE
F2F6F3FBFFFEFDFCFFFCFBFFFAFEFDFCFFFDFFFFFFFFFEFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF2F2F2FFFFFF
F7F7F7FFFFFFFFFFFF5555550202020000000D0D0DDDDDDDFFFFFFFEFEFE
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FDFDFD525252040404000000171717E4E4E4FDFDFDFFFFFFFCFCFCFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFBFFFFFDFFFFFFFEFFFFFEFFFFFDFBFEA19FA2DBDBD9F1F1EF
FBFCFCFEFFFFFDFDFDFEFCFDFFFEFFFFFEFFFBF9FA06040500000050504E
242525EFF0F0F9FAFCFEFFFFF4F5F9F6F7F9FEFFFFFDFEFEFFFFFDFCFCFA
E6E7E948474AD1CBD2595458FFFEFFFEFFFFF4FCFEF9FFFFFEFFFFF9F9F9
F9F9F9C3C4C6161A190607070300000F0909C8C6C7FCFCFCFFFFFFFCFCFC
FFFFFFFEFEFE0000001B1B1BC0C0C0FDFDFDFBFBFBFFFFFFFBFBFBFDFDFD
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFBF9F8FEFEFAFFFFFDF8F6F9FFFEFF
FEFFFDFEFFFDFFFEFFFFFEFFFCFEFBFEFFFDFFFEFFFDFCFFFCFCFCFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
FFFFFFFFFFFF909090020202000000030303ACACACFEFEFEFFFFFFFCFCFC
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFEDEDED1C1C1C0202020000003E3E3EFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFB
FFFAF0FFFEF4FFFFFBF7F8F8FCFFFFFBFEFFFEF8FFFFFBFF94938FD6D8D3
FBFFFFFCFFFFFAF8FBFFFDFFFFFEFFFFFFFFFCFCFC4545450B0B0BAFAFAF
6A6A6A4C4C4CFBFBFBFFFFFFFCFBFEFFFFFFFCFCFCFFFFFFFBFBFBFFFFFF
FCFCFCABABAB020003E9E7E8FFFFFFFAFAFAFEFFFFFBFCFCFFFFFFF8F8F8
9898981515158788880A0A0A100E0F6A6869FEFEFEFDFDFDFFFFFFFFFFFF
EBEBEB4343432C2C2CE3E3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFEFEFE
FDFDFDD2D2D20909090000000000006A6A6AFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF9F9F9
FCFCFCFFFFFFBCBCBC010101020202030303828282FDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFDF8
FFFCF1FFF3E5FCF9F2FCFFFFF4FDFFF9FDFFFFFBFFFFF7FFFCF8F571736E
E6F2F0F8FFFFFFFEFFFDF6FBFCFAFBFCFCFCFFFFFF838383000000D8D8D8
FAFAFA3D3D3D858585FCFCFCFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFDFDFD
FFFFFFFFFFFFD4D4D4FCFCFCFEFEFEFBFBFBFCFCFCFFFFFFEDEDED505050
393939D7D7D7BCBCBC060606212121FFFFFFFDFDFDFFFFFFFEFEFEBDBDBD
121212818181FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFF
F1F1F12A2A2A000000030303313131FEFEFEFBFBFBFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF7E7E7E000000000000050505C7C7C7FFFFFFFDFDFD
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF9FFFFFCFCF8
A28E8511000079746A8F9893000911CCD5E0FFF7FDECD9DBFFFBFC828685
ABBFBDE9FBFAFFFBFFFFFAFFFFFDFFFFFFFFFFFFFFA6A6A6020202FFFFFF
FDFDFDE7E7E7191919BABABAFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDC2C2C2202020727272
F0F0F0FCFCFCB0B0B0000000A3A3A3FEFEFEFEFEFEFFFFFF8484841D1D1D
BDBDBDF9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFB
5F5F5F000000000000121212D7D7D7FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF8F8F8FFFFFF
FFFFFFFBFBFBF6F6F6FFFFFF474747000000000000272727EAEAEAFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF5FDFBFDFDF9
54413AD2BEB5EDE9DD000400495760C9D2DFFFFBFFD0C0C131282B090D0E
D9ECE8F4FFFFFFFDFFFFFBFFFEF9FBFFFFFFFCFCFCF2F2F2888888F9F9F9
FFFFFFFCFCFCC2C2C2121212DBDBDBFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFF8F8F8FFFFFFFBFBFBFFFFFFFBFBFB8A8A8A1B1B1BB0B0B0FCFCFC
FFFFFFFFFFFF797979040404FFFFFFFAFAFAECECEC454545373737E4E4E4
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F99A9A9A
0A0A0A000000000000A2A2A2FFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFBFBFB
FFFFFFF9F9F9FEFEFEFFFFFFDBDBDB101010050505000000545454FFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFB
857C779B928BFDFAEFC1C3BD0B0F18F4F6FFFAF7FDFBF4F7FFFEFFFCFDFF
F9FFFBF9FFFBFBF8FEFFFCFFFFFEFFFFFFFFFFFFFFF8F8F8FDFDFDFFFFFF
FCFCFCFDFDFDFFFFFF9F9F9F272727F4F4F4FCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFDFDFDFAFAFAE8E8E8474747363636DFDFDFFFFFFFFFFFFF
F6F6F6FFFFFFCBCBCBD5D5D5FFFFFFC8C8C81F1F1F787878FFFFFFFFFFFF
FFFFFFFBFBFB525252FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCD7D7D70C0C0C
0000000000006C6C6CFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FBFBFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFB0B0B00000000404040000009C9C9C
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFDFCF8F5
CCC5BD140F05FFFFF6FDFDF91D1D25DFDEEBFFFEFFFFFEFFFFFFFFF9FAFA
FBFFFCFAFEFBFFFEFFFEFBFFFFFEFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFF5F5F5FFFFFF5E5E5E585858FFFFFFF6F6F6FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFB2B2B21313137F7F7FFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFF909090151515B1B1B1FBFBFBFBFBFBFAFAFA
FAFAFAFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFCFCFC292929000000
080808272727F5F5F5FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFF9F9F9FFFFFF646464000000060606070707
D4D4D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFD
FFFEEF645D4B898581FCFDFF4448539FA1ADFFFDFFFEF9FBFFFFFAFCFEF9
F9FFFFFBFFFFFAF8F9FFFDFDFFFDFEFFFFFFFFFFFFFAFAFAF8F8F8FFFFFF
FCFCFCFBFBFBFFFFFFFFFFFFFFFFFF2E2E2E8B8B8BFFFFFFFBFBFBFDFDFD
FDFDFDFBFBFB676767252525C2C2C2FBFBFBFFFFFFF7F7F7FFFFFFFCFCFC
FFFFFFFEFEFEF2F2F25050502F2F2FE0E0E0FFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFF010101FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF575757010101040404
0A0A0AD8D8D8FDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEF8F8F8
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFCFCFC2F2F2F000000030303
292929F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF5F5
FFFBECFFFFED8783806D6D732E323B868892FBF7FFFFFCFFFFFFFAF9FBF5
F8FFFFFBFFFFFDFBFCFFFBFBFFFDFEFFFFFFFBFBFBFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFE6E6E6161616B8B8B8FFFFFFFFFFFF
DEDEDE303030545454E9E9E9FCFCFCFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FCFCFCCECECE1D1D1D6F6F6FFCFCFCFCFCFCFFFFFFF9F9F9FFFFFFFFFFFF
FDFDFDF9F9F9070707FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F070707000000000000
9D9D9DFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBD4D4D4070707030303
000000686868F7F7F7FFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFD
FFFEF6FFFCF2FFFEFBFDFCFFFCFFFFFCFFFFFFFCFFFFFCFFFFFEFDFEFFFA
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCC0C0C0191919DEDEDEA3A3A3
171717969696FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFEFEFE
959595141414AEAEAEFAFAFAFFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEA6A6A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFBFBFBFFFFFFFEFEFEFFFFFFD4D4D40A0A0A0202020101015C5C5C
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFFFFFF959595000000
010101060606B4B4B4F9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF6F6
9A928DD5CEC6FFFCF9FFFFFFC6C9CD93969DFFFCFFFFFCFFFFFEFDFEFFFB
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDB6B6B64F4F4F2B2B2B
C9C9C9FFFFFFFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFFFFFFEEEEEE5B5B5B
2C2C2CDADADAFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFF6F6F63232320000000000002D2D2DF9F9F9
F6F6F6FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFD565656
000000000000101010E9E9E9FFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFF
F3EAE1453D32F6F3ECF4F5F5282B3AECEDFDFFFDFFFFFDFBFFFDFDFEFFFF
F9FFFFF9FFFFFFFEFFFFFDFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFB0B0B0F2F2F2
FFFFFFFDFDFDFFFFFFFFFFFFF6F6F6FAFAFAFFFFFFCCCCCC2424246A6A6A
F0F0F0FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFDFDFD696969000000080808080808D1D1D1FFFFFF
FFFFFFF2F2F2FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFDFDFDF3F3F3
1D1D1D0909090000003C3C3CF9F9F9FBFBFBFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCF9FFFFFDFF
FFFAF2AAA69AA6A39A8D8D8DACAABDFDFBFFFFFEFFFFFFFAFFFEFDFEFFFF
FCFFFFFCFFFFFFFEFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF9B9B9B131313A7A7A7FFFFFF
FFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFEFEFEADADAD050505000000000000989898FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFBFBFBFFFFFFFCFCFC
C8C8C80000000505050202027F7F7FFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFFFDF6F9
F7F9F4FCFFF829291F474141FFF9FFFFF9FFFCFFFFF9FFFFFCFFFFFFFEFF
FFFDFDFFFDFDFEFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFAFAFA
FEFEFEFFFFFFFAFAFAFEFEFEF4F4F45A5A5A252525D8D8D8FBFBFBFCFCFC
FFFFFFFDFDFDFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFDCDCDC0505050000000101015A5A5AFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFF3F3F3FFFFFF
FFFFFF818181000000000000050505CACACAFFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF9FFFFFCFF
FEFFFBFAFFF6DFDED9F4EDF0FFF3FFFFFAFFFBFFFFF8FFFFFCFFFFFFFFFF
FFFCFDFFFCFDFEFFFFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFAFAFAFFFFFFD2D2D22B2B2B5F5F5FFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEF4F4F4333333060606000000242424ECECECFFFFFFFFFFFFF8F8F8
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFEFEFE
FFFFFFFCFCFC4141410B0B0B0000001C1C1CE7E7E7FEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEF8FFFFFAFF
FFFFF6FFFDF2FFFEFDFFFDFFFFFCFFFBF9FFFFFDFFFEFFFFFFFFFDFFFFFB
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFCFCFCA4A4A41313139D9D9DFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFDFDFDF8F8F8FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFE6D6D6D000000000000070707CBCBCBFFFFFFF5F5F5FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFBF9FCFFFEFAFFFFF6FFFBF5B3ACAF
11081BFDF4FFFDF8FABDBCB7676862C5C8CC757690F9FDFFF7FEFFF6FFF8
FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFDFDFDFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFD4D4D4101010060606000000646464F6F6F6FFFFFF
FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFBFBFBFBFBFBFEFEFEFFFFFFFFFFFF
FFFFFF7E7E7E1C1C1CB7B7B7FDFDFDFBFBFBFAFAFAFFFFFFFBFBFBFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFEFEFEFFFFFFFEFEFEF9F9F98F8F8F
000000000000060606BABABAFEFEFEF9F9F9FFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFBFFFFFBFBFFFDE4766D5B7D8091F8FDFF
BBB7B4131307EDFBF9F5FFFFF7F3FFFFFCFFF9FFFFF5FFF8FFFFFFFFFDFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDF8F8F8FFFFFFFFFFFFFEFEFEC5C5C50B0B0B000000050505
717171FFFFFFFCFCFCFDFDFDFCFCFCEFEFEF575757303030E4E4E4FFFFFF
FBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFFFBFFFFFFF3F2F5
FFFEFFFFFEFFF3F0F6FFFEFFFFFEFDFCFBF7FFFFFAFFFFFAFFFFFBFCFCFC
F6F5FAFEFFFFFAFFF8FEFFFAFFF8FDFFF7FFFFFDFFF9FAFCF8F9F1FDFCF7
FFFAFFFFFAFFFFFDFDFFFFF8FCFFFAFCFFFDFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF969696000000000000030303
B4B4B4F8F8F8FFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFDFDFD
F0F0F0E5E5E5FFFFFFFBFBFBFFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFF7FFFFF9FFFDFFFAFBFFF6F8
FFFDFFFCFFFFF9FFFFFEFFFDFFFCF37E6F6754504D878C90DFE8F5EFF8FF
FCFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFF8F8F8F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF
F8F8F8FFFFFF7171711C1C1CBEBEBEF2F2F2FDFDFDFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FBFBFBFBFBFBFFFFFF999999171717ABABABFCFCFC6060609C9C9CFEFEFE
FFFFFFFBFFFFF7FFFFEFF4F8FFFCFFFFF9F7696C631B2019CFCDCCFFFEFF
FBFFFFF9FDFAF9F6EFFFFDF8FFFCFBFFFCFFB5B5BDA3A6ADFDFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3C3C3000000080808
000000838383FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFF
F5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
F5F5F5F6F6F6FFFFFFFBFBFBFEFEFE6E6E6E040404000000090909D4D4D4
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFCFFFFFEFEFFFFFCFFFFFDFB
FFFEFDFEFFFFFCFFFFFEFFFFFFFEFAFFFFF8FFFFFDFBFFFFF8FFFFF9FFFF
FFFDFBFFFDF8FFFBF8FFFFFBFEFCFDF2F3F3FEFFFFFAFDFFFCFFFFF9FDFE
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFDFFFEFFFEFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFBFBFBFCFCFCFDFDFDFDFDFDFEFEFE
FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEB1B1B1D0D0D0FFFFFFB9B9B9E6E6E6FFFFFF
FFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFBFBFBFFFFFFFBFBFBE4E4E44A4A4A
2F2F2FD3D3D3FFFFFFFFFFFFFBFBFBFAFAFAFFFFFFFCFCFCFFFFFFFEFEFE
F6F6F6FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF9F9F9FBFBFB
F7F7F7FFFFFFFFFFFFFEFEFEFBFBFBFEFEFEF9F9F9FFFFFFFDFDFDFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFF686868343434FBFBFBFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFF8F8F8
FFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFBFBFB
FFFFFFFDFDFDFFFFFFFCFCFCD1D1D11515159F9F9F9F9F9F595959FFFFFF
FFFFFFFCFDFFF9FFFFFBFFFFE5E0E0383230494A44F5F7F1FEFFFDFCFCFC
FFFEFDFFFFFBFEFFFDF7F7F5FFF8FAF9F0F372727A979BA2FDFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB808080000000
040404000000CACACAFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFBFBFBFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF8F8F8FFFFFF
FFFFFFFFFFFFF8F8F8FFFFFFA2A2A2000000000000000000A1A1A1FDFDFD
F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFCFFFFFEFFFFFFFDFDFFFDFB
FFFEFDFEFFFFFCFFFFFEFFFFFFFEFAFFFEFAFFFFFDFCFFFFF9FFFFFBFFFF
FFFEFBFFFDF8FFFDFAF6F5F1FFFEFFFEFFFFFCFDFFFCFFFFF8FBFFF9FDFE
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFDFFFEFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCF8F8F8FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9EDEDED0A0A0AF5F5F5FFFFFFFFFFFFFEFEFEFFFFFF
FCFCFCFFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFAFAFAFFFFFF
9999991111117C7C7CFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFEFEFE
FFFFFFD6D6D6222222FCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFBFBFBF9F9F9
FFFFFFFFFFFFFCFCFCEBEBEB696969DFDFDFFFFFFFFAFAFAFFFFFFFFFFFF
EBEBEBF9F9F9FFFFFFFEFEFEE5E5E5969696F3F3F3FFFFFFF8F8F8FFFFFF
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFF5F5F5FFFFFF
E1E1E1757575777777818181C1C1C1FCFCFCFFFFFFFFFFFFFAFAFACFCFCF
2B2B2B616161F4F4F4FFFFFFFFFFFFFEFEFEFCFCFCFDFDFDFCFCFCF9F9F9
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FEFEFEFFFFFFFFFFFFFAFAFA
FFFFFFF8F8F85B5B5B060606000000111111E0E0E0FFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFB
878787020202020202090909B2B2B2FFFFFFF8F8F8FFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFAFAF8FFFFFDF9F7F6FFFEFDFFFEFDB0AEAD
858382FFFEFFCECDD2606066FEFEFFFCFDFFFEFFFFFDFEFFFEFFFFFAFBFB
FDFDFDFFFFFF6363637C7C7CFFFFFFFEFEFEFDFDFD535353000000FDFDFD
FEFEFEFFFFFFFFFFFFFAFAFAF1F1F19191912D2D2D292929898989F1F1F1
FAFAFAF6F6F6FFFFFFFDFDFDFFFFFDFAFAF8FEFEFEFFFFFFFCFCFCFCFCFC
FFFEFFFEFDFFFDFCFFFFFEFFFFFFFFFDFDFDF8F8F8FAFAFAFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF7F7F7A2A2A23F3F3F
1B1B1BE5E5E5F2F2F2FFFFFFFFFFFFFEFEFEFFFFFFF6F6F6FAFAFAFFFFFF
4B4B4B464646F6F6F6FFFFFFFFFFFFFDFDFD808080868686FDFDFDFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FBFBFB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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF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FEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFDFFFEFFF8F9FD
FDFCFFFFFEFFB0AAAA0C0707EBEAEDFEFFFFFEFDFFFEFEFEFFFFFFCBCBCB
2C2C2CFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFDFDFDBBBBBBD0D0D0FFFFFFFEFEFE
B3B3B3464646262626ADADADFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFCFFFDFDFFFEFDFEFFFFFCFFFF
FAF9FCFFFEFDFBF8F15C5B56F0F3F7FAFDFFFDFCFFFDFBFEFFFEFFFFFEFF
FEFEFCFFFFFBE4E4E29F9F9F6A6A6A8F8F8FDFDFDFFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFF8F8F8A6A6A6
030303000000010101AEAEAEF9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFEFEFEF1E1E1E050505000000313131FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFFFDFFFFFF
FFFFFFFFFEFFFEFFFFFEFFFFFEFFFFFDFEFFFEFFFFFCFFFFFEFFFFFCFFFF
FEFFFFFEFFFFFCFDFDFEFFFFFEFFFDFDFFFCFEFFFDFBFDFA525451989A97
FFFFFDF9F9F7FEFEFEFFFFFFFDFCFFFAF9FCFFFEFFFEFDFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFF
FFFFFFF7F7F7414141A9A7A6FFFEFAFCFBF7EAEDF2FCFEFFFFF9FFF8F3F7
FCFFFFF8FEFAFFFEF7FFFFFA909193CBCED3FEFEFFFEFEFFFFFFFDE3E2DE
BDBDBBFFFFFFFEFEFEFFFFFFFFFFFFFBFBFB909090515151141414A0A0A0
FFFFFFFFFFFFFBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
F9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FBFFF7FEFFFBFFFDFFFFFAFFFFFEFDFEFDF6F8F5EC9E9D999D9DA5ABADB9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FBFFF8FEFFFBFFFCFFFFFCFFFFFDF6FFFDF4FDF9F5E4E2E315131EC8C7D4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F9FDFCF8F9F9FFFDFFFFFDFAFFFFF1FFFFF3F9F9FFFFFCFF756D78ADA5AE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FEFEFFFFFEFFFFFDFDFFFBF3FFFFECDCDCD0000011211F358B7B855E5254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FEFCFFFEFBFFFFFDFBFFFCF1FDF8E2B3B3A9070D25F5F4FF3520231F0D07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FEFAFFFFFCFFFFFDFBFFFEF4FFFFECCCCDC5090E2BFEFBFFFEE9E40E0000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FFFCFFFFFCFFFEF9FBFFFEFAFFFFF3F0F0EC1A1B35CEC8E0FFFAEF9A8A7A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FFFAFCFFFCFFFFFEFFF9F9F9FEFFFAFDFEFEB2AEC41C1324FFF6EAB8AF9E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FFFBFBFFFCFDFDFCFFFCFFFFFAFFFEFEFFFFFEF6FFC6B8C35E544A6E695F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FFFCFBFFFCFCFFFEFFFBFFFFF6FCFCFAFBFDFFFAFFFDEEF3FFFDFAFAFAF6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FFFCFDFFFBFBFBFCFEFBFFFFFBFFFFFAFBFBFFFBFDFFFAFDFFFCFFFBFEFF
F8FFFFF8FEFEFFFCFFFFFDFFFCFFFFFBFFFFFEFFFFFDFDFD3D3D3DC2C2C2
FEFEFEFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEF3F3F3FFFFFFFFFFFFFDFDFDFFFFFFFCFCFC
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFDFCFCFAF9F9F7FFFFFDFFFFFBFCFBF6FBF8ED8C898248474D706E7B
BFBACAFFFAFFFFFCFFFFFDFFFDFEF6FCFFF6F3FFFBF0FAF7FFFFF6FFFEF6
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFF9F9F9D7D7D70B0B0B000000666666
FDFDFDF6F6F6FCFCFCC1C1C16262622A2A2A1C1C1C777777C6C6C6F5F5F5
FCFCFCFFFFFFFCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFCCCCCC6F6F6F6F6F6F
BEBEBEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9
FCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFA3A3A3020202000000
0000009F9F9FFFFFFFFCFCFCFAFAFAFBFBFBFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFFFFFF
FDFDFDF7F7F7FFFFFFFFFFFFDDDDDD0808080000000000005D5D5DFDFDFD
FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FBFBFBFDFDFDFFFFFFFAFAFA
FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF626262808080FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDFFFFFFA4A4A40000004C4C4C5E5E5E5F5F5F5D5D5D
0A0A0A0F0F0FC5C5C5FFFFFFFFFEFFFCFAFDFFFBFBFFFFF8D6D6C994938C
FDFBFFFCFEFFF1F6F9696D6AFFFBFD8B8489FBF8FEF1F0F5FFFEFDFDFCF8
FCFCFAF7F7F7181818DADADAFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFFFFFF6363637B7B7B606060
989898FFFFFFEFEFEF909090272727313131949494F0F0F0FFFFFFFFFFFF
F6F6F6FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFDFDFFFEFDFDFDFDFCFDFFFCFFFFFFFFFFFFFCFAFFF7F6FFFDFFFCFFFF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FBFDF8FEFFFDFFFFFFFBF9FCFCFBFFFFFFFFFFFFF8FFFEFAFFFCFFFEFCFF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F9FFFAFCFFFBFFFEFFFFFCFFFFFCFFFFFEFFF8FFF3FCFFF6FFFAFFFCF5FC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F5FFF4F4FEF3FFFDFFFFFAFFFFF9FFFFFDFFF0FFF1F4FFEEFFFDF8FFFBFD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F7FFF4F7FEF4FFFDFFFFF8FFFFF4FFFFFDFFF5FFF8F7FFF3FFFBF3FFF8F7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FCFFFBFEFFFDFFFEFFFFFEFFFFFCFFFFFEFFFCFFFDFCFFFBFFFFFBFFFDFD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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFEFEFE969696686868FFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFD818181707070FEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFFFFFFEBEBEBC1C1C1
727272727272BABABAFFFFFFFFFFFFF6F6F6FFFFFFFDFDFDFFFFFFFCFCFC
F5F5F5FFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFF9F9F9FCFCFC
FFFFFFFFFFFFFCFCFCFFFFFFFAFAFAE1E1E19696964D4D4D101010D0D0D0
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFBFBFBF8F8F8FAFAFAC8C8C8
7B7B7B7575757D7D7D070707000000060606858585FFFFFFFFFFFFFBFBFB
FAFAFAFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFF9F9F9FCFCFCFEFEFEAEAEAE
070707000000000000949494F5F5F5FBFBFBFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFAF9FCFCF7F7
FFFEF4FAF3E91F1619E0D9DCFFFEF7FEFFF9FEFEFFFCFEFFF8FDFFFBFFFF
EFF4F8FCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5858588F8F8FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFDFDFDB1B1B10C0C0C000000C4C4C4F5F5F5FFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDF9F9F97C7C7CFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFD5D5D56F6F6F1111111C1C1C0C0C0C
B2B2B0FFFFFDFBFBF9FEFEFCFFFFFFFDFDFDFCFBFEFFFEFFFEFDFFFFFEFF
FFFEFFFDFCFFFCFCFCFDFDFD212121C4C5C5FCFFFFFEFFFFFFFDFDFFFDFD
FFFEFFFEFFFFFBFFFDFCFFFBFFFDFDFFFCFFFFFEFFFEFFFFFBFFFFFCFFFF
FFFEFFFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFAFAFA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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
F6F6F6FFFFFFFFFFFF6868684E4E4EFFFFFFFFFFFF585858A5A5A5FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF444444000000515151A1A1A1EDEDEDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFCFCFCFCFCFCFEFEFE
FDFDFDFEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEF9F9F9FFFFFFFFFFFFFFFFFFEEEEEEAFAFAF6B6B6B
777777CBCBCBFFFFFFFFFFFFFFFFFFFCFCFC9B9B9B555555FFFFFFFEFEFE
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFAFAFA
FEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFF6F6F62C2C2C000000030303
2B2B2BFCFCFCFFFFFFFCFCFCFAFAFA3F3F3F010101000000171717636363
808080C5C5C5FFFFFFFDFDFDFEFEFEFEFEFEFCFCFCFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFCFCFEFFFFFDFCFFFFFEFF
FFFEF5FFFBF3B0ABAD8C8A8DFEFFF9D5D7D2585B62FCFEFFF9FDFEF9FAFA
FEFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFEFEFEFAFAFAD3D3D3585858171717FBFBFBFBFBFB
FFFFFFFFFFFFEDEDED686868FBFBFBFCFCFCFCFCFCCFCFCF1E1E1EB3B3B3
FFFFFFFDFDFDFFFFFFE3E3E37979791313134F4F4FBFBFBFFDFDFDFFFFFF
FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFE
FFFFFDFCFCFAFFFFFFFFFFFFF9F9F9FFFFFFFFFEFFFFFEFFFBFBFBFFFFFF
FBFBFB4646449B9B99FFFFFDFAFAF6FFFFFDFEFCFDFFFEFFFEFFFFFEFFFD
FCFDF7FBF9FAFDF8FFFFFBFFFEFFFBFEFFF6FEFFFBFFFEFFFFFCFFFFFCFF
FFFFFDFEFFFAFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F4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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F4F4BEBEBE2626262727272C2C2C767676FFFFFF323232747474B5B5B5
2525252C2C2C2C2C2C707070FEFEFEFFFFFFFFFFFFB6B6B63333331F1F1F
2B2B2B6E6E6EFEFEFEFFFFFFFFFFFFB6B6B63333331F1F1F2B2B2B6E6E6E
FEFEFEFFFFFFFFFFFFB6B6B63333331F1F1F2B2B2B6E6E6EFEFEFEFFFFFF
FFFFFFB6B6B63333331F1F1F2B2B2B6E6E6EFEFEFEFFFFFFFFFFFFB6B6B6
3333331F1F1F2B2B2B6E6E6EFBFBFBFFFFFFFFFFFFB9B9B92F2F2F202020
2828280E0E0ECFCFCF4A4A4AB2B2B2ADADAD3333331F1F1F262626747474
FDFDFDFFFFFFFDFDFDBEBEBE2323232121211B1B1B2727270E0E0E353535
8F8F8FA0A0A02222222929292B2B2B6A6A6AFFFFFFF8F8F8FFFFFFB7B7B7
2E2E2E2424242B2B2B6E6E6EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFF
FCFCFCF9F9F9FDFDFDFFFFFFFAFAFA000000EFEFEFFFFFFFFFFFFFF9F9F9
FFFFFFFCFCFCFFFFFFE3E3E38E8E8E5D5D5D949494E3E3E3FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFB282828
000000050505080808030303000000BDBDBDFAFAFAFCFCFCFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FCFCFCFFFFFFF7F7F7EDEDEDA0A0A0717171909090E4E4E4FFFFFFFDFDFD
FDFDFDFAFAFAFDFDFDFFFFFFFFFFFFFCFCFCFAFAFAFEFEFEFFFFFFFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFCFCFCFCFAFFFFFB
FEFCFBFFFEFD52514D00000006050A4E4E54D1D5D6FBFFFFFFFEFFFFFEFF
FAF8F7FFFDFCFFFFFFF4F4F4FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFCDCDCD
6C6C6CFEFEFEFDFDFDFDFDFDFFFFFFFBFBFBFBFBFBFFFFFF2F2F2F070707
0000000000000000000C0C0C1A1A1A818181E4E4E4636363FFFFFFFBFBFB
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFAFAFAFEFEFEE4E4E20B0B09
F3F3F1FFFFFBFFFFFBFFFFFA8B8C86010100898277A7A3A003091DDCE5F4
FDFFF3F8F4E6FFF5FF393043E9EDF4F1FAFCFBFFFFFFFEFFFFF9FBFFFBFD
FCFFFFF9FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFC5C5C50D0D0D
E7E7E7FEFEFEFAFAFAFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFBFBFB
FFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFF
FBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFEFEFE
FFFFFFFEFEFEFFFFFFFBFBFBFDFDFDFCFCFCFFFFFFFBFBFBFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFDFDFDFAFAFAF9F9F9FEFEFEFFFFFFFFFFFFFEFEFE
FDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFBFBFBF9F9F9FFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFBDBDBD6E6E6E1D1D1D2727277C7C7CD8D8D8F7F7F7FFFFFF
FFFFFFF6F6F6FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FDFDFDFFFFFFFFFFFFFCFCFC616161909090FDFDFDFBFBFBFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFF9F9F9F5F5F5
ADADAD6E6E6E767676CACACAFEFEFEFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDA4A4A4
0A0A0A050505000000080808A7A7A7FFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFBFBFBFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFF0F0F0
BABABA7676767D7D7DCDCDCDFEFEFEFFFFFFF7F7F7FFFFFFFCFCFCF8F8F8
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFBFCF6FFFFFB
FAF7FDFFFEFFFFFFF8F6F7F12F2F3702020C01050400010017161B120F15
746F6FAFABA8E9E7E6FFFFFFF6F6F6FFFFFFFFFFFF7B7B7BB8B8B8FFFFFF
FFFFFFFFFFFFFCFCFCFEFEFEFAFAFAFFFFFFFFFFFFFFFFFF1B1B1B020202
040404000000000000717171FDFDFDFFFFFFFFFFFFD1D1D1AFAFAFFFFFFF
F7F7F7FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFE2E2E20C0C0AEDEDEB
FFFFFBFFFFFBFFFFFAFFFFFA595A528E8E82F9F7E6A6A5A011102DF7F8FF
FEFFF4FFFFEDFBF4FBFFF8FFF9FBFFFBFFFFFEFEFFFFFEFFFFFEF8FFFDF6
FDFEFEFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFB8B8B8
757575FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFEFEFEC8C8C87575752121212425277A7A7A
C8C7C3FFFFFBFFFFFFFEFDFFFFFEFFFFFEFFFFFFFFFFFFFDFEFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFDFDFDFFFFFF131313E1E1E1FFFFFFFFFFFFFCFCFCFBFBFB
FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FDFDFDFFFFFFF7F7F7BABABA6C6C6C727272C1C1C1FBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
B5B5B53F3F3F2C2C2CACACACFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFEFEFE
FAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFBFBFBFFFFFFC0C0C0777777797979C3C3C3F8F8F8FFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFBFAFDFFFFFFFEFEFAFEFEFC
FFFEFFFFFEFFF6F7EDFFFFF8E8E8F00F0F19000103000000000004000002
0503020C0B07000000000000FFFFFFF0F0F0616161E4E4E4FFFFFFFEFEFE
FEFEFEFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFCFCFCD4D4D4111111
0A0A0A0C0C0C3D3D3DFDFDFDFEFEFEFDFDFDFCFCFC6A6A6AE0E0E0FFFFFF
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFDFDFD7676766C6C6CFFFFFD
FCFCF8FCFDF7FFFFFAFFFEF7C0BFB83B3B2FFFFFF1EEEEEA120F28D4D2E8
FEFFF7FFFFF3FDFBFEFFFBFFFEFDFFFEFEFFFEFDFFFFFEFFFFFFFAFFFEF9
FEFDFFFEFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFBFEFEFED2D5DA767779
26231A252219747472C4C5C9FDFDFFFFFDFFFFFDFCFEFEFAF9FFFDFBFFFF
FFFCFFFFFCFFFFFDFFFEFCFFFFFFFFFCFCFCFEFFFFFEFFFFFAFAF8FFFFFD
FFFEFDFDFBFAFCFAFBFFFEFFFFFFFFFDFEFEFBFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
F8F8F8FFFFFFFBFBFBC1C1C1373737FAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBBEBEBE7A7A7A686868BCBCBC
F8F8F8FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D4D47E7E7E737373AEAEAE
F7F7F7FFFFFFF5F5F5FFFFFFFFFEFFFBF9FCFFFBFFFFFAFDFFFDFDF9F9F5
FEFFFAFDFFF9FFFFFDFFFFFFFCFDFFFCFDFFFEFFFFFEFEFCFFF9FCFFFCFF
FFFDFFFDFBFCFBFAFDFEFFFFFCFFFFFCFFFFFBFFFEFCFFFFFEFFFDFFFFFB
FFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFEFFF9F9F7FFFFFDFFFEFFFBFBFF
FEFFFFFCFEFBFEFFF6FEFFF6FEFDFFD6D4DD0A0610010005040205000000
2527225C615B979996B1B1B1DADADA686868EDEDEDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
BABABACACACAFFFFFFF9F9F9FFFFFFFFFFFF939393D1D1D1FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FEFEFEFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFDFDFDFDFDFDFFFFFF
FEFFFDFDFFFCFEFFFFFEFFFFFFFEFFFFFEFFECEBEE141414E2E0E1FFFEFD
FFFEFAFEFDF8FFFCF3FFFFF4FEFBF0605D54969590FDFDFD54525D9A98A1
FCFCFAFFFFFBFBFAFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFDFDFDF7FCFFFCFFFF
FFFDF3D3CFC37878742C2F341A19266A6873C7C5C4FCFDF7F1FBF6F6FEFC
FFFCFFFFFBFFFFFCFFFFFEFFFBF9FAFFFFFFF5F6F6FEFFFFFFFFFDFDFDFB
FEFCFBFFFEFDFFFDFFFFFEFFFCFCFCFBFCFCFBFFFFFBFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFDFDFD
FFFFFFF8F8F8FFFFFF686868828282FCFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFDFDFDFDFDFDFBFBFBFFFFFFC8C8C8
7B7B7B6C6C6CACACACEEEEEEFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAF4F4F4B7B7B7FCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFBFBFB
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFDEDEDE
8686866B6B6BA9A9A9EFEFEFFFFEFFFFFDFFFFFBFFFFFBFFFFFDFEFDFFFC
FEFFFAFEFFF8FEFEFAFBFBF9FEFFFFFEFFFFFBFCFEFFFFFFFFFCFFFFF9FC
FFFDFFFFFEFFFFFEFFFEFFFFFBFEFFF9FFFFFAFFFEFCFFFFFEFFFDFFFFFB
FFFFFBFFFEFDFFFEFFFFFEFFFEFEFFFFFEFFFFFEFBF6F5F1F5F8FDFBFFFF
F3F7F8FAFAF6FFFFF6FFFFF6FEFFFFF8F8FE75717D0B050F0E090D2E2C2B
333935EDF3EFF9FAFAC1C1C1777777FAFAFAFFFFFFF7F7F7FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFF
FCFCFCFEFEFEFFFFFFFFFFFFFEFEFE8A8A8ABEBEBEF7F7F7FEFEFEFFFFFF
FDFDFDFFFFFFF8F8F8FEFEFEFFFFFFB4B4B4F4F4F4FFFFFFFDFDFDFFFFFF
F7F7F7FDFDFDF7F7F7FFFFFFFFFFFFF6F6F6FFFFFFFCFCFCFFFFFFFFFFFF
FDFFFCF8FAF7FEFFFFFCFDFDFEFDFFF8F7FA8E8D90565558FFFDFEFDFBFA
FFFEFBFFFEFAFFFFF6FBF8EDFFFDF3FFFDF48684836F6E7116151849484B
FEFDFFFFFEFFFCFBFEFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFFFAFFFFFBFFFF
FFFEF6FFFEF4FFFFFDFEFFFFD5D7E182828A3432311818145F6765C0C6C6
FFFDFFFFF8FBFFFCFFFFFDFEFFFEFFFFFFFFFEFFFFF9FAFAFEFFFFFBFBFB
FFFEFFFBF9FAF8F6F7FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFAFAFA1F1F1FD7D7D7FDFDFDFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFD4D4D48282826F6F6F9B9B9BF3F3F3FFFFFFFFFFFFF8F8F8
FFFFFF8080806A6A6AFFFFFFFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAF9F9F9
FFFFFFFFFFFFE1E1E18B8B8B6B6B6B9C9A9BF1EBEBFFFCFEFCFFFFFBFFFF
FBFDF8FEFFF8FEFFFAFEFFFAFCFCFAFFFEFFFDFDFFFEFEFFFBF9FAFFFEFD
FFFAFAFEFCFBFFFFFFFEFFFFFCFFFFFCFFFFFCFFFFF9FDFCFEFFFDFFFFFD
FFFEFDFFFEFDFFFFFFFFFEFFFEFFFFFFFEFFFFFBF8FFFBF9F8FFFFF4FFFF
F9FFFFFFFFFBFFFEF6FFFBF5FAFBFBFBFFFFF6F6FF1B17210C0107898383
8389850D1611757676A3A3A3FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFAFAFA686868C9C9C9FFFFFFFCFCFCFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFBFBFBFFFFFF6666660F0F0F6F6F6FDCDCDCFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFBFBFB
FEFFFDFEFFFDFCFDFDFDFEFEFFFEFFF8F7FA0F0E11DAD9DCFFFEFFFFFEFD
FFFEFBF9F5F1FFFFF8FFFFF6F9F6EBFFFFF8FEFCFBFFFEFFEAE9EC070609
ECEBEEFAF9FCFFFEFFFEFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFAFFFFFFFBFFFFFBFFFF
FEF8F5FEF9F3FBFBF9FBFCFFFBFEFFFEFFFFF3F1F0E2E0DF8B8F902C2F33
171514666060BBB6B8FAF8F9FFFDFEFEFEFEF9FAFAFEFFFFF8F9F9FEFFFF
FFFDFEFFFEFFFFFEFFFDFBFCFBFBFBFEFFFFFEFFFFF9FDFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
F9F9F9FFFFFFCACACA2B2B2BFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFCFCFCFAFAFAFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF2F2F2E3E3E38B8B8B6363638F8F8FE9E9E9
FFFFFF222222C7C7C7FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFBFBFB
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFE8E6E5A3A29E6D6D6D8C939BDBE2EA
FCFEFBFFFFF8FBFFF7FBFEF5FFFBF7FFFDFFF8F8FFFCFEFFFCFFFFF9FBF6
FFFEFDFFFEFDFDFDFDFCFCFCFCFDFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFD
FFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFFFEFFFFFCF8FFFDFAF2FBFDF4FFFF
F9FFFFEEEEEC4B423D372E29171717D8DDE1FAFCFFA6A4AD0D04097E777A
FAFEFB525854131414959595F7F7F7FFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
FFFFFFFBFBFBEBEBEB595959EFEFEFFAFAFAFDFDFDFFFFFFFEFEFEFCFCFC
FFFFFFF8F8F8FBFBFBFFFFFFFEFEFEFFFFFFE3E3E37F7F7F0F0F0F414141
B7B7B7FBFBFBFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FBFDFAFEFFFD454646E1E2E2FDFCFF959497565558FCFBFEFDFBFCFFFEFF
FFFDFDFFFEFBFFFEFAFFFFF8FFFFF6F7F6EFFBF9F8FFFEFFECEBEE222124
B7B6B9FFFEFFFDFCFFFDFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFCFEFDFFFCFFFFFEFFFF
FFFEFBFFFDFBFFFFFFFEFFFFFCFFFFF9FAFAFFFFFBFFFAFAFEFEFFFEFFFF
E3E3E18F8E8A403B3B121011555354B9B9B9FCFDFDFDFEFEFEFFFFFBFCFC
FEFCFDFEFCFDFFFEFFFFFEFFFFFFFFFEFFFFFDFEFEFBFFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFF777777787878FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFDFDFDF9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C5C5999999
505050181818D5D5D5FFFFFFFFFFFFFFFFFFFAFAFAFAFAFAFFFFFFFFFFFF
FBFBFBFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB9E9E9E
4A4A4A1515154444448D8D8DF9F7F6FFFFFBF5F5F1FCFFFFEEF7FFA1A9B4
74737684837ECFD6CEFCFFF8FFFEF6FFF9F7FEFEFFF9FFFFF2FAFAFBFFFB
F9F9F5FBFAF6FDFDFBFFFFFDFFFFFFFBFCFCFDFCFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFEFDFFFBF5FFFCF7F5FDFFF5FFFF
F8FFFFFEFFFDFFF9F49C938EF1ECEEE8E7EDFCFFFFF6F9FF0000024B4B4B
5F5F5FE4E5E5D6D6D62E2E2E636363F8F8F8FFFFFFF6F6F6FFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFDBDBDB636363FFFFFFF9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
F8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7FFFFFFABABAB
3131311B1B1B808080F1F1F1FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFCFCFC
FEFFFDFEFFFD40423FBEBFBFF3F2F51C1B1EC7C6C9FFFEFFFFFEFFFFFEFF
FEFCFDFFFEFDFEFAF7FEFAF6FFFEFAFFFFFAFFFEFDF9F9F9E3E3E3A6A6A6
B2B2B2FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFF9FCFFFBFCFF
FFFBFDFFFDFDFFFEFFFEFFFFFBFFFDFCFFFBF9F5F2FFFDFFFFFDFFFFFEFF
F5F7F2FFFFFAFAF8F7EAE5E79C9A9B3737370F10105A5B5BAAABABF7F8F8
FFFFFFFFFEFFFDFBFCFBF9FAFCFCFCFDFEFEFEFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFF222222CFCFCFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FAFAFAFEFEFE
FFFFFFFFFFFFFEFEFEFCFCFCFEFEFEFFFFFFF9F9F9FCFCFC111111EAEAEA
7777776E6E6EAFAFAF6565657A7A7AC8C8C8FFFFFFFFFFFFFFFFFFFBFBFB
FAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA040404030303
000000010101000000121210353332F8F8F4FEFFFAF9FFFFEFF8FFF8FFFF
FDFBFEFFFEFDB2B8B473756F7E7468CFC4BEFFFDFFF9FFFFF6FFFFF9FFFD
FEFFFDFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFDFFFDFCFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFBFFFAF2FFFDF6FBFFFFF7FFFF
F3FEFFFAFFFCFEF9F3F9F0EB7C7376FFF9FFFCFFFFF8FCFF595F5F0D1110
F0EEEFFFFEFFFFFEFFF3F3F3595959303030CACACAFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
ABABAB828282FFFFFFFCFCFCFFFFFFF9F9F9FBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFD3D3D36767670C0C0C5E5E5EC7C7C7FFFFFFFFFFFFFBFBFBFFFFFF
F9FBF8FEFFFD626461939592AAAAAA454447FDFCFFFFFEFFFFFDFFFFFEFF
FFFEFFFDFBFCFFFBFBFFFEFBFFFCF9F9F8F4FFFFFDFFFFFFF9F9F9FDFDFD
FFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFEFFFCFFFFFEFFFF
FFFDFFFFFDFFFEFCFFFBFCFCF9FFF9FCFFFAFFFEFBFDF6F9FFFBFFFEFBFF
FCFFFDFBFFF9FFFEFDFFFBFBFFFEFFFAFAFAE7E8E8979B9A4243450C0D0F
525154A5A4A7F3F1F2FFFEFFFDFDFDFDFEFEFEFFFDF8FCF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
F7F7F7D6D6D6242424FDFDFDFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF3C3C3CC2C2C2
1C1C1CD7D7D7FDFDFDFFFFFFF4F4F4BABABA7070706E6E6EBCBCBCFDFDFD
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD606060050505000000
03030300000001010101000004000024231FFCFFFBF9FFFFF7FFFFF9FFFF
FFFCFFFBF6F8F8FBFFFFFFFBFFFCEFCDBCB07775786B727ABBC4C7F5FDFF
F1F5F4FDFDFBFFFFFDFDFDFBFBF9FAFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
FFFEFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFAFFFCF2FFFDF4EDEEF0EFF8FB
F6FFFFF9FFFFFFFEFAFFFBF9F6E9EE726A73F7FAFFB7C0C5707A79F9FFFD
FFFDFFFDF6FBF9F7F8FCFCFCFFFFFF8080800B0B0BFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6909090
AAAAAAFFFFFFFEFEFEFAFAFAFFFFFFFFFFFFF7F7F7BDBDBDDCDCDCF7F7F7
FCFCFCFFFFFFFBFBFBFFFFFFF5F5F5FFFFFFFCFCFCFDFDFDF6F6F6FFFFFF
FDFDFDFCFCFCF9F9F9F1F1F18E8E8E202020333333959595F6F6F6FFFFFF
FEFFFDFEFFFD7A7C797A7C79292929BEBEBEFBFAFDFDFCFFFEFDFFFDFCFF
FEFCFFFFFEFFFFFDFEFEFCFBF7F5F4FFFEFDFBFBFBFFFFFFFFFFFFFDFDFD
F5F5F5FCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFDFFFEFFFF
FFFDFFFFFCFFFFFEFFFEFFFFFBFFFAFAFFF8FFFDFAFFFCFDFFF7FFFFFCFF
FBFFFFF9FFFDFBF9F8FFFDFDFFFEFFFFFFFFFDFEFEFBFFFEFEFFFFEBECEE
9D9C9F48474A141213464445AAAAAAEEEEEEFEFFFDFCFEFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFF8282826D6D6DFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFEFEFEFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFCFCFC
FEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFBFBFB5454547E7E7E
323232FEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFEFEFEFAFAFAC4C4C4707070
6D6D6DB4B4B4FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCBCBCB040404060606000000
000000000000020202030102070101120E0BB8BDB7F6FEFCF8FFFFFAFFFF
F9F3FAFFFCFFFEFEFFF8F6F9FFF5E7BBA99A76757191969AB7BEC4787F85
767C7CB4B8B7F1F2F2FFFFFFFFFDFFFFFCFEFFFCFFFEF9FDFFFDFFFFFEFF
FEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFF8FFF9EE8D8077030706566065
7B8688F2F8F8FDF7F4EBDFDEFFF8FD30283180848BA3ACAFF4FEFDFBFFFF
FFFCFFFFFCFFFFFEFFFEFEFEE2E2E22727275B5B5BFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE696969CACACA
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFD2D2D21B1B1BABABAB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDB9B9B95050500E0E0E727272
DADCD9FBFDFA9C9E9B3F413E383838FAFAFAFFFEFFFFFEFFFFFEFFFFFEFF
FAF8FBFFFEFFFDFBFCFFFEFFFFFEFFFCFAFBFEFEFEFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFDFFFFFDFFFFFEFFFEFFFDFBFFFBFBFFFAFFFEFBFFFBFDFFF9FEFFFCFF
F8FFFFF7FFFF8E8E8E040000333132AEAEAEFEFFFFFAFEFDFCFFFFFEFFFF
FFFEFFFFFEFFEEECEDA9A7A8434343111111484A479EA09DEDEDEDFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF6F6F6
FFFFFF3B3B3BBCBCBCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF747474383838
8C8C8CFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDC8C8C87D7D7D666666ABABABFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFF
FDFDFDFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFA1A1A10F0F0F000000010101
0303030000000606060200010400000D0707999B98FBFFFDFCFFFDF7F8F8
FFFDFFFFF9FFFBF8FFFFFBFF917D701100009A978E676B6C080812D2D4E0
F6FAFFD9DEE18488896A6A6AB0ABADF5EFEFFEF7FAFFFDFFFCF9FFFFFEFF
FEFFFFF4F8F9FEFFFFFEFFFDFDFDF9FFFEF6FFF2E7190B00D1D9D7F2FFFF
C2CFD3CCCFD3FFF7F7A29293160D12222126C4CBCFF8FFFFE6EAEB030303
D4D1D7FFFEFFFDFCFFE5E5E51919198F8F8FFFFFFFFDFDFDFFFFFFFCFCFC
FDFDFDFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFE5E5E55C5C5CEEEEEEF9F9F9
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFD4D4D4111111
B2B2B2FFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFDFDFDFEFEFEFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFDBDBDB787878
15171445474482828011110FD5D5D5FAFAFAFFFEFFFDFCFFFFFEFFFFFEFF
FDFCFFFFFEFFFEFDFFFFFEFFFCFBFEFFFEFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFF
FFFEFFFFFDFFFFFEFFFEFFFDF8FFFCF8FFF8FFFBF8FFFBFAFFF6F7FFFBFD
F7FFFFEEFDFFFCFCFCABA5A5E2DDDFEAEAEAF9FAFAFCFFFFFCFFFFF7FBFC
FBFCFEFFFEFFFEFCFFFEFCFDFFFFFFF2F2F0A4A6A3525451101010454545
9C9C9CEAEAEAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFF
E6E6E60C0C0CFCFCFCFCFCFCFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC909090040404
7B7B7BE1E1E1FFFFFFFAFAFAFBFBFBFFFFFFFEFEFEF9F9F9FDFDFDFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFD2D2D28686866262629F9F9FF4F4F4F3F3F3
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF8686860E0E0E050505000000
0000000404040000000100000903030A0404828282FEFFFBFCFCF2FFFFF8
F8F5FBECE8F6FFFBFFFFF7FFC3AFA2E7D6C2F9F9EDFCFFFD96909A44404E
F9FFFFF8FFFFFAFFFFFEFFFFE5E0E2938D8D7B75759D989AF2F0F3F5F6FA
FCFFFFFCFFFFFEFFFFFEFFFDFFFFFBFFFBF3FCE6D92C1B11D7DFDDF1FFFF
F7FFFFFEFEFFFFF4F7F7E7E85D565BE2E5E9F8FFFFF6FEFFA5A4A7010000
DEDDE0FDFCFFDEDDE01414149C9C9CFDFDFDFDFDFDFAFAFAFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBCFCFCF6F6F6FFDFDFDF8F8F8FEFEFE
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFD2D2D2
0F0F0FBBBBBBFEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFF5F5F5FFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFF8F8F8FBFBFBFFFFFFFDFDFD
F5F7F4A4A6A330302E11110F818181EAEAEAFFFEFFFFFEFFFDFCFFFFFEFF
FFFEFFFCFBFEFEFDFFFFFEFFFFFEFFFBFAFDFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFF
FFFEFFFFFEFFFFFEFFFEFFFFF9FFFFFBFFFFFFFEFBFFFBF6FFF5EFFFFBFA
F1FEFFF2FFFFFAFBFDFFFBF9948F8FD7D7D7FEFFFFFCFFFFF5F8FCFCFFFF
FEFFFFFFFEFFFFFEFFFEFCFDFCFCFCFDFDFBFEFFFDFEFFFDF6F6F6A9A9A9
5858580E0E0E353535999999E6E6E6F8F8F8FDFDFDFFFFFFFFFFFFFDFDFD
8C8C8C686868FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB868686060606
6464641717172C2C2C7F7F7FCFCFCFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
F1F1F1FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFDFDFDE0E0E09595956C6C6C
8B8B8BEFEFEFFFFFFFFBFBFBFEFEFEFCFCFCFFFFFFFFFFFFFCFCFCF8F8F8
FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFBEBEBE111111000000040404
060606000000040404020001040000140F11BAB8B9FFFFFAFFFBEC989186
00000400000D0E0518D5C7D2FFFAF1AB9E8D00030000010020141D070008
E4EAF6F5FFFFF8FFFFF7FAFFFFFEFFFFFDFDFFFDFDEAE5E59A989B757678
929599DCE2E2FAFEFFF9FBF8FFFFFBFFFEF6FFFAED605247969A9BF3FFFF
F1F9FFEBEBF3D9CED26D6163FDF8FAFEFFFFF9FFFFF3F9F93939390A0809
CBCACDD2D1D41B1A1D9E9E9EFFFFFFFFFFFFFDFDFDFFFFFFF5F5F5FFFFFF
FEFEFEF7F7F7FFFFFFFBFBFBA3A3A3929292FFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
CACACA090909B6B6B6FFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFF9F9F9000000616161131313555555C6C6C6FFFFFFF4F4F4
FFFEFFFFFEFFFEFDFFF6F5F8FFFEFFFFFEFFFDFDFDFEFEFEFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFEFDFEFFFFF9FFFFFBFFFFFFFEFBFFF4ECFFF4E8FFF9F2
F1FEFFEBFEFFFEFFFFFFFDFBFDF8F86E6E6CF6F7F9FBFFFFFCFFFFFCFFFF
FBFCFFFCFDFFFFFEFFFFFEFFFFFFFFFFFFFDFDFDF9FBFDF8FCFCFCFFFFFF
FEFEFEFDFDFDBABABA5555551212123E3E3E929292E6E6E6F6F6F6FFFFFF
3E3E3EAAAAAAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF404040181818
FDFDFDFFFFFFC9C9C97070702525251D1D1D6D6D6DB5B5B5FFFFFFFDFDFD
FFFFFFFDFDFDF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFBFBFBFDFDFD
EFEFEF9090905B5B5B8C8C8CDCDCDCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF0B0B0B030303000000
0101010000000000000505050503041B191AFCFAFBFCF7F1FFF5E4190F01
9A9FA3F0F6FF877F8A1A0B10F4E5DE0E0500A8AEAAF8FCFB7F6F700E0004
C3CAD8F1FFFFF7FFFFFBFFFFFFFEFFFCF7F7FFFDFBFFFEFBFDFBFCFEFFFF
EBEEF2A6ABAE6D71728D8F8CD7D7D3FEF7EFFFFCEDECDED3030205D6DDE5
D7DBE60A0A12888184FFF9FAFFFDFFF8F7FAFAFEFFD8DCDD080A070B0B0B
A4A3A6121114A4A3A6FFFFFFFAFAFAFFFFFFFAFAFAF9F9F9FFFFFFFCFCFC
FFFFFFFFFFFFF4F4F4828282BEBEBEF9F9F9FAFAFAFDFDFDFFFFFFFFFFFF
FEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFBFBFB
FFFFFFC6C6C6212121BBBBBBF9F9F9FDFDFDFFFFFFFFFFFFF9F9F9FFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBF7F7F7
FFFFFFFFFFFFFFFFFF212121DFDFDFE9E9E99292922626262D2D2DA3A3A3
FAFAFAFDFCFFFFFEFFFFFEFFFEFDFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FEFFFBFFFFFBFFFFFBFFFFFFF7FFFFF9FFFFFFFCFAFFFBEFFFF4E1301F15
323F50DDF1FFFEFEFFE2DCDAFFFDFD7A7A78B1B2B4FCFFFFFBFFFFF4F7FB
FAFBFFFEFFFFFFFEFFFCFAFBFEFCFDFFFFFDFFFFFBFDFDF9FFFFFFF8F8F8
FFFFFFFAFAFAFEFEFEFFFFFFFAFAFAB9B9B96363631111113737377E7E7E
111111FFFFFFF9F9F9FFFFFFFCFCFCFBFBFBFAFAFAFAFAFAFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEEEEE151515050505
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFD2D2D28383833D3D3D020202595959
AFAFAFEFEFEFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFEFA8A8A86161617A7A7AD2D2D2FBFBFBFDFDFD
FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFAFAFAE1E1E1010101040404
0000000606060A0A0A000000020305F6F6F6FFFEFFFFFDF6EED9C6130500
E7F1F8F4FFFFFFFCFC978984CBC2BD0C0C0CECF6FFF3F8FCFFF8F233211D
939AAAF0FFFFEEFBFFF9FFFFFCFBFEFFFEFBFFFCF9FFFEFAFFFFFDFBFCFC
FAFEFFFBFFFFFCFFFFF2F3F3BAB8B77E7971897D6DDFD2C7E3DCE164626F
3F3E4C4A4C56FFFEFFFFFDFCFFFEFFFFFEFFFDFCFF4A4B4B000100000100
121114A09EA1F5F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF2F2F26A6A6ACBCBCBFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFCFCFCFDFDFD
FFFFFFFAFAFABDBDBD101010C9C9C9FFFFFFFDFDFDFFFFFFFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF3A3A3AB7B7B7FFFFFFFEFFFDF9FBF8BBBDBA454744
10120F6D6E6ED7D8D8FEFFFFFDFEFEFCFDFDFFFFFFFFFFFDFBFBF9FFFFFD
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFB
FEFFFAFFFFFAFFFFFAFFFFFFF8FFFFF7FDFFFFFBF9FFF6E7FFF9DF685648
6D7C91CFE4FFF8FAFFC9C3C12E292911110FECEDEFF8FCFDF8FDFFFBFFFF
FEFFFFFEFFFFFFFEFFFFFEFFFFFDFEF8F6F5FAFAF6FFFFFBF9F9F9FFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFBFBFBC0C0C03F3F3F
0000002929298A8A8ADDDDDDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F4F4F4F111111
E8E8E8FFFFFFFFFFFFF6F6F6FFFFFFF8F8F8FFFFFFFFFFFFE7E7E7999999
4646460A0A0A4646468C8C8CEAEAEAFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFF7F7F7B4B4B46E6E6E757575
BCBCBCFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFE0E0E0474747
0101010A0A0A030303393A3AEAEEEFF6FAF9FFFEFDFFF7EFFFF4E1241405
A9BAC1F0FFFFFFFFF3FFFDEDF7F3F0161A25B8C4D8FBFEFFFFFAECA99588
4D5665EDFFFFEEFDFFF8FFFFFFFEFFFFFEFBFDF7F4FFFFF8FEFEFAFCFFFF
FBFFFFF7FCFFF9FDFEFBFCFCFAF8F7FEF9F1FCF3E2574D41766D723E3746
D8D5E48B8B95D3D2D5FFFFFFFBFBFBFDFDFDCCCCCC020200040400070705
0000020A090C000000000000000000FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
E6E6E65E5E5EEEEEEEFFFFFFFDFDFDFFFFFF5D5D5DF5F5F5FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3F3F3FFFFFFFFFFFFC0C0C00F0F0FC3C3C3FDFDFDB1B1B17A7A7AFEFEFE
FFFFFFFEFEFEFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFF1F1F1FFFFFF7F7F7FADADADFBFBFBFEFFFDFEFFFDFBFDFAFEFFFD
DEE0DD7A7C79191A1A454646B3B4B4FDFEFEF7F7F5FFFFFDFAFAF8FFFFFD
FFFFFDFBFBF9FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFBFFFFFB
FEFFF8FFFFF8FFFFF8FFFEFFF8FFFFF9FEFFFFFDFBFFF8E9FFFADAB7A694
56647EE4FAFFFCFEFFFFFBF9FCF7F7FBFBF9FCFDFFFCFFFFFBFFFFF3F8FB
FDFEFFFDFEFFFCFBFEFCFCFCFFFEFFFFFEFDFFFFFBFDFDF9FFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFBFBFB474747
AEAEAEBFBFBF6D6D6D1111112F2F2F787878CFCFCFFEFEFEFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4E4E4E9E9E9E373737
CBCBCBFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
FEFEFEF9F9F9ABABAB6262621111113030308B8B8BD0D0D0FDFDFDFEFEFE
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFF9F9F9
C0C0C06D6D6D656565BDBDBDFFFFFFFBFBFBFCFCFCFFFFFFFEFEFEF9F9F9
FFFFFFD8D8D8FFFFFFFCFDFDF9FFFFFBFFFFFFFFFBFFFBF3FFF8E679695A
3F565CEAFFFFFFFFE7CEC7AB7F80805C64774E5E7FF5FAFFFFF8E2B49E87
0A1322E1F8FFF1FFFFF2FBFFF7F8FCFFFEFBFFFEF8FFFFF8FDFDF9FAFEFB
FBFFFFFBFFFFFCFFFFFEFFFFFFFEFDFFFDF8FFFDEFA4978C363135F2EFFE
CFCADC605C6AFEF8FFFEFEFEFBFFFFF9FFFF212222030100060000040000
030404080E0E171818757575A3A3A3FBFBFBFFFFFFFFFFFFFFFFFFC5C5C5
767676FDFDFDFBFBFB9A9A9A242424E7E7E71F1F1FDDDDDDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFF5F5F5BBBBBB161616D5D5D5BDBDBD3E3E3EFFFFFF
F4F4F4FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF
FEFDFFFFFEFFFFFFFFFCFCFCFCFCFCFEFEFEFEFFFDF8FAF7FEFFFDFEFFFD
F8FAF7FEFFFDF7F9F69EA09D3739361B1D1ADEDEDCFFFFFDFDFDFBFDFDFB
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFDFFFFFDFFFFFB
FEFFFAFFFFF8FFFFFAFFFFFFF7FDFFFBFEFFFFFEFBFFFDEDFFF6DCECDECF
061123EAF9FFFCFFFFFEF9F9FFFEFDFFFFFFFEFFFFFAFEFFFCFFFFFCFFFF
FEFFFFFDFEFFFEFDFFFFFFFFFFFEFFFCFAF9FCFCFAFFFFFDFFFFFFFAFAFA
FFFFFDFFFFFDFCFCFCFFFEFFFCFBFEFFFEFFFFFFFDFEFEFCF4F4F20E0E0E
F5F4F7FFFEFFFCFCFCFFFFFFC4C4C4737373232323252525797979D6D6D6
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9E9E9121212F3F3F3AAAAAA
D4D4D4FFFFFFF9F9F9FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFBFBFBFCFCFC
FFFFFFFCFCFCFEFDFFFFFEFFF8F8F8C1C1C16B6B692020202524276D6C6F
C0C0C0F5F5F3FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFC2C2C2787878676767B1B1B1F3F3F3FFFFFFFDFDFD
FBFBFBFFFFFFFFFFFFFDFEFEFBFFFFF7FDFBFFFEFDFFFBF5FFF9EBE7DAD1
00050B617979D2D4BC49442C565757D6DEF000011C707384CFBCA92B1A06
000510DAECFFF4FFFFF6FCFFFEFFFFFFFFFBFFFEFAFEFDF8FFFFFBFAFCF9
FBFFFFFBFFFFFAFEFFFCFDFDFFFEFFFFF9F6D1C7BD70675E4B494CD3D3DD
2C2836ECE5F2FFFCFFFDFDFDFBFFFF69716F0608050402010900000D0503
4A4B4BC9CFCDFCFFFFF8FAF7FFFFFFFFFFFFFCFAFBFEFCFDA6A4A5969696
FFFFFFF7F8F8FEFFFDFEFFFD8E8E8E242424424041B8B6B7FFFFFFFEFEFE
FDFDFDFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBACACAC171717BABABA1A1A1AFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFDFDFDFFFFFF
FFFEFFFBFAFDFFFFFFFDFDFDFFFFFFFFFFFFFAFCF9FDFFFCFDFFFCFBFDFA
FEFFFDFBFDFAFEFFFDFEFFFDFBFDFACFD1CECACAC8FDFDFBFFFFFDFCFCFA
FFFFFDFDFDFBFFFFFDFEFEFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFDFFFFFFFDFEFFFCFDFFFFFFFBFFFEF6FFF8EDFFFEF6
1E2125CCD0D7FDFEFFFDFDFDFFFFFFFEFFFFFDFDFDFCFDFDFEFFFFFEFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFCFFFFFFFF
FFFFFBFDFDF9FCFBFEFFFEFFF9F8FEFFFEFFFFFFFBFFFFFAA0A19B4E4E4C
FDFEFFFEFFFFFEFFFFFFFFFDFFFFFDFFFEFDFDFBFCCDCBCC737275232225
1F202278797BD0D1D3F7F8FAFFFFFFFEFEFEFFFDFCFFFDFCFFFEFDFEFCFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFDFDFD9494945A5A5AFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFBFBFFFEFEFFF7F5F6FFFEFDFCFEF9FEFFFDCFCED3818085
30322F151712595957B3B1B0F6F4F5FFFEFFFFFEFFFAF9FEFFFEFFFFFFFF
FEFEFEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFF4848488080806565656B6B6B
EFEFEFFFFFFFFAFAFAFFFFFFFEFFFFFBFCFCFEFEFEFFFEFBFBF3EEFFFEFB
DDE2E5505858030400302F28D2D2D2FCFFFFDBDFE85D5D630800008F8A84
7D8084CAD1D9FBFFFFFEFFFFFFFEFFFDFDFBFFFEFDFEFEFCFDFDFBFFFFFF
FDFEFEFEFFFFFCFDFDFFFFFFFFFFFFB8B6B58C8885FFFCF9ECECEC000004
B2B1B6FFFDFFFBF9FCFFFFFFCBCCCC090A0A0000000707074F4A4ADDDBDA
FEFEFEFCFFFFFBFFFBFCFFFBFFFFFDFFFEFFFFFCFF7A7378BBB6B8FFFEFF
FEFFFFFBFFFFFBFFFAF6FDF5FDFEFE7A797C1B16188B8688FFFEFDFDFBFA
FFFEFFFFFEFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFF7F6F9FFFEFFF9F9F9FFFFFFA4A4A4111111090909FAFAFA
FFFFFFFEFEFEFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFCFCF8FFFFFBFFFFFBFBFAF6
83827D8B8B87FFFFFDFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF9F9F9
FFFFFAFFFFFAFBFAFDF5F4FA787681D8D7DCFCFCF8FFFFF6595A54A1A19F
FBFBFFFEFEFFF8F9F9FFFFFBFDFBFAFFFEFDFFFEFFF9F7F8FFFEFFFFFEFF
C5C6C8797A7C1D1E20262729707070CDCDCDFAF8F7FFFEFDFFFEFBFFFEFD
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFEFEFE
FAFAFAFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF393939B2B2B2FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFCFFFFFAFAFFFFFCFFFFFCFAFFFFF8F5FAF3FEFFFFFEFEFF
FEFFFFE0E1E193958F48474208020050494C949399F0F0F6FBFAFDFDFDFD
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9272727D6D6D67D7D7D626262
929292636363909090E3E3E3FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF5F5F5
FFFFFFFFFFFFFDFDFDFCFCFCCDCDCD909090FEFEFEFFFFFFF7F7F7DFDFDF
F6F6F6FBFBFBFFFFFFE4E4E4030303000000131313BBBBBBFFFFFFFFFFFF
FFFFFFF8FAF7FCFFFBFCFFFBFBFBF9F5F3F4625D5FE3DEE0FFFEFFFCFBFE
FEFFFFFCFFFFFAFFF9FCFFF8FEFFFDFAFAFA3B3638201B1DF7F5F6FFFDFC
FFFEFFFFFEFFFAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFAF9FCFFFFFFF9F9F9FFFFFF7B7B7B000000BEBEBE
FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF2F2F2FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFAF8FDFDF9FFFFFBFCFBF7FFFFFB
DBDAD623231FF8F8F6FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FCFDF7FFFFFBFFFEFFFFFEFF3C3A45151419FFFFFBEDEEE411120CEBEBE9
FCFBFFF7F6FCFFFFFFFDFDFBFFFEFDFFFAFAFDFBFCFFFDFEFFFEFFFFFEFF
FEFFFFFEFFFFFEFFFFCFD0D27D7E7E2526261F1F1D6B6B69BFBDBCFEFCFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF7F7F7FAFAFAFFFFFFFDFDFDFCFCFC
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFDBDBDB131313FDFDFDFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFBFFFFF7F7FDFFFBFFFFFBFDFBFBEEFCFFF4F9FDFEF5F7FF
7C7A8D494855F3F9EDFDFFEFFAF1EAAA9FA15F5F67070B143E3F43898989
DDDDDDF9F9F9FFFFFFFFFFFFF7F7F7FFFFFF434343B7B7B7252525C2C2C2
FFFFFFFFFFFFDFDFDFA1A1A16A6A6A808080D5D5D5FFFFFFF9F9F9FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFFFFFFFE3E3E36E6E6EFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
E1E1E1FFFFFFF8F8F80E0E0E0505055A5A5AF3F3F3FFFFFFF8F8F8FAFAFA
FFFFFFFDFDFDFBF9F8FFFDFCDEDEDC626461EDEFECFBFFFEF4F5F7FEFFFF
FFFEFFFBF9FAFFFFFAFCFBF4FFFFFBDCDCDA0E0F0F202121444444FBF9FA
FFFDFEFFFEFFFFFFFFFFFFFFF6F6F6FFFFFFF9F9F9FFFFFFFAFAFAFFFFFF
FEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF979797151515232323171717
E4E4E4FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8F8F6FFFFFBFFFFFBFCFBF7FFFFFB
CCCBC7080804E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFAFFFFFBFAF9FCFFFEFF97959E0403089E9E9AADAEA6393A34FFFFFD
FFFEFFB7B6BCD3D3D3FFFFFDFAF5F5FFFDFDFFFEFFFFFEFFF4F3F6FFFEFF
FEFFFFFBFCFEFBFCFEFEFFFFFEFFFFFCFDFDD8D8D8888886323230141412
6C6C6CBBBBBBFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FAFAFAFEFEFEE8E8E86A6A6AFFFFFF858585616161FFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFCFEFFFEFFFFFCFFFFFDFDFDFFF2FEFFF6FCFFFFF8F7FF
F2EDFF656370F9FFFAFBFFF4FFFCF9FFFBFFF8F8FEF5F8FFB4B5B7676767
1919192A2A2A737373C8C8C8FFFFFFF9F9F9616161818181242424FFFFFF
FAFAFAFFFFFFFBFBFBFCFCFCFFFFFFE2E2E2ABABAB696969808080D7D7D7
FAFAFAFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFBFBFBFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFAFAFAFEFEFEAEAEAEC8C8C8FDFDFDFFFFFFFFFFFFDDDDDD131313
0F0F0F1919191616160303039B9B9BFCFCFCFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFB9B7B87F7F7DFDFFFAF8FCF9FCFFFDFEFFFFFEFDFF
FDFAFFFFFEFFFEFDF8FDFCF5BDBCB520201C7374743B3C3E585858504E4F
FBF9FAFFFEFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC7A7A7A262626DDDDDD5A5A5A5C5C5C
232323E5E5E5FEFEFEFEFEFEFAFAFAFFFFFFFBFBFBFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFFFDFEFEFCFDFDFBFFFFFBFFFEFA
CAC9C5979793E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFF8F8F6
FEFEFAFBFBF7FFFEFFFFFEFFC0BEC700000404040063645C90918B9F9F9D
18171C000004F0EFF2FFFFFFFFFDFDFEF9F9FFFDFCFFFEFDFFFFFFF9F9F9
FEFFFFFEFFFFFEFFFFF8F9FBF6F7F9FEFFFFFEFFFFFEFFFFFAFBFBE0E0E0
8282823737371818185E5E5EC1C1C1F3F3F3FCFCFCFCFCFCF9F9F9FCFCFC
FFFFFFF9F9F9FAFAFA050505FBFBFB323232CACACAFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFFFDFDFFF9F9FAFAF8FCFFFDF8F9F9FCFDFFFEFEFFFFFCFF
FFF4FA665F62D6E2E0F1FFFFFEFEFFFFFCFFFFFEFFFEFEFCFEFEFEFEFEFE
FFFFFFD0D0D07676762323231A1A1A6666666868682F2F2F7D7D7DFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFF9F9F9F1F1F1ADADAD
6B6B6B6F6F6FC5C5C5FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFDFDFDFEFEFECDCDCDA8A8A8FFFFFFFCFCFCFAFAFA4C4C4C070707
000000000000000000A3A3A3FCFCFCFFFFFFFFFFFFFFFFFFFCFCFCFAFAFA
F9F9F9FFFEFF8B8C909F9EA3F7F7F5FFFFFAFFFFFBFAF8F7FFFDFFFEFBFF
FFFEFFFEFFFFF8FAF4ACAFA417180EAFB0A8EAE8E9110E14F8F7FA3D3D3D
656565FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFBFBFBFCFCFCF6F6F6575757363636ECECECFFFFFF8484847D7D7D
8C8C8C252525E9E9E9FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFEFEFCF7F7F5FFFFFBFFFFFB
FEFDF9FFFFFDF8F8F8FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFD
FFFFFBFFFFFDFAF9FCFFFEFFDEDDE30F0E130909050102000C0C080A0A08
070609AFAEB3FEFDFFFEFCFDFFFDFDFFFAFA8E8C8B090706353535AEAEAE
F8F9FBFEFFFFFDFEFFFEFFFFFEFFFFFEFFFFFEFFFFFBFCFCFEFFFFFBFCFC
FFFFFFFEFEFEDFDFDF9191913434341717175D5D5DB8B8B8FFFFFFFFFFFF
FFFFFFFBFBFBFFFFFF191919BEBEBE1C1C1CF8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFBFFF6F0FFFEF6F0F8F8F7FFFFFFFEFFFAF6FFF6F6FFFAF7FD
FFFBF6AEA5A0A5ADB8F2FFFFF2F7FFFBFBFFFFFEFBFFFFF8FFFEFDFFFFFF
F9F9F9FDFDFDFFFFFFFFFFFFDCDCDC8C8C8C383838050505E0E0E0FDFDFD
FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFDFDFD
FFFFFFFCFCFCBEBEBE7171715F5F5FC1C1C1FBFBFBF8F8F8FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF606060F5F5F5FFFFFFD6D6D6080808000000
0000000606060101014A4A4AFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFF6A6B6DCACDD4FCFFFFFDFDFBFFFCF5FFFDFAFFFDFBFCF5FCFFFCFF
FFFEFFF5F9F87E857E151C12DBDFD0FFFFF6FFFCFF0B050CFCFAFDFDFDFD
3C3C3C626262F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFF7F7F7FBFBFBFFFFFF
FDFDFDFFFFFFF3F3F33B3B3B595959FBFBFBFBFBFBFFFFFF959595626262
FBFBFB8585852F2F2FF0F0F0FDFDFDF4F4F4FFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFDFFFFFDFDFBFAFFFEFD
FFFEFDF6F6F4FFFFFFFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
F8F8F6FFFFFDFDFCFFF9F8FDDCDBE00706090000000202000B0A06010000
A6A4A7FFFEFFFFFDFFFFFEFFFFFDFDFFFDFDFDFBFAA3A1A0D8D8D8E5E5E5
FFFFFFFCFCFCF9FAFCFEFFFFFCFDFFF6F7F9FCFFFFFCFFFFFAFEFFFEFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFE6E6E69090903A3A3A0606065F5F5F
A9A9A9FEFEFEFBFBFB3939395C5C5C757575FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF8FFFAE8E0D8CB00030E2A394CBEB6C3070004AFB2B9FCFFFF
FFFDECF1E6E06B6D84ECF6FFF5FFFFF9FFFFFFFCF5FFFCF4FFFEFAFFFFFF
FFFFFFF9F9F9FEFEFEFFFFFFF9F9F9FFFFFF8B8B8B101010FAFAFAFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFB
FEFEFEFFFFFFF7F7F7FFFFFFFFFFFFC1C1C17171716B6B6BB0B0B0F5F5F5
FFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFBFBFBFAFAFAF0F0F0707070FFFFFFECECEC040404000000
050505000000020202686868FFFFFFFAFAFAFFFFFFF5F5F5FFFFFFF1F1F1
555555E4E5E9F3F7FFFBFFFFFCFCF8FFFEF6FFFBF6FFFCFBFFFBFFFFFCFF
FCFDFF494F4D353F3AEBF4ECF4FBEBFDFDF1FFFCFF271D26D2D0D3FEFFFF
F8F9F9BCBDBDDCDCDCFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8
FFFFFFD7D7D7262626727272FCFCFCFFFFFFFEFEFEFFFFFFBFBFBF3F3F3F
FFFFFFFEFEFE7777772E2E2EF5F5F5FEFEFEFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFEFD
FDFBFAFFFFFDFEFEFEFCFDFDFEFFFFFEFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFBF9FFFFFD
FEFEFCF7F7F7FCFBFEFFFEFFDAD9DE100F12010100010100070602514F4E
FFFEFFFDFBFEFFFEFFFFFDFFFFFEFFFFFEFDFFFEFDFDFBFA919191E0E0E0
F9F9F9FFFFFFFEFFFFF5F6F8FEFFFFFEFFFFFBFFFFFCFFFFF9FDFEFCFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFEBEBEB979797
4343430D0D0D5151513A3A3A141414D1D1D1FFFFFFFDFDFDFEFEFEFEFEFE
FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF6FFFAE29F9989485468EFF8FF2616201A0A0BACB3BBF0FBFD
FFFFF1BBB2AB0B091FECEFFFF7FFFFF8FFFFFCFBF4FFFFF6FFFFFBFEFEFE
FEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF4D4D4D0E0E0EFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFDFDFDCECECE7E7E7E
6464649F9F9FECECECFFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAFDFDFDFFFFFFFFFFFFFCFCFCC1C1C18D8D8D9999991F1F1F060606
010101010101000000E9E9E9FFFFFFFFFFFFFFFFFFFFFFFFD5D5D5656565
F7F7F7FDFEFFFCFEFFF8FBFFFFFFFBFFFDF4FFFEF6FFF7F4FFFCFFE9E3EB
3132325A5E5DF2F8F8F8FEFAFEFFF3FFFFF3FFFBFE463E47BBBABDF9FAFA
FEFFFFFCFDFDFDFDFDFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFF
C4C4C41414149D9D9DFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCE5E5E5414141
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FCFCFCFEFDFFFFFEFFFAF9FEE0DFE20A0A0A0503040402013F3E3AFDFCF8
FFFEFDF3F1F2F4EFF3FEFCFFFFFEFFFFFFFFFEFEFEFFFFFFFDFDFD6A6A6A
F4F4F4FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFE4E4E4A3A3A31B1B1B0101014B4B4B9C9C9CEAEAEAFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FDFDFDFFFFF8FFFFE9C9C6BB090F27F8F8FFF6DFD9120000D0DCE8F0FFFF
FCFFFFFFFEFBFFFBFFFFFAFFFEFDFFFCFEFFFCFFFBFCFFF8FEFFFDFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFBFBFBF6F6F60C0C0C050505F7F7F7F9F9F9
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9DDDDDD8D8D8D5E5E5E969696E6E6E6FFFFFFFEFEFEFBFBFBFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFEFEFEDFDFDF1A1A1A949494FAFAFA919191
1919194F4F4FE3E3E3FFFFFFFFFFFFFEFEFEFFFFFFB4B4B4828282FFFFFF
F9F9F9FFFEFFFFFBFFFFFCFFFCFAF9FFFFF8FEFFF5FDFEF8D2D1D41F1E23
807E7DFFFEFDFEFBFFFFFEFF8585780A0C00303030AAAAB0FBFFFFFCFFFF
FAFEFFFCFFFFFAFBFDFEFFFFFCFCFCFDFDFDFFFEFFFDFBFCFCFCFAADADAB
121210BABAB8FEFFFDFAFCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFBFDFDFB
FFFEFFFFFEFFFFFEFFFDFCFFC0C0C00F0F0F0100000B090AE8E6E5FFFFFB
9998945A5857A09B9F5B585EE5E4E7FDFCFFF9F8FBDFDFDFFDFDFD7D7D7D
B6B6B6FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFE3C3C3C343434A9A9A95757570C0C0C3D3D3D909090
E7E7E7FAFAFAFFFFFFFBFBFBFEFEFEFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFEFFF9FFFFF1F0F1E9101026E2DAEDFFF7E77B6A58838F9DEEFFFF
F9FFFFFFFFFFFFFDFAFFFCFCFFFAFFFFFCFFFBFFFFF9FFFAFEFFFDFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFBFBFB292929DCDCDCFFFFFF
FBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFBFBFBFFFFFFE5E5E59393936A6A6A828282E3E3E3FAFAFA
FAFAFAFFFFFFFFFFFFFBFBFBECECEC191919909090797979E4E4E4FFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFFFFFFF9F9F9919191A7A7A7FDFDFDFFFFFF
FFFFFFFFFDFFFFFBFFFFFCFFFFFEFDFCFDF5FBFEF5B7B9B3161717A5A5A5
FFFFF8FFFEFBFFFBFFFEF8FFFFFFF4A1A395DCDEDBE8EBEFFBFFFFFAFFFF
F7FBFCFCFFFFFEFFFFF9FAFCFFFFFFFFFFFFFFFEFFFFFEFF898987191917
D1D1CFFFFFFDF7F9F6FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFCFCF8FCFCFA
FFFEFFFBFAFFFFFEFFFFFEFFA9A7A60604030604077B797CFFFBFBFFFEFB
8B87848B8686FFFDFFDEDBE2090A0EFBFCFFFAFBFFBFC0C22F3032161719
EAEAEAFDFDFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF0E0E0E383838FBFBFBFFFFFFF9F9F9B4B4B4676767
0808082F2F2F878787DCDCDCFFFFFFFDFDFDFAFAFAFCFCFCFFFFFFFCFCFC
FAFAFAFFFFFDF5F7F2FFFFFDB7B3BD332A2DFFFDE8978E7D363E50E9F7FF
FBFEFFFFFEFFFDFFF2FFFFF4FFF9FFFFF9FFFBFFFFF8FFFBFCFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E3E3EB2B2B2FFFFFF
FDFDFDFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFF7F7F7EEEEEEA5A5A5656565
7E7E7ED9D9D9FBFBFBFFFFFF949494ACACACF9F9F9FFFFFF585858EEEEEE
FDFDFDFBFBFBFFFFFFFFFFFFF4F4F46E6E6ECECECEFFFFFFFEFEFEFFFFFF
FCFCFCFEFDFFFFFCFFF8F5FCFDFBFAFFFFF898979014130ECECCCBFFFEFA
FFFFF4F7F6F1FFFBFFFEF9FFFFFEF7FBFBEE8F8F8DD9DADCFBFFFFF7FFFF
FBFFFFFCFFFFFAFBFDFEFFFFFFFFFFF8F8F8F5F3F4666465343231EBE9E8
FFFFFDFFFFFDFBFDFAFCFEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFEFEFAFFFFFB
FFFEFFFCFBFFFFFEFFFEFEFE949291020000110F12FFFEFFFBF6F8FFFBF8
DDD9D5120E0BF3EDF4FFFDFF79797F898C91FCFFFFFBFCFFF3F4F8F2F3F5
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFEFEFEADADAD343434272727FFFFFFFCFCFCFFFFFFFAFAFAF6F6F6
FFFFFFC1C1C16A6A6A1919192A2A2A7C7C7CD0D0D0FAFAFAFFFFFFFFFFFF
FEFEFEFFFFFFFEFFFFFEFEFEFDF8FABCB4B166604E61615400000BE7EDFF
FFFCFFFFFEFFFBFFF3FCFFF3FFFBFFFFFAFFFCFFFFF9FFFFFEFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFD
EDEDEDA8A8A8717171707070B1B1B1FCFCFCFFFFFFF7F7F7FFFFFF494949
E7E7E7FFFFFFF8F8F8D5D5D5575757E8E8E8FDFDFDFFFFFFFFFFFFFDFDFD
FCFCFCFDFCFFFEFEFFFEFFFFFFFEFD6864602D2724E6E0DDFDF9F6F8F7F0
FFFFEFFFFFF8FDFBFFFBF9FFFDFDFBFFFFF4FFFBF86E6C6FEDF3F3F9FFFF
FBFFFFEFF5F5FEFFFFFEFFFFFCFCFCF3F3F3484647535152EBE9E8FEFCFB
FFFFFDFFFFFDFDFFFCFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFAFEFFFB
FCFBFFFFFDFFFDFCFFF8F8F854534F0100009C9A9DF8F5FBFFFDFFFFFEFB
FFFDF71F1917E2DBE2FFFCFFA6A9B0454950F9FDFFFCFFFFF9FCFFFEFFFF
FEFEFEFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE
FAFAFAFCFCFC6363638F8F8F000000FDFDFDFFFFFFFFFFFFFFFFFFFDFDFD
F3F3F3FFFFFFF8F8F8FEFEFECACACA7373732B2B2B262626616161C5C5C5
FFFFFFFBFBFBFEFCFDF9F7F8FFFDFFFFFDFCF5FAF3FAFFF9555754AEACAF
FFFAFFFFFCFFF8FFFDF8FFF8FFFFF8FFFDFBFFFEFFFEFFFFFEFDFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCF6F6F6FFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFC1C1C1F8F8F8FDFDFDABABAB7C7C7C6F6F6FBCBCBCF0F0F0FEFEFE
6B6B6B7575755F5F5F333333FCFCFCFFFFFFFBFBFBD8D8D8525252F8F8F8
FFFFFFFEFFFFF6FBFEEBEFF04343434F4949FFF5F4FFFAF9928984030100
7C8067A5ADA0000019DEDFFDFEFFFFD8D5CCFFFCFA857E81B2B6B7F9FFFF
F4FAFAFBFFFFFEFFFFFEFFFFE0E0E0312F306C6A6BFAF8F9FFFEFDFFFEFD
F9F9F7F8F8F6FEFFFBF9FBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFF9FAFCF7
FDFCFFFFFDFFF7F6FBFFFFFF0F0E0A040300FCF9FFFFFDFFFFFBFDFFFEFB
F9F4EE746E6B1F181FF4F0FA878993515860FBFFFFFBFFFFFBFEFFF6FAFB
FFFEFFFAFAFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F90E0E0EEAEAEA151515E6E6E6FFFFFFF6F6F6FFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF2F2F2D4D4D48F8F8F292929
181818616161B3B1B2FFFDFFFEF9F9FBFBFBF9FFFFF9FFFD64635C544E4B
FFFBFEFFFDFFF8FFFFF8FFFDFFFFF6FFFEF8FFFDFFFFFDFFFEFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF4F4F4
F8F8F8FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
777777878787FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C58C8C8C707070
7474746A6A6A808080FDFDFDFFFFFFF8F8F8FEFEFEECECEC101010FFFFFF
FFFFFFF8F9F9E2E6E5222625716F70FCF5F8FFF6F8FFFCFA575048C0BEAD
DDE1C4000300555674C5C5E9F7F7FDC5C4BD342C2A0E070AEBEFF0F0F9FB
F9FFFFFBFFFFF7FBFCD0D1D31A18198E8C8DFFFEFFFBF9FAFFFEFDFFFEFD
FFFFFDFFFFFDFEFFFBFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFAFEFFFB
FFFEFFFFFDFFFFFEFFFBFBFB0100006F6E6AFFFCFFFDF7FFFFFCFEFFFEFB
FFFBF3D1CBC8040004605C6600020BBFC7CFF0F7FFF9FDFFFCFFFFFCFFFF
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
F9F9F9AAAAAA434343F8F8F8FFFFFFFAFAFAFBFBFBFFFFFFFBFBFBFCFCFC
FFFFFFFAFAFAFFFFFFF7F7F7FDFDFDFBFBFBFFFFFFFFFFFFF9F9F9FFFFFF
DFDFDF9292923F3C420B090C5F5D5CA7A9A4EBF1EFEDF3F1B3B1B0A39F9C
FFFEF7FFFFF8FCFFFFFCFFFFFFFFFAFFFEF9FFFDFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFFFFFF
FCFCFCFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEF5F5F5FCFCFC5B5B5B
414141EDEDEDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFDFDFDFFFFFF0E0E0EF2F2F2
FCFCFCC7C7C7151513929290FFFEFFFFFEFFFAF5F7FFFEFB6464588F907C
FFFFE49A9A8D0B0527FEF7FFFBF7FFFFFFFAFFFEFBFAFAF8FBFFFFF8FFFF
F4FCFEF6FBFEB7BBBC141517ADABACFFFEFFFEFCFDFFFEFFFFFEFDFFFEFD
FFFFFBF6F6F2FDFFFAFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFFBFCFEFB
FFFEFFFCFAFFFFFEFFBFBFBF010000F8F7F3FFFCFFFFFCFFFFFDFFFFFEFB
FFFCF6F3EDEA231C21F2EEF8FCFEFFF5FCFFFBFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFDFDFDFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA4A4A4CECECEFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FBFBFBFFFEFFFFFEFFE5E4E797979550524D0206034B4F4EA2A0A1EEECEB
FFFFF5FFFFF6FFFFFDFFFFFFFFFFFBFFFEFAFFFEFDFFFEFFFFFFFFFEFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFB2B2B2505050
F4F4F4FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFFFFFF
FEFEFEFEFEFEFEFEFEFCFCFCFFFFFFFFFFFF797979989898212121D3D3D3
A6A6A6131313B8B6B5FFFEFDFEFCFDFEFEFEFFFFFFFCFCF8BDBEB43D3E2C
FFFFE5FDFAEF130A27DDD5F8FFFCFFFDFDFBFDFDFBFEFFFFFAFFFFF4FCFC
FBFFFF9A9DA1101113C8C8C8FFFEFDFFFEFDFFFEFFFAF9FCFFFEFFFEFCFB
F4F4F2FFFFFDFEFFFFFDFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFDFFFEFDFFFDFFFFFDFFFFFDFFFFFCFC
FFFDFDF0EAEA20191CC0BAC1FCFAFFFDFDFFFEFEFFFBFBFFFDFEFFFFFEFF
FEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFEFDFFFFFFFFFFFFFDEAEBEBABABAB525051100E0D
41403C94938FE5E3E2FFFEFDFFFEFDFFFDFCFFFEFDFFFFFFF9FDFEFCFFFF
FFFEFFFBFAFDFCFFFFFCFFFFF9F9F7FFFEFDFFFCFCFFFEFDFEFFFDFDFFFC
FEFCFDFFFEFFFEFFFFFEFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFDFDFDFEFEFE
FCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFCFCFCFFFFFFDADADAFFFFFF
F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBF6F6F63E3E3E1C1C1C979797
1E1E1ED3D3D3FEFFFFFEFFFDFAFBFBFEFEFCFFFFFDFBFAF6FEFDF6605D54
959287FFFDF9524E589B97A5FEFDFFFEFFFFFEFFFFF8FBFFF8FCFBFCFFFF
71727626272BDFDFDDFDFCF7FFFEF8FEFAF6FFFEFFFAFBFFFDFBFEFFFEFF
AEAEACB3B4B4FCFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFF8F3F5FFFDFFFAF5F7
FFFBFEDDD6D9A69FA2C4BFC3FFFCFFFDFBFFFBF9FFFFFEFFF9F8FDFEFEFE
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFCFBFBF9F8
B2B0AF5C5A591917162E2C2B858382DFDDDCFFFEFDFEFEFEF9FDFEFCFFFF
FFFDFFFFFEFFFCFFFFF3F9F7FFFFFDFFFBFBFFFDFDFFFFFDFCFFFDFCFFFD
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFE5E5E5FAFAFAFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEE3E3E30F0F0F4C4C4C
EDEDEDFDFEFEF8F9F9F6FAF9FEFFFDFEFFFDFBFAF6FEFDF9FFFEFAFFFEFA
8F8B88726E6B171516525154FBFAFFFCFCFFFBFEFFFCFFFFF3F7F6525451
3F3E43ECEAEDFFFFFBF8F5EEFFFEF4FFFEF7FBFEFFFCFEFFE8E6E9A09B9B
8985822D2D2DD6DAE5F4FAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFBF9FAFFFDFFFFFDFF
989194D9D2D5FFFBFEFFFCFFCDC9D392909BFFFDFFFEFDFFFEFDFFFDFDFD
FFFFFFFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFDFC
FDFBFAFFFEFDF7F5F4C8C6C56969691515152828287B7B7BC9CDCCFEFFFF
FBF9FAFFFEFFF3F7F6FBFFFFFCFCFCFBF9FAFFFEFFFDFDFDFAFEFDFAFEFD
FFFCFEFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCFBFBFBF9F9F9
FBFBFBFFFFFFFBFBFBFFFFFFCECECE747474FFFFFFFEFEFEFFFFFFFDFDFD
FCFCFCFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFE6D6D6D0A0A0A
C7C7C7FEFFFFFEFFFFFCFFFFFEFFFDFCFEFBFFFFFBFDFCF8FFFEFBFFFCF9
FFFDFAFCF8F5F9F7F8010003E9E8EDFEFEFFFCFFFFE6E9EE363C3C5A5E5D
F4F2F5FBF6F8FFFEFBFFFFF6FFFCEEFFFFF8F4FAFFF8FBFFFFFDFF4F4840
DBD4CC666463D7DDE9F8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF8F9FFFEFFFAF5F7FDF8FA
F2EBEE3B3437FFF8FBFDF8FC2B2731E7E5EEFFFEFFFFFEFFF6F5FAFFFEFF
FDFDFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFFFFFEFDFFFDFC
FFFEFDFFFEFDFEFCFBFCFCFCFFFFFFFFFFFFC9C9C97475752324241F1F1F
726D6FC2BDBFF9FDFCFBFFFFFFFFFFFFFEFFF9F7FAFEFEFEFBFFFFFCFFFF
FFFDFFFFFCFFFFFFFFFDFEFEFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFF
FDFDFDFFFFFFFBFBFBBBBBBB151515CDCDCDFFFFFFFCFCFCFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFA9A9A93C3C3C
1F1F1FE8E9E9F8F9F9F5F9F8FEFFFDF2F4F1FFFFFBFFFFFBFDF9F6FFFEFB
FFFEFBFFFDFDF3F1F2202020B6B5BAF6F7FBE0E3E81E2126767C7CF6FAF9
FFFEFFFFFDFFFFFBF8FEF9F1FFFFEDFFFEF7F1FEFFF2FCFFFFFDFDFAEBE3
83796D8A8683BDC4D2F7FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFAF8F9FFFDFFFFFDFF
FFFDFFA7A2A49A9597979296ACA9B0FFFDFFFBFAFFF4F3F8FDFCFFFFFEFF
FDFDFDFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
F6F6F6FFFFFFFFFFFFFBFCFEFEFFFFFEFFFFF9FAFCFEFFFFFFFFFDCDCBCA
888282342F31171B1A5E6464B5B6B8F5F4F7FFFEFFFDFEFFF5FBFBFCFFFF
FFFDFFFDF6F9FBF9F8FFFFFDFDFDFDFEFEFEFEFEFEFDFDFDFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFFFFFFFFFFFFF7F7F7FEFEFEFFFFFFFCFCFCFBFBFB
FFFFFFFDFDFDE6E6E60F0F0FC8C8C8FFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFCFCFCFFFFFFF3F3F3858585FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C5303030
7B7B7B363737FCFDFDFCFFFFFCFEFBFEFFFDFDFBFAF8F6F5FFFEFBFFFBF8
FBF6F6FFFBFBE1DFE09D9D9DBCBBC0CACBCF0C0F149DA0A5FBFFFFFCFFFF
F8F7FAFFFEFFFEFEFAFFFEF4FFF6E7A19893000A1DC3DCF0F8EFF0FFF9EF
FFF7EC221C195D6675F2FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFCFDFDF8FAFFFDFF
F7F2F4FFFDFF2D282A444245FEFBFFFFFEFFFFFEFFFFFEFFFFFEFFFEFDFF
FFFFFFFCFCFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFFCFCFCFEFFFFFEFFFFFBFCFEFEFFFFFEFFFFFDFDFDFFFEFDFFFEFB
FFFAFBFFFBFBD6DAD98C9292424347111015555459A9AAAEF0F5F8FCFFFF
FFFAFCFFFCFFFFFEFDFBFBF9FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FFFFFFFEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFEFEFEFFFFFF
F6F6F6FFFFFFAAAAAAD7D7D7FFFFFFF9F9F9FEFEFEFFFFFFFEFEFEFFFFFF
FBFBFBFBFBFBFFFFFFB3B3B3464646FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFEFEFEE6E6E61A1A1A
FEFEFE535353626363FCFFFFF8FAF7FCFCFAFAFAF8FFFEFDFFFEFBFFFCF9
FFFDFDFFFEFDFFFEFFFFFFFFA9A8AB0E0F13B9B9BFFCFFFFFCFFFFFCFFFF
FDFCFFFFFEFFFCFBF7FFFEF6FFFBEDBAB1AC3C51649DB3C8FFFCFDFFF1E6
FFF7EBFFFCF9636C79EDFAFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFEFCFDFCFAFBFFFEFF
FFFEFFFFFEFFE8E3E5E9E7EAFEFBFFFAF9FFFEFDFFFFFEFFFCFBFEF9F8FB
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFBFAFEFCFBFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFBFCFE
F9FAFCFEFFFFFEFFFFF9FAFCFCFDFFFDFEFFFBFCFEFFFFFFFEFAF7FFFDFA
FFFCFBFFFDFDFCFFFFF6FCFCEFF2F6EBEBF197979D4245490D1517424848
ABA6A8EDE6E9FFFCFCFFFEFDFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFBFBFBFFFFFFF8F8F8
FFFFFFF8F8F8F6F6F6FFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFBFBFBFFFFFF
FAFAFAFFFFFFFFFFFF5A5A5A919191FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFF303030
F3F3F3F4F4F42E2F2F8A8B8BFFFFFFFFFFFFBDBDBBC0C0BEF7F5F4FFFEFD
F7F5F4FFFEFDFFFDFE7F7F7F242326D2D3D5FCFDFFFCFFFFFBFFFFF7FBFA
FCFAFDFFFCFFFFFDFDFCF7F1FFFFF1E9EAE2080D1EEFF1FFFFFDFFFFFDF4
FFFDF2F9F8F4F5FBFFF8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFEFFFFFEFFFFFDFE
FEFCFDF9F7F8FFFDFFFCFAFDFFFEFFFFFEFFFFFEFFFAF9FCFFFEFFFFFEFF
FDFDFDFDFDFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFCFCFCFCFCFCFEFFFFFEFFFF
FEFFFFFCFDFFFCFDFFFEFFFFFEFFFFFEFFFFFDFEFFFEFEFEFFFEFBFFFBF8
B6ACAB0E0808DFE3E2FBFFFFFCFFFFFBFBFFFEFEFFFBFEFFE5EDEFA8AEAE
4B464A140D10454040999796EDEDEDF8F8F8FFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFEFEFEFBFBFBFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFF4F4F4969696
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFDFDFD101010E8E8E8FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
F9F9F9FFFFFFDBDCDC1A1B1BB9B9B9FCFCFCA2A2A05A5A58FFFEFDFFFEFD
FFFEFDF5F3F2676767353535DFDEE1FFFEFFFEFFFFFDFEFFF9FDFAFCFFFD
FFFEFFFFF9FFFFFCFCFFFEFAFBFCF2FFFFFA27232DCAC6D4FCFAFDFEFDF9
FDFEF8FEFFFDF4F8FFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FEFFFFFDFEFFFAFBFDFEFFFFFBFBFBFEFEFEFAFAFAFFFFFFFEFDF9FFFEFB
FFF6F7635D5DF0F4F3FBFFFFFBFEFFFEFEFFFEFEFFFCFFFFF6FEFFF6FCFC
FFFDFFF7F0F3AEA9A95D5B5A131313383838898989DADADAFFFFFFFFFFFF
FBFBFBFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFEFEFEF4545458E8E8E
FCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFC3C3C32E2E2EFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFC2C3C3151515DBDBDBBCBCBC444444FCFAF9FFFEFD
F7F5F64341424C4C4CF8F8F8F1F0F3FFFEFFFEFFFFFEFFFFFFFFFBFFFFFD
FCFFFFFCFFFFFEFFFFFFFFFDFFFDFDFFFDFB94908D767475FFFEFFF8F8FE
FCFFFFFBFFFFFCFFFFFDFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEF9F9F9
F9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FBFCFEFDFEFFFDFEFFFFFFFFFFFFFFFFFEFDFFFEFDFCFAF9FFFFFDFFFEFD
FFFDFD9B9698B7BBBCFBFFFFF9FCFFFEFFFFF9F9FFFCFFFFF9FFFFFBFFFF
FFFDFFFFFCFFFFFEFDFFFFFDF4F4F4BDBDBD6969691212123131317B7B7B
D2D2D2FFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FBFBFB353535686868FFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFF8F8F8
FBFBFBFFFFFF717171858585FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FAFAFDFEFE9B9B9B292929D9D9D9191919FFFEFDE0DEDD
2A2829706E6FFCFCFCFEFEFEFFFEFFFEFDFFF8F9FBFEFEFCFFFFFAFFFFFB
FCFFFFFBFFFFFCFFFFFEFFFFFFFDFFFFFDFDE4D7CE190E08F1F1F9F8FFFF
F5FFFFF6FDFFFFFFFFFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF7F7F7FFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFF7F7F7FCFAF9FFFEFBFFFBF8F5F4F0FCFDFDF8F9F9
FFFAFCDEDCDF6B7171F5FDFDFEFFFFFAF9FCFFFEFFFDFEFFF8FEFEFCFFFF
FFFBFDFDF6F9F9F7F8FCFCFCFFFFFFFBFBFBFCFCFCFFFFFFC6C6C6727272
2020201F1F1F757575CACACAF8F8F8FFFFFFBDBDBD7C7C7CFFFFFFFAFAFA
FFFFFFF6F6F6FBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFF181818DADADAFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF646464414141090909DCDCDC1C1C1C
8F8F8FFFFFFFF9F9F9FFFFFFF8F8F8FFFFFFFFFFFFFDFDFBFFFFFAFFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF5FFFFFCFFFFFFEBE13A1D17DEE0EAE9FCFF
F0FFFFF3FFFFFFFBF8FFFCF9FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFF000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FCFDFFF7F7F7FFFFFFFFFEFDFCF8F5FFFDFA9A949114100DCCD0D1FAFFFF
FFFEFFFCFBFF545A5AF3FBFBFEFFFFFFFDFEFCFAFBFEFEFEFCFFFFFCFFFF
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF6F6F6FAFAFAFFFFFF
F9F9F9D1D1D17878782A2A2A1B1B1B6D6D6DA0A0A0FFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFF8F8F8FBFBFBFBFBFBFFFFFFFDFDFDFFFFFF8F8F8F
666666D4D4D41C1C1CFDFDFDFEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFAFAFAFBFBFBFFFFFF444444080808585858ADADAD
FEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFDFFFFF8FFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF4FFFFFCFFFFFFF1E733140F9FA1ABEEFFFF
F0FFFFF4FFFFFCF8F5FFFDF8FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFF
F8F8F8000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFFFFFAF8F7FFFCF9FFFDFAFFFCF7B5ACA5494541B1B6B9F7FFFF
F7FAFFD2D2D8171F21C6CCCCFBFBFBFFFDFDFFFDFDFFFEFDFCFFFDF8FCFB
FDF8FAFFFCFEFEFFFFFAFEFFFCFDFDFBFBFBFFFFFFFEFEFEFBFBFBF8F8F8
FFFFFFFEFEFEFFFFFFCDCDCDDADADA8C8C8C3737370B0B0B616161B1B1B1
EEEEEEFFFFFFFBFBFBFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEF6F6F6B4B4B4
5353538585856F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF1F1F10B0B0B666666FDFDFD
FFFFFFFFFFFFF8F8F8FCFCFCFCFCFCFEFEFEFFFFFDF8F8F4FFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFEFFFFFCFFFFFFFEFFEBD7CEB7A39EABADB7F1FDFF
F4FFFFF8FFFFFFFFFBFDF7F4FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFA070707FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFFFCF9FDF5F0FFFDF6F7ECE4110B08EDF4F8F6FFFF
FBFFFFFBFEFFF7FFFFF4FAF8FEFEFCFFFEFBFFFDFBFFFDFAFCFEFBFEFFFD
FFFDFFFFFEFFFCFFFFFAFEFFFCFDFDFFFFFFF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDA7A7A7535353FBFBFBFFFFFFFBFBFBE3E3E39E9E9E3E3E3E
0F0F0F5858589F9F9FEAEAEAFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFCBCBCB
2F2F2F2F2F2FC1C1C1F9F9F9FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FCFCFCFEFEFEFEFEFEFCFCFC4F4F4F060606CACACA
FAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFDFFFFFBFFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFFFEFFFFFEFFFFFCFFFFFBF6FFFBFAFEFEFFF8FFFF
F2FBFEF9FFFFFCFCFAFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEF8F8F8FFFFFF
FFFFFF000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFDFBFAFFFBF8FFFDFAFFFDF6FFFBF3FFFAF22C2623BDC7CCF4FFFF
F4FAFFFBFFFFF2FBFDF9FFFFFFFEFDFFFDFBFFFDFBFFFEFAFEFFFBFEFFFD
FFFBFDFAF8F9FBFFFFFBFFFFFCFDFDFFFFFFFFFFFFEFEFEFFFFFFFFEFEFE
FCFCFC8E8E8E191919EBEBEBFFFFFFF6F6F6FFFFFFFFFFFFFDFDFDFFFFFF
E9E9E9A0A0A05454540404044C4C4C919191E1E1E1FFFFFFFEFEFEF1F1F1
070707111111FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFF0F0F0FFFEFF84838658595B17181A
E8E9E9FDFEFEF6F6F6FFFFFFFFFFFDFFFFFDFBF9F8FCFCF8FFFFFAFFFFFD
FEFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFEFFFFFBFDFFF9FDFCFBFFFBFFFF
F4FAFAF8FEFAFEFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FCFCFC050505FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFEF9F3FFFEF6FFF9F0FFFDF394908C747D82F3FFFF
F9FFFFF9FDFFF9FFFFFBFFFFFFFEFDFFFEFBFFFDFBFFFEFBFEFEFAFDFFFC
FFFEFFFFFEFFFCFFFFF9FDFEFEFFFFF5F5F5FFFFFFFFFFFFFBFBFBFDFDFD
E2E2E2272727E5E5E5FBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFF3F3F3AAAAAA5E5E5E0D0D0D3C3C3C8D8D8DE4E4E4
0E0E0E515151FEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFF7F5F6FFFFFFFFFFFFFAF9FC99989B5C5D5FB3B4B6
717272FCFDFDFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFFFDFFFFFBFEFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFEFFFFFCFFFFFAFFFFFEFFF9FDFE
FCFFFDFCFFFDFAFBFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFBF8FFFFF8FFFDF5FFFEF4FFF9EEDDD9D50F0F17F8FAFF
FBFAFFFEFEFFFDFDFFFEFFFFFAFAFAFFFEFDFFFDFCFFFEFDFFFFFDFFFFFD
FFFFFFD2D2D2A7A8AAFEFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
CFCFCFEEEEEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFF1F1F1B9B9B96464643B3B3B
0D0D0D8B8B8BFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFBEBEBE444444FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFDFFFEFBFFFEFAFCF9F0FFFDF2FFFEF4FAF6F2221F26DDDBE8
FFFDFFFFFDFFFDFCFFFFFEFFFFFEFFFEFEFEFFFFFDFFFFFDF7F7F5FCFCFA
FFFFFFECECEC141316F9F8FBFFFFFFFFFFFFFBFBFBF7F7F7FCFCFCFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFDFDFDF7F7F7
010101A1A1A1FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFBFBFBD5D5D5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFDFEFFFEFDFFFEFBFFFEFAFFFCF5FFFFF6FFFFF4F3EFEB1F1C239F9DAA
FEFCFFFFFDFFFDFCFFFEFDFFFFFEFFFFFFFFFFFFFDFCFCFAFFFFFDFFFFFD
FFFFFFFBFBFB2E2D30C0BFC2FAFAFAF9F9F9EFEFEF5F5F5FFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFFA5A5A5
2121218A8A8AFCFCFCFFFFFFF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFEFCFDFDF8F8FFFEFBFFFEFAFFFFF8FDFAF1E5E4DFA29FA6C2C0CB
FCFAFFFDFCFFFFFEFFFEFDFFFEFEFEFDFDFDFAFAF8FAFAF8FFFFFDFAFAF8
FAFAFAFFFFFF7C7B7E79787BFFFFFFD8D8D82828289E9E9EFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFBFBFB606060
555555696969FFFFFFF9F9F9FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFEFFFEFDFFFDFAFFFCF8FFFEFAFAF9F5FFFDFFFDFCFF
FFFEFFFFFEFFFFFEFFFDFDFDFEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFBFAFDC3C2C5343336EDEDED1C1C1C999999FEFEFEFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC131313
959595525252FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFEFFFFFEFFFFFEFF
FDFBFEFFFEFFFFFEFFFFFEFFFFFDFDFFFBF8FFFEFBFFFEFDF7F6F9FFFEFF
FCFBFFFFFEFFFFFFFFFEFEFEFEFEFCFFFFFDFFFFFDF5F5F3FFFFFDFFFFFF
FCFBFEFFFEFFFFFEFF0B0A0D858585BABABAFFFFFFFFFFFFFFFFFFFAFAFA
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFBFBFBFAFAFAFEFEFEC5C5C54A4A4A
E5E5E5717171F4F4F4FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FDFCFFFFFEFFFCFAFDFFFEFFFFFEFFFEFCFBFFFDFCFDFBFCFFFFFFFFFEFF
FAF9FCFFFFFFFFFFFFFFFFFDFFFFFDFBFBF9FEFEFCFFFFFDFFFFFFFCFCFC
F7F6F9FFFEFFFFFEFF535255191919A2A2A2FBFBFBFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666666888888
FEFEFEFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFEFCFFFFFEFFFFFEFFFDFBFCFFFDFEFFFEFFFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFCFCFCFAFCFCFAFFFFFDFFFFFDFFFFFDFEFEFEFFFFFF
FFFEFF9D9C9FFEFDFF98979A4C4C4C181818A7A7A7FFFFFFFFFFFFFBFBFB
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFEFEFEFBFBFBFDFDFDFDFDFDF9F9F90F0F0FE7E7E7
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFEFEFCFFFFFDFFFFFFF5F5F5
727174535255FFFEFFDFDEE1171717D6D6D6171717999999FFFFFFFEFEFE
FAFAFAFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFADADAD414141FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDF9F9F7FEFEFE606060
3C3B3EEFEEF1FEFDFFFFFEFF252525C7C7C7E5E5E51D1D1D979797FBFBFB
FFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFCFCFC989898BDBDBDFFFFFF
F9F9F9FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFDCDCDC4C4C4C
F9F9F9FFFFFFFFFFFFFCFCFCA2A2A2B0B0B0FCFCFCE0E0E0242424676767
F6F6F6FFFFFFFCFCFCFDFDFDFFFFFFF7F7F7F8F8F8FCFCFCFFFFFFFFFFFF
FCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFEFEFEFCFCFC
FFFFFFF8F8F8FAFAFAFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFEBEBEB646464
1F1F1FD0D0D0FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFF8F8F8FCFCFCFEFEFE
FFFFFFFDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFDFFFFFEFFFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFBFBFBFCFCFCFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF
A3A3A3181818949494F8F8F8FFFFFFFCFCFCFCFCFCFBFBFBFFFFFFFFFFFF
FCFCFCFDFDFDFDFDFDFFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFAFAFAFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF7F6F9FFFFFFF9F9F9
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FAFAFAFFFFFFFCFCFCFDFDFD
FEFEFED8D8D83131315C5C5CDCDCDCFFFFFFFFFFFFFFFFFFF7F7F7FDFDFD
FDFDFDFFFFFFA2A2A2CECECEFFFFFFEFEFEF696969F8F8F8FFFFFFFFFFFF
F8F8F8FFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFAFAFAFFFFFFFAFAFAFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFE7474741313136C6C6CEAEAEAFDFDFDFFFFFFFCFCFC
FFFFFFFCFCFCBEBEBE2B2B2BFDFDFD898989666666FFFFFFFFFFFFFBFBFB
FDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFDFEFFFDFEFFFDFFFEFFFFFDFFFFFEFFFFFFFF
FFFFFFFEFFFDFEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFEFDFFFFFEFFFCFCFC
FDFCFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFF9F8FBFFFFFFFCFCF8FDFEF8
FFFFFBF9F9F9FCFDFFFEFFFFE8E6E9716F72121315808181F5F5F5FEFEFC
FAFAFAFFFFFFFBFBFB292929C1C1C1323232BFBFBFFEFEFEFEFEFEFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFCFFFBFBFFF8FCFFFBFFFCFFFFFBFFFCF9FFFFFFFF
F8FAF7F9FEF8FCFFF8FEFFFAFFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFFFDFFFFFBFEFFFBFEFFFDFEFFFFF9FAFCFBFCFEFEFFFF
FBFCFFFEFFFFFCFBFEFEFEFEFEFCFDFFFEFFFBFBFFFEFFFFFEFEF1FDFEEC
FFFFF6FEFFFDF9FDFFFCFEFFFFFCFFFFF9FFD8DDE15159591A1A188D8C88
E5E5E3FFFFFFFFFFFF9696963D3D3D202020F9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFBFFFBF9FFF8FBFFFBFFFCFFFFFBFFFFFCFFFFFFFF
FEFFFDFCFFFBFBFFF7F4F6F0FFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFEFFFFFEFFFFFEFFFFFEFFFF
F7F8FCFFFEFFFFFEFFFFFEFFFFFDFDF9F7F8FBFEFFFCFFFFF9F9EDEBECDA
0B0C02414542293038F1F3FFFEF8FFFFFCFFFBFFFFF9FFFFCDCDCD605E5D
0F0F0F4A4A4AA4A4A4EFEFEF101010CFCFCFFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFCFFFFFBFFFDFCFFFDFFFEFFFFFDFFFFFEFDF9F9F7
F7F8F8FCFFFFFCFFFDFEFFFDFFFEFFFFFBFDFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFDFCFFFFFEFF
FDFCFFFFFEFFFFFEFDFCFBF7F1EDE99C9A999B9EA5A5A8AFFFFEFFFFFFFA
DFE4DD9FA5A1E8EAF4FCFCFFFCFBFEFFFFFDF9FDFCFCFFFFFFFEFFFDFCFF
FAF9FC9D9D9D4C4C4C0F0F0F383838717171FFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFEFFFFFDFFFFFEFDFFFEFD
FEFFFFFEFFFFF8FCF9FEFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFBFAFDFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFDE3E1E2101115D5D5DBFFFDFFFDFCFF
F7FBF8DADEDD8E8E96F9F9FFFEFFFFFBFDFAF7F8FAFEFFFFF8F9FDFFFEFF
FFFEFFFDFDFDFFFFFFE2E2E2919191141414EEEEEEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFEFFFEFFFBFCFFFAFCFFFBFEFFFDFFFEFFFFFDFFFCF6FDFFFEFF
FDFFFAF8FDF6FEFFFAFEFFFBFDFBFEFFFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFCF8F5FFFFF8FFFDFDFBF7FFFEFAFF706C69A09F9BFDFDFFFCFFFF
FFFEFFFFFFFFC4C7CC95989DFDFEFEFEFFFFFBFBFFFEFEFFFEFFFDFEFFFB
F5F5F3FFFFFFFFFFFFEEEEEEF6F6F6515151969696FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFFF8FFFFF6FFFFF8FFFFFBFEFFFFFEFEFFFFFDFFFFFEFF
FFFFFAFFFFF4FFFFF6FFFFFBF8F9FDFEFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFEFDFFFFFEFFFFFEFFFDFBFC
FFFDFAFFFEFAFFFDF5DAD5D500000E2621318D858266615BF5FCFFF9FFFF
EBE6E8FBF6F6E7ECF03B4248F7F8FCF7F6FBFDFBFFFEFEFFFDFFF9FBFEF5
FFFFFDFEFEFEFBFBFB151515E6E6E6C0C0C0272727FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFCFFFFFFFFF6FFFDF3FFFBF6FFFCFAFBFFFFF7FFFFF9FFFFF8F8FE
FFFFF8FFFDF2FEF3EBFFFDFBFBFFFFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFAFEFEF9FB
FFFDFBFFFEF8FFF8EEBBB7B4090818FFFBFF2A1B1E18100EE2EEF8F5FFFF
FFFDFA685E5C00010989929FFFFDFFFFFCFFFEFEFFFAFEFFFEFFFAFFFFF8
FFFFFDFBFBFBB5B5B5393939FDFDFDF8F8F83B3B3BB1B1B1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFBFFFFFFFEF8FFFCF4FFF9F6FFFBFAF9FFFFF5FFFFF5FCFFFEFFFF
FDFAF390877E1C0E0B352D2BA3ABADF7FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFEFBFFFFFCFFFFFDFF
FFFDFAFFFDF5FFFEF3CDC9C5100F1FFAF5FFFAEAEB070000C7D7E4EEFEFF
FFF7F9FFFBFAEDF7FEF2FFFFFBF8FEFFFCFFF7F8FCF8FCFDFEFFFBFEFFF9
FFFFFDFEFEFE5656569C9C9CFFFFFFFFFFFFCCCCCCA5A5A5FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFAFCF9FEFDF9FFFDFAFFF9FAFFFCFBF9FDFCF9FFFFFFFEFFFFFDFF
FFFEFDF9F8F4AEA5A6DCD5D8E5EBEBF9FFFFFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFBFFFFFDFF
FFFDFAFFFEF6FFF9EEF8F4F011101ED6D2E0FFFBF49289847B8A9FEEFCFF
FFF8FFFFF9FFF7FFFFF4FFFDFFFFF8FFFDFAFEFEFFFCFEFFFEFFFFFFFFFB
FDFDFBFAFAFA5B5B5BF4F4F4FEFEFEFCFCFCFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFBFAFFFEFDFEFFFDFFFEFDFFF9F8FFF8F6FEFFFFFCFDFDFFFCFDFFFAFB
FAFBFBFCFFFFF7F5F68F8D8EE1E5E6F6FAFBFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFBFFFFFCFE
FFFDFBFFFEF8FFFDF3FFFBF7B4B4BE16121CFFF4ECB6AEAC212B42F5FEFF
FFF7FFFFFBFFF8FFFFF7FFFAFFFFF4FFFFF8FEFEFFFCFFFFFEFFFFFFFFFD
FFFFFFFEFEFEFFFFFFF9F9F9FFFFFFFDFDFDF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFBFEFFFDFFFAFEFDFCFEF9FFFEF8FFFDFAFEFDFFFFFCFFFEEFF4FFFBFD
F9FDFEF6FFFFFEFFFDF8F8F66E6F73F0F1F5FFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFEFDFFFFFDFFFFFDFE
FFFEFBFFFEFAFFFEF6FFFEFAFFFEFFB1AEB4685F60696269373C50E8EDFF
FFFBFFFDF8F8FBFFFFF9FFFFFEFFF8FFFFF8FFFFFDFEFFFFFEFFFFFEFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFBF9FCFCFDFDFFFFFBFFFAEF524944BFBFC9FAF7FFA3939B100406
E6E9EDF6FEFEDFE0DAFFFFFB7A7D82B6B9C0FEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFFFEFBFFFFF8FFFEFAFFFEFFFFFEFFFEF9FDFFFDFFFEFDFFFAFCFF
FFFFFDFFFFFBFCFFFFFCFFFFFEFFFBFEFFFAFEFFFDFEFFFFFEFFFFFEFFFF
FFFFFFFDFDFDF8F8F8FEFEFEFBFBFBFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FEFFFFFEFFFFFFFEFFFFFDF8FFF7E9B3A49D474A59F8FEFFA9A2A94C4143
BEBDC2FBFAFDCAC1BA36312B00060EE4EDF8FCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFFFBF9FCFEFFFFFEFFFFF2F0F1FFFFFF
FCFFFBFAFEFBFEFFFFFEFFFFFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
F7F6FBFFFEFFFFFEFFFDF7F4FFFBEDEBDCD5000012D4D8EFE6DDE0170D0C
FCFAFFF9F9FFFFFDF5F8F3EDF2F9FFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFDFFFFFBFFFEFAFEFDF9F6FAFBF9FDFEFFFFFBFFFFFA
FCFFFBFAFFFCFCFFFFFEFFFFFFFFFBFFFFFBFCFFFFFCFFFFFFFFFFFFFFFF
FAFAFAFFFFFFF1F1F1FFFFFFFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
FFFBFDFBF4F7FBFFFFFBFFFFFFFFF1FFF8F11B162A1B1129FFF2F42D1B19
CFD5E0F4FFFFFBFFFBFFFFFAFDFBFFFEFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFDFEFEFDFEFFFEFFFFFEFFFF
FEFFFFFFFEFFFFFEFFFFFFFAFFFEEFFFFFF4F8FBFFF8FAFFFFFEFFF9F8F4
FEFEFCFCFFFFF9FFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FFFEFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFD
FFFBFBFFFAFBFBFFFFF9FFFFFAFAEDFFFEF6776F824A3C51A28D8A2D1E19
B5BDC8F1FFFFF8FFFFF9FBF6FFFCFFFFFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFBFEFFFBFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFEFFFFFFFBFFFFF1FBFBEEFEFEFFFEFEFFFBF9FAFFFFFB
FFFFFDFAFBFBFBFFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FCFBFFFEFEFEFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD
FFFDFAFFFBFBFFFEFFFDFCFFFFFEF2D3CEC45E5A68958E9DC5BDB8040100
C3C9D5F8FFFFF5FBF9FBFDF8FFFEFFFBFAFFFDFCFFFFFFFFFFFFFFFBFBFB
FFFFFF000000FCFCFCFFFFFFFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFDFFFFFAFFFFFBFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFBFFFFFBFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FBFAF6FFFEFDFEFDFFFFFEFFFFFCF1FCF7EFFFFDFFF5F5FFFFFFFAFFFFFB
FBFEFFF1F7FFFEFFFFFFFFFBF7F8F8FEFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFF000000FFFFFFF9F9F9F7F7F7FFFFFFFFFFFFF9F9F9FBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFDF7F8FAFDFBFCFFFDF6FFFDF8FDFDFFFCFEFFFFFEFBFEFCFB
F9FFFFF5FDFFFEFFFFF8F7F3FFFFFFFEFFFFFDFDFDFFFFFFFEFEFEFFFFFF
F3F3F3000000FFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFCFBFFFFFDFEFFFFFFFEFDFFFCF7A09895C5C5CBF9FCFFFEF9FBCFCDCE
888F97F8FFFFFDFEFFFFFEFDFFFFFFFCFDFFFFFFFFF9F9F9FFFFFFFBFBFB
FFFFFF020202FCFCFCFDFDFDF6F6F6FFFFFFF6F6F6FFFFFFFCFCFCFCFCFC
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFEFDFFFAF8F0EAE8343336FEFFFFFFFDFF28272C
EEF2F9F6FDFFFBFCFFF8F8F8FFFFFFFDFDFDFFFFFFC8C8C8FFFFFFF9F9F9
FDFDFD000000FFFFFFFCFCFCF9F9F9DCDCDCFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEF9F9FFFDFDFFFDFDFFFDFDACA7A9979598939498A4A7AC
FCFFFFFBFEFFFCFFFFFCFFFFFDFDFDFFFFFFF9F9F9000000484848FEFEFE
FEFEFE050505FFFFFFF0F0F0101010696969FCFCFCFFFFFFFDFDFDFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFFFFFFFFFDFBFCF6F4F6F7F7FDFDFDFFFCFB2E25263E4549F6FFFF
FFFEFFFEFBFFF9FEFFFBFFFFFFFFFFFBF9F8FFFFFF959595040404545454
FEFEFE000000D7D7D7141414000000E9E9E9FAFAFAFFFFFFFBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FBFFFFFFFFFFFFF7F5FFFDFBFCFFFFFEFFFFFFF6F5F2E8E7E3ECF1F7FFFF
FFFEFFFFFBFFFBFFFFF5FDFFFBFBF9FFFEFBFFFEFDFCFCFC121212000000
3434340606060D0D0D060606707070FDFDFDFFFFFFFBFBFBFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFDFBFCFFFFFEFFFFFFFBFAFFFCFBF8FFFFF7FFFF
FFFEFFFFFDFFFBFFFFF9FFFFFFFEFDFFFEFBFBF9F8FFFFFF9B9B9B080808
121212000000030303030303F0F0F0F9F9F9FFFFFFFFFFFFFDFDFDFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFEFBFEFFFFFFFEFFFFFCFAFFFDFBF9FFFFF8FFFF
FFFFFFFFFEFDFCFFFFFBFFFFFFFEFDFFFEFBFFFEFDF9F9F9EFEFEF030303
0000000000000606063A3A3AFAFAFAFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFBFFFFFBFFFDFFFFFEFFFFFEFAFFFFFBFEFEFFFCFEFF
FEFFFFFEFFFDFEFFFFFFFEFFFFFEFDFFFFFBFFFFFDFCFCFCFFFFFF434343
000000000000090909A3A3A3FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFDFFFFFDFFFCFFFFFDFFFFFFFAFEFFFBFFFCFFFFFDFF
FCFFFFFBFFFFFFFEFFFFFEFFFFFFFBFFFFFBFAFAF8FFFFFFF5F5F5A0A0A0
0E0E0E010101080808F3F3F3FFFFFFFEFEFEFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFCFFFDFFFFFDFFFCFFFFFCFFFEFFFBFCFFFDFFFCFFFFFCFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFFFBFFFFFBFFFFFDFFFFFFFFFFFFD5D5D5
0A0A0A030303191919FFFFFFFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFCFFFFFCFFFEFFFDFCFFFFFFFCFFFFFDFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFEFBFFFFFBFFFFFDFBFBFBFFFFFFF7F7F7
0A0A0A000000585858FDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFDFFFFFDFFFFFFFFFEFFFFFFFDFFFFFEFF
FCFFFFFCFFFFFFFEFFFFFDFFFFFEFBFFFFFBFEFEFCFFFFFFF8F8F8FFFFFF
3232320000009E9E9EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFF
FEFFFFFEFFFFFFFFFFFFFEFFFFFEFDFFFEFDFDFDFDFFFFFFFFFFFFFAFAFA
616161010101BDBDBDFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFCFCFC
8D8D8D020202DADADAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
A6A6A6000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6F9F9F9
D0D0D0000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6
FFFFFFFDFDFDFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFF
F7F7F7FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
grestore
%%Trailer
%%EOF
\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{373, 274.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Body", " ", "A", " ", "and", " ", "the", " ", "horse"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"l3", "=", "15"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ma", "=", "10"}], ";"}], "  ", 
   RowBox[{"(*", 
    RowBox[{"mass", " ", "of", " ", "sling", " ", "and", " ", "rope"}], 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"mh", "=", "2500"}], ";", "  ", 
    RowBox[{"(*", 
     RowBox[{"mass", " ", "of", " ", "horse"}], "*)"}], "\n", 
    RowBox[{"rH", "=", "0.5"}], " ", ";", " ", 
    RowBox[{"(*", "\"\<radius of horse\>\"", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"Cd", "=", "0.1"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"coefficient", " ", "of", " ", "drag"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Aa", "=", 
     RowBox[{"\[Pi]", " ", 
      RowBox[{"rH", "^", "2"}]}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"cross", "-", 
      RowBox[{"sectional", " ", "area"}]}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Body", " ", "B"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"l1", "=", "5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"l2", "=", "10"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d1", "=", "2.5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mb", "=", "5000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"B33", "=", 
     RowBox[{
      FractionBox["1", "12"], " ", "mb", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"l1", "+", "l2"}], ")"}], "2"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dB", "=", "2.0"}], ";", "  ", 
    RowBox[{"(*", 
     RowBox[{"joint", " ", "friction"}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Body", " ", "C"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"l4", "=", "2.55"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"d2", "=", 
     RowBox[{"l4", "/", "2"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mc", "=", "1000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C33", "=", 
     RowBox[{
      FractionBox["1", "12"], " ", "mc", " ", 
      SuperscriptBox["l4", "2"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dC", "=", "0.0"}], ";", "  ", 
    RowBox[{"(*", 
     RowBox[{"joint", " ", "friction"}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Body", " ", "D"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"d3", "=", "1.5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"md", "=", "12000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"boxH", "=", "2"}], ";", "  ", 
    RowBox[{"(*", 
     RowBox[{"rock", " ", "box", " ", "height"}], "*)"}], "\n", 
    RowBox[{"boxL", "=", "3"}], ";", "  ", 
    RowBox[{"(*", 
     RowBox[{"rock", " ", "box", " ", "length"}], "*)"}], "\n", 
    RowBox[{"D33", "=", 
     RowBox[{
      FractionBox["1", "12"], " ", "md", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["boxL", "2"], "+", 
        SuperscriptBox["boxH", "2"]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dD", "=", "0.0"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{"joint", " ", "friction"}], "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Height", ",", " ", 
      RowBox[{"friction", " ", "coefficient"}], ",", " ", 
      RowBox[{"and", " ", "gravity"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"H", "=", 
     RowBox[{"l1", "+", "l4", "+", "d3", " ", "+", " ", "boxH"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Mu]", "=", "0.5"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"g", "=", "9.81"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.512441095381968*^9, 3.512441183254314*^9}, {
   3.5124414964235287`*^9, 3.51244150356697*^9}, 3.512441806935925*^9, 
   3.512441890356752*^9, {3.5124422740960827`*^9, 3.5124422749429283`*^9}, {
   3.512442326949463*^9, 3.512442327620895*^9}, {3.5124425395236607`*^9, 
   3.5124425562869*^9}, 3.5124427796819077`*^9, {3.512443281519062*^9, 
   3.512443294286931*^9}, {3.512443471493733*^9, 3.512443475763206*^9}, {
   3.5124436371789427`*^9, 3.51244363786479*^9}},
 AspectRatioFixed->True],

Cell["\<\
Clear the integration variables. It may complain if not initialized first \
time through, just ignore complaint.     \
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"q1", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"q2", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"q3", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"q4", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"y", "[", "t_", "]"}], "=."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=."}], ";"}]}], "Input"],

Cell["\<\
Initial conditions and release angle.  These can be adjusted per the given \
situation.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"W1o", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Q1o", "=", 
    RowBox[{
     RowBox[{"-", "40"}], " ", 
     RowBox[{"\[Pi]", "/", "180"}]}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"W2o", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Q2o", "=", 
    RowBox[{"40", " ", 
     RowBox[{"\[Pi]", "/", "180"}]}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"W3o", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Q3o", "=", 
    RowBox[{"0", " ", 
     RowBox[{"\[Pi]", "/", "180"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vyo", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Yo", "=", "rH"}], ";"}], "  ", "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"W4o", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"q4", "'"}], "[", "t", "]"}], "//.", 
       RowBox[{"solDq4x", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "//.", 
      RowBox[{"solq4x", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q1", "[", "t", "]"}], "\[Rule]", "Q1o"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "\[Rule]", "Yo"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q1", "'"}], "[", "t", "]"}], "\[Rule]", "W1o"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}], "\[Rule]", "Vyo"}]}], "}"}]}]}],
    ";", "  ", 
   RowBox[{"(*", 
    RowBox[{"must", " ", "satisfy", " ", "the", " ", "constraint"}], "*)"}], 
   "\n", 
   RowBox[{"Q4o", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"q4", "[", "t", "]"}], "//.", 
      RowBox[{"solq4x", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q1", "[", "t", "]"}], "\[Rule]", "Q1o"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "\[Rule]", "Yo"}]}], "}"}]}]}], ";", 
   "  ", 
   RowBox[{"(*", 
    RowBox[{"must", " ", "satisfy", " ", "the", " ", "constraint"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Vxo", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}], "//.", 
       RowBox[{"solDq4x", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
      RowBox[{"solq4x", "[", 
       RowBox[{"[", "4", "]"}], "]"}]}], "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q1", "[", "t", "]"}], "\[Rule]", "Q1o"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "\[Rule]", "Yo"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"q1", "'"}], "[", "t", "]"}], "\[Rule]", "W1o"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"y", "'"}], "[", "t", "]"}], "\[Rule]", "Vyo"}]}], "}"}]}]}],
    ";", "  ", 
   RowBox[{"(*", 
    RowBox[{"must", " ", "satisfy", " ", "the", " ", "constraint"}], "*)"}], 
   "\n", 
   RowBox[{"Xo", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "//.", 
      RowBox[{"solq4x", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "//.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"q1", "[", "t", "]"}], "\[Rule]", "Q1o"}], ",", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "\[Rule]", "Yo"}]}], "}"}]}]}], ";", 
   "  ", 
   RowBox[{"(*", 
    RowBox[{"must", " ", "satisfy", " ", "the", " ", "constraint"}], "*)"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Release", " ", "angle", " ", "of", " ", "the", " ", 
     RowBox[{"string", ".", "  ", "This"}], " ", "is", " ", "adjustable", " ",
      "for", " ", "optimal", " ", 
     RowBox[{"performance", "."}]}], "*)"}], 
   RowBox[{"q4R", "=", 
    RowBox[{
     RowBox[{"-", "10"}], " ", 
     RowBox[{"\[Pi]", "/", "180"}]}]}], ";"}], "  "}]}], "Input",
 CellChangeTimes->{{3.512443026138897*^9, 3.512443033378024*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<W4o=\>\"", ",", "W4o"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<q4o=\>\"", ",", "Q4o"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Vxo=\>\"", ",", "Vxo"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Xo=\>\"", ",", "Xo"}], "]"}], ";"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"W4o=\"\>", "\[InvisibleSpace]", "0.`"}],
  SequenceForm["W4o=", 0.],
  Editable->False]], "Print",
 CellChangeTimes->{3.512418944715137*^9, 3.512441224261634*^9, 
  3.5124415229094143`*^9, 3.512441902757162*^9, 3.5124423316718807`*^9, 
  3.512442577378799*^9, 3.5124427837968063`*^9, 3.5124430373920927`*^9, 
  3.512443298372608*^9, 3.512443484519462*^9, 3.512443641655931*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"q4o=\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2.1650706736417784`"}]}],
  SequenceForm["q4o=", -2.1650706736417784`],
  Editable->False]], "Print",
 CellChangeTimes->{3.512418944715137*^9, 3.512441224261634*^9, 
  3.5124415229094143`*^9, 3.512441902757162*^9, 3.5124423316718807`*^9, 
  3.512442577378799*^9, 3.5124427837968063`*^9, 3.5124430373920927`*^9, 
  3.512443298372608*^9, 3.512443484519462*^9, 3.5124436416579447`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Vxo=\"\>", "\[InvisibleSpace]", "0.`"}],
  SequenceForm["Vxo=", 0.],
  Editable->False]], "Print",
 CellChangeTimes->{3.512418944715137*^9, 3.512441224261634*^9, 
  3.5124415229094143`*^9, 3.512441902757162*^9, 3.5124423316718807`*^9, 
  3.512442577378799*^9, 3.5124427837968063`*^9, 3.5124430373920927`*^9, 
  3.512443298372608*^9, 3.512443484519462*^9, 3.512443641660318*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Xo=\"\>", "\[InvisibleSpace]", "6.7620412951753615`"}],
  SequenceForm["Xo=", 6.7620412951753615`],
  Editable->False]], "Print",
 CellChangeTimes->{3.512418944715137*^9, 3.512441224261634*^9, 
  3.5124415229094143`*^9, 3.512441902757162*^9, 3.5124423316718807`*^9, 
  3.512442577378799*^9, 3.5124427837968063`*^9, 3.5124430373920927`*^9, 
  3.512443298372608*^9, 3.512443484519462*^9, 3.512443641662717*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Numerical solution to the equations of motion.  This switches regimes based \
on the normal force then the string angle relative to the arm for release.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"tf", "=", "1.0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"estimate", " ", "the", " ", "final", " ", "time"}], ",", " ", 
    RowBox[{
    "the", " ", "integrator", " ", "stops", " ", "when", " ", "the", " ", 
     "horse", " ", "hits", " ", "ground"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"nIntPnts", "=", 
    RowBox[{"50000", " ", "tf"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "number", " ", "of", " ", "entry", " ", "points", " ", "for", " ", 
    "integrator"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"tip1", "=", 
    RowBox[{"tf", "/", "nIntPnts"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "time", " ", "divisions", " ", "for", " ", "integrator", " ", "stepping"}],
    "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ti", "=", "0.0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"initial", " ", "time"}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dt", "=", 
    RowBox[{"tip1", "/", "2"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"outer", " ", "loop", " ", "time", " ", "division"}], 
   "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dts", "=", 
    RowBox[{"dt", "/", "5"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"small", " ", "time", " ", "division", " ", "for", " ", "table"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pntdiv", "=", "5"}], ";"}], " ", 
   RowBox[{"(*", 
    RowBox[{
    "number", " ", "of", " ", "points", " ", "at", " ", "each", " ", 
     "integration", " ", "step"}], "*)"}]}], "\n"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"flag", "=", "0"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"first", " ", "pass", " ", "flag"}], ",", " ", 
    RowBox[{
    "used", " ", "to", " ", "initiate", " ", "table", " ", "of", " ", 
     "data"}], ",", " ", 
    RowBox[{"do", " ", "not", " ", "change"}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"flagNa", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "flag", " ", "for", " ", "using", " ", "constrained", " ", "equations"}], 
    ",", " ", 
    RowBox[{"do", " ", "not", " ", "change"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"flagQr", " ", "=", " ", "0"}], ";"}], 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "flag", " ", "for", " ", "using", " ", "swinging", " ", "equations"}], 
    ",", " ", 
    RowBox[{"do", " ", "not", " ", "change"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dbFlag", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{
      "print", " ", "debugging", " ", "messages", " ", "when", " ", 
       "dbFlag"}], "=", "1"}], ",", " ", 
     RowBox[{"none", " ", "otherwise"}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"main", " ", "loop"}], ",", " ", 
     RowBox[{
     "ends", " ", "at", " ", "tf", " ", "or", " ", "when", " ", "the", " ", 
      "horse", " ", "hits", " ", "the", " ", "ground", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"y", "[", "t", "]"}], "=", "0"}], ")"}]}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"While", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ti", "\[LessEqual]", "tf"}], "&&", " ", 
      RowBox[{"Yo", "\[GreaterEqual]", "0"}]}], ",", "\n", 
     "\[IndentingNewLine]", "       ", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"flag", "\[Equal]", "0"}], ",", 
        RowBox[{"NaHold", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ma", "+", "mh"}], ")"}], " ", "g"}]}], ",", 
        RowBox[{"NaHold", "=", 
         RowBox[{"First", "[", 
          RowBox[{
           RowBox[{"Na", "[", "ti", "]"}], "/.", "sol"}], "]"}]}]}], "]"}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "     ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
        "next", " ", "we", " ", "set", " ", "which", " ", "eom", " ", "to", 
         " ", "use"}], ",", " ", 
        RowBox[{"depends", " ", "on", " ", "the", " ", "motion", " ", 
         RowBox[{"regime", ":", " ", "dragging"}]}], ",", " ", "swinging", 
        ",", " ", "free"}], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "      ", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"NaHold", ">", "0"}], " ", "&&", " ", 
         RowBox[{"flagNa", "\[Equal]", "0"}]}], ",", "\[IndentingNewLine]", 
        "                    ", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"dbFlag", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
           "                         ", 
           RowBox[{
            RowBox[{"Print", "[", 
             RowBox[{
             "\"\<Na[\>\"", ",", "ti", ",", "\"\<]=\>\"", ",", "NaHold"}], 
             "]"}], ";", "\[IndentingNewLine]", "                         ", 
            RowBox[{"Print", "[", 
             RowBox[{"\"\<q1[\>\"", ",", "ti", ",", "\"\<]=\>\"", ",", 
              RowBox[{"q1h", "[", "ti", "]"}]}], "]"}], ";", 
            "\[IndentingNewLine]", "                         ", 
            RowBox[{"Print", "[", 
             RowBox[{"\"\<q4[\>\"", ",", "ti", ",", "\"\<]=\>\"", ",", 
              RowBox[{"q4h", "[", "ti", "]"}]}], "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", "                   ", 
         RowBox[{"sol", "=", " ", 
          RowBox[{"NDSolve", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"eom1d", "==", "0"}], ",", 
              RowBox[{"eom2d", "==", "0"}], ",", 
              RowBox[{"eom3d", "==", "0"}], ",", 
              RowBox[{"eom4d", "==", "0"}], ",", 
              RowBox[{"eom5d", "==", "0"}], ",", 
              RowBox[{"eom6d", "==", "0"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"q1", "'"}], "[", "0", "]"}], "==", "W1o"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"q2", "'"}], "[", "0", "]"}], "==", "W2o"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"q3", "'"}], "[", "0", "]"}], "==", "W3o"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"q4", "'"}], "[", "0", "]"}], "==", "W4o"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "Vxo"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "Vyo"}], ",", 
              RowBox[{
               RowBox[{"q1", "[", "0", "]"}], "==", "Q1o"}], ",", 
              RowBox[{
               RowBox[{"q2", "[", "0", "]"}], "==", "Q2o"}], ",", 
              RowBox[{
               RowBox[{"q3", "[", "0", "]"}], "==", "Q3o"}], ",", 
              RowBox[{
               RowBox[{"q4", "[", "0", "]"}], "==", "Q4o"}], ",", 
              RowBox[{
               RowBox[{"x", "[", "0", "]"}], "\[Equal]", "Xo"}], ",", 
              RowBox[{
               RowBox[{"y", "[", "0", "]"}], "\[Equal]", "Yo"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
             "q1", ",", "q2", ",", "q3", ",", "q4", ",", "x", ",", "y"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1"}], "}"}]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", "   ", 
        RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
        "                   ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"q4h", "[", "ti", "]"}], "\[LessEqual]", "q4R"}], " ", "&&",
            " ", 
           RowBox[{"flagQr", "\[Equal]", "0"}]}], ",", "\[IndentingNewLine]", 
          "                       ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"dbFlag", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
             "                            ", 
             RowBox[{
              RowBox[{"Print", "[", 
               RowBox[{"\"\<q1[\>\"", ",", "ti", ",", "\"\<]=\>\"", ",", 
                RowBox[{"q1h", "[", "ti", "]"}]}], "]"}], ";", 
              "\[IndentingNewLine]", "                            ", 
              RowBox[{"Print", "[", 
               RowBox[{"\"\<q4[\>\"", ",", "ti", ",", "\"\<]=\>\"", ",", 
                RowBox[{"q4h", "[", "ti", "]"}]}], "]"}]}]}], "]"}], ";", " ",
            "\[IndentingNewLine]", "                      ", 
           RowBox[{"flagNa", "=", "1"}], ";", "\[IndentingNewLine]", 
           "                      ", 
           RowBox[{"sol", "=", 
            RowBox[{"NDSolve", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"eom1s", "==", "0"}], ",", 
                RowBox[{"eom2s", "==", "0"}], ",", 
                RowBox[{"eom3s", "==", "0"}], ",", 
                RowBox[{"eom4s", "==", "0"}], ",", 
                RowBox[{"eom5s", "==", "0"}], ",", 
                RowBox[{"eom6s", "==", "0"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q1", "'"}], "[", "0", "]"}], "==", "W1o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q2", "'"}], "[", "0", "]"}], "==", "W2o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q3", "'"}], "[", "0", "]"}], "==", "W3o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q4", "'"}], "[", "0", "]"}], "==", "W4o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "Vxo"}], 
                ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "Vyo"}], 
                ",", 
                RowBox[{
                 RowBox[{"q1", "[", "0", "]"}], "==", "Q1o"}], ",", 
                RowBox[{
                 RowBox[{"q2", "[", "0", "]"}], "==", "Q2o"}], ",", 
                RowBox[{
                 RowBox[{"q3", "[", "0", "]"}], "==", "Q3o"}], ",", 
                RowBox[{
                 RowBox[{"q4", "[", "0", "]"}], "==", "Q4o"}], ",", 
                RowBox[{
                 RowBox[{"x", "[", "0", "]"}], "\[Equal]", "Xo"}], ",", 
                RowBox[{
                 RowBox[{"y", "[", "0", "]"}], "\[Equal]", "Yo"}]}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
               "q1", ",", "q2", ",", "q3", ",", "q4", ",", "x", ",", "y"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "ti", ",", "tip1"}], "}"}]}], "]"}]}]}], ",",
           "\[IndentingNewLine]", "      ", 
          RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", 
          "             ", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"dbFlag", "\[Equal]", "1"}], ",", " ", 
             RowBox[{"Print", "[", 
              RowBox[{"\"\<t=\>\"", ",", "ti"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", "             ", 
           RowBox[{"flagQr", "=", "1"}], ";", "\[IndentingNewLine]", 
           "             ", 
           RowBox[{"sol", "=", 
            RowBox[{"NDSolve", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"eom1f", "==", "0"}], ",", 
                RowBox[{"eom2f", "==", "0"}], ",", 
                RowBox[{"eom3f", "==", "0"}], ",", 
                RowBox[{"eom4f", "==", "0"}], ",", 
                RowBox[{"eom5f", "==", "0"}], ",", 
                RowBox[{"eom6f", "==", "0"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q1", "'"}], "[", "0", "]"}], "==", "W1o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q2", "'"}], "[", "0", "]"}], "==", "W2o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q3", "'"}], "[", "0", "]"}], "==", "W3o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"q4", "'"}], "[", "0", "]"}], "==", "W4o"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"x", "'"}], "[", "0", "]"}], "\[Equal]", "Vxo"}], 
                ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"y", "'"}], "[", "0", "]"}], "\[Equal]", "Vyo"}], 
                ",", 
                RowBox[{
                 RowBox[{"q1", "[", "0", "]"}], "==", "Q1o"}], ",", 
                RowBox[{
                 RowBox[{"q2", "[", "0", "]"}], "==", "Q2o"}], ",", 
                RowBox[{
                 RowBox[{"q3", "[", "0", "]"}], "==", "Q3o"}], ",", 
                RowBox[{
                 RowBox[{"q4", "[", "0", "]"}], "==", "Q4o"}], ",", 
                RowBox[{
                 RowBox[{"x", "[", "0", "]"}], "\[Equal]", "Xo"}], ",", 
                RowBox[{
                 RowBox[{"y", "[", "0", "]"}], "\[Equal]", "Yo"}]}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{
               "q1", ",", "q2", ",", "q3", ",", "q4", ",", "x", ",", "y"}], 
               "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", "ti", ",", "tip1"}], "}"}]}], "]"}]}]}]}], 
         "]"}]}], "]"}], ";", "\n", "\t", "\n", "\t", 
      RowBox[{
       RowBox[{"q1h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q1", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{
       "build", " ", "solutions", " ", "for", " ", "this", " ", "time", " ", 
        "step"}], "*)"}], "\n", "           ", 
      RowBox[{
       RowBox[{"q2h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q2", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"q3h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q3", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"q4h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q4", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"q5h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q6", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"q7h", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"q7", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"xh", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", "\n", 
      "\t", 
      RowBox[{
       RowBox[{"yh", "[", "t_", "]"}], "=", 
       RowBox[{"First", "[", 
        RowBox[{
         RowBox[{"y", "[", "t", "]"}], "/.", "sol"}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"re", "-", 
        RowBox[{
        "assign", " ", "temp", " ", "variables", " ", "for", " ", "use", " ", 
         "in", " ", "normal", " ", "force", " ", "calculation"}]}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "        ", 
      RowBox[{
       RowBox[{"q1", "[", "t_", "]"}], "=", 
       RowBox[{"q1h", "[", "t", "]"}]}], ";", "\n", "           ", 
      RowBox[{
       RowBox[{"q2", "[", "t_", "]"}], "=", 
       RowBox[{"q2h", "[", "t", "]"}]}], ";", "\n", "           ", 
      RowBox[{
       RowBox[{"q3", "[", "t_", "]"}], "=", 
       RowBox[{"q3h", "[", "t", "]"}]}], ";", "\n", "           ", 
      RowBox[{
       RowBox[{"q4", "[", "t_", "]"}], "=", 
       RowBox[{"q4h", "[", "t", "]"}]}], ";", "\n", "           ", 
      RowBox[{
       RowBox[{"x", "[", "t_", "]"}], "=", 
       RowBox[{"xh", "[", "t", "]"}]}], ";", "\n", "           ", 
      RowBox[{
       RowBox[{"y", "[", "t_", "]"}], "=", 
       RowBox[{"yh", "[", "t", "]"}]}], ";", "\[IndentingNewLine]", "\n", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"flag", "==", "0"}], ",", "\[IndentingNewLine]", "\t", 
        RowBox[{"(*", 
         RowBox[{"first", " ", "pass"}], "*)"}], "\[IndentingNewLine]", "\n", 
        "\t\t", 
        RowBox[{
         RowBox[{"q1tab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"q1", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"q2tab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"q2", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"q3tab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"q3", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"q4tab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"q4", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"xtab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"x", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"ytab", "=", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"t", ",", 
              RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "ti", ",", "tip1", ",", 
              FractionBox[
               RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
         ";", "\n", "\t\t", 
         RowBox[{"flag", "=", "1"}], ";"}], ",", "\n", 
        RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", "\t", "\n", 
        "\t\t", 
        RowBox[{
         RowBox[{"q1tab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"q1tab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"q1", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"q2tab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"q2tab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"q2", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"q3tab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"q3tab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"q3", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"q4tab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"q4tab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"q4", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"xtab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"xtab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"x", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";", "\n", "\t\t", 
         RowBox[{"ytab", "=", 
          RowBox[{"Join", "[", 
           RowBox[{"ytab", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"t", ",", 
                RowBox[{"ti", "+", "dts"}], ",", "tip1", ",", 
                FractionBox[
                 RowBox[{"tip1", "-", "ti"}], "pntdiv"]}], "}"}]}], "]"}]}], 
           "]"}]}], ";"}]}], "]"}], ";", "\[IndentingNewLine]", "\t\t", "\n", 
      
      RowBox[{"(*", 
       RowBox[{
       "new", " ", "initial", " ", "data", " ", "for", " ", "next", " ", 
        "integration", " ", "step"}], "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "      ", 
      RowBox[{"Q1o", "=", 
       RowBox[{"q1", "[", "tip1", "]"}]}], ";", " ", "\n", "         ", 
      RowBox[{"Q2o", "=", 
       RowBox[{"q2", "[", "tip1", "]"}]}], ";", "\n", "         ", 
      RowBox[{"Q3o", "=", 
       RowBox[{"q3", "[", "tip1", "]"}]}], ";", "\n", "         ", 
      RowBox[{"Q4o", "=", 
       RowBox[{"q4", "[", "tip1", "]"}]}], ";", "\n", "         ", 
      RowBox[{"Xo", "=", 
       RowBox[{"x", "[", "tip1", "]"}]}], ";", "\n", "         ", 
      RowBox[{"Yo", "=", 
       RowBox[{"y", "[", "tip1", "]"}]}], ";", "\n", "         ", 
      RowBox[{"W1o", "=", 
       RowBox[{
        SuperscriptBox["q1", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", 
      "         ", 
      RowBox[{"W2o", "=", 
       RowBox[{
        SuperscriptBox["q2", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", 
      "         ", 
      RowBox[{"W3o", "=", 
       RowBox[{
        SuperscriptBox["q3", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", 
      "\[IndentingNewLine]", "      ", 
      RowBox[{"W4o", "=", 
       RowBox[{
        SuperscriptBox["q4", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", 
      "         ", 
      RowBox[{"Vxo", "=", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", "\n", 
      "         ", 
      RowBox[{"Vyo", "=", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "[", "tip1", "]"}]}], ";", 
      "\[IndentingNewLine]", "\n", "    ", 
      RowBox[{"(*", 
       RowBox[{
       "reset", " ", "the", " ", "variables", " ", "for", " ", "integration", 
        " ", "over", " ", "the", " ", "next", " ", "time", " ", "step"}], 
       "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", "          ", 
      RowBox[{
       RowBox[{"q1", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{
       RowBox[{"q2", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{
       RowBox[{"q3", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{
       RowBox[{"q4", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{
       RowBox[{"x", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{
       RowBox[{"y", "[", "t_", "]"}], "=."}], ";", "\[IndentingNewLine]", 
      "          ", 
      RowBox[{"t", "=."}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "     ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"increment", " ", "the", " ", "time", " ", "counters"}], ",", 
        " ", 
        RowBox[{"step", " ", "smaller", " ", "near", " ", "release"}]}], 
       "*)"}], "\[IndentingNewLine]", "\t", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"q4h", "[", "ti", "]"}], "]"}], "-", " ", 
           RowBox[{"Abs", "[", "q4R", "]"}]}], "]"}], ">", "0.5"}], ",", 
        "\[IndentingNewLine]", "             ", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"dbFlag", "\[Equal]", "1"}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<diff=\>\"", ",", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"q4h", "[", "ti", "]"}], "]"}], "-", 
              RowBox[{"Abs", "[", "q4R", "]"}]}]}], "]"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "             ", 
         RowBox[{"ti", "=", "tip1"}], ";", "\n", "\t        ", 
         RowBox[{"tip1", "=", 
          RowBox[{"tip1", "+", "dt"}]}], ";"}], ",", "\[IndentingNewLine]", 
        RowBox[{"(*", "else", "*)"}], "\[IndentingNewLine]", "             ", 
        
        RowBox[{
         RowBox[{"ti", "=", "tip1"}], ";", "\[IndentingNewLine]", 
         "             ", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"dbFlag", "\[Equal]", "1"}], ",", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<near release, diff=\>\"", ",", 
             RowBox[{
              RowBox[{"Abs", "[", 
               RowBox[{"q4h", "[", "ti", "]"}], "]"}], "-", 
              RowBox[{"Abs", "[", "q4R", "]"}]}]}], "]"}]}], "]"}], ";", 
         "\[IndentingNewLine]", "             ", 
         RowBox[{"tip1", "=", 
          RowBox[{"tip1", "+", 
           RowBox[{"dt", "/", "100"}]}]}]}]}], "]"}]}]}], "]"}], ";"}], "\n", 
  "\n", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "build", " ", "the", " ", "final", " ", "solutions", " ", "as", " ", 
     "functions", " ", "for", " ", "plotting", " ", "etc"}], ",", " ", 
    RowBox[{
    "also", " ", "record", " ", "time", " ", "of", " ", "final", " ", 
     "step"}]}], "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"q1final", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"q1tab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"q2final", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"q2tab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"q3final", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"q3tab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"q4final", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"q4tab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xfinal", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"xtab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"yfinal", "[", "t_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Interpolation", "[", 
     RowBox[{"ytab", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "3"}]}], "]"}], "[", "t", 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tf", "=", "ti"}], ";"}]}], "Input",
 CellChangeTimes->{3.5124191249618893`*^9, 3.51244055354881*^9},
 AspectRatioFixed->True],

Cell["Plot the coordinates for each degree of freedom.", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 4 4 377 279
%%HiResBoundingBox: 4 4 377 279
%%Creator: (Mathematica 4.2 for Macintosh)
%%CreationDate: (Friday, April 29, 2005) (19:00:52)
%%Title: Clipboard
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 283 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def

%%MathematicaCell
%Cell[GraphicsData[\"PICT\", \\
%\"\\<\\
%000000000A<1M@0A0_l<0?on0000B00004P0000000014`\\
%5e0000000N00402P00
%00014`5e038000000A<1M@0OP0200800PP000==H00000@000000000000000000
%00400000000000000000040000000000000000000000@00000014`5e00030000
%00X02P0000014`5e0000OWAYIVH0000000000000001QL71/000000001001M@4C
%04P0001800000=:<004:E4U6AR0XC5YG:@00000000000000000000000000000H
%ool0000<LgAbL00001d0000<JFiTN0000040000<M6UVH`0000D00000CDd0:P00
%dHB0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@B6AB>BBFCBND
%BVEB^FBfGBnHC6IC>JCFKCNLCVMC^NCfOCnPD6QD>RDFSDNTDVUD^VDfWDnXE6YE
%>ZEF[EN/EV]E^^Ef_En`F6aF>bFFcFNdFVeF^fFfgFnhG6iG>jGFkGNlGVmG^nGf
%oGo0H71H?2HG3HO4HV=_g6@=oHmli63?c:H[;IO<IW=I^i?K?@Ikj61iikIcCJOD
%JWEJ^P__G@W:?cFK?JKGKKOLAK7_kB@?6?gG?_OkWRLGSLOTGimL^4l7TloXM7YM
%>djC8_UXMT0M_ZMg_Mo`N6NL]m@UCNO]P37HoaNggNohO5o_j9k7Mk56oT1O]]Og
%i?o040`4_[j?VPD2X90/48;1D3@M1<3WjnKO`TP[b33300`dG/>=fgd:@[1;M_I0
%LBa=4lD:G0[I7o5R2@[4<7`ZnTFAM0/IWfPAm/O5alAlPHIB2m9?B8RD@AS5<TbD
%P3oPD3PT5Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMP[nPClT<6TCoTDPO/UT
%d2O[oOL2O<3T3oU[oOd_Ud/OLkPKgW`:X00XAHXSmXcnY59Q=9XdeSe?Z5AZECZU
%EZeG[5I[EK[UM[eO/5Q/ES/UUSTcVLRV/]T/WUeZUL[W4aPDcYdhW5>PKE_U01@3
%`0I`D3Y]=YEVa69aF;aV=af?b6AbFCbVEbeU]5eVT/^=>ODPUlU]T2W4fcFTdSjO
%ChPKeebPf0>f@1fP8fccg4bY65XfGgfoh71hG3hW5hg7i79[nIPMhcNVVcjdU8Td
%Pc;mVO@Ode_;lkd38OQXGS009lbSm5;jT8`o:mg_n7anGcnWengg/EYdldUlgk:d
%^TOYm[XeR?YBe2jYJVjK7jO<77O23006lRQ0=2`M@`eC?_FPSf_a3l@A34DAa94/
%CA>[;m>PoSn9:k9m^TOQm`:NjI<h^JI@DWIl`:Oi=anf`40U8Ka`U2AhBA1bj88g
%RmAA9lXBS:DYbY:/[?c1227^N/F_fNajWTM1cW6MQhaZdjGY`NZFafVcnYBkdQPT
%lHJC[2`30K?<kSQ?RV^JWRF:?3T[d9@]3D?A54dDn[//8OIn7/NQk9m?dI1L4XC1
%l8XTW]6d5Wbd22`77Y:e:0UCRYE:T_6JmFPYEkaWCFD=Cnd[2=kAMLeeGMNEkGeO
%ZPOd79XU[NZ<EQCUBBi:T`BI:4`DQCUHTYmY0]]0ZM9CaRAKRTZB0]`8791h0QLX
%dg>kbE:KFUPGKMeggQN=iBSMT4WneIh7DM0J1V6c/YJ50CQHMai7bNdf94O65E^Y
%aTHLPLU:JlJ1gC9A^H_FZ4bENN>HkSf?i1T;laTUSo[HNi@4`BYRV:IIlY>O9mVN
%IYW4@Ai;`:k5k92_F=]9@1oP5XEdZJNfS87Xe>Y3M>V9ETFWjQ:Z0X0oh50h91H=
%1hA2HE2hI3HM3hQ4HU4hY5H]5ha6He6hi7Hm3Wk0Wg0Wjmg`nWjnghogjmYHn7k8
%GhoX4oWfoWhngc0W[8IXog`mgW0io<I3=Gm?gnljH0:M2GYDHOAXoEJ]EjaFJeFj
%iGJmGk1HK5Hk9IK=IkAJKEJi8nge;WloKS=H4o7Ro7^kiHogZmH6nY5=gnlG^ojD
%ogg9WaQh8m/M1ZL086nLXml]1/XnGgVh=E;IWm1XM5Xm9YM=YmAZMEZmI[HYLgkP
%<i=7k:l<lVVcV8GRdJ4ZSTjaEj^080@0`fBeGa?9dngkbiYKYI]X;Vi70/Ro>e1^
%e<jCgh7A/mIioS89AoA98Ki_30/1R<=M8;Ah9iH9el5LZ9l_I[_lol0@30D1`90/
%3@>ZZH/@TIm<hOjMWnOAm7J`ak3^=i12D7PXU4AY51J3`<UZGYT7RPCU`NOJG=/f
%bJ?0P[_P36D1::mCh/<Xkl>S7JF?]6lOA^n31/fMbT/<j9l_NjkH^/^ZmWnUaoWY
%1T8BNUJLb>YC^^jPLV`A;l`C3<Dac9</c@?7:DWXNkl894al7R3H;1D3H8QBOii7
%X5X=PbIiZW0NRAB4U2AY`^TG_ZY<I036TK:>l/L_LVQm>R^BhaLoSmb2`1o;e:Al
%96Tjj7bO1j:BkL7bLXlXbW2<ZZ?5/8`TXTS8:c<ceaG=MEgGUNemGkhW^Ne2[XT]
%0WfMYeVhJZW0TJQ/7NLa^W02h6PHOS0<XTQjW`NIfWTWLDAKF]4WmAM6bOAkfb4`
%Cld/YDOGSB9oDXOYlW]1Yl_e@JE^UE33_a5R4@Tmk1WS4c0^^PV2F1Q^7HOR68hU
%RJ<da8:R^FNidUVDQ>R>9@//FOiDU4E8V228IO5jHBg7jIAPUd6`HQF0030LLQfW
%aLKcAS6L2B1MLL]YN==Alf[3BD_JM9VnAi7QQ1ogkBS1Ao7^[J[MJ5H8Xe4HY[f_
%k1/>aK7M2@jFOT5?POAgRT98R5nGiTWd`YATVCH8080ac7BMYk:BKi`6dT@m3j@A
%K5bH3bg9FUcIm<KdbO65<a^kJKA?Y6ZWmOBm[VOCZAcPCh/5BV[j0URHWae;_^][
%W5k9eoHMSfGImXSBO_c2:hYVWIo>Ff:ijR`agf?NbiBRfWDW/=`gSWYjoAMed/g?
%<?8LQC?P?A5e2dh^5>7nF9G5X=0_S0=8a3B6hN2PM4:?Pim@8522JAA55mamFoJo
%coGmoio_o4YDhOXWa8EB50KlGE1CJ48U^<fKHNhmAk2?4J8hL8iAc;hJXedY3SE6
%85NZSIbB=eH:2JRKA@[_RQV95X;@G`5P90LBT>`F`[QF0Q1F48NY?c2W`A@HDmjP
%BP96EReUA3n7CSm;jGiodBhVA=RM4m01?g?3i;RC/f:3c04iGd?a:Z=DL:T7X:hD
%XYUUSH7:>/MKlX=T6Ik1e0T7g8We?Ti19I97^8?7LZDN04@80N6/=8L1R1j2B4B8
%@?HRQ?S^=/RPWL>e0U7MlY@VSC604a;LQ8;LVBXZVE>ZR8lD9@BQU5:>DQEROX@H
%DkeZ:PEkV87dQ29@mBEU57d?<B0Q`o0L0L0/6X;@ERS5F:f7K>hf::LLP>>1m8i@
%R<<MLfaj30A8<<?<IXbARP@0N1lOAOQm3Z7F0LY`aa[STB:@8Ni>bg3]7^?hNA8V
%A4[9<?aWAnS18@GN5JO0W9m466I?dD/oiBd1X5@>PU0YCY>86BhO/:DEX=W<o54k
%8RP4/7T?hNHjbF8>G56]64aXgC8DM22ILGSKBB<eAT`abal3^5f;LFP2@40H?PW@
%3`6080>757V9A;1m1X2l5`000@4R94T9m:bAgLWa?NoDj`]JW0iZPDIe8n0MeE5S
%ENP]FJ]EKZhk5XSUdXEPPc5hYD?b19A7f?QOB]GX<lXlV:I<LWP7f9BB^:jm2F3e
%6d=EIP0070V1234AXQA11V325^FBZAoS[7<>Q5@mQcS/7P3/8@B9h[2>LXDfR:Ao
%A:GNMH2]XAcFS61JD4mYj^fY]EJ^eR_ee7A9Fiha5VdJSl7/Ch_HnRH@7M9IUReK
%IR`LC;724=Gc^ShRDkhU9QJl1`3H6TD0Wa=`9Dd@8HPaaV2E4`9eMiPJT=3<@GdX
%I1AgGU<L?H:=jA;G[]KNfmekkhAAVFj5N2=RiZG?TcZ:SW3iDLG:m=0KYUdTR_0e
%QU[F6SehOL?dLHhAa0@0R1F_Pfbm]7CH?PK@gQ^R>4L9IKC]cHTVM8D1cMM6dSo7
%5RTB>:`:H]_:>jn><LIHcaXFHna?cK4SJ?KQ9lEAlVFMB`:0B=cW7aPdm:HioX_;
%ZA/SZfKYdG]7?SU9B1>AkSa7J>TCPVQ<RK4m?lE0[e=SO78=dChYA@SX7D?@kI>B
%RaK>XKBf8nAn2Mc/4c?03lm0hch77?a0d^Hed5X?@VQB8i;b8HQL98bAhiX@/EOY
%8akSd7/?1h:@[PDM^4P7A2?e8e9]kEn7C>V/55G/BH`A]S:;97H=X1H301112:48
%58<0L3a:7:Yh9ed83=el60;`GLm0?2E/DDVaagk90Q//IncC`hWd=]4P3oPD3PT5
%Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMSdOQ[nPCmTKoTCoOSoOKkOkhU</U
%<ZU3iPShOCgO;nUd]TCjU42UTVTcnTl4XSn0=9T5;QdTOm>Tm5YckTEDYlWO;jOS
%kOU4X4YTmKXm4OTTZ//Z;nN;mOc/PCfTCmO<T[/2V<dK3ML9A;9I3@J32=AR8L[U
%LL6Bf97^;46=O>?YVAbFCbVEbfGc6IcFKcVMcfOd6QdFHZ=6ZnW/dUXD6^=aT^UP
%M7eU4Y81Sn`QN]e6j]Vkgd2f6hQCm/5@U3l//aPCjiT3i7:O;hX?7O5/O50aki/^
%[M3VM9a=ib2@C2Z0@:1N_Y/W<We0UHYn31n@bnRoneSo43UOCPKmocA`10<1@70T
%2`=0l4@C1D5`HdCI8:XkJ]^h2@]lg/;]i3;F@XeKP`hd[WXFYbW7nmR1_I4:A_nh
%2R3Y5`9aP=TI7E6SoA95;SWhGdMQG7/K4C80cB4Pcma/oBEaa8d6bG9TVbM9lXBS
%:DYbY:[LZm23J:Dc/=@`gl?8M<3BW^NbJ84k<7XDk<C;/i4K:>K4hQS>H^CZKTkX
%BNlmA]9AoU5?iWD2PIgd8==37aA23D@jlfZk;2WaG:e9DWBU:d]Bm<DcCC=cBf<]
%=];T;@e3/?XU3ao><Pdm7_8TT>A=<L86DMIPaFY:E_AKW>Ni3mX<ilnDRPM5cC=T
%LckCbRdgIEUfII]WFOJ5XdiAmT@U1<a8C4KEA8PdK?fXlLDGH[n_mHYeg><UdPoM
%IXGKGB]YFQ=LXFimNX;AKWcC?[meSJEoGoP60h5PN2BIC/F:A;L2f`eJ3fdYm]XI
%>i^2IR[/eli4oU4F6>>NL6?Q9T8ci6NfBgO?]Eg`i6<>EEKIWmRj4COAlnf?P^Ki
%aW>MIgWVNhAUm[8hgV8`gDVSHIQfRHOYK7W^Xh`JP7PMQlMig7SE4:1;[ASjh`Yb
%Pk/1;k5NaoiRPTKAaF6EXA9;o>NC6h5k^B1c@o:2gkWflke_NnKk_d2H>XN4e1XC
%DJ925Bj?a=TX;YNU96/SE7nm9jST>8j2V:@ZZ4Ki_722o@6]dG@0^C?CFAH]Rf8i
%[UmHPUaX5bR35KfPPm]LU^G_A>omig_OMoh7PXQ`<8hDSL^]MX]CYRdYnZhdjAKK
%4Rb>@[An?KYM>Y4CY>4o[1<4^CF:RIFX<5?lmF^W/R:Z??ZSb;H3/POnIco[I6G`
%1/gLIIhGnolon040GS[DH@d5hjXV8?::Nl`U0nSDU27lE^1KcSU527dMYVA8bETi
%PRi8ijI2J6ULb5D3<9F==TCBh4S1ngeT;B46HA4<HE42ILJ1H[nSg7lP53/QQ0B0
%?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@@=oB>3B=o06DAio?
%mnb^FbbG@BE_nIbimb^J`:I_en_mm_RJ?^J?ek_IlcAo_bQDRABIo?b1CfF?Ej_>
%X`>UCRM?l5PX6XF`;Za@UmFFC?^dB6NBfAfQmfEmBIRg<UGEbgLhgUjG^3?boB67
%bJ1g21fj3?W4H35H_6Hg7Ho8I79I?:IG;IO<IW=IC1@FCBP0bZHJ>Ge^VCWCe6LC
%en_ZTd1oFEl_FFBbXJVTF_>e;NEOJ`:g_eQ/9RS@ISIflT>L]<lfcfV@HB2gkK`[
%Z1?/9G]5;^HGXI^Vc>6ig`NGcNOdNWeN_fNggNohI3bN7@J:GjGaJSmCAnCal=PX
%CHX4O3FWRLYb6nDA?U<HAP6FOSG7jfkEYXTJe[:O4<:S33Y7n?PmSl?8l3fPI/A<
%54D4m5C`Z`_j;[Fl;iX:^2g316`Za`=<M86a1l/<c<H>W5ao[Q7[hb?94TbE9LVB
%K9dWbPT4I@ZTjDXjUd/=<g3D9NObNWm0;G7hfQoW/PAj7VMiePn3PATnCYE:NZl9
%:7;B1`U23O:TWbd1L5XH60GiQB:a1gd<;m48<Nm5XljSb;M8b45;BH@dZAE;^XPK
%oWa:K8bVTe<b4j/Xe9D]CE?E5DeEEMBDnTKjb^dSDBfdbJbo<9n7bN2F7TVQj7dN
%ai143hC6jKId=neT9ZfgJXdFNZo=LPAfFX2P9P/O9l:FPRgDFNm@X98:<`j`JbX<
%]befld1@gI>jNAKDK9Y=LC`[LJ]keIO=mGgOUngmOn0AHceGb/SckeVoKLCXWl1Z
%WGaoWbMa^VbJX7PN2l<YlebBGNVK2BlfdjfBPIYI:DiDCRQ5`>lOIWiLMfH8gUKP
%>nN>K5cW0bId7NN0KWa5j0gBB?K7ioUmXhRJCVJ:cfg26?gQ>0jUZNZJ[Zc;hBlF
%AjgE3b?8jP2k3YLG]lVEJeZTV@C0OalZ/OdcEdUQiTXB163X?Y1:]R217bWZSYlT
%EKYI0:K]RWZX9bfnnj6ZTbFh]2eW5b@ClX^ibj;L]YBX_/QWWcaEM0;gAIl1XNM<
%A_D79e@7MH:?G:MXJTb6bZEW^N/cAVO9n4bC1=Rh;X_UVFQK3R>@i?kYZXWjYL_]
%jWbHjc>jV=_JBElFZ4j=J]6]J_k__Nol7`k=FWYJgi=BmPOe=X<07fgPS>eO?j=`
%[NWbP=JUTc7fZam7T5P9PARm6><`NRIcG5;7T?/O[Odj_;L6C@^;ccJ`:7d?Q7a`
%21?88<XHMihCZ2>Q01V4@jhB437]2LPbhQd`[512d:T;`2@a2I3<B<=A``g?2cHN
%81hN0AQldEc3F4k3`R8DP@PPa31H2b5/2h60=3XQFFb4k^7b_;FbGhX2A3E4RK>n
%>1C44952:F[n2Y/F?;VO56V=DJhf<1NLliP1L8N07GXAQn99H^TeKBh9G8oAjZk7
%j?HNhk1b0A0F0PMXm1l>h:FCLOhmh3:LCTV21i[An=[=ZE8UKe9=[_84hdQQJaCb
%S2W:F81J1abYAD9h7d[F;0?2a;4Cl/aeBe8B^0IL^@GbkUh<6Gb?Beae<TSeAc/3
%Z1?V@0JI@bYV;T9dk5D9DRU[BL:DU;AZ3KSkOdG4ULFH4]/PbWU`3g8fcUW=>NM1
%khg]UE>n^IihU=_]00YdR/Mc?AiWNH<O4T5LT/C4?LFX[1BQ92:44F8]QLb@TNJi
%TXf0;PO12<HIPc33;_HjmTO1BQn/IT^ajC[bc_W?9nOmP@oaVdW6eBTAU:`Kd]0G
%Bl<=<AHdcIP>iURkTl7E9=5<FU?IBQC;08D=m@cg;PQeBl1HIZUC2DfMBHY>co`5
%RdlnCLGJM3o7F=LI`]aARN5F:dFhlBNeBRbL0XT1F@CY[EF^]UKJg4DFlnam/m2:
%Ag[Bn@VIoI7Z<L2?`O1]3FRJ4X942P406S<6P=5cDVbQ1D2d5XNKfdkU?7dhE>De
%Tm?S8C5=3Z?AXfO3aJ45EX`=fU3KJN5XX7<T<DfFiXZhQ7faZD6HJU]CUPLJ4V0k
%iU4;UUJ:dT8P2;QBa2`:fha9T>YC>TE:;<eFQUJ7oE8jXlAcPc0X0lChXAEdf7n[
%^j<6JoT/O^nN]miKcGW_@eMM=O23[PDRAN^ccH^Eh8:]i21Ai:4o7Z?@N3b8;577
%d?`K`g1_Q[;b?DWS7WM6iVjB<j/2Y0V87_AU8IKU`36``lH>@8<>0O`l7G44c1UC
%^7n;g4`O<DF[855>8:hI?4/aN@H36<jDSJV4NEW@I0Phk0CSdKV?kKfa4NS`a:0j
%B459i=<h3JBLTcC8MDMHh@M0M0^=hL0jQdU@^lgYnaBBSha_CV7<FHfY_cc<WIEE
%CdNg_a_?FnDmWaTc7g9MPi27hgg:^b0WPVa;2H5^;/GQBl5Tc<BhZ31_T9Vl;f?C
%4`_DM1Y0UY46>T`mjEI:=8QSSBg0edh6SCa36RXMJ;JdkiN@he1?:?T/YK1=j]1C
%ZlK>/HA0I:6>0K`g@E0X1B70=`KjWU8I11I`[e3PCIPbUXgPoAbEJ0b0h13=U/bO
%aFlU]FI=[KGf`Zc<mm6W:UVL@Ym;l<ggbW^`XUMUCBU^^A6PXMn2QB2365d;Xl4d
%B=9a_Nc0mRESf;nCdNhl1iR^5B:T;XF`]7H0V3SQ@RN6HeG>MmLFgh>15hY20Abh
%<BDUDeTMcI0QQlO1Mb7SBlR132hn1GU0fnE2liIL3?2GWK3f26448D<`V:K7S`3H
%2MWV6gFFm:R`nfj2=3/7@>YB3ofG:FKLo6fNWM?jQ>Zj1>l7@;`VKE22GfcSjd6E
%^H<WXhKPc@_nn9@jW5nHCGZ_C2D^]YS4?PF`[1Ek>0@=lLHh^U/d@[18LXkAgRX5
%L:h9HAPU0D0J108X@0P2I4^9Hi8kN<ciH7KYKJh[gj;4]iVW73li^c8;Rd]H4?A3
%Xm8f<Rj=;M]lb:?lKN?`=FUI`;TjPXQA2P/N5Q>[lBZSb3?kgCP=A_SN73c/dKOL
%0Ved9>626LeNY41>2<5XbQS3DjbUiaJW2FB:L0DcZ?gO_OO</F`oZ440]W7@><LX
%jAcSZTYeaTES6f;J8Af4Q:/f0?;;RD[g;l]R]/`2=@eD;l=H9FcV?b7dTPO`od9h
%=^gh7h7N7T7/Q87R4^4^4j242:2B0J0Z0^242@2@5F5<5@7J7<7BMT:6fni68Da8
%Y4hf[:DfRVoZ96m@Fffn/N2dQZ4R8fV4G01Q1jLl7VdF1LUf4DJ08<a<5f60605l
%M/[@:8_fPJ7l3o2T18161<6T6V6ZkDd>7^;Njb/a0F7^7R847R7B7D740@0J0l7O
%34FBP:7j7TFb7X7Z:4RbGRo13_3a3b8/JP_l@RTN7U3L7n1J1@1D290^TX_X[^MT
%jH/b=ng:W8J/Y4m=4F=A0:BhX^:2B8S47f6/6d6b4H4T4T24262>0R0P0Z2Z2X2b
%5B5D5L7P7ZXb<6:PdB;@PHLhN@OU1TgHBVgDMS1P84M05D6_66b87bJlMR]L>n5W
%6F2=6J[X8NDPmF9<7=6X0e6/9<Yn343636=^@bFn@P@dKD:4Wk4`Jd5B5@kV0N0V
%I`5nilf>I2:@:DTPKN9l7J5d5R5H1h2R384j5V6@:B9j7R7<TN7Fbl363H3b7JP?
%3e8I8K8L8F?fPZbn/b5>54584d4[0X4T4/5H5B5PPV=LC@@8FFSZWG4LcRJW4V9;
%5lQ@lnXj==02Jd7j6J6F6D4@44441X1N1R0^0f0d2lId5Z5/5`_g7V=73VcVj0:<
%7ffRaP`BMP]blhV4FlJn;l]N9i6X7<UN6A:hlhY^W2>[1nZ2cJ8/@j;V6;1j1PdZ
%3f1/YJN@ilT`bBPZ7/=X_bFdQ@;@726n704k;j5i2@6D6F6N0H0N0X4j505:kb7n
%WfHf@ZHfP:7/7>524`4V000D0j666h7P7`7NEf7bPjT6140h0b2j3<3ZnJFg8O=D
%80oh50h91H=1hA2HE2hI3HM3hQ4HU4hY5H]5h<oX56XM78dnW`nGo7gZmgjn7dlW
%FkQf=1^og`ni>o1F9aRig:kY76gnmWZnYfoJ4o7i@7noH5B:?BH?7XaCjQCgmDgg
%EJ8o:KB7kF7mB:joWhnj_1VCICXMCZ8a890oKCTKCN`Uj_gcFgg6GnnG^nZVo[^o
%jaC<117kDj5QJW3kk0j[Ol9@[kRjC@/IEEgU`[VFKVh7EgeWh=Qh<nM9HjQY951E
%CZai[KJ7g@jGC8GbmGbn8doGTm7S0[o<WbmY7MkmAgjlgRlQ1be/]EdmW^ng0hg@
%7Q29S/O3hmWe8XiBWg^7c_GnkI6mgS6WUPJ4nWFhd6NCJRT<Peja6Tmh5PJSoOlo
%l0@30D1`90/3@?144`E1L2ZLSZN9fOIlZ0YBT4`B9:6bJAZWnOJ=:`IYTVVBA84f
%YJ^Y6[C:?fX[1@Z`B2`M1TIX@bB7:fXin7jOJP:jNijWXI1S6:=<R/b2XDBB?LUV
%BIYV8i2DNWnNIkW/_j[bRX;fZj_RT7hg:28hQRn]4Q3D8bZL/:Ze36/ZaaWCP>Ti
%876c3]<`2[Z8olbAFTJYSK@05D4Hm2@L`;Lbngj]W`hK094OYm7hO3K7^O00P00I
%dW@M[4/2LadWL6cFRd;`^WXNAjWfNe6>:W[09dV1j:0V:V2N90P6fJQV3<<PaV^K
%[I_g6UQf9H]SF?I5TfEIMV@C6Da`PY1l7VNZUWdT/>WlKY[6bDa?U4HQOV6`LM`j
%e:==^a4aAMMRU[`WMVfM238/C6:``TO1I5PEh^2d;8<P^2`G1H5I2T6@A_VjKTD[
%j^Z`86YD?X4NJm:HZ[S:B[4L:e65h8C?S3gESjZ:[<Z6/nXb27;UND8=U/HgZOij
%iVZ<K;jLNL0OW@VIhM^O<@fS^7bg;LahNb^^m7Ym4NAI43T=`eP^2X;2T:8ZAi?5
%//7:LZRT:PXQn7`QWHMCc@kBJM7lNSc`l`2=7ACi@4fCI4T:@@Fk`Ja]7;FF?GS_
%o0L3`G1l9`_3@?XTjGW6:_HiMbUCdXAh7DM@@0b3QP5dH<F/Xa>;/:WS9AOan>l?
%12=A@PYnWDMIeUGehY2P:880L1XPR07Q:4VAibW6LDDn177D[b`[n8e7TLJfdSmA
%A?B_ha;lM9gIlo<RQnGnZd>@gE>n8Nfc/m84KGaX7<lF?i=b<;jaYkOJ7ggPin9;
%oV3gjVWnjWDPZ/dZCXb^Sf305d:PUA927:>?T:@CP/2K4^:E523UJ3h;2H4>8LPk
%0V1>2/Kk2B]_<=`?XhA7bkXkM@?lE`[QF2c5X;@`:QgC@_QQ366D<hJ9QLFgi6<=
%d7@kQ_3YV/?G@5R>:QlXa6QOa7D^00O0mai]K?HA/^ho1k3c7J>X4H70@Sb7M18S
%@mB/6oF53PdD3g6_0M8^i0HY8e9`6L@=k3gRU?I8:mR=iThh_Y:L>DLPigiRE2P5
%89X0P3032F4l9`XQ@2Q7L>`MI0UZZ^S@KhTJ?B_@f:JQ2Bj=Ta/aAXmdSLW242bU
%452DPm9C<^=19mjdMTj;d;k9hOhNII2HUX26FcmaYRVUd1>GP^3V/<AdSHXPn1NR
%n5X3d7`;213UDP>l2H2PCSM6ZXaSB>bQ=]7nDHNQA2oRJ4j:4204@9S8W8l21lfA
%lUL96F6D`lRTWOU13FNDlijCeW/P27T>9;CiWi3eN3e2;CiGLGa3Zl68XM:[4T=h
%KPe;T?dfiAXnaiSA6F<P0P0021P2h6H000P5Ro6><lN1nRja>LDV6</I5f^S:N?R
%UaZ1EDa27C>UbS21<XCJKhZchI/bY7n?NX1QjLT4O<?n3Hga9E91n3`8@2`4P<2n
%5d;PYaDRT7F?4MhkCT2c5R;0DHWa>7W851:<==bAZ?Ta@5=:NCnE/?hbI6TVYF<`
%7lc>;aA0]ei23G]WcIZR6TC@F0XUAG`7lZ:bH1eRAiF;:^X@HiV@9e94Q?nK:f2o
%1T385PAhT0n42789XC@S@5P51>?ho@nj7cI>6ImFQ<21CK7lUHO`]aMRl0X1D2h[
%AER/NVm8SdID>_]7TDPOEa9kg7^ALViEbinXeQmIBj2cj1?ZR0^QB99XWYE<L0l1
%`2P20300?`e9h2_8B7X>h>SD0?PH0n?@N0nQ3R94V54;0H8`=J>hLBWYAWAd/Y>^
%]01Z;4P>LX>Y8hi/443OJL:^UL24F;7T=C2@Sl:0Y`/1S30HL=EL5TRLdQSCDZ?E
%j5`:PCPU]JFUF=Md8E68_N6@ZEeLR2BV7YCEl]P5U<X`MO/Q>2`kho4?T4Q;f1Ri
%54ITL>6BDi1d3ETd@6CfCDe;j>c:P4<[46=X>8L`i@A0V1:74=hL1n3eDHZ/`0nP
%[Q@2@<0G`[A^SQ68YP00E@[1db:>VX8aAR2m1X2`5@3P3P:7F>lN0l1lXBTUCl/@
%d1XSC0d1P38SQ62=@RQ>LeoGS_7^GY_CVWM?>1^K9Nj=ckYgC8_?`YE12a5o:dER
%VXE0YQ?RB9bKbThAa@:>?L3k01a3KMnEPD`ZAH152B52TYPIdcoU1Oe66YR:V=;j
%bPZhHmZHD4N03K6>hh3cfh@?:ADaUKQ3W^<5Ni@CKW`d678XaDg5P7jG[5[6BOSc
%:0?T:XE`Z@X5OJX`N;E6DfaKOZgn<5j46:_P/QUQ70B`SZ@@H?3jJV7MN:/k@O0g
%lG5iaW@Xl2nQ[hlFP>XGnA0ci8WLaXf>D1BiESI25/]1S`YV4<9hB@T/bKFMdB@R
%A203D^7`@0IaBR]51]P38gQ_^P7n=PJXc<cR53l84F@]QKVYET?X_j3Q`MI1R2l6
%0K0e1[90Mia[bjG=7G<N7CoJNeM[kHPCD=e;X@ikSg27IR2SGj;2j4ZHU192A05]
%P283`98Ac<N4KXfAZPB0L0^:SJbTBb3n8TAPTC0URBWSDNBe5XJSkVDnXYOAFnQ1
%Yj<4oYK2a^<o`PPG3aPi=3D1Wf0:_ILE6QkGQ[=YE4W7d;`FP/@c1P2MQX:Vf05S
%WK=2h^hlb/A=;nD3I5JBVcaNe77QA19H8;aU:g07eRR67[j:Sl0LOaI93P;7lbMj
%PFYiX4TLokM_D^6[o4:oladOeafWKkYG8BTK7j6P<P<05X4h4PL`L0K[MiEHNhN0
%P@Mj/IL[A2Jjei/h=`=P=j[ARSA8MiVI@`XSKPNH908`8h:H:8:@MIC@/3EPbJR2
%>k]/5T5/5d5iMkI`R/6D6@RSE2HHXQ:A[2bPE8DhD`0bkl800h?H?:cYRh_`AH@h
%@PAH@`@`YHKcG`181@1cbcZ`OhGhH0HC[P6@2`2h3;0[7JiZ5[]aV;0H74<jXHe2
%5HFP<l=X14=h5l>;88@hKT>Z>3JBWPcbE8OXTZM`XhFhFHGX6H5@5XXhM0BhA`?X
%6`7`:3?1[@X8Ol?a]K4:PZecbd5HRImh7bDC3Z>bXKk91DCiTPa`PKm8MdDhD/E8
%</EH?dEXK<EjXHBTF@ETFRXX;4FlDhMbXARhP[6P=dGj=SkB`Ye;Eb;a7HX`O0C0
%BhB02P2H1`I`IPIJBJei:XgXhQLhj8OHMc2PAXK8K@KP_jQi:jVhVC02VXNXNHNQ
%GP<X6P6@6<4XM15`VAB9E/64NdNlO3CS]kDjObokj2P:7BlQLZ7Q70H4PaW@1j9:
%Y`1A^0LXg`C8C0BP;@;0:i^@Ch;H;0;b?@Li70fhOJXh`h?/T@FdTTObj4<JT`oX
%ZiV`ZHeX7SdH6PeHE;nH:h1TV`7/W0B4WCmXLik3J0`a?Z>0_0e8N8N0N8M;:`4`
%L@K@l`NhLh?H=@;0@HAhCYF0e8`Si`[0Xb;hP@TBPR><D0ha7HaXZ[2`5<>YQJW@
%acjYHY=@aaUHLXBL^Ce`@D^YW0LIU3QXa[:PMSf03<W@B2F@?8LT`SP`XS6@e0B<
%a@DlaSK@l2<8[Y7AE:^XFhG8FL;X2lE8D[5@hXhRV`OhNPD8DHBXKT:0M3@KiXP@
%j9l8SQ2Im4O`A8A8@kf02hJ8J8IhY8Nhh9<4O<NhP820?n1@>2@F3@N4@V5@^6@f
%7@n8A69A>:AF;AN6?j1AYoab>AR>a^A@J?B>@BF@bUo_f1?enBmoBb@_Yl_i`=ma
%0ZM0D1P@2080SlO3ZG?R>_ei_5i?Ag_=o?bCAeoAmneDeEMjEV1bRDE1oej`B2Ee
%F3>Bc:>d1^e06f4^g9bh>Zi@ImgF7eFlC:2GR1DIo^UT/IMPT7RMlDIk=m/Q8001
%X=ad?21Ej>_]oiIo_ZSen=E1me1lAYne?BAnjGEkJT6J/2jekjmlk64jBaAKH_U^
%kU6k/_Ke;KmcL6]e>jiRmeGJA^Y]oV1[W9CX?[Y97Z1W[4o/>?]BBY`=JMm1N61k
%NDiRX?bJGf=?GA_QY=5Z1l?2=07hndMoIR=8E2WP50H00H@4EAE5Plb17dc/47fd
%K9YN_SA<nUim5JEYEPT2@85dGAL=4OAn7bf/AA74TBa=4lDAC5DEaI5/G;4[RXXP
%Z[<9HV:SWjOK=9FdQn>@TJl[8RDHY2^/@ahYkGW^OQmXdSA]6bK`80N2Bf01:`3P
%<0@XRN9b@ac9bFY76jHabOCZ4RL4e?8TIjW/d:A`>Oil]6[cTX8dRn8@MLn4_?`Q
%d01]12S@PMD<2U46SAB1[`d[^`@jCQ]=8Ik<bLA?TbA8T2X=1gZ<4`;103@50FEQ
%IUfN4684N9MUTEH5PB3if7NOik[jbImWXPE:/_Ae9/^^b2RKHH7F:PJGWi>llb4P
%mTF@dkSCeH5XZZIe[3mK0bFdCm^7IKe6B3Ij4>TOEYF>UiPgBgI6TcMX?gN0eh[I
%NH0/J01dg`QQZgf<]nbE1]TWnO3S</O]M7mBYkedZ1dW6MHHQT6@]2l;Yi<>d<4W
%nNJ1Hg9XS1l8iMUdGYl^TSTO;cLBYC:_B369Um40XC^I]VZMT7;W0PieL6FX4hZ3
%FLUlGj7XVRj=XnTJCYFSB9Gj4>;WjEYK<c=YRe=MC6bMV8=LcIjbUBI7j`mN:ZZ1
%lW`OY^6fL4/PCN`104005PD0ejP0DaB5>U:I8h/RlAdDI@U0K72I`L]ca13nCYHN
%akWb/;<c3UM98<h9c4Qc531eN832ocaDm0dSRQcdP^M<>_DJjPmOC^RIo:<OAd70
%K1UP00H71D78V5lFaQP>0025NFAL/XOYf7RLa`3F=Y27IBYjX58j_nPOV3afPSKc
%_=QoTGkX8NoLR1o2Q7]mDh/kbDPedV2>?fSGmiHORN_ilA[V]XAm:2^;LQhOj>3o
%b1[N7HCh0RmSFP5KNg0=42ga:A84o=j2ZahSa2[1DLPiAdScE/NHOQAV46GDZT`b
%iTb_T/2B4l9X=@OPj7F?@MPm1mS[:Z?4[ho`CPM1<=8J0db>3h=R;`GX_A^A38Bb
%XPK5b1SGRD2J9PLXW<ZC^;n:@?hZ:B3_5L5dFH8;:DNEmXCBh`AQS56><TIHc93J
%ndhQ;HFK6_PRIQ9XoDS]R<>BPOB`DlAM8Jdf;aGRI8e9XE0S@gQ^SS0N0h2H2@4P
%502g4eH22M08KJ:lE`/db8n;6ITO@SQ62;0BUT6/XAGBSQlTdU[TTR8B8hQ9BAc1
%_YX1Y;42l/`^be5a;LQ;DAoWF0b;jG`79PA88Ln<RinAoSf<T`PN1QeK4R7dYDe9
%VAkT/7f?HE`YA@2U5J;PNA0Qi@K?dIR3aNSK^ZR6=`ATj@LC[P>VXL2dUTBjDU<8
%hiNUTBn5lnd>;WP__[>;?@kQ7eO>DNRK8Q2M``D9PP@<Je3@4D?G/_IcRl`UDEJ1
%5lQ@JWUS:6J=B?b>GYT[<dSTOPmCcTR7ZfL?`Q@o0E0h18KHgaX:kQZ0/0X33d5i
%1iC/<E?G]a684TZGBdQie51gDL;=BFXAh4[DfWXHSRWl4:2nZSoAh5h:beR?]@8c
%eMZmEn/5HJaAX9BBPS9CiCU?AXchSXnQU396:WhBKQYE<nX`oDQlO8SSh7/E>>hn
%eK4U60;hHiSH200366@;PT18R;Fh9d305`>F67P>nKZh1o6b9LI^PY=F_bULKIj/
%Z2amc^?2886mZ@<F[=j5imMAAi]1A0K5UA]eb@7>:a46@b[NC4WTY1ji5VnT/=RM
%8O1D6aFdA/bLP@m1m1V2n68J`hQ`@d:U2@T;=Z1T26QMd>eg`AgQ>L1X<eiH5QXZ
%X2l?]jb6Fb8<KN2HlD:R]ON6/=mmaRgiDTjfc]12275ZiAMhYb2YS=`<:S13R5b1
%<`H0O1e4L85X57P51aj3Y7T8d8/APT1?RN576i13?Qm3hE/SHoA:Al3j7X:`EhY0
%;PH0L:lF0Z1e3X7B141`5<B3j1kSeOXIKgd6_o7QlaMET6Y7/5O9@=/V@2868C:5
%j`ncY4H2G:bn1dglSc@:?EHl_IOc1V7<B;:m4>SX[b>2C9VSk6H</Hm3`2Ed9QGH
%bUN27EjEnS]7CSb@RG4Z9h0P0`42N4l9XEX[QC0i1d3A<A6QKRf5h=?BA;Am?d;8
%BDNPle:^B<nOUI9GBZ^46`8PA0QV8P`D@18=VZaMj]][T;>d3D4UC7A[DZhJR1eB
%33[]J50CJjM9CAlUPlR=3f:mR@OhlQfSo3:6<>28HkSoHFR4bdMAjU65X;DFhIm^
%Bl1E]l>NhATKS?6K7GHHA0kY19^_FA0l0DH75_4ENl`dke41_N9@eiRK^;ZWNGE_
%dI_gSk[8dTXaGKS6@jXg8g@9l=0O`nGP5^903hX9_Rbb7E4:8d;TFh^0oQo3jBc4
%J8;T4N9H?e7JCVa4^7Z;dGP]@@0P0h7<>PM0MPl1l5SW@D0W1?7fbE;o0W]YgX0@
%QI0N^TA<1=`/;GCGC1L_22=`b_[OAhbeV?[7FN]MKjhE^=:<kS5EB>In`3?Q]SJ6
%]N43kHhkAh_m7_[i:XBi[]63`7@A@:PD0bchMXkQb0A0T0a?PjHA3gf<^0bb=cYD
%TAiJ=8PcaX3B3j]P4/C5gPMON6TGo;RW[DIj@A9Da2lELDK5dKOYn6PCb:LIWQ5I
%Ee1VW2<bj>AmS^:P?A>PoQjZf3h7XAXB@T1E7V?TMY;1gSj7R>XE@Wa@^N3>0L1H
%50O0o268Wjg2g]T3Ob?m@0@aKoOb/2DHGhb3B^53nOFnma0;k6[^EjG[B2kk>D[n
%GGlXnbjWYUXk@h`gOmoP8>7302[f7`F:0LP>jJ2d]Q06m4AXK>9F7h6l6l6h3438
%327J7N7HlB7XmfX4<^j0<bBHJ`7fR66d0LhN101212291FinY6LT8:b@oLgJoVj:
%8>Cl4^0[1bjRUV0^;<78kNIlkL8:nbjk2;2=2?2@JBc:8JK29N;lSPAd7/46443j
%Nj4>U>96I@SFh4MFkR8dCHAfS^G:7Z^L3`3/426`6^6i2LEf2b2d2Xo>4n;/>jQl
%k6JXC8CV7^Pl946:6<6@3b3d3h0j0l101<1>1BOn3P`<6Ja6/2a</hbfhc22><=8
%o]1ZM81b5U4dO/;bon[8:lPL;0Af7`7Z7d:L>D9B71024V4Z4N2@2>240@KR2P2B
%2H4X4V4bOj7/Ad;bbdFT=^1?62XJ6/bTZN4U6>376BL`4Pofo/IZ8nG94T;6;dh1
%1VLV8@XF8:m69O4G6FO@=NULb@Ue1lhX06G/mBeJ5f8BaBBF<^<lB<7Z7V7X342j
%2n766l7092BHDO50CV=0@l>T1f1/1`100f0j7^CM0N]6G8C_0Hlo2jT31T843g8X
%G/Wa7F<>nd=N8<7U8k2C8o919394A92FK2C52`T`[HPn7`fFH@0l121:6H6P6^@J
%FT^69LAn9DSDjl]6BncZIlk57f92K?1N<`7d50524f2L2L2H@J[<JTJTC:<n6J6F
%6H3V3T3Z16141:0n10143`3b3f6P6R6W3dN^=X/f/f9Rljem6d`8oXSa6Rh4;`>P
%4Y0@_l`X8X8e3V8e8@df9L/b=46N6L6V42404:1P1T1N0Z0^0TZB2^5V5R5P7]0g
%8F/l=<M4gjbj882A<joDan_Z7O=56/UF9P>j?b7f7V7L<Z6j747:2Pid9j@21N1@
%6U=/:lYR7@UZ360@<J4N4D483j40486D6R6ba>94[G;F[DY0[BLFln5`5/5Z4H4@
%4::n7bP4/<5T5R5/JTin<Y:Z6H0B9dG/`L0>2NXZ6jk>Aj[H<nmTA/Q83d3V3`5f
%5/5`^b[HQ6VN7j?H:V3d3b3h0f0/0`4F4<4@A`Ae9jJV;dj^^08<l<A32nb459@X
%0S@/TD0BV8^fFVb2NU6M97A1A3A5949;9<Ej<bE_A@Z2VX8lH:fF7/6h7H6l6N0<
%0R167DA2C/=TA^96HbLPKjiD8:<jT2?A9>TdAg2JJ4<jU<:XI/:b7U0;38/2h684
%IN68g23VjRo23cBi67<bmHc0b`@`0T]P@85D6YCA8U6_BXFVIDFAAh8dH^OFlbiR
%101:181>3J3H3N61CjOVHf8b<gCL[^84o6643aD@fh3>5SDI0E@Fh0=6V<EZY0A^
%7fNP7b7F7>6d6R000:0F33Bh6T6X5h2B281H2/bD6/6l7PB^0h3P3V486N5h5B1F
%0d0=Dj0P6d7HfTEfT4_n[J9S2N@n7bSP@@<jd^NR7/6R6>5j3P3>2l2G5ZdT6j1H
%1@1/7H7:Vj^@[F7n3B3R3N0<0@0:9n02KL000J9h2D;L6B6N6Jf>7dVJ88?@BJAl
%K`5:=n4/ndSZlJ7j4MGlgF18242023>R5^DTm:MH8IHA20FV5IHM1h@f5d_6gm25
%6Vm8Jg;fG;4l@@A09HT`BHi@@SI3Gh@H7d6N6R6L]hhC>J9MB;6VAZI]9?A=IWIU
%A7I]I^jf=4=5?bU<;mIl92;l]4Y07`7B<b6d5^5<4X2/383l78<dH30l7h=NB=Ho
%?b7VH79[BF:OBD8fSnk58`;mCHc/>:2?K:h<RT5n3KKE@/0R_CD@3`6OKSHX@I2h
%c7:F2Ld84l]B1^6GKjFG8N^0h0=8=^gV5FZOKH@41PNj4F^j6QHFO8ePEf=BNd=S
%Cj61KD3JanR25jgh@T<YL6b4e4F?JnmU?JHf7`7<3b3B2d1n2/2h7D887>6L6>5F
%3ng^2h383^2L2l3o5:;j745X4l4>0D0V1472:<^/7T<]3dT4lCIlk4@BF2CTX4i>
%:<7j7N584^4H1/1R1Z7T7N7l6N6D6h302h3DMNIF<`B>12141406G[E^N0<J9j08
%0@F:aN0`M@3Z`U6Z84_b6:^n3/Kn;Z4eP;H07?P@GN0nhF[bDM4iHH86PQ7BhT0/
%oILf1mP`86ZcLjUc<dEoCQGTJ2=:9G7IIeQ9GP=4LL7/4l504j1^1b1]8<0e0R6i
%DOFiIKBAI[:QIYQgB=IaQoR0[3Q=A<U=32a3ABmS0lV>7>CV6n3@2/2@3J3h4R6O
%1naB7n6B66621L1B1C@/0N7I0^^>iFmT[<9@?J7]5:VNIlNfnf`5KWL/RX1nG]Rj
%1B4ES_PH8G@g2:Fh4n>`2OKHeZ7@8=1R;k8b8;P@7>GJ4b2=TJ9d0ETJ2<bX;UMQ
%@L`[PhmQGS@N=N>n5Xoj3MOd5iU48=8L8<WMK:2>GWTO7:dD1d7D7L7N7/?BA^7^
%EX7X72180X0:5B5d62<T86Hf7j7J7^7V7P0/0d1:5`686`U<<b7H5B4Z4@2J2/3:
%fF7n7L9IK3AJ7jHD?D7l@o?c7Jmb@U4J/b7R7h7V742^2J223/3J3T1l1^2<6`6Z
%78Nj4Z6V6ToK4V;`6IWlKPN0P:`LP@00040D0B@0`PG/c/nfL/]J7MXPonUZ2jRg
%<fX3@J8?DL89L/hN0N67Xn;aDH5Rj@3dRh8n=_;cCD_R86hn3n_VO?I9I67k7`6k
%423b0b>L2;TJ5V>oDRa0Y4a7ITB=QeQiZ;QmR3ZAZBS5R7IU;gIhndNRF><d7gU/
%721P0n0Z1T1n2P6jQX>j746h6d;6j@3`5R5T5X:l<`7X7^AdlBjmGV[E9?KXNTWY
%8HRjG85c[c6B37KIKfF`3mKICDWR;ZG9[/Eo6TbmXP7M1b0ZP?@j8==/6T47/Vaj
%1jKP04ZB2b5O/g=4EX8;CNRkX`8=/j`@5@g?Y9/R>:MD_LoR>U0272GV/><JLiTN
%KN060;1RKj7/7L6b6<0VP@7>7R7`Zd9N4^4B486F645j=F0HNLHd^>H47T1V120j
%4V4d5EUn7L</B?:4V<A0[J9KW9ZLQZfBZ:@h5^3l3b3R4B3j3J6n6T6>766h7238
%343N:42H2D2H2/KgEm9l7oGD2FB^<JGZ0T0R0X504l53BT8a8j7Te_Kj6G6/IiY<
%bdEm6fI@;dG9LfNn0P6C`nonO?X/oW9]PLX>RjLdnoH=>CF87`5f5j5d2:2>280P
%0T0N3Joj6^L9B1>I6eZ7Qf@WZ9b5Qkb9ZEb=b>J?ZIb:C`@JCW?b<ZfUEf7YT67b
%7T7R8d7G1NAbSXoj3H]2CU[B?>KhAU6WF8K4RP:V;aHRPZ2[C7P`1m6>4TL]T:7o
%cOC=PQSd>9HZj`21cj]F0`FU`n6C4Bo20kd=L`5[dBon;`O:h4ZGKYN_=56F2gdX
%bXW>ejJOHZZh0Gdi7:G/GWXDP>9h080gYaGWJTQX7Z780b0N024d4n567PDZ4>3n
%4D0d0F0P7X7:6m0<005@5L5D^>7f3n3N3P0LN0666D6`^/kX95JTa:lB@Hf07n7F
%7L7T5<5F5L3J3R3T4J4N4HRDQiUZ:n7KAT6V06040:6/6j7:6^6f7<9d0T4@4248
%CVY6H47^I<7n6`6h6jTPnQdh58565=`<0Yh45=6/G8YoD8fT:b]>W`]/lFh5Ko5l
%AYHZUd6=hc1B137BW:j4b4WQhHo/>;SL8;hfULbacRjD1KiH`U6RC/95D[H[Y<`5
%bAi]i_R5GiQlAR8hk6:f</VZ7n7ZEXAeb^fB@FVX7b4X4N4Ngb^Ij4^?iPJb[Dh`
%C1Ghb@M05Bid2a0:U21[TFL/H^MD;`bX_?;Jbg]I2<>:4=kHLhFd391h1IkUYKKR
%6OPf8GYF8;i;6VWLZJ4ZeF3ILG/kLjAkhHF@H_;bC^WaKHG/P8LilJ9lKR02P:00
%0X0N0R@h5ba27f7H4`4R4</<<J0K0<0`6Z6>6T<b7R5F4l4JM]`800100X0jMn0@
%787ESCR@iBJV;67DI`4d4`4f3Z3/3`4T4Z4b6hgRHcaK9DDZ7d7J302T2>4/4d4g
%D07RA2Ch7V6b6L6T3J3236K4HcbLHd=S4`0D0@0B6FXh?N6X0f0d0kKcPNPNOXoV
%nf>:`UcS`WB5a<WZ80oh4nh90X<ofE2@C2e]3H?0Wa4H<oXY3go17g4h[0Wk7Hm5
%XXoX=7h4nI<09@HID4iHEILaYQ1WY<go8Y[=Gjog/mGa=i_7Y35Y91giAH]AjABJ
%EBjICJMCjQDJUDjYEJ]EjaFJeFjU=X?=Yc=i4oIjo9k?GgJ7e>W_5gkKGnkYcAGh
%Ze:YG4gFnj[hnGdnWi0/2og^ngiQY5RL2oWiHGnlWTl58YU6DRXD@QVB;VdiWKhj
%[YC7[Xh/i]<3=AM=EAJ7C:3G=QC]Fo4Q]@9]cg^G3^h=Oge68doY<nMK3mm1VUbD
%=bc5cDociVm7WdmkOh=/h=6>;Aha[h?bd<3_41O9:?<0=^1?<0I@2@60`E]d5li5
%QWhlXPn7ZngHj7/Rj1;JHIGU4Li[64Taf/2OY;4PC@R209alXPPBeYlLY`74BI6T
%J?HjSZCY<4db9iWZNc0<4PBK;6PJ;WVOQc6b5P=PRJi_VjN<0aDVaj7^NicW@;X[
%2fLAbWBWZM94DYB5>mP06lKY`7j`<X702T[/jCR?8lhlMZlY:<6O<@gc8Sb8W`kc
%PY0SIo]6N[T>B1li5g>TdX6PS@X5=b;>1>j<XO<lnWnSajW^NS9U660H1L288PN@
%=8<nWba/75Io/>RR`d/OImBg>bSdnf=AE7DUBe=DmDECEEBD/SUG;5@J<X:]IoET
%W9lY4`<T;PAeN_D00IQR6AGF8Vam7m:LE8WIAg7HMYDU>E0QfWAX8R@9@STlD1>W
%KK[Pe2TZC:BNeb8<7McUiM;GDc;Ing1EMB3YN@LGXAUk96S/n8:Qm18lI5oSkP8c
%H6EN2bjRmmZE?:3h>T;_GJac/hBD>:CT1keP20;gP6l`3Hl0@003Gh6P>0i<TfC2
%<fB]j9;32JdaJB8nSP2:D4dBi73>=Hf0@1096TJQ`A>Oi/VlL924@A8eJFF1EUJN
%YgWNOak[F^L9ePOij7aG5U8m2Io?nNAcPb1H06RK9[_`OiQ6NJIVKJ`QkU4BA9P/
%1X91448C68IIWb@Lae7GSIZ6RJjO/2L_4PcaI7lKO37;XXJ?D4Pg4W:;W<7McCQZ
%5O:T:6JW@fZFGBFoMS7:1=TO;PXn3lNPa]mR?7IPZ2h:2:8hR?V@56PNJ_O^?BUU
%L?IETFEC2O:ACo:GQi_WNOj7XnUjJZXla_T[3BZO8bjbNWj]O[[P`<o`VOYmWckb
%LboMeJYZVaeWHMa>ThChT2>9@:0T2HS288YE?oLd>iBSkCH<;8<O<@@KH54F=lD<
%kc[WW/;;X`mcaGdf4H2Y1T?d6`I@MPXjPSY8CO34Q8724d2PfRdQD^mjQBaU`_?B
%ah0aihJ02Q/0<080P3/I0T0h1H^1NRg7/Ha925QlScO0nhOhn1k8C7Z>LGHZA=1f
%3Z74B8UQ=2g5l<@?0Oa2Qf3h7`FP^1KSa<P@Mk:^BJW4D6lEhJUUg80RF?lO8kQ6
%R03^0<0h1P[1P3:7/@`R1i4A;N?@MHga_A;7j3050<A0244F:<EP[aj;8CnYM59H
%R:3RTh2NC`Fi@7G:<ELT8JIC496D^mb<5CTSB0g:mPXZgGU8PP@MiT]V4TN5c;/:
%4_Ca0>3U<4K@g1/SkNn9`C`V`OQ11l_@73`Hg[:7d?PS9Hc3:CD^KlT;TX:WE@]2
%fL4hIaCSW9>DQi@He?HELH`RiAD9Si<2[BHdCD0?]@FAU[i>B2TR=lT0M0Ua=RJ2
%44<8X306P?2T54:RBaCScS<Cme9Hal3lJ^EV0b0DO3FXd2BSS44eCWM>K6EAAHF5
%>>f3bU0`ZE0LYH=NUa@cXRjYU2H>0KZK;Y5i0iQbGic>O8j62X1i02WVHfaQS9:5
%OPT161mlKEbhDEO6?HR<Ub<Sl7N<dGP/0kQe3`6/>@NQMS46>?DW8lAjSd8jWmbK
%ieJ:_;1=5EYHdF3oO0OPOXm1fS^7P>nJQohj4C;FnLN`jAg1b3D7=ZPoaKS06:70
%?@NGba]7j?Ilhmj9bS7n82c@2k>46C>EPT:i1k6e4PolEA`IJ^[5kJ/KU[GE/;D4
%W/`A[2>fRLNG@hHlKM:m4L22g`<kP2E^5KI[YH`m1l3cLL?8:KV2n^LY`SYRbL[9
%WHCimQQakeW9a;M@QXf5WKYkN6lEhkbGUE0/ZN4kB1gCODm]@MCAjef[LVdNkJRo
%Sh7^>XLXia>2J4f3O003c<QJU0:YP]UTT=M<=Fab9[c1ZTX^?l4F4da3?UZD>FiF
%b@hALNL<gbWl=dTCHL<^ReC?QgaACH=`[lF1UaL7[62oaT9P88`e=UiR>4M=lNVX
%Y:6<Y>00182@40JPc1TA6B]M6[elSV[4a8oAI2h5X7<>XK`o1d3@<lHP_Xf]G[ln
%F^MJUGT?^VmZK1BD__L[]IA7@oaiclD^L8NHnAh3[3h7<>eOc1dC7n5T;hG`6PA0
%P?0M`ki/7C7V5WABRPHBXXnEK4>3iH`8U5PlhI6<>7i`CSJWS23kH?6WZ4<nXcD0
%<2mZLHnZEmBG7bFT/HHPb1Q4V9DBEYPRQ42>/VjddGc?SV[EDT`n1jIS>6M^Sf>=
%TK9fE/]EF_GSIV9ZbZBi=S1Un@/maHiRB13S76>4AhSQ510G?T<28E@YQDUf;Ta/
%8B=Wf<H^ijj[GQ_/V[QY=V4LD1gMV7S=2K:MJM:U/HSY`jBZGWL^8Z8aN52IhI;d
%:06>8>o6ZDTgd]C^dkfHUhS0W^>1:hl1GT0A>A8L4J?TNmOQmVS7RH<MaKA@RY5X
%7C?0Q11Qn6N=HIb^RJWoi<AEZhlRoZb9<O/O@mZdiS?][[NACB_?6iBYNk9>Dgi=
%AH?TNPW19R>7Ro4M0id542WXBP0@BnbIo2n>Aa=6Q[0^kH6?]eWn`;UddEEMk/A]
%m^36@IcQaS[Hi;8A:S3[23>[l6ShPd/@Hn9UN1^c@P;M8iCmg[Q71QnEbD6408@?
%aO2o5n?<N@m@>0K0l<LH`bLcV:OD^hO@maoM59ZQIFPoCQkL76:KfcY1IJ?hck_g
%W_OO5:O==m?jOao7jcT@CE[hm]I^7R?0L@h1_R;4N905P;`IPG0Z1@<e@1MRf5a=
%?<18M[4fJfe`SWbi[6788ZdhV3b/Bekf@PQ8:ojBcEGN3_ceRRlEkk6RKXP@b0NC
%fPAL0S_1aXAhM<18Pc2H4CE8HiRBBkOXaRc3PZL`^S^3CcC8PhM0L`LXDHD@Cb50
%APBHCHKHL@d20RJP`POHOa=hOH]XW8RCbZC2>POHoihaI3o@eT6SYHTHW47jLiII
%Bik`O@NBHcHJ_h^9IX9H8@7X6h5`582l:@K0KXL950D`DPEX1X0P18?`>h?AHhOH
%:@;0:P2I:jh@B[`PY433^Q=QPhS0ML>;A@;9Z8Mj1Z2[B:cbZIQ8kcfP?l?iR`8<
%@@Fl@RFl=CbQ<1kh/H8X8`8`L:CQI8BXBPBh:`:X;1C3GZjamBJY2a90NcThMilh
%WXT@MPMHMa_84PFhF`G9hSYBJ;dlEkglFDFLFQN3GB^Q5Y5D6l92>8OhJXJhL8nH
%A@6P6@6;R02P;h<h<XH0V8/<5@`J>9;hVclKb8nX_b9P]/JBC;J0[ACi;P_h3lL:
%U`JhkK38f0S2FXYRFYd8JR11<P=hCLN;A0Rd33aYYH=@Y8^TM;_d2ZlPgcn8P`gH
%L<0PAH=LPboXCHN<>;>8`KhH/PTA=2^ROSoJR29B]T7h_haSJLKJC;mZ^Ke<82=a
%hIV4D@PD92RZNXokU8giOILX3H2h481P080hA8@LV`A8@X1X2`28>X>`>`DLX3B/
%O:c0[Y=T=S_PO@=4Y@I<YTXBT478aa@APH<aRdMjeXKPYSPAlaQ8kY@IBQe8Vjo0
%O@1h1`28K@K<[15LCHO8N[b4C`O8N`MHR4S@VhM@M8MR?H1<DXM`OBm;9lEj^<`4
%F/`L`T`[3A;HNh`;1hOXNHJHIhHIfH>SjX6P3@384`=@=0>HHhHXHPaXNhN<6b8L
%aDG9kDRi?ALQmJ]<^QhaCCbPnchIhIjZ2XkB2/34Y@=2132<3Bd36k_bEI;I@C6@
%g8?H=ThXEThj0;B/3@g`j<@PFhfK40RSRkY/gZldXhOhKdk8l4P`=HE<kd>[GJ>B
%]CIjOTR0RTUSl`V`a0XPTY1J^0PHTAZiFQk@/<f471hZ^<6d]XWQl`P@NJb`_j_e
%0ClQ=2:X?X1H0//P181X5`5P5H6H786XMXNHMkJ`H=2kO9PieKo0Z0T<322LjXT8
%AE4Ji`GaeJ3l?A=1=R5@FPj;ne3HS/@hPbhTA3<T8KeKJR4<69ZPA`AXB4BX;4[c
%h;J;ek/0]8MY@HNI@HNP@cVP=h=`>82`2X3098909Ih`Vii4`<F5;T`e;e;m<1iA
%C0RPJ@JXK@>`>h?84`4H3@4X4@39N@>@HPHXI9c`/9:LlilZBh`LJ0V[mb2IhJnj
%MJ]8`0gii<[b0TKSB3S3^I?e2hH;006lOID4j[P;om6[Ce4[60?DfjW1<kHhYD?8
%QlgI;d[;MSP2lTMR3H?`>MEYHPEd@jfAIAlilI2ZmSXJOQFk<IjkN97H`:m=?[GZ
%j3JRC:J/nQ5/72m/F0T`^2mZOH`AFXTB8I98W8J`JPKX1@0`20mP0X0P0BXHU04X
%4h4@;P<8;HBhC8B`F=MHKEM/fiK]95DLXPZ8k`T:V@GCAaL<U0P@BMOXJ=OhRe6C
%<TfXR9Ckn3bHh=D0/H^KNABd_I:h2SihL<7keYI0/]9A[9FXN0<0;X:PB`BXB0S`
%:P:@;XC@C0D<RQQ1C];T7/8EE4`Z2ENMC1ChG5VY3h>/[DXK1iPm3QQMWUBlYb^S
%o]WZc5WiR=NEWMXJ2[29@C4UVCAjWKCYQLO[Cd2C6EVh4=[84ULECHI0HhHLG<85
%U/G[Y/F9E5UYDbKJ2XUP2LP@R`^QOZ2/P3_e]jfPaaeMNlhX=RH8>EAlL`ZJR8P`
%F]`H7m`X5U`lhhEU]EXimaQaPjF[2;n<j8[eDUXDURBhH5c;O8?=cPHMcd32Fm43
%P4eZMB=]deNU/`T4`@XCYUFMUI7KK8aIIDCmN8O0M0M0N1>@39T9SPliGmKh0H0@
%1P1H0j6P00P`N5i8U@<8LUiYdaF/?Tj/7DMQJX1EjcDX7]k:R<7DNhL5ka=MbRc4
%LY?5YhZmlKCialW`>e_@SPXZRH]i2XVXNhH0GhG1Lh5hP@N9c@M@2@1h50JPJ@M0
%T@^0NIl`n]RT_ii9FQG5IE@l`e`:Tb2[Q@HX1^2XLn2j4Co[EMNZ2iQ<263P[bFl
%jKAn4CmI=Pkf4/5V4n3ZHbj:c1@DjialOhTebN21@LfKi3bL3BeHG[5@3^7jC`4j
%<8?PK68]P@WC^EC5<8fE^e^XOUiJdR]L29;aChk0QhhI=`E^;C5EmBE5aMb/X/Z0
%DV<Mj`1BX@laWX10Dn=KnelmimW@Y=^J2aQei5i=NmmAP8?XI^?Hkd@l2k`2G6:N
%9L89kHOSU3eN1/K0N85h5h6j6dVEKYT8002h2`3MoX2X>Q<PEhEHE0M8LhLe6N98
%PdhMVXG5WF3:KhRcaJ6`0@m=h`>>F0kMOhJ;5PEk`YeU3Q[eQ4Y0[KPUBXQjCPL@
%e01AK/^DlEn:^P;8;@:AGX@CT`L`D`DXD3@@5Zb`Vl90MXOHNPS8W[EZ>@SI5Ikc
%X`RUAD`N:ea^>;bN2hLn7h3Y>PGHfJKQkkX9Q;H]BlKmbkb@hVNk7FNSEPTd[@ge
%Y^P6OVNNO=OE3QCl09cXadKeBm52fKm`YKcPGlfkDYLh7Ka/MU5>QV<6@MPMaUWE
%MHF;T@8Pd@dQ2^3@Qhd`L`C6Ue_Ca/Zll4YmP;``Zn8h7FW;7k7mhf</fR40acA0
%T>4NR<jmV<aNOYCXS/0<k`E:50@nZ3D8JIai<iMnWn9fSii@PJDLnbK<D@NH:h:h
%:HU00Xmh1H0@0`0h:`;@;8GXGPH:JIUDCJmml1QKSPC`BF_>QSCPSc^cDZXPmhlb
%cP1N=<>^Wn=HDj5hIMdAai<eP^GkbV>@[1@CB>Lj1@=LW`>Q?`^3l0NH;h<0;5c8
%F`LPK`J5gX9`:P=PG@H@JhT@NPK0JPHP?h>H?X1`0X30MPN0OL8b>@W`jeFPT/f>
%9Hj=4X4fhf8=`h5Um@Pb3X6AN@>U`HFX4^jNi>i:VQChQXFbh06LL83knP5K5Fk0
%Q^kNk^knl<j^k>lTL>lbVflFkBh6l[nVlkC^m>n6mNnBVbFkM>AP5jg`405702Gk
%2[S`9Cg6;@E^m@3nh`4finNE4X4O25[84;aN8:Gh6_2l0hD73D1RiP5>klNnSPPD
%ic]P5bSP4VmP=f[=BTZ3B^N`a`g`lfVHPkn9QKfRgP;_70BW7CfSgFT66`f=^0PW
%0050lbXF=;7X067Pgc2>QfT>GVR>FmN73@D6F0>:dUiXLVa^Y8kLODS<j/go5C=6
%[LODn0`hW2Q89YSX0X1@9fe0J8JXJdSHVjJL631m5eY1QN?HI]_EaK30S1Q>oQT]
%h]h`U3DX3G@iB0@?;3_4277_5J3mZQMKC/7BK`T=iXLBcP18jKb4f2^PAHAP@bXh
%A8@@>hDhDHD00H183XKPLZ]3=cHFD1=h78608HM8MXNPN8`7>FKbHcJ^hBWXP820
%?n1@>2@F3@=k`V3>n6=N7=68=J9=n:7j;0J<<^=?:>@i[]F@=2A>NB@=kBMnbUjB
%]UBe`bnA=1bC>CBREBbGC2AC=bCEkBUnb]jBeUBm`c6NCjPD:RDJTCB1BNOcNQcV
%Sc^X?mje^1_2_=V`=Ra=:b6Vc86d2Be=ZfAai=>h=fiFa]DJP@=mgUDG/[Gd;GlF
%h4nh=aHF1_W4??5F9/A1Xb1Z^[9@J4_O5?>H]k==C>>_?@O@J7AJ?BJGCJBPGOC`
%D]Je?jnPGUm`>:=m2kL/kUAk]dkg@d1nL63?[RK:3L7T?cEj?R?[T9_X0OY03ZMG
%ZP7/0c]>c^@=oMn4@Z1MmoMk_hQl`Kd@>N93g77h:3i>gjIF1lSS@GbL?RJRD^Jh
%kQ>G0L2@;0cbWo12D]VOimWdO9jQl7@KP2jP=Pf39/6^KD47dOYo^DOil7^OD4_6
%OYn@NPcE88i21ZfN[=6l</J<lMJl;boQm3=7SZPO7h8B2k00Ta8Z`6c7Pc099H[b
%JIlW]TlTF7a:S:`0P[eb`a438<lTG85;j3_@<@a30A144<klB`JOAmWZl/87XMZX
%WfO9l7XNYoa94aj8XJHM1T7iEU6Fak7bOd6@A4d6X53l47c555BiBM:>FXCo7jG=
%=0[CPNDlH]@=9:l4_0oCbE:OlF?gDeCX7EED?=E]6YCF<^e?AEGdTlMKeMFS@E6f
%CT65HHJf:jZ3BXO5Ea5:QKfL:5X0UJ@RfXAE[77K5T_^h=A]S7=MdDo;A<ZZE:g=
%Ll3G5KL@X>lUTUIN5Z2:Iej47NdJ3:D]m7SOS@_8i]Ue]GB2F30E:^1P`UhDjX1h
%Jj[Y0>0F90;RPQh]746E9PN4GHPJ96/An@[<=9Di:]bP>K5T`haF=AiIL3Ch3M6I
%iXlNK7oB4@WjaAgU>DAA0J10444@8n84OI[V/KJ_7]4<@dDlYl7/Nl4Wjm5;X;LF
%EX5OQhSI[jh6WGYng43fcE0HZd438Y<8HMk;Z1]QEKW<i413^hNkb_ID?3ZSUfG5
%Uce6i]PFnOmj6L38<P^Q<l`K=B1CFianlM3m7?:OIn7TZ9IUNGXSR8:YoDME:2@E
%VmD`GV_EiYMFS[c6G50bHOJ1mfaLM`lT/WoL[@>A5VGMlh?P?jdOOelOoPX?hl?l
%Sh[ANHPOUFdPGMh4iX8ncJ@9G4b^mRUl06o5R`QT]lacO@PN/89SVaiUPW3C3P^>
%c1PgFO_LdF=UefLBfPCJ0e@10G0=N0[2Y?_H`o`i9`D_?fOZ?amke5:W84c1Djd5
%aF`I5g1]R@0X;P0G/8<`koT@@;:0f4@4:@g@[Dd;Tnbh84?EQ8@I63PEI_=OPiV1
%ck3D`hOa3m;R2Sb/MLTlTOhha_3R7j?XMhj1d3N>X0LEh[QMZ@>LPeobSQn:>Qlj
%lOI@70?8?DHPAdIAJAWE6;2=@>8f:gH6NQ/8WHi2=SXHiI<6AF]i1jk:<XSQgAoC
%2LQjd3ecaQRj@MLAi0W1>2HTDBa`Al4Y?BXaaj3FYSg7lV]3jKAhW>7/>0Khk@k1
%e4:ZTlXoSdZAL^ZA4kAe6a0UPP=kY2ERPeSjD09T^AJbk8<n/m4=WC:XMg<1F/<Y
%9^YT?<Eo/aiR<`V<f=Od`XIb48:`1F10PScI0k=]TXZ@WcOP60/9Dhff7d7Je^I2
%jiP>mQb^]jkciPC=US?<djDdZAW5X7FOD:`g;364D2LHBQCd3SLR^<D=j3B7V10e
%nT4cPV@HPMLk0KJ::aKDMDS01SZRoXhChHm7`kdQY4;ZTRhY[<3WM<jH;Xj3c8V1
%>QKc6IjDc@8PR8Bod4XUNK3PN`B`U136P<lJX<`IPk7<>XM9bQnWPElNDhPn4`c0
%PTLe[D33_]kSX8dPHAZ^6_4oBU1YNHW3X3WFDf@bJd0H[E6XF531Ve_BJ5MkHLZj
%<OH`/^@L@I[`UGHD25i1j?S50n1l3[ZW7bITTNF7dVal3i4084?8F`^QHJ88lM8j
%1k=E84?RcDYk5>GA39ZVTm5Ac/866Re4R`W462aJeO@YCB@a]7K>fPo`RFg>Z56g
%@XKNCVWUKFh4b7g`;PPMn<5aRD__X:@EG=NB1ao7L:nj@JkZDR8d</d9ccX1E^i<
%ZgjTkUX]H=BLPco2Y0/_@`aQX:kfB1FhL@7mlDQWE0_OD<MmhDR0K@niFlj;IG1`
%1P5;[Ah6:=JNN=?8naiR`5F:dAPRQ6Y`6Z=LJ@F0]QRPPcRYHnCRDfVBP>QJJSR=
%Q]J5RnX5gm^687>Je0J7iW8BN<m/`7QIheVP@9K0h`lhk0WSfKhCj>2oV0Z>fC^e
%EXXAC6>HjRg<>6=UE`8Qd1<Z=>9IVDdFdCDfEC5/NjMD?FLDHiPlXmW<:;JLZjYd
%[l1<eI@lnfBb`^ia?T:2onJlkBaI6n81Y_AdZHc_?AoSQ7WX6d4V]SDj4`WL7H9c
%AT0@e2;dPf5F=9SR8/dESd2Lk<jde[gF0dTj4H43C86:3k3@1Y7H4D:2XVFQ08X`
%AR[PAT0[/E6V6l>OmLG1bdX]4`n[6X97XZTNHJ@aQZ7hClZ8m1kS^4B8TBHdQZ3P
%c>?eZHnfX;XPT@H<nf`DkM<L@=I>>@nKS^PJ5I9QAa7@4foY`c71:k_1E_45nlm6
%2Le3I]:V/f1?7f/?hi9_cU>SQi3R3H^kf0Y;c9=/RMGBiIU<PfBCI4h9PA<iUgVI
%D4IWDKVWQ^^GFB9E_GoKHIgc2F^?BSSg:EcjS_@2`EO;cT;MYKbYeKkEOe?BXU6i
%4Qggei>K^Q]VXa:M398>LZDj5eb6KkKL8P/NWGUaDY?Va1lfXN9C>SK90VmdIB6a
%@0XY^`7X^Q_FOTOCJRbk@a18L7Kl`SV?K9iG=>iA0@jGU3[aCISjf2?eZT37oKFU
%<NDN/TO08<`>jQ;Tk7MUB0Ehem0i^BQNlTO0>=M0iAj0iiUjF7C_g^XJLf_klcd2
%nm84;ddf`>QkmE>JhWFJn7VIe<0mN^hQn08:2kg46AE[LM<jQ1TV^1L=Q`Pc<1/k
%?B/cDPc3oLkHhRd=TXd=I@i[F4E[OiWed1[baKZ?k6Jm=d9eWGl^QkQ8;hZmWa:E
%bJmW=mMjiDHTOhHUkL^OA4T4ZGOd>`Hi2<U>0EPnX2oP4RWd3Z4W0:mHQf863Q0D
%>ZjleJXn6>[^EhYDnk0XIZefT^UND@EBYdA:7f7`7D7<763632303Y1<3L3N3Vl:
%JR=V]2NJi@=<FFC2FBgD[RID>2aB7fK@>Z]h52VRE`9B<ZFL5^5i2:QjXDN@<h6X
%aJNf=J2dL@kLG4^>IdER?8><mXI/AH^T5N1c2jBXc8hXei0dRFJZ@@l<>l=W38TZ
%TXGHh50dn30ZIRE@?8[n9l?8_b8/3lnK1Q3RkV<21J5k42HPoV84OG3jG?1b^bQ<
%N@FBPTaR494PdL594VKLKjF@gbPNND=TEbNDg@[D0a1^XJ@6j@Q^YRUnYJV01_5D
%>ZPk4ni:7;5PQX:hV<ON1g5/Pn/60nlNa^[h[o594?60=52`[2;b7^f27l/h7j7`
%7H7<780:@Z6h6f@f6d6`0P0R0Z7b>D@H7/f/l13J[e1P?8_H1FaZ5VdlYDe<BF08
%:TYS4888[74n457TkLE6[b;LfJ4B177e2j1bW`=6RFel/<VBmZU>bfCHM8?8gR1D
%WlQdTVGH@L[2hZ/fULEVA13BZF84Klc0hJba3i62ZRQk4_8f:04I9:l/cm62njFP
%2P86SH1`Y85e7LkS9B=:a2U@<@OhoB7j6I9h3e9lI65]:2Y>n/mNBdbF=0YNQfNH
%iK9PVDDX?`jR=:PT=T;X1e:/PnXbm85m957L[0=T[6Ng5HHU2M9VHe:M9Y;@`6Mh
%7^D>C0l0EX`D@B7/2d2X2T4`4T4TYbJ>8X7:7`=V@Hn8=W;lehG<IB9B61<A3ng<
%BY<<Q`Ub2HjllX=2UVKl7n<T7D1Y<b3a<g5h86<^iRNN<ZX65>M/1lMT]DI6hBbX
%elcDH8@lbbL/l>DTST4j_R1nDO32CI8Rc:A58XMBhPMB@A8dELC0M9;B=0XHIN_4
%^:7li:aJH5;?>>iX:0KE0D3P[`VW>T@8=T[bA/63>nl/l]:J8:WI52g^Qc5n?@oZ
%eX>8:<i:2K?PB20P9S3Z_0[fXI:Q0m<H>86A?jmD3g06<63jXR>XXb=^U:Jb;biT
%Q`AI?DZ/7l5M@S@8>/j64XAPd2d7>e>e66@N>28D7l7X7d7V7B0n0/0b706b6h@B
%T`I`?0`bTRTX7N7XZPl@IZa:I24N=>NHjL5R>d0H>Z69B3??>R:0?@g6J<V[@bT@
%L<<P3OBLNb0Rlb0iAlk@5PDJhBljK67hl0U?1O2b>DNHK^1268E0l?=nEY8:DHAA
%CD@n`?3==bM?<8ea6d/DbI32R78=<0MB>@Ea2bhTTX7ngZnhQPdk@diC2/;b<P11
%DFo`]6DLA:M6hb>lI_CACFA1DWC]:@lfd<:TS`BC@5?j6@YPiWBBnNXA7noDH6C2
%<Q4P48UZNfcR2jiN5F:l7PES5n=>i0D@L<FBh;@2<7B268:0ci7d16_D0621FBge
%@B7fKV5E:hEH86l];404Xb[N6K>RnoD=3RDN?j`lA07V7/7R7B0b0T0Z`X6//f6J
%6L6@[@6NCfA2444<4:2@2F2Q6cCT@<PU5P7:lJ0Ddd[fmLj:eN0<0MH<;M5hXGBl
%c4CHRn@LQ`ljAB7j5>5:5@1j1l200`0h0j3d3b3h71I087A`TF2HlkBbhjmjn2/D
%`?BfH79:4H2YIRH73M8@M98`n=><?eA[GbebJXfEA0hJc0f2M:CbA67n7V@KJ@A7
%3<@jhXPQ<7307k4V59ES;;FfnHC3BTdT8:BnYf@6IT=RcD=RM6/b7l7R@J7Z6Z6a
%;k8bKlNJ7hFD7b7VLLLLglLS0bBm<08H7Jk05<XX3J3oL2eAFI<j>FW@L6lhH6AQ
%0NY55cDF10Jn3Hh:V6NACh[g@aE<^4if:U@R5MLS3cJfYF:0O02TPj_X_[Gi3f?8
%B6jBE@Oh:41SMRPn1AMX;M4gL[@O1oL]8mJ^`11U@l?4@L@PC@4>0804062h2h2d
%;@3oHNY^61>n4l4n53Mh>FMgEJaK9djPHbidDE?THN>TGTFFOiCFJ/I/A:7X?B7X
%7F7L7TSX4V6h6l6f3f3d3/0n0`0n241h2<5B5J5X7TgjJ?=Nc67X7WBPj;4BEHi>
%VDC2:4a><P[nNDQO@HN@?@OhOhe`Cb9F7mJ@NJCFhD7oE/7Rf27LEB/hRn7V7_;l
%@@n:DHBff@7hWlDl1hOODKMj]ZXH?8WiEKDf^I=KAdPMK2n58X/h7h7R5J584j>X
%0J6f76l6hfJ>UB7d7[23B_0fI/F`724l4h4f3@3<3:nX:<ERAQ?C>c90QaL@7d[n
%N87eAh2oSNMT1?SU@48mEbk/EA5o2>K6<Z<[JV^X3FK[L688[b?A;`4TPnW37;:k
%E:86>[M^T>Y>PT6gTVd`_V>X2WTaNg2ZigMgQ^nIQ]5kSi<ZGF=Ti6j:^ML<H<<^
%0eUITV6fAHHh]T>@jI7D>[Gla;SBmkD_8P>EAX7/5PjM6/0V000800/T2d6d6T6j
%I`TXf@f^GFl]1<3Y>QE>HeU17`39Vb9l^Pi75o<JbEP`hl?BR^n=32`>/h7V>D/b
%A:7h7Z@4ZQ1JhY1J/hLV7j[6ojgg0ATliCF2U[VYJlH?HRABFhTU0f7H6h6d2l2P
%2N6L6J6P2N2b2l7DJh?6n9C`A07l6l6j764L4R4Z303:2n4d4h4/[7HUQk0VRl=>
%NEMnXJ^PZl^h2ZXb23YXZc5fQ^L:Of?AQcD:HdOV86[6i;>]AaI071FQ68[08mM=
%@:8`l/imLBeWMH=1Yo:<86Vk0HHX>ZeGZX=4WUU1WfYWTkJhPG>Dd:=T]EU@dhDE
%FM=]D@YUYE[73J>oLRPoGl0C[^]E<J?gCB6n70784@4>4DLF0/F:1B4f4j4P1d20
%1h00060>7<7:Lf>DBf?fRFJ]31D^7n@d6d@^0fFCNeVZ[0WTdDjlAT87425k7i>`
%DPNA[LkLVjn^RnFDhjC[1`FA;dh36e8bf>A0@nQdNZhfYH7jXbPU:9[0cF=TFB<Z
%oj;UVFjYQoUBRfK9K4nCKP7Z2j]d6b[NMB3i4PD85dLf/d6d6P6b4>3j3h3N3B3>
%4j50587@:mUj@nJXM?HNK77J84APXbO8IJNOPB[h9iIO5/1gAl]d2ReGT8<@mLo0
%>HWPN@6i`NZbI6In54ch=oE8NCBDJkST1>e<>[5D1_4<=6:UNj2ga;/o0U>FkLT4
%<A07FYF]^g5;`_TgN[^>^1]MZVORN6N@6=ai03J/>FAI:/1e=7FcH34`89EJHPeK
%FXjmQW@L7h5jm82R2Z2/0J0L0T3>383F6b<h847N7:7<6/262>2@3D3P3f2T2/32
%7ZKl]2ZDn<7f7R7T7Xl?=;FLEbdgNjg1b>KDI686ZmNB2icg8fXCGi7T45LO7ian
%cGDZ>1CJ>>A:7^/cdN7n7L9>ZE=o6bA330Ee4nacL;aZ`4PD>2:8gAYfE;X1[E^X
%n4IiI06iRh4/Tb/bf]6H7J2d2h3<3b3f4@322l3N5T5L5`7/7Z7PJRc1d89n7dTj
%7ZUB/eTN8<<^iJ>ZW<VD[n;86U3c3o4nGa2fj`o_aTRlZVNO7HYK2E<f3aSnSa<^
%eVb6>9Mf<_5he6B6e<W2aS4E?Hd<FFNEYIa@8<W=3nHPPj;D18]<PNWSECe3^A:R
%eWTNND[6Sd4_hRMI2ELN>K[5``d=;;T;;aAlPjojKEF:>[7D15i81H1F1L4T4V4_
%CF7i;IR^7l7J]d28;475G`3b40485V5^5]8i^1<8Rnd<VjSe`FHeFeZ@84g@oj9h
%nY06]U9P;j2]?Ti72Q0Xb`F30dTXCK;nTgdNl1f?ALUNA2DBQ^SdWm]1;=hB`2?9
%gP^IMa2YIA1S0Tb@@N7cKL`87g6h7`7J4H4B442@2>2J3P3L3f5n5d6DR=/bL/7l
%JJMiJ@7f7QSD:S;UDbY@?@8lW2>ZBB:0j>>3>n62e78EBTY5ah6=S8odPF^DoGBD
%Ad879h6IBMmP3O:e`EFS:<_mYj=f57ZF>/ZlGFZYhF85kH89H@N5KQb?Sf?489^K
%bFP_ES:C>IkBn^^8o`FCfNNMDh9>iFC8kJ=1B7mZWB85JV>[<NlT2mSN2oESGlAn
%0N_gDWY>Fn7`8T6B4X4V4I^V`b7RD<3B3J3D80ogfoDFQ4Bng`oWRl7ZogloGjo7
%`o7hnW_5`a6Fe6gm7Hloi18I348S5937Wg:I5:c7;Cg;c1<Da<i2ki/T9`9id<Ih
%U9ll:1:gnmZ8nZ=@ZABJEBjICGno7gCgi3X587]57e0gnnWnoGLljkAWdmWXoGnn
%978;<mgaFHLoYFGkTX;Y98o8;_C[eNkiOKmOl1Bh^mjK9:CIZkPHYDlCSGk=WJ/e
%V[cNJS4OcNGe>WDV0004W<m85DgmG:ON93KGflGc8:S3WjmZk/[PoM[S=M:EY^`3
%_@?_`O`FY`e[aIRH0QbAabd?cFOci3A=U:iC[jgAiFn>e7^e4i=QhPnO4^O8L_<M
%o@aoEQ]ce/GH^[NJKeI?7Xk8FSn@Wnmj0Ll00^`2T;Z_4eZE[4T<490/Bl[51BA@
%:nBT^Z/AE`/oh5@boi>@i0ZU@T]jh<34LBA;4dC_JYBk8jTT7ZDN<HA@XAgAXoH9
%WA73^_[4Bc^dnRE_HTA3B6oheb<6DT?nA<Uad_3ka4Tb8:jORh7g:Ze:XO1k7bfb
%Z@FO`h3L>8FQR61cWFM2^[<UDN7nl`i3W>:BB2_;5cXS/VcDa1oXfKDK2;@2O4X=
%520c@`VD@GU5@6UB[:96E8;hUAn8PZK6:hnj7=THaL66;`Z2D=`dRn7HRRHLIgXS
%:4_=[88heNAMH_]C=8e[FeKa<_:?B37jd/KBE6Wo6Qf5>DiBSD=@d48@Q1?bIZ7=
%4OAc64FQDRn=a0WJT1leFOcGa4f:@8V[ZXa5C1m=]KbEW1MPRGL15h05NCnPMNX6
%g^8=lYVC1aGkG/?Xk3bVH4Y2lZ0N1DHB>V5SmQYVhO7N2>ZaK2bTUN:ACKKa:4NV
%>QiSko_n5NAWKT]MEYFLNCWRd@U=UbQ>TXENF3VIm/G8`ei2cejPLK^OIRjUPeaX
%NRJ:YSg^`TFDafT>2AgULm/2AfYRiZZU>[G/@Ejo9XYd4knR[/9MK67fbiLDf9^n
%]DeZhO/[7m::f7`X1g5^FYJ58DAAbbNjcJR@I64:2H=0VN1e7DPCJWo0YclKNh6Y
%AH><CeYT9YBaJ?9J<KnP[cY0LnKo@Z51lkII8>SA>OE;=A2:]gBFAG683P9Q8XIe
%5`Ei?1B6HM7QLCGklg4m/GOHbN<XD@MAiGUa;bJ@lWX2AZaVGC8PMO[Tek8cnfA1
%44=d9^XkBVg=MJ2QW8>HbRd005Pl6`US<78O2NM1b7LZVg:hRD5WdQk64?=J@Q4@
%k1h3a3Q0L1L2CoWmGT08oh1X81JPT?:2SdGA]996baibCTfT[N^>]HXY`f@SFF8@
%Jl9e67FNHD9Ya:cd1gId000L<aX@e;bcD_K:CnXXLVH/aIg@Fa1QV0<ol@@F/M=4
%B]>[JXEa=RM4l_D;BY6hQBB44LEaUAI>RXlUIPd4]97[65/k7`N0GS<G8;h`8e91
%=f;@WP<H=Vi84E4OKoB^`18XFPdXK`fQ`2F4X:2SCJ/fBX?T]0nQDRb5D<DG``CC
%V9RlB1A0C1?BE:4[e?;cb:4T<G1l?TWhc0G21:<olB3DWJRQ4daQY1l[U=<?<X0k
%0=0K1Z<hI0h2]S_4d8X?@NQ12:7RnDOhmb[UDV8PI48/YUBCM?1bE<ciXAOGA1Y]
%AMc4=^F2^`L3Da7@S3H9JL2<1hY=V^BU0aR8jSeFd?<LP6`808428XBhlR@0O103
%0GX^AQV=8O<8OXm2:`Z7f><Khg0]d7<m0f1c>X6Wm?o0doh1J92KXY64Q[JfXTPL
%V`@TS11ddO4IB5h`I5mSIY<lQ5S;9XbW7`B@G5;h806XLIhBE=Ch/XEXT6:DdR@W
%oGnY15HoQYE309DEN023oQQZDAj2c6JEe?ZPdFRcCCaDgAh;J[0=j]DF@Ni4ma51
%cEQVlAT30Ajc2a[@?>]Ce5dWfR<XXGQB2EAe7lF@RK=S4Sn;0?/NXF0/1R5D:dGR
%E4_6i7hF@OXmHj3i7XFRU]0H<Sm<T;<7EUIC=1QEAPS``K>1D/lQT1@K[AE36T>>
%d`7;DDoZRd@d]6Re;URB>`IPcARP90L2]M@oQdST0LIhIHdQ[3ZSXR9:/icH4R6]
%LT55bfXFA]GLmF[TiVTRJPN8Nk?Q]R:^d6FkPZK_<U7JF9>iYAmD]O8HhSYYQm3F
%6V<`5h:`C_B7n4T8XDAJ2`5hA6jQ4:kV4;>B04X90@04<lOh0@0`105]@1a/X?V`
%QE9N7]chP0fhEF@6ZBI`@7da`SB`aJ_KY4@]<><iXQ`ghWQ31n]UK;YbYB2>c62=
%Z7[b[<4NB<Lk<U8B2PaFTVQn@kDQN:UAkA@i5?nKl0ioaEI;AET>j6ClX5>Tc4YF
%QR`XiGGgTdTXo;_2Y2EUmahM/a<n6jiDTB;X>;k2QV]YdoAmV]DZB0FH]AH1^364
%l<PG0XVN0Z>0M;Rb@3d7]<4OQH2QVe7_7EER8A1j=PnF83FTA/JCYfB1`hjZJRB1
%EY/5>WI`2FCbH^^0>MB4Q<6[_9fDC0=`8Ll0Z8o1hSm7`>8b@Z@3P=1:?Dd@=@@0
%S0n0d0i31ldG;D>9W`4P80K6<<DJDoB@eZ7WJ3<cbMEKE;lGT`I963RAfhTH=8[Q
%G2/9/>o5ICRB?0]N?^o`na6R;4H8H@8PB77J7X?42`6@@3K6j>LZPm1i5P;<M/]0
%ob6SnK:3`BKDa`SL6l[m4>8DiiVfP<kRUCLL4Q>6=AQXOVL2]hlPDjANLYXQ^W]B
%9iR`TlYYV01@`6J`SV^LT39f;E73fZ]@L;O8m[iERHB36kVSoa30Cd<KgAHOM7f]
%dWYA@ZYT[>T>GZ3?:[4Qa67gZ`6n/12jd9o[Q@/?^GijB:SIhSYBQ79fM3en]I;T
%5F:lG2I@JSo7P=`C8S@oPb1h5DMaL2bYI:jJ8Oeo[2g4Cdf<GDXATn9dJ8>Y@HBl
%jC6`6KbFT@=1Bl/<;c3V60X5HfB248G_@:miYd^7?Q4e42d<>`KPg1X6N0R243h=
%A5Qk4:5h:@E36L3gV?^F0G@]QXMDFm498K@K@c=jCi1BnVU8Z`;Jd@KYa5Z:<@UF
%TDZ;@]GBE3=khWbU61>1X48ha[SId294CHSPY1V3;^@ZPnQa3J6^1T1X6AZS<6hU
%_@3RedTWKM8JWPYSE2][ZIL@kB;8I@?<134h=jbHX@`IGZeBb942CS/9iQZ1F8AJ
%1j20ohGL3RU1U@R2Zb9Hg2[YFS=14a[;7XUKBh4/5S92V:iH53J11Z33i<6ZJ2>9
%?8?47AQH>PT8Fl7kb`:@1T8IW2i8Jb5PlCTaP23XTB5ikH<jjS>0M`N0MHLH2`3H
%5hL8Khd@O8M`@@>8<X?XAXCQa3o9SYg`ZY:JCHZH[9;[hHT3i[[03L3PGHi821/h
%6/?:D;2K4I7I426hR1j:><6`_I;PRASJJhdbH8OhNKcXZH>X=X?0EXDXEa9hnj`h
%L0J`JP>X>P@8NZ?AEY?H5lDHITD[7d@TE2e@`JUhG3[PClDj>hO8Nj>9YI0i1cPJ
%Jh]Bm9aHO8<09h:XAh@3AX@P?P@8A`@T<ZNPOhNPNXL[_h<8;0=0NHMI;3o1:b`/
%=9e@R/3``K6hX@k[iZG/L@?B^1U95/6S<iY8k[dHSccD9RE9QhIZXj6;SJUPYB><
%4`XCh`UJ2TIA6@k/0:58_8ihIj8KX:6K2X=[dLE4QSTh[2<2<:181JCh?P44R`64
%S0^PD3LJBhU8_8j[TJ[cLXTCUiajl1L@T0M0IHHPG80cG0N8dCFHLX1Xc`IXK`La
%K@dio8NXN8N@NPehO8dRjTGH[XSbR`HLY094Y@oj:h4KS`EYPP/DK`T3iKD`RkT[
%WR:TQZ^@/i:jEH]@fBOhO[HHLPL@LH2X2H3`I0HhJRliBhN`E0C@Bj[0H10dMhOk
%2kC<F4[L6Z:C29[1X@abZTX<2RYdGA^3jI;0Z//IaHN`O0M`MPMbbkPH^0d`L`K@
%JPH@<X=H?8Nh^0OS>10`ZIlPR:obaCMD`HYCBki[b@<b4/PP/CW@Y;/IKT59PXSX
%jZjL@IiJR`3dg`oZXX0RbX7DSPY8n4`;/A]A1liHXd6Hda4KdCE<ZR<8XC8XD:68
%ohETkDfD_TkYiP/A8H@bY:Y@H/lZ:/FbJJS8YId/m@TS6hjXjD9jk@A@[XQXO0Kh
%CPBX@H9X;@=HNHZH4H1P4P3P0h2`D0F8Fa=8OHL`LhJjnP780DU`GXHXJhQ8[Hg3
%PKF8OPNlY0HI08;Yai@P=1k8CB=kD;/90/54^jHHRlMdk`Y`Z<cdaI1H_0f`f8O0
%NXMPC`CXC8CXCXDXEHEXG9;aM0OhMhMX=H;h;a6SV`e1Y@S[CjkP<[hm5kED2@R0
%BM;9?:Vld4FD[43kR:oJljJl41l]3H/8ejoa7Te0OHLPD`D@B@FPG`HhNIL56TaH
%j`dbRk7:ShM:BXC`==@:T8APJM@/KjE4fHRT@4mCol=j:LgBCLjB5KW390oiWQd8
%KlTJjLkUAJlI/iB92:W0OaPQbHjZ_`;2R@0Xok3CX[Q]:]Eii29DK5FJ2lik7dYk
%3DO[TeAL?aFIR/mD4`I5H@3mHPQ2H8OHLhL0K@IP000@1`586090HHFHIJY01HEH
%G8GBH8O0M0L`JXYhN0GXH8I0=H>H@YLJ`QLDb0KX5@584SCX5;KPB:91bH4ENc2K
%RPIdfUF/_JeD9EEiaB_=9bjROa;9;Ro@ZPF39H1PghMHM@MZhP/`_8IMRP5URc[d
%`]F2Z9?8TT>R6XJ17JbH8eTH4eT/Yl9KWLM[dhQiEH[LX8f5H`;P;H:`N0NHNm8[
%]DJk`SkPPC/hLDEc2hAmXEC3V=S@_L2L[@T@kY/lPc0Xg[L0EaPUOi6B7@gZJ91k
%LLg`3eE8oj=mZL2=GeXaG2O[IeAP^3daL5/jea;aom9alK`Q:B`Q]`OXOCfh:8C4
%^@]Bjb6l=UUm/mAUU<_LZ`NiO888E8DhD`QaeCMEQhNEM8eXO5Vcg:e[`91HB0B8
%BHIHI`JLB`THLHL@K`GXGXGM:S70W0B3:h:82UeLSDSXjdZM<De:c5/@P820?n1@
%>2@F3@=n`V3?b6@R5@9ma63A5m_F;0j<?Z=?V>@N?An@B6AB>BBFCBNBaB3@Un`a
%n8NH?>I;2J0VK02L0:MCP0::OAal`>PBbD@=oDNFD2G@>;?FJ;08E5aE>5`f1=Z/
%9:]6N^:2_=b`B:S_jRfFcFNd@>U`F/=X6fnM0:N66jFZ[@AkGVdd2?aYm@>NBZdh
%=ogj1]340?5C`4Hf^6Ne`C8f?3HC;IO<B=o?f8@;>?o?`:bFAojCCJ:1?ZbJYo__
%>hFb?fajS2_al_[KK5I;AHS8J366Go@H;Binb?amdS1f?8gIn@=Fm4Lm?TJ?DIEo
%l7?IkP[QL;IF:aE@Im?UnNGWjC?Bb7mV6F=iO6K0URoDCOM<OV?dCADNB_hc<0`4
%XZlW/PKR:Zij?@05<6VA1l1`S2D9[4ocDXdUR:3I3J1Q_3`3A0WP0a6WP<a<O4D@
%BXbSYLRSIX;04G/T^joATJ<KT778gAfELNWI7j?YLiZ88U2TS@TNTTYLjHLYhWPF
%BQ0/G@/Oikb/c<JbXidAP38jB^`PI:C59bLBhElcX=99jAFmDQbm=l9/o>C]X<dk
%=]:fSI=0jdlCg2amWhOan<hfD;=8g1lPn48?6FIITXBecn_E0im<iBK<b/Nj9XR4
%U>V6HARc`Y/489>AR68HC_5/N=F;6URU^>i<I@?8Z3RoFi2ecEQhS]GZ:CLmR4c0
%PBU;_>5S`4_TH8CIC@?K6BF39JA;FYI5[F^_J>;6C=^7AK`EG1<P009LT^0GLigG
%BUUQ[?H/5B[:mR8ha1X3_N`jg`j9FZKFQm`1>ZT?K3=JfaP[BbXX3R3KQJN0EQec
%PGAYU^9:M;`S:B8[6;N=a@O62[7RR8[l:fB<D0JN0SU9`iFoKfh=Uk2CVd4j8:dk
%Zc_?5;idPE1cjOEo=??[B4FAY52h;P]AHUTIDcXC1Z1FJ2hjPI6JZ:PYR]?Z?FDO
%YO5lGRN2V:HXg`>Z7=2OM:jdOnYi[:QhKPIfi1?^VXWnX2VeMUd;WeYZ2`;V70Y2
%RUVgnPFfX9MQ6lF>76gi`G8B>iR6L0PYgl^[A95;cMb08]h6[RWSkQ<_Zo@a_J2K
%dd:EXC[aOEj>`imTGWJBcRdfDgB<IgO5G8bl/LI;6FWQlj0oS9hBOTX=`[fcLU38
%^a6EfHo:SRAnMP?NcLD?1_/jGAUDWOO5D^J91X;AbdXc2WdO1nkBccKd<R50ijdQ
%l8hM]dPWoMMen^j0735WGHgI0X4`90E6f=XKY0e<_BOHIi5QNDeZB<RBd`YiVc[m
%>LD`RbD0F2kQ11TP@gHB2XQ<@=jJlQlXbL@n=gcNDZ@]8:n4Hl=@F`gMa2j7B0f>
%SVQlF<=D@B1PaR8bQU89HTA96a4^1[jGDU7;lVhn8lQIAE3G5L?lFECS4QBDE_c1
%gK]lGM3]8af1eAWOf1<WSaP3Q<SLS8UbcFk839T?<PdDgaAO<S5]TbG02ao3;85g
%/H8b@jITB6<923AZF=TLPcZMbb8X=VJA@3CTn/T2/8VCBoD0?ORLFIh30Fd4ALN?
%l>HLPjQf3Z7Qj;jD<Yd?HkUYbk3/;/4_;L:<^F>X0:01nG`M9P46LZJdR<Gi2/`H
%B[FC`oUV_Q>LGiQ`2RTTMV?=DTQOQMCIHf5/34gAWcO;6lTBJjAg46KP?0PI?QA<
%Y0REhD48UW4];^iLMjnPdCg4=?TK<niT^jMHJ4YYTD2[=Pf//O/GI[6IF2?dX0A:
%7A[N<1ZRCehLTP8Y04U4]B=@X8e0hhBeef:INH?dB59FC6<<J;FUAHj2D9LRd4cA
%]3C:4<hA8Q@oSGDh7b?M0aI4[54J2oDe:oQUE5@J2VGKZ:<5UQU<BOa7QYeALk7D
%lU7IABU>8/fUXoiB`<GS60RQ568Cd;7:DM]Ij7142CF^;mFbQ^XYL/NY[07PC`87
%1j6Xajhek8m5T?h>[0>;4JE<LCZQdf7/4l69aKE`0Z2cHm=A0hO3V?b9QQHKG<a;
%6aAEg;R4Q;6DTkUJ5L;@W[MGG`b`R;E4lA00HWP`;HBQ?Dn1S<WbdFSURY8De^ga
%EK>LF<8m`IXTl0[LDLUai1fXF]C0/AZ7g5oC^@ZSM>3BSk7`?@N8hA_SN7Z?@eCj
%1oUiD6WbXECZSRo_AEFSmBbcW4]Tji/@Dif;D4]KnDA7kIDE]aNZcS?268k3L7_0
%Eo;C;f3_AEYM][UCFSTDMFhGa?HARjoiMlcRdHF89QQ01f80[/F0/lXiCADhSC49
%@PKR8YT^ARU@/HCLG<M/ECQFZV@/He^:1D:V>L8RNS>>Z;ZKW`hH`FUiibA5IFb7
%lGjKhcjCTi9d83:52hMFbBiT<LnE`>IIA4R<8FGC/AaVY8A`lT/5I39ALbA4S3Rg
%?=1M1]8mXkDh7H>PLX0BL2Z5B:loe=dn?a=8oDXhUM1He2aSl^n@KJee8lF=K`j;
%10QdP2kBF9Hj]fb4P/Q>AIhiWU3E4JJ9P<d5`bA4b>@624NPZlfd6IT1aM;m>9J@
%I7UiQM;MnA;cmEjUeGRM51TCR9^;m5nY9XIjCK0I/O;X@WGH4dgOhlkYc@S[fU[7
%GSkB4i;3c]T<ffaEKM/[A83@W=a9^V==NSNA]F;GEN@b[ITHYPMgPG6?h1DVEcFa
%Ki_QP2LJGV><?ObG5a1bh5Z:9ZP]EklgCOPfQV/e4]7f?USe><TZJ^XKH9`BPSSA
%6N=060;`J3U7:>^WkmQlYj>bYIBB1MSP<[>>gMIb5JR>iTa9S/GF@4Agl<>C6h0^
%lmHU@/bMmb2kUOFNGFSKV;<3b>I@SChE<PhjP:CZA1Z^fUS087[1cV:TD65edFoG
%mJl9@5R[41jQ[MW15fWE=Yb3gi@UQ`m[Q>SW^7i]8MHJNl3OkeAbSi0nkH=7mb0L
%]m:ZISHmdSDChIB/[72fG0gF10S1lU/0SFB`EnG;X66b?B>bCb=]g?XWHT_@`H/M
%QS/fkFa60R>3eT6W1>f@CUG1J;B8T`4>G4^9lhZRbf[?3X>]oAL:KFB5>A6_3d<Y
%hLDhX/1G2]4:8<@BN1W3=6T60<0ISoGUCdXLR:00aoO3in5=Q;;hTl`CjDSB^a8o
%[Q^2fXlVQ4Zk;m<<oU1gfA`/ncU@R2U9T/iZg>T>9:;6DbWD1o0<0g0@l4S`l@84
%@:>`2G0P2=0TV6K>bP40Wb4<GFg>n2CRdbeF;lbb0h;06hK/YHkVSV]^NZEZbT8:
%>`SZDj18Fh4b9Lf2B/W4^22>HPj8edfNXnO2kFB28HP0XFH4kRe>7nN^/N2bR81R
%6_2Lg/ZL[/gA0h@VbneFMDg44hbf02]J5?2m1@O6H`b>Vg2P[R8XfBG4113D/8CH
%VJe8;_312XMBhF94IT@bAH>27^^jR^3FD47j^j7^Ij4F4H4P6R6T6/7^7`=HClD6
%i<ATk>6]0@0f>`V03X;R354`CH;libT23:0U4nT`]P60>8UY0f>h?>ZlDd8:hPYb
%^L>N_HUPZJ;l8Y16o23he10T2<?25HSZkPkH[Y0d7e3hKX1>W><R3S6@]D4@^C3T
%@2kFHdHfafVF[XWn<bmnCH8X>`X^8B`N2m6lWP[Bd8]f5<ljS6QDddlf8>Rn[32>
%94>8l:K^c2>`/ZLn:NH[7BP2lk6J@Xo>]`6[7n8`0L<J0@9hW^3@:4c33RCNNQ0f
%XlgBN/Ao12bJ00[F2B8734eV:2]=7fO=3Xn8UP8S8dClOD7n68666<5052567:7<
%7D7X7Z7^O>PPY`8HGl>47jL^7J861i9h:N2M9n0402080:080>@N6@W>4k:D1O:H
%M76Dk/mLZLGHL@8i5D7k:D4j<NkJYU3X`XAPn<Mb5c;42E;8a_4jkd6o30UJaTD0
%d>njM@4o;RKT6LAT3a;/49;`GHhA8hO<BXo>8<Q<5@27<6_DaS8D;>P330AU0a4T
%Lf5:L@Dc6NaHRLaFh<MhL6dC8b>8@:mXb?6dE[590fA^6RkB14k`3Bem1F?K3;;h
%</_f8:/J9hI=:H1NHjen?Nj4LS7P870F^DkF:0MLh0C83m>98b_`c;7fc@90CT>2
%=S4J=^>@D2=86/6^6f00020:7@7B7F=87/7^?<8Bcn:8D2=0B/7ZIX/ZUl0n]J0>
%0<0B0/0Z0`nn36SBUb2R>l5`>8W9:S6Y0H@bEfa^l4KbYZDZ>ZKBlm1@CT^>78`4
%3g?D1Y@Q;R4n>a7G<bfLIJD:o@=`;_7P9Hh43Ta;8M=J<`kL89@FVj0`W>CI1i5P
%@5=f8:dll^1FI<g0mH70iO22GNXdXo30jg92kV/nGNATjZ8?5l@0CDHZ86N^2eBI
%=Y;@o?27@cA6<`lXXn<Nm`9e87;V[XX@FAAfkiA4[fJHZn9LlPLk2fMX5h>Ll1BV
%dG8lO8CgCROL?NF9@fIhL>=L5R5X5b2H2N2XnhhNXkCTD2>BcJ=/<m926YDDM69b
%06040:bM:4<Nl4WP_HLW<_:U5<IWDf7j@f3I;/3`JLP/I`=>aF7h5R5R5NaZ2]4n
%0UDm=6_EAK2S@_EXE;0lGNjDWP2UEflPCBBCCJ;BO2[N=32I555m>>n09<@16f7j
%/W5l_@5o<JLfSL2HWDX[;f8>CLFJCM1YDdkYC1;lDQ@/c4fKG:mj]<oF4Ra^5MGH
%UUA9CNYW98]V9F<j8DFNL4Tj8Hjn5^M2bL04W4CHd]7JF@]a<[76gBV73L7g0<1n
%;RBi4U:Pj@ga;h=8T><nYbCT;9D:TZX>HbD67<IF3>36303N3L3R9`0H545@5XIn
%TD>6X?HZ:?;JTXhO;`44^69`mB01DO::9bHP1[J0Z:6EFi25?2RM7e?m;0=1@GFX
%?@P/JL7`7^^P7nW>4EJ/kB101/1/1X:d4PSZmnP328eEB4U3H2RQ0fj8>`:14T0_
%KK176_F09<L@K/>a;`48MT3W3[2<hNkWB9BR86dm@JZ>2;L8>L9M8ZMP;6GdBH95
%=BGlk;KR886=LW1PLJ3Q@ZZN;`;dDTFP;98dMeHZD/DSJOB4=@D2l>@=5@^jD?CN
%<90Xj/CMA/0]MW8WEf2U2XbXA6b7Gc>T?D9H77N1MV0]=T<E8Z[Xde8iHZhF>4Hm
%G/C`=`KH=L7g>n^lGB0h0D0<7<6/6>7b7R7H000<0f6P6m4DD/I_J:cn847R7Z7/
%5b5d5hSBA49`0C?J0?:8I@0P0V0204089iC>9`/K:SKYFm2TKHABQW=Dll866CPH
%`O83BH2djj64LPP9Lf8>9H@;4_4`2_PiKJ0^lHHZ@0ZK=OF0O2@:[bZ?Q4AAETe<
%7g7Bi^MddP12`=PH6BM=0foPNi<n7g?E4P:0M]F57UP9KRlI?//01d;JK>f694RR
%L>F998Y_M6@DGO5NET<:B]9d7hHlV:A@DSFB<8;l_HDc<627HLA712XX[iHV>`<3
%H6V?A;?j7n:NBi>400Ab47GL:;SPV]NEDfKI0J>bIX7`=L;e5D7f3?Ph5@4N4D<:
%7@6J645d0>0T1J7H=M?8>@hX_3?<7/7d6j70780V0/0e>^05DL0:?V2P2L2J3^3Z
%3XnH5JR81N4^4/4b7P7R7V;m;AFQ2c=kAb8<HjaP`EFGAnhPA@WLdT1LZ>Eb4;=j
%`gR6F?A`l<8<Db2AVZd8ff3<WLib4eVi05K>e]CJjD_MIU2?A@6gW>8=5/WMA:8X
%Hj9L6IWPK:GXBoFlicPlajDbRoE1:e0IE/=3NA;iMNS0oP0YX::O6IFnb<=9Ln8@
%?F>:=SGVUWD>=J=1Rf7aXGMJ9<oaD`g8Znm/G4Lj[bgBmP8:9LmTc=<[PaP/863e
%YJHJHLLkLV6<K?EUFAC4CX?EMAT3SmIJAB7d?R7L1JgP7J6/6P<:7>1P1:0j3l4@
%527R847Y9R8PYgX^=X20262>0h0n164<4D4F76747:E:?BTHfj5@201n24D1YcP?
%7S94khRRefn9G5Lb9M=7@nHQ5c;45cVVB/LA=HF>80nh4oh91H=1bk2BG2h:GhLW
%HQ1GM4h4nh;5Gi6H:oHi1h<mY17Y58i99I=9iA9We:h:oYM77k5Hm87]2BjV9a;W
%lLIhBIm<X?>X:[j86:<::@O:DlJI<8[>WaDJ51ha6J18Xbo7;F`IGGOGiY98ZnK9
%5h7:KAJKEJkI1:Rn8lb;T5[XN[]Kk<niFnXmFGhoGno88oXg18jogkQ<7Rl@nGjo
%7`/e/^TXUD^ngZlWoV<Dmge;[K;M118[<99FH:aMD0=H0mM[00Q]UHM3]M]JYYCi
%LFmiN=__mo<9QDh=Z8>=^@1^E/0icG?ch;aWo>^9`>]enWQ/Hog]1>kP/AfGgPWe
%5WjlWTl124@TlVjf4ZPSR1mHX5@_FHfWYh7LkGB9hVRLAa7TNlK^<Lcao?0_C09J
%a9n;dO1k/<2@8PXK9]6hScR9P_J[Y8Nl@X:/Ql^Tdb24g58NaF4TFR[5i8aRj:<^
%ZPRm^a71oa2NlC/2SB23Q88OB6VR/S38i?BBTiABHKlW>6dLMA36/LbZf/X<DOlK
%X>gaoTe;h[c2FLaPk<YhC>PYTcDSdMUk=a]CQ6In>97J?B`jBB;g4SY2]?Y7CnSK
%3^hT:2:bfT[DAA:39dNU6X:YQhR7B@MDXiiccU7[YBc@;Y/O@ZF/<V9k7H]a:4`D
%8G1T7LK;MB4/df]LNd31[RanOlcWP3EM03GSG068=PCZ`LXdE:cYBfjLXfAH]4fF
%]BM75J86fVf3H2SJjmeTX=RFIK[/]7;;^^h`=?/9CbHX8NMe1N40@PTeQN5DCHC0
%j2P_S>?9e`W@AmT<@Q2VZJa[<E1K2?0k9jhCC[4<4Od6Wj?0kSd=`gSR_/JBSC=K
%A93M^7o>1]3cT@7I89VC:8Ej:gDNH:iJK>G[cI5]Fld:H:b@nL1OWAeIhdAoC2:i
%?j57/NVQXeM0e=aNa6/[B85VNJJROl^jHO:[ZcB`7jeTP74G[`^K1JH6TK/VKE/P
%/?;?:D9X?UJ?F@d]19?4Q^KZ^P;6K_<@A5ZFnfNUeQ<A@CY8[W13PYa1LLDP^Z@f
%`K0HLj=?/IM1o7NOIl7N?A04LAQ9U6PFf7ZlB;>bflZEW]2EROeP2mLf6]0OWQe>
%9e6o>a]b3_@cGKd@hTmJK7dibRFWRP9hh4NBf3I4<]3ZNOg[P<9F3_N[1^6lVNYl
%[haAj>jm9oWcDQl7PNk2KHaD97V9XURHlJo/8OC0A:cM2Wg;:H[iCf79LOQc3U7@
%N`2RSAj8mM/h8OZcR34`5E0eB@@fkQcPT>62Q>V>473M1T?46ba42NNoQ^COH;][
%8:8b4ac@>3SQDch_HUXG5b6@@E@j?AO@e0W3Ma@^8I:4NRe9Z18gOT[0o4>2@LdE
%Pm4[4TM4Bg6YJ9FWPPT8eI[79HMj7S?R/UGRTRQ58<8_5I9dG^3l?Hb5XA8kDUi7
%1RA[C:1dY@O3DVZKZ=a1AP2>V7<Bi=EiPbh3m7H?XNHj0=0R1X</Jhjec7N@PE=j
%QK4/<M>Y2hBa/04bE=PbQaQDHbWFFA9dUL@BnBK=ZCZ7i8TZ1]U@K1hh105b]QQ6
%1SdY2>@7U4BQCJ3Aj?F>d`AbHo7i9J<8GXa0lAl3c7F?T]cmQo3A6P<`?HN@m6:N
%fPZG[SbP^@V``TNKT@V1=2NT`DBE6c5n98>2L`OYd=81a>/E<kDR]WD:[H]liQ`0
%GW/`TNZVV?BeIl@ET`C01D17I@>OZXAnaWOj[HWAEF3SNXL7NR3<ilClDC5U]A=9
%`1JXdR@<]7DGQEKRC5]CL6e4NRfl:Tc`BB8LD4L@[:?B5Q;3kC=3m1ZJdDIY:1e:
%`d/UI7CCl8E@@Oe3W/1N2PhF5TM7loMQQfgYT6;P?/L`jA_SC020h3hj2h9c8/?i
%dKdc5B==3CL_Hf:c07[@]DeR@@hDkDG?^W4@6<W2EXCXDeMjhU]YM@XUe9gEBQ7n
%LP6eJP00S/=?R1E1Jl[?PFmELK3eT[T<@^JYSYBbSl7VFhNaO9T464Z9@B0cQV3=
%?;DbbB2e@6XOfAbHAhC22a5T;@6E/blf:[X?dFe^@YFkK^6Ng`e;PEo[LAjVlBad
%=YM:[D_m;Jh;NF@d2MH>5L9f[YM@a:DF[c`O3BXPT1;5[6E/7FlAG@617_<:Bm2B
%A?0Y_IM<PkA;ZgO9:YI^hakk=EAkCL_ef[4gbYFU64M2jBU^;O9XPPJ<46`_/<MQ
%Hn9TE;?<mbJQfAiSiKHMdOHj1D2K4P58<8LQgAA9H?h^2iY/6e[95DOk:`Fh]/82
%_62T6;/7RQOh]<7eN01a/XU:QFEXSR0QT4f6>@Yi5AkA<PkPLMbV<FPeLDOC5WP?
%17^dkT2h9JbT@Bd@b`:PD0P<@H@`kBUo/T?PRc1eH>AcEI2YhohD3CcQ;1;8kLj2
%3c/Rd4P<Lm4h4`kVkMWKU6gL30M`SJVIb?_OKM@BMb<S[dL3cB56P]5O7O6Q1Ef/
%Ugn:^FlFFWB/Uk6OZ66h4aYJUCUGnVnVBAjM5TlT16U;5B@KNB];/];iGmPAS>Ti
%Ka@jm9l4T2F`A1R145M]`Ai[TVO7j?POUWC2HH7D3H4h7aLS96`>]>`nQf3[7RN2
%?;YbG<b8iKh<j_YE?7[<=RC>IVeJYeEGi6f:SHK^eDL14Rb1FkiEm@40A/1;koIW
%4gN]HLVc9a8jIPcTn4>C<>jFdbRd6T2VVXD`4_c`K<LQ=MQKTKG>Vc/8>SXIB2Ro
%i8d3H84PaLYe2<lTm]d[5kWdMBhM1/i6W^e1JkPoj73Nca4GVM:=jm1RMH2<A;Rg
%PKj@:kYEOlJgFj4B8<gD@JMCIGYo5A^ZaE_jc_E7^0BG:7[MLJX8@TDRK6gfL8P@
%PQQ;2<4PM3ol8e;?2N4N@nak64`L>LK88P9P<50:hFheQdBi8h<LGX^d`QM2J54;
%6gbfUkk0@@EOTjd7d=I_c/]Om;Jaj5dEjQFLLm?AaSF3lAMcb[09b_Vc`n]eih8j
%HjKg<B^Vbbi@kG/?LHWfJGXk^KL7:N]>Z3R76lf>VMVjh0]k0DP^nHf@A^S]/KaO
%UJ`PGCJN7F7=mUUhfJm/7RK`:N<_RmhZ9ei7XHa_d0AoDd8Ci1LTIoL3n3dE>>GH
%4b^@HR_nMfh3eco<Z30`Oh=l0CZH6RO3j`Pc9@PSmkYkFcoXcJ3b=8OZ>H3d2SY0
%3JXkmaQ8?@?8?P4D3`H0HPH8OCIY7`OHO;<bbI;@LPJXIX10eP@XAhBadJ:<4hoX
%Z@3H3h4ca`jj>If;diX0W@jCnD1[NXg<20O`gP;KnCnH]8]j3hhQgH6l:@f3OP44
%:`]kN3X:GSf0OaoAkSKkfYdbYC:;QC=B[XOHakfHNhZ@dSQ9ZK<S=;4kSSS8a@V1
%=@I8GL?9@l8RPaVL0h]0]hX`337kG3FJ`4@400PY`8DlAQf8H<AkG2k9Pl9T9Q3[
%5BjcV<;;9IVH_J]Rj9gKmjO0hS[4BQKIjPZl18Oi9`Kl2P3cSl@BRbd`N[IPE`F@
%FJN`2XAHAAiXcIQ8N:cIlanXOQ48N8McQ`j8OXHhG`Gh^P3`JHJhKd7IVXSP_IH0
%88f1Gd:`42PHMT0klbDZob:R`2WDDXd<9Kj@PZh0JQf;7:EX1JgH:C6/?keb?@U[
%29C/;LBL<h``aAd[=2>`lXNjG8cJ>ZdZ?;Rd<[SC=JGKg3XJn1FQgL@cG2Uj48fZ
%]RR0>l@aFKP<A;l;V8PYfH9DTCiP5c>0JJVklZ7Q@lCDLZ<P[94PR/E;0Anj_Yh;
%@lR[Yj9[10=40TDRP`Sa;/Lk6bTRi9S@OPJ<Y1UX2[mSmP;<Y`_YnHdPPPLZL`70
%6@60989@8PNXNhN9L`e3SRYPOY49dHO0O@O8N0NH>@>@?@BhCHDDJ@]XRX@4^Sdh
%f0ID_2U94YF`ZlL3nK?`P/R<UY:hSSnA;ZL2`Pf3GXD8V4XBaL;J40a2[/<2YakR
%D;h2cZi;^CIHa0O@N`NXN9KkRS<XR`ac=Y1chTQSeX_<NH[0S8]l_`]94S>PMX1D
%fd1Kjkl;Wi?IFaI0C<gkm@2:=lU1IDBhZSoT`HP`P820?n1@>2@F3@N4@V3?f6@U
%l@mka65@ElaF9aN<AV=A^6?enAn3@ml@<hbD>BMOBUiB^>af1_^HA^IC>J@R:_V4
%c2M?^1YVO1NP:^QAmn62S9bT?jUBn1?N1>mjB=n@9l_LdV`aQ/@1UW/eV?mo?nN?
%ml_em?Uk>mo_fYCbY[EJ[eAZIF_f`cF2<>m02n0RoG`08?1@=kHF4hEk@Ijh^lHg
%7@UmI61i5mI?8dZk_o:Ho>Ig7c[5H_4BnHIPgJL2JW00WF=CG@>RIkIAVke>`KF1
%?fN?jk@;KIUoIEob>ef?RCSLcbfF;R?]o?an_9i_>k_Yn_oKFF`iV1Kb`MO_F^`N
%>bAJ4J3L`bMDBF`c<@j7ik<;7j=3k@=LoUcO^4a6W>jYCd;4V1b@:9D3QO19Y`FP
%bM<fgb@@0OcAX:f;I`_34<YW1kb^@PSo=Q2<1[6PSYWW3DD8c0B1_NPClUbX0;SZ
%>Hj7PMah_6Qk4[F^cN:FPkN_8kS^aBVC<:92c/8n8lV1Y9a/BQ5RU0m:Q/b/Pc/X
%4O3[^`PAm7`/9m5>EQBPX2@8TTB18[74SQW^Mie1B40@Sd>XlTLAa:=]8:JWE?dZ
%0l0=1<09e2YfV<9=94RRAJcC9B;5=6_K;SKWlDe;b58TQ?0gKQ>8b[]]l/B`^_;S
%`DdlT^;_D;b898K>Z93T/A4M]J`B5k0<05EM/FN]8DSDEFe=DcLEJOe>]c;:a86Q
%Zc;0gJcDNlQkWfSmCX@ke/dY5Scd@PRGDBRK<G1556/`4md6kMDSa59<1<XCmhPc
%NHlG[AE6`i1mXc0lBZ<RglFE;CE@^L]MEeoQ64hEQN68bN9gWL<P_S24P=16GQJU
%hPF2WfiZ5^PcBY]eSK]i0Q]B?M7mG:ELU6X_MSK@k0EhTn4VK3OW2A;aPkb7`NbW
%=hSimE8KFRQ]XhXRT:Aj<FimX7fO9mHNN3ai0RmbBC9PS]H1;00e[kmW=LJ6hK/Z
%4e9]63Ahk4NP0081dcO/^:Z]K4W`MSQW6K9YV:KQ^W2Ii[6dN1n7LM1gW>KAY7:K
%YZWHJa^W:hVecHg=Ul_E=DK<XT[6b1_?/00_A3?dSea5AFFiE/eDIiEmFh2km^KS
%COHg5fGEmaIVb88bS<15gi`N2c7QiELSG6Y@XW1WiI]nJNWW`KKb5WfhF2WdZN2l
%^NUS^D]K:n_bin>NOik97JVBMOg?eOGmWLj2NilV>GYS1:3`BSD=8bV/K1Y7Tb9b
%4;?F;:Uljk<CN?D<BAihS`bR4jG8@UBL47MRhPX3:2bCPJ2kPdkYKI=FM7YDXXM4
%PkhB1YQ<1n50eXE=SDXI@SZBEg?B84WPA`1XK60Q/0HnP/H9@MOJ[lO0nQk]Y=j?
%]JPn6A5l04?X/IHAl3e:VW/WRKbe]h7X=X>8JP/5l08:TF@]bW3b72>PK`9P?0e0
%T0/5@^aPS<@lb0OIebaabHfN8^jZWLTR8j:V?RPP0Zi;h::@A1VH469_3nA4RHO[
%TET@844SfRSJIL@DILU@ZBGD0H8@I7I3[HMDNU=Se1jYQSR?XN[DBaTh8l//OY>8
%h737V?LZHmRLBd;2`2AD^IMBk9X?b9PoQlU^7n>lMXl0kQf3TBL30A0SQ;5<:TEb
%eGa:S>6mQ7jU4^72QlAM0DTb2@=D>:NLDU`Z0SW<:FM10i>Y:IRQN1jGUY43Sh:T
%1DmA=cgDDP:Mj?8O3:Wm3T`01j1@V3Bm54TgYN6c;_<5;If5B?HP6fh0JZeC5D;2
%?MG`o1j737DF0M0Wa<R92X5T;Z7QoSd7h?/NP:@CPlW4<69[^Vf9M?6`MJk[V5c[
%?lCX<U?@1doZ13TJ]@e546<A?^Q=BJU6NBBRH65CeiPI@:>A:@oZQSE2aEV507a5
%EM7CElba`Y_TOVlRd/Hm1kSh7Lg:VPn2N5WU7BXZLYQlTSS^N=Z0nak=3F=D^_eO
%i4/77X?>^aTc5Sa5H:/F8?0MQ1CV24?hP@n3R7;9:EQVRY;7C2d:PaR96ZE8^id>
%MX`7fU29JLCEZD>@O]0Idc288@8[Hf]hbRjQ^PX]`5VgA:ai43Ek1b5c^ahG31;L
%Ed@1C00a^E2m4Bn9hf0<Njd]HmAkUA7jnLOPFP]QK[BZ1CEO6AW;7mH@MhgP?PK0
%N:`FH]akBY7N=LIhbVg0D7?F]n2VUVY4MMCMmR9R3G37QLD4YP01H5^D35dc<ImY
%9^QPg1c;bU1k`T1;2SWG>QO``173@S<>H0WG?XmA<<6@P8;BXN`jB1DK8jIE2:G:
%D_N>@Onm/ecM5::VM^?63lMHk@dC2Te5iJ9NHf/i;XcQVS@3H6`=05P;P=0X1D1h
%A`RQ@4684A`_QP2m7H>m/ChbI4g?/=2NMX`iPic<il1X7Le1ncH>?=e[59HQDFjL
%adnco8DMiLnMV60_fh1@<c@4724U43;XFX1P<dBA]U?bY6?2IDY<c@aU1VR`eiGh
%NB^Y^cdSe7NgQ2Hm1f3Q097l<XK0h1N326D?XJ`cPN0P0l60?0UE[KGCAKKUKlGl
%QnB9A^H@7Jo`:08`0H]RH;8oX_AfbIMVDdFldKIP11KA0[]<@^eAhkGZ:@E3V8b5
%8]?0Z2F@oDCVJ7n?DOXSQ0R:3HDH;PE`/Qc3h8LMQUIE5CXKF;LU=:LK:gi_dQ1d
%6DWQFniH]`mYFSfa^I<LXi1`2c5T;P>`MPo0h1d3L1`405PQ121m@6JP>lJ122WT
%B^`ELPfV1G?`CNE27iH<7U`jnH:cWKRC4^8/j6=PL@aG]2>J8SM@@`D7@NCRFj8X
%ff0oaBM9X3@8`4PQAE6<<Q20dWmo>fYZ@8N@m1h]Y7f?4NHl6dUR[8bajRcg_2TY
%04<8@?Aha8UFn@NPH@W1?4@9DDKE3K]eUDcdZU<VC^JK;XeKi39kRKT000_`21DN
%;j>@>eWEO8@o/nCL27U@eNG]ic`Oj9UbK8G2@LWMMD]7HaAi/<@FPcR43`8Xc@n`
%]=94V9lEZ>?=UVg]@`lTZO0NAmiXiH[@d^<M7]:<k/1B9;7LbUfH6UVQ_I>l=kj0
%hOY3RnY/hJGeo/O@6l>ckQSlE[B<XTWcAWYeXQB@^@S/gQ^O[1Gnd;_kkFBA0]o?
%`hG_k4jj<A8P_P_N^l7bhBGdXHP:dZXHN^JR7h>@?10DDL2HBHj84/7bIh7F7H0^
%040:6@6X707BRRklFVm6?BYVEHM`8jdFo:842e1@^><0]:0NTRZZfbok1RH@THcd
%lB]ngni^8dQH[:DJXd;86j6F5f5B0F0N1@7TEl;87f1<0^0P6B6/6h7J84n8;^In
%9P>8=/Ua1U2d^P;^;LI49P?nUJ9`>0R@7^A`U^DlL//f<d=j>0dHMfT8IDPG1hgf
%8^?I3P<jlll6QJcd<`@49^A<o/2lclZ^c<1bM2M4I/18f^mX8`^2Vg2fMZXNWh[^
%7h5:5>54dZdZP:?D<RC0:D7/JHf406706n752`OP6X5f5l0l0D0NY@7n]j7n7^I>
%H4?72@:LDi12[jl2Mg1<[67hA=4Df2<01e6<ca3e4S6D=T/n<`lZ0PE[2R@TVjID
%oa3W3ZQ0?O151l7d6j423L2f3X3f4ZNf7n645Z5d0d0H0>7N[LXfL^7a5XFdSZBD
%OC6G7^UbPDGh<RSR;^7^g`>`aDRA4dkj>:BlSRR@BlF_7`;`BC4NlL?Rof8H:@4h
%lB<0Sl^>6K8e1XRHFlo77`^TZZa/00f54fdXVX8J7i0V7H2d2b2hRh4P4NCd>^6Z
%6P6T0l0F0H0R040>5h5l6D?n7U0@I4e]5V:JGj>Dee6`Udd06HWZ0Dl>=>3LW0CJ
%]VA8f<h14Q8I7`G8Qc1_3NQlJ`F]3`9[2j<B7f781^1:0/585D5`732R;h0D3230
%3:Gj;26h6f6/3J3H3N0@0B167I2R?27hElh5:g<@OF;6AfR4nK7XSZRX7h7`>@7X
%ab7l[L7[5TF[7Y:G<B8>o4jX86lJ84Pd5fX0T04==BlO:/9b=:N97`dbKRC2FTKL
%00N^UU<^O4GhR<;@Ak7lh@JZ908J<TNZV[:<^^7l:LLZ>@96LZknMV[n<`4Y>V<0
%d>;h5W>`o=1:?<@k<m<B<@]H8k:NEj`h4H`0[3:n9^fh9X=[3@Y>7>5:4^4D060>
%0<2b3<3L1l2<2`5P5Z6<blKX7R7<>:121D2>712Rn6[]7O:[>m@LHD=fO:7V7J=/
%Hl7n3X3V3N3^382f382/2V3D3/48mXR@=f96I6O47VTk<k@N8:NO7O;11N84`0oV
%0]8^D4Jn0dclK2PFT<8ZdG8o1RMk</WHD77X[h;;9>=dF/>g4VL]0@YW0RFF:F<B
%;>FFLZmdHhMS92`L9d^f2fl>`d0RoF6hjP7]1j^Ja]1cAJgk:no<86i88j3[CVI`
%3NdFWg5n8f;^[L;4>_7R;F7X7P7X72El7^0/0j1b747@L`7jn66Z6<2L1b1X4N58
%5j718FYDk=CIDfB;>7A>R27i7n;02N2/2h4<464B<d7V2j2T2H4R545Dm:>b7VA`
%_2kNYSDh8fWFVl9d2;El=B08f3AZK2]B4d^>5OFA8KCG7^;3@DNX;/>_BnAd8nDn
%8O<[9>;8N^<TEF>2U4YX=]5b<Z7S629`[Nb4E8[Nd[3DH6`J@47AGNG@1>l?6<1d
%<Xj>oBIHh2d5Ebmh<`WFPR84Zn7C6N7MH;AU>j@^>gE5@Rjf7n7H5N5/5H0<0J1>
%7U>JVV7c2R7J765d5<5:262f3TZXEJ[de[GiI><ln2;07Y5T7F5h5h5N0T0Z18Bn
%Bd7T140f0P6>6b6`7IBL[V7f7ZUXk0j`US7]I@WE>iJBSN8n4OJM68T0ANDJn`Zf
%bB3HEj8k?2?K<@/hNmFg4T;4onYZUKB><Rh<I6FhI1=WJ2;90hL^U_9?G<;8n:[V
%V/S]GH`NG861KfZ1F0Qc:UCNij9_B3J@`KG`>0N8QP8n2_LH4KLL8G;9L8F`:JUJ
%R3>DP:7f:l6@4ZW^4X4j5D6R6`71IF>`;DBn7D747F363T46k`[hk=<?L;MTB=7X
%9R7j783/3J2f3j404RXJ5f5^5X0V0V0>7JJQ5`g6:V>@ElLW;_MV@UJc8RIF7l6;
%NZ0GN_4@0:9:3Ro<^H7hQ87OLH2^ZN1PZW1P[37_IDL`7W2>Dbjn<BXXYB?n>4NZ
%:8n7MN<[7f>6>_33Fc<T7b7R8l:MOY11><O1:D`JBBG90Nl>Z05YPO=GHAASNNfC
%PDMfa07j`07;Pg1Q6]AH8EG0kj>^RHO9A>YX>@E8>`7V3l3N3>2X2P2J4>4H4P6n
%7@dh:U=IPYQe1d<e5X>`9h7R721j1>0b5D5H5/70gV000>0B2n3:33@]3N545[24
%5h64V09`m5;9QfWF]hi41Bl>1gS5AO=JA89^QXZR5ESEL7=36F;=KHDMIZd[2^h9
%K4?2NX7b:R7_<d>nUG2Xg;0S>Db490dd>6NlgbSV>=KZKEK``MH1SR@>2EN^0F<0
%i>nX74^0ce6CQf`L/oCMNP?J/n/n8d;75T]jU^STH4^j;0NnR67S;?Pb7`7BEljR
%RJa`mgTiUcKa<V>67J5F4X4D04020<2l3@3R262D2U?j5b>/8;<^5X;P00080V70
%mXS^PC:eDhQIAl7b:<30l>`X0TLkNk;8fiKf60W<163_WGO?SL:DNZ?DkNaL7n5?
%;JDf=h>AOYOT;FhBJSQ8O0aHm7K4IS<T/`O3P:[i<fCiPo7c;8`B`0AS>/0027XX
%c`Z[TgUdUhWg8iH??F:YJD<L;6g6?oRaCjJPWJ>2>IT@g:7n7P967X;690:FAoXI
%XcI?BLBhRXg47T7L7Fk:160l1L7@79U>>j7b605n5d4b4d4l3D3R4B7QT4?6Ve6E
%6^=hMf<aPSNl86jL<1F0<0W45>GbFUX`86iP7FJeGXK33R>Nf>FmP]VbZDX[VM0F
%SnKPB0L/[ILV=j_hIiBgPA[bChgk6XN695:Jf3XT3c/EGfimY]/LIO7XP=[bT90F
%S`d[K]KaY[/OGh[_Y?UH85;>7Z5V5H5N0R0@0f7k847d5j5h5^3>3@346:6@6H3Z
%3/4QBBR6O8>7QC:g189PWgVf8:N?6O=>00Yj39X/lnljD>ldcH3l9>0h5_^U]lNY
%[9=MZ_[RZECbWP[4<1[;/fiUL>ZZ9_JL4Nl>Qb5e_CGm>iXm_1_M_O_PEn>h[PBd
%6^6V6N4b4X4/5@525P6b6T72?5Z@5d5:5<500T0V0^4`4`5L7PEl7RV29hH;^bgm
%Pl<PFU^Blf>W4<Sl<0i1S8jTj?3lQTm1a8865ka@ZR41aFDK5o^2adMjjX:8Sm_R
%=VG8<@2=abl?N60VnhK`@ULUa[b5b7b88VlNJ2R<>aA>>^>AYR>obJ2X2Z2^7R]k
%Be5VUK/dfC_5VMGc:d:9CV3Zl?F0Z^B@8o5o3^DYC@iW6087O025cOGYH4[3`/lP
%<APmFUNUb;L28ETN7?cl0ad0l?XX27PSced=d?dAVLDea09N=eX27iC>Db8RA<>X
%;2V2[JdQFHjXehID@h8kIN5i8`M4<04Se:8ebg4YbjinDXWG:n3ieNAR65eU;4B@
%`O8LFT^M81dB8AZfika?a@jF0>fPfS_Kegf=f?/LXNknUFIm<<<ZXZaZbl[HEI3K
%<ll5NRLVnT73AZl>2[fme@QH<X/oP`X=94N:Mg=;A[=B4=dibbZF_l8:]ifAWJWi
%H>j?gFl>Sl6AggU7gWgmgoJ@E8[g0SBJFH]V7eC>aN[^:Z>934n8B3/590:E=7g[
%]0<:2IhaXT0Yhf`0j?^nWI:ag:8X8ZVlcL77GYTS[?f:XC[6[5aR<cgkcdl5a6SS
%;9AOcN258/;hAScl7?h1ioj1Gi>7@ZC0M>8IWbSZa^YR[[7NDnDI:fWF@h@4?mLL
%4Jl>Jh9B5lG9PSiYaO8QNJFjA9Tl<HiZ7fhR3/D069kD`NcR9JZZD^5=fACaY08?
%Aj85Pf7;hf0YA^022Ckmj3l1l3f]88AjkcI90ofO[bXY]1lHM_6GkKeb6OlTf3`j
%;i/D3bWgd:XBQgd00`ZjmIbh<cPaeXPhT;_TN9aYl49Y^XiL63JPEb49mSJGS;mE
%m[m//0R:KAh:F50n/;[d?37OAQ>Q2eiF7nCl7Di1Zn;iGXiUi4K=4OiR86N270J>
%1]TSH:eX8`dGg8jT<O^gSR87^ma=m_:Yjn87k?F0SmF1W>PhG9nom_oQoROFk3=T
%92m7Bh87n2nCgLfB80oX4oh8nX=17nIXD08I3@Q3fo4Gk4hY27c5hA6He6hi7Hm7
%hk5Hdo997SK9`i:FG:h<nX4oXA;H@miY97i<iY89e>iK;hg=P3@Ig@j9AJ=AjABJ
%EBY]6i4oa_DHJ1:X7j/jJa>7_CiUBjmGk1HK5Hk9IK=IkABH280oh50h91H=1hA2
%HE2hI3HM3hQ4HU4h8oH8oX567o6X8nX4n8g6I58H4mY;98]98Y:iI;HHnIQ0dU<`
%1=@7=`9>EM>gi?H<mJ11Wk@iM;WWAh7?GhnjI4U[C`QDDKDh6oZ]0geFH7@iC6j_
%1JHnj;27]IK3EWlFkDn;IHkMKkQLKU0kI88;<7bhkd6;i=Kl02EPJ5A;WQL=QlAR
%LERlISLMSlQTHSGI97;4ohmEH5:HiMY16]1T]5GXi0fUY`WZKo=C7[H=BX=HJ[Gm
%72[AFLc1:EB[@i]l=^0C^4kN9J87@7[2Ji/m;5=Q0]ac:aF][eN]5=U1JiaXcEUU
%gkl0_40O8R_=1^ieoEjoIkOMkoQlLKXH5Uh]m7oUmc:97V>Pb[n_T^:l86Nl31Q1
%2KP6W821=1d37^ik<>XOkU^ji[J]a2B4`8/Rb]`=4@Q34IZA;2D9@k2[2<<XiiX<
%NDH@56C9:i3J2`T]0jAdl@1;l1<OV98;GYm6LRb=8lTBC9DU/dUC<[4o2DWfS1n]
%0S2[Xa:Kl`0UDV9H_0eC20daam7iXC>[LE`;0b1^c5C:<Q2b:Z6^Z4_C=<h7nDTm
%PS?Y<CnPJl>RQ4g9G@L9]bg3dd?;e6XU2CLD?@jd:D6m;;m1PBddLm>D;Ae?e1D=
%AE7D;l<_:40/g:T[:lT<ZbfnT<E8QAKeZ_cb02_a:efjKL[:TdKYk>lVX9Dj;Y7F
%:]eEE<k;@fTfZJn]XX>/<96eJl41P9U]dlo:VA/USdZi>Bd5=LeIg@Q=6>Q2S1Wj
%L5h:R23EP0;=k>gImdgeOMnGkObgYBnmV8@o5UH;9UbFLSTi75QX;hONPXHU?2RX
%dnin8bTam7TT:UeK8V<@[=//i3T:;cc@efXA2AjIJ=VGQ1V9[IWG]VeTkBQg0m65
%EaOnO8RYAGj5NRo9VBE0YRQ4iIeWnVjMYnXJS94iGFdRTYj8>/PG[Jo0i[e>7>m>
%V8M:jkEm2^>7lRbDh`OIl/g;/YBhRZGCUV/?F0OjUCfDSDPVC_0Ca^b1AB[Tj[_Y
%:3d>_e^jUO_3]8=_9GX0o:VGbkSZ3YDEk7ag?Lod7@m4UcN=Y5Z343e=j0;eQUMM
%ZinF6RRDkO_B@WfSak6nKa/WXMYh7o5co<^^fC:BRanEO;L^Z;J/R895>kWndiY1
%Gj`_naZ]X7g`IolQG_I:EW_AjN]6FWX6Odc60bo19mafOPPg8;ak_bO]nolOcZ2d
%CM=bU38P0GieP1DN1oP<m8PJ_e`We@Z?HO8malSdH`?P58:@?Q7Jb?mf[Kf@^eI<
%aI]KbV@/g8NoEJ@ne85IDG2XZci`]@_Dd2DK4<gW<VG6R]aY1EOUW:/FX;Kggm:P
%R0@@KTAH1Zg?92l;C/8Pa=RM4n:2o6Z5I:hRd3/EdOP9;l3b;QN5^`:9LAPOS]BD
%/K5D:HC@YQARJ:V8dEPZQNSm<^A`ScJR=<UBJfX]c2R>;PMU3TOhVi1=n5?8EMbg
%D=??DVKAkDDEA`l7l:fBDAcEYo4`@I22kY7BKTi9fCaTDg5L2]:=NRlQdbWHY2L]
%im2;3c7D>48X?@I3f7V>`NQ@0D0[1d>`M[Jc=UR:6AZ3JCBR@T8Jd]iijAHC;APa
%`cJJRBXO@X<bJSkPB9Q3D?2KA2G>T2M>@FI/We7B=CN6VLaOP4CYWD=6MR;dHT2V
%k>:NDlijCc;2m4PB^a:a802n/FTodD^bJ@kDUZFBbRJ4T8dJXcQS=jX8<HI8cA9R
%F4jkJRdMSl/H7k1mPI;W2U35]B49m8g[0[6CBLPb:E^S^YI3h5U;e[SJQ<XQjBRY
%6<ZWZO1L2n2>:o1UCmNP;JQ5hS0VnW=AjTE9W/Da4Xe7:P7@DGi48J9<^4LC:6J1
%;F0Wg9<?a];g6<AhWQF<SJ[amDJXhlb[CW2NS0[L1V^0gZi2S[X`l2hUZl>bCT`T
%OdnP:Eo9f:i@kYF5`g>H^HDeBTRe5CLNVYX2[88lE`5bbR@gSF:/aIVcBC3dUXR7
%@=?1BPGfS;lPZ2X:JRV?=2?XX8naf427J8L@HP791c1L387HQQ42B7f?N/QV1lSk
%7ZGHnd:5_8E</Db_MFG<W984KhL`5[Y2h^X@J^@gU/QD^e:LM:9gWc87h<jlDE`>
%Q__<K]iln4gUhZO?6cJAQ?gaZN_A`0WK_FGYY?1imk[ggm_mOlURgJN?cLB6C0aO
%Wee?ZJKEF9magQT2j4/A8QA0_97n4@90Da?RQ5Jb8Oe`CX>aJBOXO3KbR?:8jEUb
%1BY00^aL8_63fhKab:H6O6d<AQHiCMEE_DbB[C=HT52dH;eh3P>EEUG50/0992_T
%eG23;80:QV=Q>Ej[;9[]mT_;FFl^4;K5Mm5J:IUR`D`CT_`W<dDc<L?ii8o1l3e6
%H<DGX507P59:D<O<E`B^k7Fg>3AFBa3l7d?iE6Q2ACgLCBUa9b21QNdL5SB42Bb[
%^CTMlFCOX31ob>bPPXT=?0Ee0;7DAHB`ZA@XGk;ZBi4Sl]?>RM89mHJ<QdFELEK;
%lJYea[VcJL]B;C;`NTKN`EiBD01MX:VEcJWg7f8D?PMa=RB4F?dO@kaPS35j0/1h
%61j<J7_78NU_Xa4FKNfiK`n8a<3;[N1>ElA?j`1>nNWMQYWkB:b>SN`Aml701/=o
%OQ1ZR^G6F=GPA0h0380o`L?72B4UQ2U`gGBAhJSGhT0cRRm6GQ/Nf^2;bdleL?hm
%anCJKXQUQZ;_P8jm=g3ZiDFSSYRB=3eSUWP:P@@M3B5l;DMXjA^P0080098E``39
%6T=m;Hd1P311S;T183@73I7H>PNRbUHHP_eEi60R>/8Y:ESTH@4^_K16fc]IclRf
%bZQ>NHA@6neISG07W]b35N_`7H4G^RUPKSTkaOcT1lRl2JkmU5NPX_149Z;S?_OQ
%b0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN1_f=?j>@Ilan37jA02BBD2bMSbV
%<aZ1_ZGAR:_j1?V1?an?QA8i2Q6B7Tj6Y7YQ9P04Q5V=E`?mk_ef=U]_mm_a18I2
%Z]O[ed_]mE21E]o_f3ZJa0:bB]n^Nd1Ve;ZfCInFJ4aZ`@^>?ji<:l22m7:n?2oF
%iHH6BZ?2GFj`=2HT>h]Nhf?cBIb2HI?:IG;IO<A>GEj2?_?5o@BFBQ;B=OC@>g@=
%kj^3G;<joHK7IK?JKGKKOLKWMK_N@W3i5ljV1;cR07SF@10?U8;VJkN`bI?nk?Qo
%_ah_mi^En?UiFmo_B`?Vi_^1?OZ_QjW4iVic?9hMB1C9n_JX_ZXcJ1X?mBE/Og=Q
%k012`4hB_YH[ZGX4ib26Y1Rg;Zcck^lOif`X:4;1c33C6^hQN0=3`@a0^3hXhaYN
%]82A0aC23WaI5/G<XN/HX6N<J1E6bB^D0HHag1k?=K0cY8k5lQb98/SB?94TbE9K
%:/NQ<:7J3TY>@TXOB/^:=@8ikW?8OAh>TNR17fNil7`kamYTOch?8BQ9TNJa/6Vl
%SZZjO3b;Vj:JY/8/n0G?aGd0=E12I@TEY[=3D?a<DOCdOQEdN0@006M9cW@UZG>R
%nj1c:O1<Dl2]@4>A140EDX80L1he3@=:j`DPIeeP8MI1IFQae]9UL8bR3XccG:i@
%EEZ=6UHH4f:dBBD4=B3<=8DPekG=XFSJEYfYJ][=kIUW`:OXYFj0U_Y:2ma79LT5
%;M@dS_7<D4X7GT4c@D9?U4KI]Vc6Qg_^j:i7lOR`GLOIlWd0`20:T/;2L4PBQ:Mj
%oH2OSXWXNYlW/Nilge8AnY/OAc7>M8T2>9AXVFJ@/RX;3YI@kn7/Pj;7/NHIR6<2
%`=0b0`3P>0JB0OHYT6<Hl2@8^ZBPgXQPJ<^Ed@QEe5cVPT]8;YMY[]P1l8h[anW`
%NbJCB[kiIBVF7dAOb_[NhBiaIM3=X<B6fBXTTLUI^;O^[AAobMJnlKc_Fmki_^n4
%G`5_P8T[S02E?3d^OFigKI][TSakT1QbAGLYYmWH0]jI58DAAPJ1H6><05_P44HB
%19dXB0X2X;Y80PPR48f;gdSC87j:XY2`K1ZVfOAjW^A134>EaFUU>fk9VP@kSb>`
%L1`6`;0Z32B0415RP2/VLdTTP:0T2MH7FQ=>@l0aKo;L@;T1m=4hOa^VFGI^T<ma
%MZDc>kaYLjSiC@NAk7VlQMVbYMP0ElPR_FXVh@8?:1AZSF452[0m]`006`C6k1Ea
%PoUd=nPe1^3T7H?@O8RPXcJ6P7@U9:0R50JhE46KD@R3;NHF`5FI0`lbJBgQ9Q`B
%H0[fCA03Fnil1`P10R3I@aU^QfakSfC4=HJ8da;2>4fE`P@n1f3b7@74?0P1jUP>
%lOIf`FPZ0T1B2<1h3P8P9060X2`3`9@l02BB=h1D?0RSX>Z>aSfiXi86>R?P@8o1
%1T0>V@BVdb_c7nI]bb_dP;EMVeQ>bS44UPD<deODDTiVY;/AUmY^HGT:DhU1Q@9B
%B^21o:D_`l6PbKQ1:^ET[IGB_BD?>F@:IJ;7003BG0mYM>9KVFi1dZUYX:Dh^PeK
%5C97B;N=DJHeUBP:U]2P0`5@;0F4l9lCk5cZZ8GJN<[@mDj?77o=hc`kSb3d7V@:
%KcM2<UK7bUdOYFao7P5`:/F0D`VQ=0L1@200P5P6U/BELiWRg1AX8R8OhNJ40JXD
%<FQQ0i>T9;M0MnQ6TbX5FFeU0[5QoWd?U99ARLf0>:V>]Xg/<J38:6GBU71bRBd8
%3c@JF5<JIDcYYCDS210bDiYF0=Vh1aYdoYQ94O/QW;;GT<@JH[:0U192I<dTZOP4
%/77L>hMQ6C_;^7bV@OQZao3j?<?ljQgYcS65b<X<XHPWQU3H5P6@A@Z3P>^Xb31i
%1l4d9Y5dPAm2_Sk?0?PCXYaA0R1<2E`A9Hj0RJR/1IYK1M0D/LOZ8Q`5>6KKV]U_
%LVBi9UK^EmRJo2XTe?R?`c`nAl3jRhJemSG4G5bQS9e6Qeb1>?4RSVF`][KFKY]K
%VgE^kNDb53Kn7D>cU2R^8@aOJcIN]eFY@6BQ79OV686=dKPh@6P<0Nm<Th1FhRZG
%N`11=9RI=D>TonN4BRgS85l=H281@;eP7<8dA`O0D0m2P>e4LhAgS/:fVJ0RLicb
%79V?M>lgQm7NO:;Mlh3<5;50C;:ojfhA887n>72R00NZb26>o3BF6c_[Z:]6C=V:
%mWNJAR5/K:HSA6JQA8g>7b2:L7YS5mhoPSHeL:SVJH5Ub3T]kSg7f?lP;D6eT?1@
%34o0;9:5S9D5kV5bTC8Z3LQVU4K8h3<6@=gYPH0^1XJ6GKAg>^L^a/1mX2DFWN?T
%NPkSY3f7TQ@3`6`G3F6N=m^`kA=RC4@8DC8[abhW:n?M/=@k@5LTLaVoPoDiYT?P
%@@BnSG2`C0K@K9hoC7Qgd/GX40bM=HaC2da0V;<@;l>TF0OEHBK[m@TB`/0kiS:j
%7i;Xj9gY<95/ZAaM2iRKH>17[^FdY@Od?b3/7HF`mR6``]144fbJYiZDJ@JC^]i5
%[FTDfNeV4R1]a5H0@0H2090A0YM8Ki_m4GNJj_`OVI4dTPP`EnlYGajSK6^=@1H3
%P>jU84>lM@6`5P96:=DMEmRU3gVl?hNdVAiSfa>WTZ8oS85@TQ;hVcL`[lC<8:<Q
%RW235^5Sa/2?7E?2H/fg?D2d;A[[:d:@C`W09PK0j<@I@bSZSm345`;PaQWSB7P?
%//1;:/YW@??3?a_;LK=A7B@PX_nTH<PR7KYVaNW=k820P3oPD3PT5Pd7Q49QD;QT
%=Qd?R4ARDCRTERd>O/IOTKQQhS`0T4Q0TSIlUPKjU4GUD[UT7SKlQ<_O4cT860X:
%M[/MkoOd4OKkO;nOd`OkmPCmXM6W[lNkgWSkX[jWSfOkhN2`EjZ99A;;lWXf40S3
%851bhHCGLKdXkjL3GJ0B2@LJ3FLE1OkgO[iV3kW]lO=@XdlQE2`Sn0>7U[Na@faQ
%?aceb4_S>1WU2bLWU=7bLIPN4c]2U5BPF4WkkUl3O>YPNWQ6QP[mOSkYfaOklOAO
%<iYF:gFneOZJBRDFboHCa[e5XffXShXD4Oe:U_AR^/Oj5jdQ0OIT:ekT3bN4boBl
%GSlWUlgWm7YmG[mW]mg_QfUPfYO<3GOgT85oF70:4ob1_TPBVW^cch@<QSB/VVIl
%86=L7960Qc7:MAmWdOYjWXYb2<33RS]/Z2NWnOBH<hOL67jYao7/K9]6X0020:4h
%EQTEA:U21H00>D1CUbN[EZXNQgRb;Hd7DZT=7U2jH=4Z2X=[4AlBLPkG84T<0X/U
%k@SO;HCBjH/_/nXJ>85:SJYO<JO9nQ;j8Nd/bYS<JU:<X2V7^Ba=4f;@_2ni0nS`
%?A_7<M3jZ>PBOa2OD@Z>dd3YH`T5c2`PVDVVX30<3]<71CB7^YA]?DoD5@e5DMBE
%;DbEW]E;_8c<YbeL3MH?d0Z@R3F/0CDPCZB_Dkd<9=SG/hPYgf6`CW]6i1nYo@RT
%:6cEPZ>W]S7hn[I:VY1k7HO1iD8Om27VOig7PY2CWXLi[VZ>8kT:LTO7TPD6@I4D
%A:U9bR9jd<2X8Ukn?50K9UAP0;H4Cf2EBZSA^Jn=LGVdB5EnPl1X=;;<f@WT;WWM
%c0YjDYBU6@a348I9T6FE1CUDOR<d@_CH>MI]LcAGR7HSH1nWCV`?i`T;n1mWSj?3
%=<YISXFQj9X^SJ?Y5?hNPHUJJT:@d`3YcjW<ZG_1InT_8Un7/9</5WTN:eDDZZI`
%m3jP>MReX<4i2WZ;Pil7ZObVX71QoAlX]2a4NQB4/BYIUdI2MWnN2RZM3BX:8V1o
%BM/J1h<d[22gbM88_Pf98fKO=1OcP/LmVJ2<PNZGW=dYGM>IgDWYeMlio=KE8:dV
%5]FSUYA8bS@VPIQTRF98T3F=`i7/O:T=Xf4XbO3L:kC[:2M1fDY<8H7YY20G[?h?
%o/mY<kDMQi__o1l?aO7lSf@CIi6oBoSn92Fgg8C<[=jalZ8CNP[ZL[Hk1O/bJnC8
%XM]IPS;[67nQDO8m2NUoA4heaJQ4@[C7n?DN@I`^QL7<]T]D4D15E:6E12cNEY?n
%C8aAO;mRE_b=PVQ0HHhF0UQL=661Q1C`cH41H3<=e9Q<Lh2l0l?HMSJR0a=QYYE>
%T;JF@8O8mbZ4Y8bULL@g1]06<>>m3;3B>A=D<Mh_ZDVD?R>n`UUYcfDU24?6Do9n
%R@S7SDm/NLKGjA_SQ76>DLgVa57n<J?02hm<j<>7F?bnHS[MNljj>Q3hD?MFhP]>
%S;R2TcH?6=U2bB_::9jb`cdHQn;a7d?@O8lRR>`<XF/G@/QH0:0:0M@@lWA[MEbg
%UAJdGm>>856eKi1AiBg9J_TQhXiN@e2A;l5L`A/c3M0Bm0H[IT0:VE30J:]fPT2M
%4cmAkIF4=SA2AY^Q1A0Qk3f=dK0f3V><<jXE9aXX1VD=<DAlC3d[^PH<4>N2/R@P
%?WX>bNdQIlCiWe?^OQj39S`X02NPBUP34Q1_@LjSX9WCBS1?eEIU7X46Oc08_TTY
%9=j7j?=eRQY9baEc92;<1BmSgA<faAATalSjP0gX_J5ZE:<NC08Z@nRm6HHJ_R<4
%9R9DXT6AV@9X@@e1WP4<PdQ23SQZ@B4G5Bi0V5S0iMnjJ4?W8CZ7`?PN0X1@2L<P
%H`bFlZ9@Z/HYID7R;C7j`e]Sm39af8HZhLX5jh7I06O`85MH_bbXMGV_ENjn?TIn
%6:`3Cb@0=/9DPL9m4[V4S]Fb_T^R2YGLR_IoBhiGASA3INSm9UXCGYm9D[b83J`O
%KJKA4D3iFb^G_0UIR7Ja6JXZ//`PYAC2V/aAjTb7Gm46Efc@FM_HKPICLBPjSEid
%<;63LL35bGESdZP@M:i8JgF40J:njTiam3h7^a`D8eec[9UQ9FB/0W5U5_3IQ0<X
%F/[i/DVR8S<212m_PB8TI8F?R6XOGfo5nKmGk>UDIn;lR3Fc5=H9YhY<3GlSSGPQ
%5U<54=>>Ibg1BjE=iCXLMa@nf3Sf>NGHOh00304W:aZ958Jc5<DA;0OmbkM<;=;@
%L6h_<H<o=2eJQ[=46X>45SU<9lg_4Q1ESl5^@D[/o8fXVYae3=fBaXHG9606GbCb
%HVR@nCjW9RWEU=<fD;eiGFOK]3Jck73o47V<k1fG[02^><77J0Y/`5HGV7112KJi
%c]]W@j;EDdIEcSW_13?WiaQ87<<K<NTL4PET5kA3MBIi`ciPVg93;JdnMFWE]YZX
%[U6]I;2LYJbOP00608_2bF4FW:9FMMkRZ>BbQ<JFjD]egA8=COlbTk3BTo4e[N5P
%HfOd:VZQ0T:VQ`>?EEXdRMS256U@F3gIElP2:`0g?HMUmiZT9bm/BcFelkIfUcSG
%;<9F:KFg1?Uo:IF7j^1U^NPULPAK[UY^6Qe]B6fHFBE9Hc:CE6Z8b;/kP62h0490
%5/;8FQaTj@eILV2UP21m3l7h?HP11Qj3j86Ea]RRZ47d7cR?2a2203n8:Z`O<N7d
%7b7CTP4NC1miAamehnI^1k43bmk8OnGlB84=;V`:NL6C3ec/A7?NMQj41d4Mg@`4
%M53CdLPO7nPlLNcbP?ZTH`M>iSc7YgD55MBjV7oZ/eElmHjWe/bYQB1mNjYbSZgH
%nDLa3cf/o`Q<_E6Nf@?J03>jK<2KgMGC2mSK^W7]S>_ObEiKGbI;?oO?3A_Ye]?9
%o;GZ_F[T<cb2IGAN7SU_3B4/GRY=LBkLE<_=o005R:TD`f1US31<283`H`j1k7J[
%VJho`GLhiP7KQHOc[3n7dDkDblbV22468L?W;_PQnc68>@90`kO90Cl/S`N>fYW8
%fUN<XQnFm>iD@8D7f@ZoKk@7gWo<nFeI2PB5O??nUlOn;Uhd_aN?oXc7nXWok?fQ
%loBk=@glLaocoYnonfKQm_i?f_jYW_o@0;j^HR639TbT[T5QL`6R@YU052@WdQ6^
%hUW7<9e=g=/_0=]2::8_525?9_:@A7`;853X`2G`6QL/22@Q9@FSZ>m`AYn[<1kT
%<6e<84;Z00:9j1L;NRRT61lQe1C1@Q;P:PEPK1c_G:@UTRlQjU25^?L3JQk2T1l4
%B6f<A=_:d5W>L0DRBQW]82Q<QUWV3>W?RZ9R2SkQM_6P12://93<W28@fR<@g`g3
%=R4Y5@C32/I8B8`@@R28o0jR@_UP4Zi1Ta2Z9=5`C[g@H]]/6[R>@/R?XA5a97_W
%@:eR=VYQcP?A=<bP1ZQZN5^@:a9]g_<@K3H2VQRWYP7YU1kYL1nT61mQf0o0kPfP
%[Pg0mQdU39:QiRX;/2N1m1jUT_M5gRYUkWKRH9<US]N22;V^?P^aW4baU<_2GQha
%ZA=0?<dR36^RD>C08PYa_487l2IWnRO^h6J=Jab?2acAcab/_UTaeadafacQmaf:
%7/_?1R=`?Af^@S@]U0N/2:10CUQQg`c88S8AA3a]6>`RGWA7laa]Jb3b86RAi943
%j0WB;8cP2]W1eB=R31fb?@B`1b8YlSH=iVe3WQA1@1?PJPIPI1o=kRe5bPB0?P;Q
%@1IQO_FSJT@TW=A4C5276Qm2Z1o9=4ASj`>9W<_9J4^PC9N1A`Gal=^:7R@_[RkR
%VSZ>F`841R@/e]S_n]Z[7b^_n/E`1b_6PBa44B`B@YIXg@?a3Ql:S<`Q^BhP:BiZ
%22@a_0Y/`b2:m?;43b4WX;00a>W:gA/X`BmBAC3T3a;9e>NQ4@ER@;h1N]5@ZA5@
%HC4?:Ti6;1l1k1jQGQFQF04P3P31a1^Q^U^QkPnPj0fP60402QfRX71SSX2QoR/Q
%E2Q>:9F3=2XTb:>=<C<@m66al[^1[R@_TPk3j5lT[b=Qe0RcV@8:L9I321YcY;WR
%@7A6L0?QMC/W8S;Ah:7/Zaj5WC_c^c`ZWC`5TCa;d23Zka`Uh^`bb7FUW/UQICiX
%n00/cQ8Cl=[Bn43B4b71Ocoa0_UQ5d1]GCSbXC;AAA898cd_SR;V7QVd85:P3<c_
%Vd4@>/Sc:<lc^3:3Z8C8kC5=Y66@;R5TD@JC<c=QfQeQe0S0R0QP0R@DGP00H0G0
%HQ`1_Qa9`X721C=Ql038NU4]A:HS0X^bQ4b=D:dR;^QQg370WXMPdDWV21??RP[d
%Z0:d[17D/:072R;R@Phd_0]D`D;3gPhDb3n5I3n?81V:K@4<^b`W`@=284f;<:Y[
%<2TRFYT1FSn>j06:20NDo7CQG:gA7<Wb]c3Da:mZVcKA5<Ze6E6alR1PbE8cj]cP
%I:ke7E;e<E<e=E=e>E>e?E?/ZS@T[XCEB6:39QdED263@TbQ_eFdA]HA@8S3DX/>
%:XUBC2lXU1aDK1e1dQf5E8`2OQn8<[:000100==VfcI82Y:TDZBCM[b>`e?b732@
%DQ<E[E8Pb>B0j<31BCQ?4b5D=<[3@T86XQeec:KE@EdeeEeefEfegE=T1PHEiCjP
%eEjR363:S<E<K>^Egene>;ES;F0e>S_3C2T`JBPZ?@h]096YZ1oQ=f7bj[1>RP4:
%i09f;:jPP?RQAF=QUF>QaF?e3/mWWRQ<28NP3cjc7FD`EZiFD[Y=VFEFHFHfIFIf
%JFJfKFKfL=38d;1FCA>FJ7fDH7eck<cW[B<Cj/c`e2@f9fJF9S3P0FWFDRAfT2@=
%o00P79CP8P3]o??dHVWfRP1UIP0F`P2]oC@eRZ2]?7ZR@01??eSFLa>@8FDfQF^f
%P6WT8=OFMF`TG[ifefRc7FNfgg0g1G1g2G2g2SnG000FU[15I9iC7EkUDfYg3G9g
%:FIDHg;R@:iP104P20301g<dHC7FifHflFEF9f8VWYj07fD;11DgGF@/hRG/_AU2
%E6^@n38AZ1hd@gH:RXVadDBT==hRQ>5PoA[;VT5a]66cRbUD@242Gd]0JgXW9P]R
%34Z:c[[Z<2SWE]G[:851kSABGDMQlQl84210Y7?529eBM;CdRRZTW76SY;VT`VOa
%f<][4@l45e[1<2@b2GJGN2ET[gLYRTdGkTY39V3B6caVSDh=hZ?8TTCZF<D<6S1Z
%WUDf7Q=P8H</25IDmgE0Mh?cl18BV1THBB?1fccGoYl5o5WgTD3eXedY4946OgKE
%oHJhKHKefVO`nde_k/<5D]40_0MHQEc1ehHZXQnE/Do0NHC2IF6W]S51_:h0;^I/
%iC^BMgO6d;:cK6dT@`Z563:GT<AUiETggUXT25^eT5aee<Ua7hFAa<ohf25a<2h0
%9=P=Q63X`hLHmHmhnHKYWBcHNi0682V[4hnhnF03Wf1E<[=<<H8BLTA@ZT?RTc5H
%hf5QoQJI<3nG5P00QI>QHi?hk@;HNhJC:hDY2aU;e:W2FT5Xk4[d6iC?2H`HgXDY
%<RIi>PQ0XiLaU3ZHRCV0RUJPPgi<Z8`8e1S[OQ?iT>[Em<g5UUU<RZ<2D6k2Y1lb
%PZ<RS1gW5/i`U/9dQ55eWZH;93aeA65iMa8/5Wi3j0RIe>fY0iBiC29UlelChic5
%mBWh9eH7`h6?;`[DS>9Qo1_Q]1^I8DTB]`;QRJ3d91:j5IU[V`/GMig[m41ch@ji
%Qeeba7cWL@mi3J=j>EoC]U5IHR1eD1dBU0ijC7A?h1mVK1dei0H470eba<`i?QHd
%[0:jIR1fAj@4hZ<5UEVIZAi]j2Y1nQhTC1hd]Qg41@W5LTV3A66]C4D;E3OCNbCE
%daX<fZ7_X@<IciJ237DQW>Ud>eC<`J>jbJbjc55IGd5IDU5AUE;JchLf1I4E<h7W
%mQjaQ6lQd1aQb_?QIQG1H2P@/^`ceR=T1c0=LW8EPR=V7f5:KJ?j8:m8k@5Dg2;C
%Wa@Z6IkiC8C1[K=P>K>Q6K?XC<]bhQ^8JQ5KC9fj[UW1>KE[TP<1UkGhSBbceG/e
%X5akK3HRZJQRN1kQeRSD]X54WQKQG1GY<YEZHYa@XEU[Lcmj2H6Z:9e2GZi8D<`Z
%S8Q4`]SB4k7R8/V]IW_4h<^5V55IQ7_im7H[K@KST83Ql0Z0WPXQ[8H0GPFPG:01
%k=5][]7S:Y<c=V;9;4?2290T[]SBbK]L2L2`kHW211OL5C[dXbfR3L51OL66224a
%U>IP=L;eFQ_U6RU4@DPQi]j3AVDDHV;9[SV]j/7[`:><]Dk3J8^lGK`lCIn[L;:1
%oSn777XKZH5L3LMS1kJg/[FWT]BSATVTDQmQIQH1K121112SWQk1Y1Z1XPZP^0eB
%g:<8aT@;bSj]C76;CKk[:lNL`L`RFVOQElb]WJKj]R1lbQElci?gZ]_dMUDPblie
%:DUE_Sf;c8?Zl3nK9@1[?L^LOH]2RTBM2EXKcAG2YLQK03j481j38a5>[HDLaLaL
%DlIbC;CUjVGRWQkQiQh0j0gPh[[T=2ISHQ0Q61?1X1/1fYa4c<CRl/<CMaG2RZHM
%<dT30bMm9mLmMHZ/[17mOL;P=J_C2<XQnMO17mPMQ7HgKX99KbkPSmWdU5BUX/A8
%1;;:i21[3C/QMHkloWoKK8D98Y8dPDPD5S>?GRV7R1lL@21R@QW2BkA]GJ2b_bdm
%Ml`M:lD/jjYTiQkJQ3=89AL<DVgT@Vl1hUUS=2RGh2TMIN5mJGf2O@UMjn8mMS9^
%F/OPEHX<m<f=@Qnn:/On<IEN=21hCH?PMP`NCIUgo3gSHh9KlGc0Y0Y63=WCoQO_
%1W63Tm:a/WmDSW7:;TAl_QkM739R@PAPB0BB1@/Lkn9MLmkkU[L]=l^SA2=QEQCQ
%<PNPKPCQU1Q1NQ3Q3160@PEPP1abL5kS8:B8881MHTCn6WTVaggVmNUNhLMjIPLn
%jD]C_2Q7lninjZ0NkbQL41okF`1B]ig3c822N[/:E;A23e/EjPe:5R<RVVl4>97;
%b=jlDngO:S?He?k/g6;8fQhXNP2QKQLQK24kYn@NhmM4>Dh2nTbJjDQVGQkQgQa0
%9@8Pc0]P[QC1@1DG50>QfRW:J5X4WAP:HcIL]nei`Z@mL6HR0X0oh50h91H=1hA2
%HE2hI3HM3hQ4HU4hY5H]5ha6He6hi0TO7gY8H6oI92Gg9hnSi2m979HA9gg0e;<i
%JoGm=h==gm7HVnWbo7o>j30Z51F5A`oBGEBgaCH@oI>nI9<H7@Z]@go@:cA:i1J4
%o:1H:2oCRLCN0;@o7lngeKKM<8CH7i97k?;]MkaNKeNkiOHIEjaEi/ojXog`mW^o
%k[RWdefHa0EJ5<V4Vhfhh@H51>hWOGI]E7[HH5DlI@GgFZYFX;E:YRkm[mQ/MU/m
%Y]M]]khm]e0jJn7__hI^W]_:K_lC1Mk>X7L=7;]a1:^o/G>iQKQEeeCfNHoiGd;[
%d/E@:5RnWF:eijkd>JnI2e6Td@T4PP1@:0Ig[Y[M:[>Yacolol0@30B_:jX1n`<[
%BQ:RPAm:bNJ/WXDa=4d4ChWnOAj4^Ai6Sh@Y:9Hl:^7TZAl84NamY`kl6/8e3dX8
%eSA`76DIaY6/KA_0Bi8<kJ1adPDOANTj3B0V/R8:O<T?lOTD:6l4VY^@dXP9:Jd0
%00D[bZ0<]BZ0Bd02]4^P00JdC60DaP9;h2;A=@0CI=@0c3<80Bn002[A>di[@DAA
%51:[kahQ2M?e752D;@dI>R[T3aI4:]Z6aLBWo1io7/60@Q<GQEUN`ah2D88N4>B1
%=VTKaf?0Maf7J90WRVAi<4jO3_Z[5KCX4ZRR/DaC5YSG53emGmPF3HEQf8RcZ9n`
%9oVcIH9fJ0Sj9/jCWFB[:eBBTZ]AFm45=5Ab[?jXQnTJAI51l7PM]7:H1?_H]fgM
%MjkDCAjPEZZ4OdDPE8WXNih7@4h=0nOIe7POihWF4@<PX<0d3TN:jWbO5N7j?i34
%HJ9/W3FmIe/ZQlaL^ZGEiN6Ai9T^CI?U27/?ScZ7eF@QIPB>IClQ1m7`O9o;WGC2
%9RTQ>4ZC080B21[6PK1EU@E`70J2Ag7NNJ]7YVl4X591lW2Ki`0`2`:VjKI]=nN/
%lgIU>bk=H[0:jnl4G_NInW^]IjDY1im[[Ud;a:O9kdRhM`WXMigRB9XZ7U1[D^W5
%ImHk5cV[6[6clQb?9LWbRo9fOVG9lOQcW<M9LUdGEXP7:KafVWNmERYbBi_2inTH
%@I40>003T^B9<6XJI/:o]Yl;WWB1VBHiT6TJ1XX=:Zi_ab_UnI030:_9TV:Q8CbK
%/N[37SWQoiaSaoWPNjf7/NI/VVJ90MQB;F;DX?4lGajFlMG_VoWnWjo]U3bgV`dT
%=>OP^1M2jg]B9@BK/fIHSm0aMFM506D<4H`5`80G7^?54Y>bQ=g7dM@dL5VZY9E`
%?6401`408OjoN4d9bl`LFC1T`a8d38[>VB`Oa;5j_K84?LTXoQl2B4D8LI0b1W5D
%7]0LXSkFZ^<OR[:54BhVA=RLKPWK=Vj]D<0?T]YP2h;7@JBB7B9G58G7l:DCPX@<
%PB0^?4MPl689<DM3QAKfam?[LL?N8JbD`?bRO7V9ii3e;D@^_TiAEhY42N^?lhKY
%al3nNk1TOXga/3@0b101HaQSS;:Tje]DAXK:>SjfV?DWi@BQU4@/Z478eZ?9^lUV
%k>42aLIdH/]ZS8hS/72><?HLPkPJ0V1PHh`QS2l5f;j:aHS2B0?jJN5D5SbSe7]8
%VDLci?_bAP^52l[8>=e@^hZ=kQHF4a7/>d`T<U_C:R:_UmaZRZ]ZVQ>^MTkHCAl:
%6F``IF7nU2R]2aA@n8]UeKf5l:PEP9P80D?`N8ma<2?4X0`0X2Qd>MMg<F?lm2e4
%nDX?E1[;J9AhWMA]bIh:?CZ=8[ZE<=g3:fY<H=S`oD7SjL:a5I1>3V:AHS4NCTjH
%oDLYaCVWBkW;]gT4BL`2dIk99Y/T8/DEY<@H<8?JRhofmaaY<XiVlK5Z4k=lbj5E
%>j];]TlS6HYh9hCc9Pg17kUbMSf;0cdV;jjDT/7j?HZ1JRM]kW@?ia:1V=84OOE^
%_UOJo>ANO>ZVm=Z^T:EkAZ_mREQWh/;?2Z]PTHU[==9d[ai;2f:/aIVcEVk>FM/m
%Ind5XKAFS]9JF_Y0@0003@4000<000010GD0004100<000010A<0004200<00003
%003B9P4300<0000100D0004600<000010080004A00@0000:003B;04E00<00001
%00<0004F00@0000100007@4G00@0000:003BE04J00D00001003BO04K00D00001
%003BQ04L00<000010040004X00<00001008000000000200800P000080004CP00
%3lD002LV001?Q@00Le800926002V6`00]/L00<^K0004AP002gL001MQ000XG`00
%8ld001dd000EU@004:`001CD0005j00:o80002L@00[lP0009a001`2^07X01`01
%00400`0300@0000=00`0405e0GD1M@5e02P0O@25455eJF=[E6U]IJXPHFiT8640
%02P0R@1]5eA9ATHP:4aJEbTPI6ESKfe`LVEcLfmb02P0U@1M7f5bIB1^IFETIF@P
%M6lPLfEU87AXJG<PL6USM7EbIBh0003o\\>\"], \"Graphics\",
%  ImageSize->{373, 275},
%  ImageMargins->{{0, 0}, {0, 0}},
%  ImageRegion->{{0, 1}, {0, 1}}]
%%EndMathematicaCell
1 setgray
4 279 moveto
377 279 lineto
377 4 lineto
4 4 lineto
closepath
fill
gsave
4 279 translate
373 -275 scale
1 string
373 275 8 [373 0 0 275 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFEFBFFFEFB
FFFFFFFFFEFFFFFEFFFFFFFFFFFEFDFFFFFDFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFFFEFFFFFEFF
FAFBFBFEFFFFFEFFFFFDFEFEFEFFFFF9F9F9FFFFFFFFFEFFFFFBFBFFFCFC
FFF9FAFFFAFDFFFAFDFFFAFFFBF6FAFFFEFFF7F8FAFCFFFFFBFFFFFCFFFF
F8F9FBFEFFFFFFFEFFFFFEFFFFFEFFF8F7FAFDFEFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFEFDFFFDFFFFFDFFFFFDFEFFFFFB
FBFBF7FEFFFFFCFEFFFCFEFFF6FCFCFBFFFDFBFFFCFEFFF9FFFDF4FFFDF6
FDFBFCFEFEFFF7F8FCFFFFFFFFFEFAFFFFFAFCFFFDFBFFFFFEFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFEFFFBFAFD
FEFFFFFEFFFFFBFCFCFEFFFFF9FAFAFEFFFFFFFEFFFDF8FAFFFDFDFFF7F8
5F545613080AFCF1F7988F940C050AE8E6E9FEFFFFFCFFFFFBFFFFFAFFFF
FEFFFFFBFCFEFAF9FEF6F5FAFFFEFFFBFAFFFEFFFFFBFCFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFDFDFB
FFFFFDFDFEFEFCFFFFF7FAFFFBFFFFFBFFFFFBFFFDFEFFF9FFFDF3FFFAF2
FAF8FBF9FCFFFEFEFFFBFBFBFFFFF8FFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFEFFFEFFF9F8FBFFFEFF
FDFEFEFCFDFDF8F9F9FEFFFFFEFFFFFCFDFDFEFCFDFFFDFFFFFAFAFFFBFC
FFFAFCECE1E37B72771A1318C7C2C6BCBBBEF9FAFCFCFFFFFBFFFFF8FEFE
FEFFFFFBFCFEFFFEFFFFFEFFFEFDFFFFFEFFF5F6F8FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFBFFFFFBFFFFFFFEFDFF
FAF9FEFFFEFFFEFFFBFDFFFAFAFBFDFCFFFFF2FAFAFEFFFBFFF6EDFFFBF4
FFFEFFFCFFFFFEFEFFFEFDFFFFFEFAFFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFAF8FBFDFCFFFFFEFF
FEFFFFFEFFFFF9FAFAFEFFFFFEFFFFFBFBFBFFFEFFFBF9FAFFFDFDFEF8F8
FFFAFBFFFAFEA59CA1191217F1ECF0F9F8FBFEFFFFFCFFFFF7FDFDFCFFFF
F9FAFCFEFFFFFEFDFFF7F6F9FFFEFFFFFEFF000002FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFFFAFFFFF8FEFEFEFFFEFF
FFFEFFFAF8FBFFFFF5FFFFF6FFFEFFF9F8FEF9FFFFFAFEFDDFD8D019100B
C6C7CBF9FDFFFAFDFFFFFEFFFFFEFAFFFFFAFBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFDFCFF
F8F9F9FBFCFC5C5D5DF7F8F8FFFFFFFEFEFEFAF8F9FFFEFFFFFCFCFFFDFD
FFFCFDFFFCFFCAC1C6171017F7F1F8FFFEFFFEFFFFFAFDFFFAFEFFFBFFFF
FDFEFFFEFFFFF9F9F9FFFEFFFFFFFFF1F1F1070808FBFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFEFFFFFEFFFFFEFFFAFEFFF8FFFFFFFDFCFF
FDFAFFFFFDFFFFFEF4FFFEF4FFFBFCFFFDFFF9FFFFF7FDFDFFFEF8928A87
C8C8CEFBFFFFF6F9FFFEFFFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFEFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFAF9FCE7E6E9
B9BABAFDFEFE030404FEFFFFFDFDFDFFFFFFFFFEFFF9F7F8FDF8F8FFFDFD
FFF8F9FFFAFD8C8388070007979198D4D3D8FEFFFFFCFFFFFCFFFFF8FCFD
FCFDFFFFFFFFC9C7C8D2D0D1FFFFFFFFFFFF000000FCFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFEFFFBFEFFFDFBFBFB
FFFDFFFFFDFDFFFAF5FFF8F1FFFBFBFFF9FEF9FFFFF0F7FBFAF6F3D9D3D1
808388F8FFFFFBFFFFFBFCFEFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F6F9FFFEFFFBFAFDFFFEFF
424242919191000000FEFFFFFFFFFFFFFFFFFAF8F9FEFCFDFFFDFDFFFBFB
FFFDFD9C9598100910D6D0D8ABA8AE0E0D12EEEFF3FCFFFFF4F8F9FCFFFF
FEFFFFF9F9F9E1DFE0181615DDDBDAF7F7F5000100FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFDFCFFFDFCFFFFFCFFFFFEFFFDFCFDF7
FEFBF4FEF6F3FFFBFDFFFAFDFFFAF8FFF9F7F8FFFFF6FFFFFFFEFDF4EFEF
494D54F2FAFFFBFFFFFCFDFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF9FCFFFEFFFFFEFF
D9D9D9131313040505FDFEFEFDFDFDFFFFFFFFFEFFFFFEFFFFFCFCFEF9F9
FFFDFDFFFCFFFFFAFFFFFCFFFFFCFFFEFFFFFBFCFFFCFFFFFCFFFFFEFFFF
FEFEFEFFFFFFFFFEFD8D8B8A3E3C3BFFFFFD040402FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFBFFFFFCFFFFFEFFFDFFFFF8
FFFFF4F7F0E8271A1FFBEAF0FFF1EB221914606872F1FDFFF9F8FBFFFEFD
7F868CD1D9E1FBFFFFFEFFFFFFFEFAFFFFFBFBFFFFF9FFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFEFDFFFFFEFF
FEFEFE868686040404000000020202000000010101000000020000010000
020000030000030002030004010004000004000004000004000102000002
000000010000050000050000010000A2A2A0000000FEFFFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFCFFFFFCFFFFFEFFFDFFFFF8
FFFFF3FFFEF6302126BCABAFFFF8F04A413C87909BD2DEECFEFDFFEEECED
484F538F989DF8FDFFFEFFFFFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
F8F8F8F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFF8F8F8F7F7F7
FFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFEFDFFFFFEFF
FBFBFBFAFAFA2A2A2AA9A9A9FBFBFBFFFFFFF4F4F4FFFFFFFFFEFDFFFEFD
FFFDFCFFFEFFFFFDFFFFFDFFFFFEFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFF
FFFFFFFFFEFFFFFDFDF9F4F4D4D2D1121210050501FEFFFDFFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFDFCFFFDFCFFFFFEFFFFFBFBF9FFFFFA
FFFCF3FFFCF4A69A9A221212FFFAF4978F8D7C8594F4FFFFFDFCFFFFFEFF
F2F9FDF8FFFFF6FBFEFEFFFDFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FF4F4F4FFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFBFBFB8F8F8FF4F4F4FFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFA5A5A5FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF9FCFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFC2C2C21F1F1FEAEAEAF8F8F8FFFFFFFFFFFFFFFFFDFBFBF9
FDFDFBFFFFFFFFFEFFFFFEFFFFFEFFFEFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFEFFFFFCFCFFFCFCFFFEFD71716F000000FCFEFBFAFAFAFAFAFA
FBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFFFF8F6F7
FFFDFFFFFDFAD7CCC40A0000A69893E3DCE10C1427E2EFFFFFFEFFFFFDFE
FBFFFFF5FCFFFCFFFFFDFDFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB1B1B1393939F0F0F0FFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFB1B1B1393939F0F0F0FFFFFFFDFDFDFEFEFE
F8F8F8FFFFFFFFFFFF181818838383FBFBFBFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFEFFF8F7FAFBFAFD
FFFFFFFFFFFFFFFFFF6464646A6A6AFFFFFFFBFBFBFDFDFDF7F7F5FFFFFD
FFFFFDF8F8F6FFFDFEFEFDFFFDFEFFFDFEFFFBFFFFFBFFFFFDFEFEFEFEFE
FFFDFEFFFEFFFFFBFBFFFBFBFFFEFDF3F3F1070705B7B9B6FFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFBFFFFFAF9F7F8FFFDFF
FFFCFFFFFCFCF7EFE2120A00665B57A6A0A800081DEDF7FFFAF9FFFFFDFE
FBFFFFF5FDFFFCFFFFFFFFFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD7B7B7B2A2A2ADEDEDE
FEFEFEFEFEFEFFFFFFF7F7F7FDFDFD7B7B7B2A2A2ADEDEDEFEFEFEFEFEFE
FFFFFFF7F7F7FFFFFFEDEDED3B3B3B606060F4F4F4FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFF525252F6F6F61B1B1BBFBFBFFEFEFEFFFFFFFCFEFBFDFFFC
FEFFFDFEFFFDFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FDFBFCFFFAFCFFFDFFFFFDFFF6F4F5FDFDFD000000232424EFEFEFFEFEFE
FFFFFFFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFFFBFFFFFAFFFEFFFFFCFF
FFFAFFFFFCFCABA7993D3727CAC2BD87868C212B40E3EDFFFFFEFFFAF5F5
F7FBFCF9FFFFFEFFFDFFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC8F8F8F1A1A1A
CECECEFFFFFFFFFFFFFEFEFEFEFEFEFCFCFC8F8F8F1A1A1ACECECEFFFFFF
FFFFFFFEFEFEFFFFFFF5F5F5F2F2F2535353474747EEEEEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFFFEFFFFFEFF
FDFDFDFEFEFE030303FFFFFFE1E1E1BABABAFFFFFFF6F6F6FEFFFDFCFEFB
FEFFFDFEFFFDFDFDFDFDFDFDFCFDFDFCFDFDFAFEFDFAFEFDFCFDFDFDFDFD
FFFEFFFFFDFFFCF7F9FDF8FAFFFEFFFFFFFF000000CECFCFDCDCDCF2F2F2
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFDFFFDFDFFFDFFFBF6FA
FFFDFFFFFDFDF5F2E9FFFFF4FFFDF6FEFFFFF5FFFFF1F9FFFFFDFFFFFDFD
FCFFFFFBFFFFFEFFFDFEFDF8FFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB
1B1B1BB1B1B1FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB1B1B1BB1B1B1
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6656565323232EEEEEEFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFBFAFDFFFEFF
FFFFFFFFFFFF010101FAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFEFFFDFCFEFB
FEFFFDFEFFFDFFFFFDFFFFFDFEFFFDFCFFFDFCFFFDFCFFFDFEFFFFFFFFFF
FFFEFFFDF8FAFFFCFFFFFDFFFBF9FAF9F9F9040404F4F5F5FCFCFCFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFBFFFFFCFFFFFCFC
FFFEFBF7F3F0746F71FAF8F7FFFFF8F8FCFB818C9ED0D8EDFEFBFFFFFCFC
FEFFFFFAFEFDF9FBF6FFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFDFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
BEBEBE1F1F1F9E9E9EFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFBEBEBE1F1F1F
9E9E9EFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF8181811A1A1ADFDFDF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFBFFFEFDFBFFFFF3FAFF
FEFFFFFEFCFD010000FFFEFDFEFFFFFDFEFEFFFEFDFFFDFCFEFFFDFEFFFD
FEFFFFFBFCFCFEFEFEFEFEFCFDFFFCFBFFFCFDFFFCFDFFFCFDFEFEFEFEFE
FFFEFFFFFAFCFFFDFFFFFDFFFFFDFEFFFFFF010101FEFFFFFFFFFFFEFEFE
FBFBFBFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFCFFFFFDFFFFFEFB
FFFBF7FFFEFBB3B0B6848285FEFDF6D2D4D1555C6AF8FDFFFFFDFFFFFDFD
FDFEFEFBFFFEFEFFFDFFFEF9FFFDFAFFFEFBFEFFFFFCFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFEFEFEFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFD6D6D61C1C1C8C8C8CFAFAFAFFFFFFFFFFFFFEFEFEFCFCFCDCDCDC
1616168A8A8AFBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFDFDFD9C9C9C181818
CBCBCBFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFEFFFDFEFFFDFEFFFDFCFBF6FFFDF1FFFEF7EBFDFFF0FFFF
F9FBFFFFFCFFB7AEAFFCF8F5FCFFFFFCFFFFFFFEFBFFFEFAFFFFFBFEFFFF
FEFFFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFFFEFFFDFBFCFFFFFFFCFCFC030303FDFDFDFDFDFDFEFEFE
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFEFEFEFCFCFC
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFDFDFDFEFEFEFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFDFD
FFFDFDFFFDFDF9F4F8544F51D6D1D12F2D2EF0F0F6F8F8FEFFFEFFFFFEFF
FFFFFFFEFFFFFFFFFFFEFEFCF8F6F5FFFEFDFDFCFFFEFFFFFDFCFFFFFFFF
F9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFCDCDCD000000060606020202787878FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFCFCFCFFFFFF
FAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFDFDFD
FFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFDF7F7F5
FFFEFDF8F6F5EDEBEA464443010000010000302E31E0DFE2F8FEFEF9FFFF
FEFFFFF6F5F8060707FAFEFDFBFFFFFCFFFFFFFDFFFFFCFDFFFEF8FFFFFA
FCFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFEEEEEE4F4F4F2F2F2F6868689E9E9E8383835757571515158E8E8E
F0F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
7171715A5A5AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
707070010101050505010101CCCCCCFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFEFFFFFEFFFCFAFBFFFEFFFFFEFFFEFCFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFADADAD0101010C0C0C0606063C3C3C
AEAEAEE5E5E5FEFEFEFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFD9D9D90B0B0B
0000000505055E5E5EFFFFFFF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFDF9F4F4
FCF7F7FFFDFDFFF9F9FFFCFCFFFDFDFFFDFFFFFDFFFEFEFFFEFFFBFFFFFA
FFFFFDFAFBFB000302F7FDFDFBFFFFFEFEFFFFFCFFFFFCFFFFFDFAFFFFF8
FCFFFFFCFFFFFBFCFEFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFB0D0D0D
F2F2F2FFFFFFF9F9F9FAFAFAFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFFBFBFB
FBFBFB9A9A9A636363FDFDFDFFFFFFF7F7F7FFFFFFFFFFFFFEFEFE040404
000000E0E0E0FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBF8F8F83D3D3D0000000404041B1B1BECECEC
FFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFEFEFE
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF4A4A4A0000000000001D1D1DE7E7E7FAFAFAFFFFFF
FCFCFCFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF9F9F9FFFFFF
FEFEFEFAFAFAFFFFFFF8F8F8F2F1F4FFFEFFFFFFFFF8F8F8FFFFFDFCFCFA
FBFBF9FFFFFFFFFEFFFEFDFFFFFDFEFFFEFFFFFDFDFFFEFBFFFDF6FFFFF8
F5FEF7F7FFFFFFF8FFFEF5FFFFFDFFFFFDFFFFFAF4A49695B3BAC8EFFFFF
F0FFFDF7FFF7FFFFFBFFFCFFFFFCFFFEFBFFFFFEFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFCFCFCDBDBDB2F2F2F585858F7F7F7
FFFFFFFFFFFFF5F5F5FCFCFCE6E6E6AEAEAECECECEF4F4F4FEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFCFCFCFFFEFDFFFCFCFFFDFDFFFFFFFAFAFAD0CCC94B4948
6B6E72F6F9FDFEFCFBFFFDFCF8FBFFFCFFFFFFFFFFFDFBFAFFFFFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFBFBFBFFFFFFFEFEFE
C0C0C00000000202020101017F7F7FFFFFFFFCFCFCFCFCFCFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFF9F9F9FFFFFFBBBBBB000000050505010101848484FFFFFF
FBFBFBFFFFFFF7F7F7FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFDFDFD
F8F8F8FFFFFF6B6B6B040404E6E5EAFBFAFDF5F4F7FFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFCFAFBFFFEFFFFFAFCFFFDFDFFFBF8FFFDF7FFFEF6D9DAD4
000405272B32AA95A10B0007A0A7B9F5FFFFFFFCF6FFF4EF595B68EAF6FF
F7FFFFF2FDF5FCFFFAFFFFFBFFFBFFFFFCFFFAF8FBFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFAFAFA6F6F6F262626C5C5C5FFFFFFFEFEFEFCFCFC
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFDFFFEFDFFFBF9FCF7F7969A9B5A5E5F
FFFDFD7D787ADEE6E8F9FFFFFFFDFFFFFBFBFEFFFFFAFEFFFFFFFFFDFBFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFEFEFEFEFEFE4C4C4C
0000000606061D1D1DE0E0E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D3D3D020202000000262626
EEEEEEFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFDFDFD
FAFAFAFFFFFFFFFFFFACACAC040308121114DDDCDFFEFEFEFFFFFDFBFBF9
FFFFFDFEFEFCFCFAFBFFFEFFFEF9F9FFFEFBFFFDFAFFFEF6FFFDF5DBD7D4
0B0E1DFAF8FFFFEFEA1B0B09C5D5EAEDFFFFF7F7F5FFFEF6FEFDFFF3F6FD
FFFEFFFFFEFFFFFFFBFCFEF9FFFFFFFBFBFBFFFFFFFCFCFCFCFCFCFEFEFE
FFFFFF575757A3A3A3FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
FCFCFCB1B1B1111111989898F9F9F9FFFFFFFEFEFEFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBF9FFFFFBFFFBFAA49E9C131B1DC4CACA
FFFCFD625C5CC6CFD2F0FBFDFFFDFDFFF9F7FCFFFFFBFFFFFAFAFAFFFEFD
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF090909020202
000000767676FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDADADA0C0C0C0B0B0B000000
585858FFFFFFFEFEFEFCFCFCFBFBFBFDFDFDFCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFEFEFE33323700000218171AD0D0D0FBFBF9FEFEFC
FEFEFCFFFFFDFFFEFFFCFAFBFFFDFFFFFDFDFFFDFAF9F4EEFFFEF6F2EDED
1E1B2ED6CFDFFFF9ED9B93888599AFE5FDFFFEFFFFFFFDF7FCFEFBFDFEFF
FFFCFFFFFBFFFDF8F8FDFCF8FCFFFDFBFFFFF7F8F8FFFFFFFFFFFF979797
0101010D0D0DFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDF9F9F9
777777202020C9C9C9F4F4F4FFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFEFDFFFAF8FFFCFCF8FCFDFCFFFF
FFFDFDFFFDFFEFF7F9F9FFFFFFFDFFFCF6F6FEFFFFFCFFFFFCFCFCFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFBFBFBFFFFFFFDFDFDFFFFFFFCFCFCF3F3F3232323000000000000
3F3F3FFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA1A1A1000000050505
030303A2A2A2FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFEFEFE
FCFCFCFEFEFEFEFEFEFFFFFFDDDCE10D0C0F000002050505ACACAAFFFFFD
FBFBF9FFFFFDFAFAFAFFFFFFFFFEFFFBF9F8FFFEFBFFFEFAFFFEF6FFFCFF
C8BED6110517FFF8E68D8E7C283D50EDFFFFFEFEFFF5EFECFAFFF8FCFFFD
FFFBFFFFF3FFFFFAFFFFF9F7FBFFFDF5FFFAFCFFFFB7B7B71717170C0C0C
090909F3F3F3FFFFFFFDFDFDFDFDFDFFFFFFFAFAFAFFFFFFE1E1E13D3D3D
434343EFEFEFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFDFFFDFBFCFFFFFDFDFDFB
FEFDFFFEFDFFFEFFFFFEFFFFFDFCFFFDFCFFFFFFFFFFFFFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F4F4F4FFFFFFFFFFFFFEFEFE464646010101030303161616
E4E4E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF646464000000
030303070707D3D3D3FFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7FFFEFF4A494C0A0A0A0000000B0B0950504E
EEEEECFFFFFFFDFCFFFFFEFFFFFEFFF9F7F8FCF7F7FEFAF7FFFFF8FFFCFF
FFF3FFC6B9CA65624F656C58324554E0F1FFFBFBFFFFFEFBFBFFF8F9FFF9
FFFCFFFFFAFFFFF6FBFFFDFBF4FDF89DA7A2222625040404000000222222
FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFBABABA141414838383
FFFFFFF9F9F9F8F8F8FAFAFAFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFDFDFDF8F8F9F9F9FFFFFFFDF9F6FEFCFB
FCFFFFFCFFFFFEFCFBFBF9F8FAFDFFFCFFFFFFFFFFFFFDFCFEFEFEFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFF
FBFBFBFFFFFFFFFFFFF1F1F1FFFFFF919191030303000000000000B6B6B6
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3292929
000000000000343434F6F6F6FFFFFFFAFAFAFEFEFEFFFFFFFCFCFCFCFCFC
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FBFBFB
FFFFFFF7F7F7F9F9F9FFFFFFFEFCFFD5D3D60A0A0A000000000000080806
1516169E9F9FFEFFFFFDFEFFFCFBFEFFFFFFFFFEFDFFFFFBFBFAF5FFFCFF
FFF9FFFFF5FFFBFBEEFBFFF4F3FFFFF5FFFFFCFCFFFFFFFDFAFFF9FBFFFA
FDFAFFFEF4FDB8ABB0534D4D0E1410020B06000000000000000000FCFCFC
FBFBFBFCFCFC515151FFFFFFFDFDFDFFFFFF7979791A1A1AC5C5C5FFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFDF8F8FFFDFDFFFFFFFFFFFFFEF8F6FFFDFD
F9FEFFF6FBFEFFFDFDFFFBFBFBFFFFFBFFFFFBF9FAFEF9F9FFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFDFFFFFFCBCBCB000000030303000000797979FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAD7D7D7
0E0E0E0000000808086B6B6BFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFF7F7F7FFFEFFFEFCFF494949000000050503000000
0000000304040B0C0E808183FFFEFFFDFCFFFCFCFCF9F7F6FFFFFBD6D1D3
968E9BFFFBFFFFFFF8ECF2E8717880F5FDFFFCFFFFFAFBFD555A54242923
0F0E1109030A160F12030000000100000100050606222222EAEAEAF9F9F9
FEFEFEFFFFFF030303FFFFFFE8E8E8404040414141E9E9E9FFFFFFF8F8F8
FEFEFEFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDFDFDF8F8FBFBFBFFFFFFFFFDFDFFFBFB
FBFFFFFBFFFFFFFEFFFFFDFFFBFFFFFBFFFFFCFCFCFFFEFDFFFFFFFDFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8EDEDED2525250000000404043F3F3FF0F0F0FCFCFC
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8B8B8B040404000000010101A9A9A9FFFFFFFAFAFAFEFEFEFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF919191020202303030AEAEAE
FCFCFCFFFFFFFFFFFFFEFEFEFBF9FCFFFEFFA4A2A30D0B0C010100040402
232424232424141517000004414246FEFFFFFDFEFEFFFFFDFDFDF9FFFFFD
555258D8D5DBFAF5F7888687AEADB2F8FBFFF9FFFFF9FFFF777976383836
161518000002080909010202030000030000141213EBEBEBFFFFFFFFFFFF
FFFFFFF8F8F8060606B7B7B7171717808080FFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFBFBFBFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFBFBFFFDFDFFFFFBFAFAF8FFFEFFFDFBFE
F2F6F3FBFFFEFDFCFFFCFBFFFAFEFDFCFFFDFFFFFFFFFEFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF2F2F2FFFFFF
F7F7F7FFFFFFFFFFFF5555550202020000000D0D0DDDDDDDFFFFFFFEFEFE
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FDFDFD525252040404000000171717E4E4E4FDFDFDFFFFFFFCFCFCFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFBFFFFFDFFFFFFFEFFFFFEFFFFFDFBFEA19FA2DBDBD9F1F1EF
FBFCFCFEFFFFFDFDFDFEFCFDFFFEFFFFFEFFFBF9FA06040500000050504E
242525EFF0F0F9FAFCFEFFFFF4F5F9F6F7F9FEFFFFFDFEFEFFFFFDFCFCFA
E6E7E948474AD1CBD2595458FFFEFFFEFFFFF4FCFEF9FFFFFEFFFFF9F9F9
F9F9F9C3C4C6161A190607070300000F0909C8C6C7FCFCFCFFFFFFFCFCFC
FFFFFFFEFEFE0000001B1B1BC0C0C0FDFDFDFBFBFBFFFFFFFBFBFBFDFDFD
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFBF9F8FEFEFAFFFFFDF8F6F9FFFEFF
FEFFFDFEFFFDFFFEFFFFFEFFFCFEFBFEFFFDFFFEFFFDFCFFFCFCFCFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
FFFFFFFFFFFF909090020202000000030303ACACACFEFEFEFFFFFFFCFCFC
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFEDEDED1C1C1C0202020000003E3E3EFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFB
FFFAF0FFFEF4FFFFFBF7F8F8FCFFFFFBFEFFFEF8FFFFFBFF94938FD6D8D3
FBFFFFFCFFFFFAF8FBFFFDFFFFFEFFFFFFFFFCFCFC4545450B0B0BAFAFAF
6A6A6A4C4C4CFBFBFBFFFFFFFCFBFEFFFFFFFCFCFCFFFFFFFBFBFBFFFFFF
FCFCFCABABAB020003E9E7E8FFFFFFFAFAFAFEFFFFFBFCFCFFFFFFF8F8F8
9898981515158788880A0A0A100E0F6A6869FEFEFEFDFDFDFFFFFFFFFFFF
EBEBEB4343432C2C2CE3E3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFEFEFE
FDFDFDD2D2D20909090000000000006A6A6AFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF9F9F9
FCFCFCFFFFFFBCBCBC010101020202030303828282FDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFDF8
FFFCF1FFF3E5FCF9F2FCFFFFF4FDFFF9FDFFFFFBFFFFF7FFFCF8F571736E
E6F2F0F8FFFFFFFEFFFDF6FBFCFAFBFCFCFCFFFFFF838383000000D8D8D8
FAFAFA3D3D3D858585FCFCFCFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFDFDFD
FFFFFFFFFFFFD4D4D4FCFCFCFEFEFEFBFBFBFCFCFCFFFFFFEDEDED505050
393939D7D7D7BCBCBC060606212121FFFFFFFDFDFDFFFFFFFEFEFEBDBDBD
121212818181FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFF
F1F1F12A2A2A000000030303313131FEFEFEFBFBFBFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF7E7E7E000000000000050505C7C7C7FFFFFFFDFDFD
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF9FFFFFCFCF8
A28E8511000079746A8F9893000911CCD5E0FFF7FDECD9DBFFFBFC828685
ABBFBDE9FBFAFFFBFFFFFAFFFFFDFFFFFFFFFFFFFFA6A6A6020202FFFFFF
FDFDFDE7E7E7191919BABABAFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDC2C2C2202020727272
F0F0F0FCFCFCB0B0B0000000A3A3A3FEFEFEFEFEFEFFFFFF8484841D1D1D
BDBDBDF9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFB
5F5F5F000000000000121212D7D7D7FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF8F8F8FFFFFF
FFFFFFFBFBFBF6F6F6FFFFFF474747000000000000272727EAEAEAFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF5FDFBFDFDF9
54413AD2BEB5EDE9DD000400495760C9D2DFFFFBFFD0C0C131282B090D0E
D9ECE8F4FFFFFFFDFFFFFBFFFEF9FBFFFFFFFCFCFCF2F2F2888888F9F9F9
FFFFFFFCFCFCC2C2C2121212DBDBDBFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFF8F8F8FFFFFFFBFBFBFFFFFFFBFBFB8A8A8A1B1B1BB0B0B0FCFCFC
FFFFFFFFFFFF797979040404FFFFFFFAFAFAECECEC454545373737E4E4E4
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F99A9A9A
0A0A0A000000000000A2A2A2FFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFBFBFB
FFFFFFF9F9F9FEFEFEFFFFFFDBDBDB101010050505000000545454FFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFB
857C779B928BFDFAEFC1C3BD0B0F18F4F6FFFAF7FDFBF4F7FFFEFFFCFDFF
F9FFFBF9FFFBFBF8FEFFFCFFFFFEFFFFFFFFFFFFFFF8F8F8FDFDFDFFFFFF
FCFCFCFDFDFDFFFFFF9F9F9F272727F4F4F4FCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFDFDFDFAFAFAE8E8E8474747363636DFDFDFFFFFFFFFFFFF
F6F6F6FFFFFFCBCBCBD5D5D5FFFFFFC8C8C81F1F1F787878FFFFFFFFFFFF
FFFFFFFBFBFB525252FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCD7D7D70C0C0C
0000000000006C6C6CFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FBFBFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFB0B0B00000000404040000009C9C9C
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFDFCF8F5
CCC5BD140F05FFFFF6FDFDF91D1D25DFDEEBFFFEFFFFFEFFFFFFFFF9FAFA
FBFFFCFAFEFBFFFEFFFEFBFFFFFEFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFF5F5F5FFFFFF5E5E5E585858FFFFFFF6F6F6FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFB2B2B21313137F7F7FFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFF909090151515B1B1B1FBFBFBFBFBFBFAFAFA
FAFAFAFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFCFCFC292929000000
080808272727F5F5F5FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFF9F9F9FFFFFF646464000000060606070707
D4D4D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFD
FFFEEF645D4B898581FCFDFF4448539FA1ADFFFDFFFEF9FBFFFFFAFCFEF9
F9FFFFFBFFFFFAF8F9FFFDFDFFFDFEFFFFFFFFFFFFFAFAFAF8F8F8FFFFFF
FCFCFCFBFBFBFFFFFFFFFFFFFFFFFF2E2E2E8B8B8BFFFFFFFBFBFBFDFDFD
FDFDFDFBFBFB676767252525C2C2C2FBFBFBFFFFFFF7F7F7FFFFFFFCFCFC
FFFFFFFEFEFEF2F2F25050502F2F2FE0E0E0FFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFF010101FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF575757010101040404
0A0A0AD8D8D8FDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEF8F8F8
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFCFCFC2F2F2F000000030303
292929F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF5F5
FFFBECFFFFED8783806D6D732E323B868892FBF7FFFFFCFFFFFFFAF9FBF5
F8FFFFFBFFFFFDFBFCFFFBFBFFFDFEFFFFFFFBFBFBFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFE6E6E6161616B8B8B8FFFFFFFFFFFF
DEDEDE303030545454E9E9E9FCFCFCFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FCFCFCCECECE1D1D1D6F6F6FFCFCFCFCFCFCFFFFFFF9F9F9FFFFFFFFFFFF
FDFDFDF9F9F9070707FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F070707000000000000
9D9D9DFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBD4D4D4070707030303
000000686868F7F7F7FFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFD
FFFEF6FFFCF2FFFEFBFDFCFFFCFFFFFCFFFFFFFCFFFFFCFFFFFEFDFEFFFA
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCC0C0C0191919DEDEDEA3A3A3
171717969696FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFEFEFE
959595141414AEAEAEFAFAFAFFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEA6A6A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFBFBFBFFFFFFFEFEFEFFFFFFD4D4D40A0A0A0202020101015C5C5C
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFFFFFF959595000000
010101060606B4B4B4F9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF6F6
9A928DD5CEC6FFFCF9FFFFFFC6C9CD93969DFFFCFFFFFCFFFFFEFDFEFFFB
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDB6B6B64F4F4F2B2B2B
C9C9C9FFFFFFFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFFFFFFEEEEEE5B5B5B
2C2C2CDADADAFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFF6F6F63232320000000000002D2D2DF9F9F9
F6F6F6FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFD565656
000000000000101010E9E9E9FFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFF
F3EAE1453D32F6F3ECF4F5F5282B3AECEDFDFFFDFFFFFDFBFFFDFDFEFFFF
F9FFFFF9FFFFFFFEFFFFFDFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFB0B0B0F2F2F2
FFFFFFFDFDFDFFFFFFFFFFFFF6F6F6FAFAFAFFFFFFCCCCCC2424246A6A6A
F0F0F0FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFDFDFD696969000000080808080808D1D1D1FFFFFF
FFFFFFF2F2F2FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFDFDFDF3F3F3
1D1D1D0909090000003C3C3CF9F9F9FBFBFBFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCF9FFFFFDFF
FFFAF2AAA69AA6A39A8D8D8DACAABDFDFBFFFFFEFFFFFFFAFFFEFDFEFFFF
FCFFFFFCFFFFFFFEFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF9B9B9B131313A7A7A7FFFFFF
FFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFEFEFEADADAD050505000000000000989898FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFBFBFBFFFFFFFCFCFC
C8C8C80000000505050202027F7F7FFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFFFDF6F9
F7F9F4FCFFF829291F474141FFF9FFFFF9FFFCFFFFF9FFFFFCFFFFFFFEFF
FFFDFDFFFDFDFEFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFAFAFA
FEFEFEFFFFFFFAFAFAFEFEFEF4F4F45A5A5A252525D8D8D8FBFBFBFCFCFC
FFFFFFFDFDFDFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFDCDCDC0505050000000101015A5A5AFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFF3F3F3FFFFFF
FFFFFF818181000000000000050505CACACAFFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF9FFFFFCFF
FEFFFBFAFFF6DFDED9F4EDF0FFF3FFFFFAFFFBFFFFF8FFFFFCFFFFFFFFFF
FFFCFDFFFCFDFEFFFFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFAFAFAFFFFFFD2D2D22B2B2B5F5F5FFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEF4F4F4333333060606000000242424ECECECFFFFFFFFFFFFF8F8F8
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFEFEFE
FFFFFFFCFCFC4141410B0B0B0000001C1C1CE7E7E7FEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEF8FFFFFAFF
FFFFF6FFFDF2FFFEFDFFFDFFFFFCFFFBF9FFFFFDFFFEFFFFFFFFFDFFFFFB
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFCFCFCA4A4A41313139D9D9DFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFDFDFDF8F8F8FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFE6D6D6D000000000000070707CBCBCBFFFFFFF5F5F5FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFBFFFFFBFFFEFFFFFEFF
FFFFFFFFFFFDFEFFFDFEFFFFFEFEFFFEFEFFFEFFFDFEFFFBFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFB7B7B7000000010101000000959595FFFFFFFAFAFA
FFFFFFF6F6F6FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFEFFFFFFFF
FFFFFBFFFFFBFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFDADADA
3030304C4C4CFBFBFBFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEA6A6A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFDFDFDE0E0E0
101010000000000000595959FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFF4F4F4FFFFFFFFFFFBFDFBFA
FFFCFFFCF6FEFFFEFFFFFEFFF7F7F3F3F3F3FEFEFFF9FBFFFCFFFFF8FCFB
FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFAFAFAFFFFFF
FDFDFDBCBCBC010101050505000000919191FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFDFDFDFEFEFEFDFDFDFFFFFFFBFBFBFDFDFD
FFFFFFF9F9F9FFFFFFF5F5F5FFFFFF7C7C7C171717C2C2C2FDFDFDFFFFFF
FCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFDFDFDFFFFFF
FFFFFFBDBDBD000000070707000000828282FCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFBF9FCFFFEFAFFFFF6FFFBF5B3ACAF
11081BFDF4FFFDF8FABDBCB7676862C5C8CC757690F9FDFFF7FEFFF6FFF8
FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFDFDFDFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFD4D4D4101010060606000000646464F6F6F6FFFFFF
FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFBFBFBFBFBFBFEFEFEFFFFFFFFFFFF
FFFFFF7E7E7E1C1C1CB7B7B7FDFDFDFBFBFBFAFAFAFFFFFFFBFBFBFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFEFEFEFFFFFFFEFEFEF9F9F98F8F8F
000000000000060606BABABAFEFEFEF9F9F9FFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFEFEFE
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFAFAFA
707070383838F2F2F2F5F5F5FFFFFFF5F5F5FEFEFEFFFFFFFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFF7F7F7FFFFFFFFFFFFDFDFDF1E1E1E838383181818FCFCFC
FBFBFBFEFFFFF5F8FCAEB2B31717158B8A86FFFFFBF5F5F1F6FAF7FEFFFB
FFFCF7F7F1EEFBFFFFFBFFFFFFFCFDC7BEBF16161ED3D7DEFDFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA414141
000000030303202020ECECECFCFCFCFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFD4D4D40F0F0F0101010B0B0B525252FCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFCFFFFFEFFFFFFFEFBFFFDFA
FFFEFDFEFFFFFCFFFFFCFFFFFFFFFBFFFEFBFFFFFDFEFFFFFBFFFFFCFFFF
FFFEFDFFFDFAFBF7F4FFFFFBFEFCFDFAFBFBFDFEFFFAFDFFFCFFFFFCFFFF
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFDFFFEFFFEFFFFFFFFFFFAFAFA
FDFDFDFFFFFFFDFDFDFFFFFFF2F2F2FFFFFFFFFFFFFAFAFAFAFAFAFFFFFF
FFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF707070777777FFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFEFEFE
FFFFFFEAEAEA4A4A4A2E2E2ED3D3D3FBFBFBFFFFFFFFFFFFFEFEFEF6F6F6
FFFFFFF6F6F6FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FBFBFB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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF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FEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFDFFFEFFF8F9FD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FBFFF7FEFFFBFFFDFFFFFAFFFFFEFDFEFDF6F8F5EC9E9D999D9DA5ABADB9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FBFFF8FEFFFBFFFCFFFFFCFFFFFDF6FFFDF4FDF9F5E4E2E315131EC8C7D4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F9FDFCF8F9F9FFFDFFFFFDFAFFFFF1FFFFF3F9F9FFFFFCFF756D78ADA5AE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FEFEFFFFFEFFFFFDFDFFFBF3FFFFECDCDCD0000011211F358B7B855E5254
FCFFFFF8FFFFFFFEF8FBF3F05D5B68FAFCFFFEFEFFFEFEFEFFFFFF0A0A0A
F3F3F3FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFB6B6B66E6E6EF1F1F1
FFFFFDFAFAF8FEFEFEFFFFFFF9F9F9FFFFFFFFFFFFF5F5F5F9F9F9FFFFFF
FFFFFDFEFEFCFBFBF9FEFEFCFFFFFBFFFAFA271A21E3D7D9FFFFF4919B8E
526665EFFFFFFEFFFAE2DAD7190D19D5CCDCF6F9FFF9FFFFF9FDFEFEFFFF
FFFEFDFBF9F8FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FEFEFEFBFBFBFEFEFEFFFFFFF8F8F8CACACA7979796F6F6FB3B3B3FFFFFF
FFFFFFF7F7F7FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFDFDFD8B8B8B000000060606000000BBBBBBFFFFFFFFFFFFFEFEFE
FFFFFFFDFDFDFBFBFBFEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFEAEAEA
252525070707060606282828F3F3F3FEFEFEFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8FFFFFF787878747474
FFFFFFB7B7B75252520C0C0C6B6B6BD6D6D6FFFFFFFFFFFFF9F9F9FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
777777676767FFFFFFFFFDF9FFFDEEF0EBE3161B2FE1DFF4FFF9EE827165
7D8D9CEAFFFFF9FFFFF4F4F0FFFFFBFFFFFDFCFCFCFDFCFFFAFBFDFEFFFF
FEFEFEFFFFFFB6B6B61B1B1BBBBBBB101010A6A6A6353535171717808080
E3E3E3FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDF6F6F6
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FEFCFFFEFBFFFFFDFBFFFCF1FDF8E2B3B3A9070D25F5F4FF3520231F0D07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FEFAFFFFFCFFFFFDFBFFFEF4FFFFECCCCDC5090E2BFEFBFFFEE9E40E0000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FFFCFFFFFCFFFEF9FBFFFEFAFFFFF3F0F0EC1A1B35CEC8E0FFFAEF9A8A7A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FFFAFCFFFCFFFFFEFFF9F9F9FEFFFAFDFEFEB2AEC41C1324FFF6EAB8AF9E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FFFBFBFFFCFDFDFCFFFCFFFFFAFFFEFEFFFFFEF6FFC6B8C35E544A6E695F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FFFCFBFFFCFCFFFEFFFBFFFFF6FCFCFAFBFDFFFAFFFDEEF3FFFDFAFAFAF6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FFFCFDFFFBFBFBFCFEFBFFFFFBFFFFFAFBFBFFFBFDFFFAFDFFFCFFFBFEFF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FFFDFDFFFEFDFDFDFDFCFDFFFCFFFFFFFFFFFFFCFAFFF7F6FFFDFFFCFFFF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FBFDF8FEFFFDFFFFFFFBF9FCFCFBFFFFFFFFFFFFF8FFFEFAFFFCFFFEFCFF
FBFFFFF7FCF6FFFCFDFFFBFCFCFFFFF9FFFFFDFEFEFDFDFD060606F8F8F8
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBF8F8F8F7F7F7151515DDDDDDFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FDFDFBFFFFFDFFFFFDFFFFFDFFFFFBFCF8F55D5151D9CDCDFFFDFD7C8484
A3B6BAF2FFFFFEFDFFDAD0D9877D7C6F69679DA0A4E8F0F0FCFFF8FDFFF7
FFFEFFFFFDFFFBFAFDFFFFFFFDFDFDFDFDFDFBFBFBFFFFFFF5F5F5060606
434343FFFFFFFEFEFEFAFAFAFFFFFFFBFBFBFBFBFBFFFFFFFCFCFCE4E4E4
8C8C8C3B3B3B0C0C0C515151999999F9F9F9FFFFFFFFFFFFF9F9F9F8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFDFDFDFFFFFFDCDCDC8D8D8D696969A2A2A2E9E9E9FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF1F1F1272727
030303000000373737F4F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFF
F9F9F9FCFCFCF9F9F9757575000000020202060606CDCDCDFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFCFCFCFDFDFDFFFFFFC6C6C6919191
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFF3A3A3AA7A7A7FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFF8F8F8FFFFFFFFFFFF848484070707080808000000020202050505
3C3C3CF9F9F9FCFCFCBDBEBE5155560D0E1267646BD9D4D4FFFFEFE5E6D6
4347486A707B525661F5F7FFFFFCFFFFFAFCFFFDFBFFFEFBF1F2F4FCFFFF
FEFFFF3E3E3EAAAAAAFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFEFEFEFFFFFFF8F8F8FFFFFF818181696969FFFFFF9F9F9F
5C5C5CFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFDFDFDE5E5E5828282202020
393939FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
F9FFFAFCFFFBFFFEFFFFFCFFFFFCFFFFFEFFF8FFF3FCFFF6FFFAFFFCF5FC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F5FFF4F4FEF3FFFDFFFFFAFFFFF9FFFFFDFFF0FFF1F4FFEEFFFDF8FFFBFD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F7FFF4F7FEF4FFFDFFFFF8FFFFF4FFFFFDFFF5FFF8F7FFF3FFFBF3FFF8F7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FCFFFBFEFFFDFFFEFFFFFEFFFFFCFFFFFEFFFCFFFDFCFFFBFFFFFBFFFDFD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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFEFEFEF7F7F7FFFFFFFFFFFFF6F6F6FEFEFE8080807E7E7EFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF2D2D2DBDBDBD070707FFFFFFF9F9F9FFFFFFF4F4F4FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC
FDFDFDFFFFFFF8F8F8F8F8F8FFFFFFCFCFCF8484846A6A6AA4A4A4EFEFEF
FFFFFFF7F7F7FFFFFFFFFFFFF8F8F8FFFFFFFCFCFCFAFAFAFFFFFFFFFFFF
FBFBFBFDFDFDFFFFFFFEFEFEFAFAFAFFFFFFFFFFFFE2E2E2181818FDFDFD
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFBFBFBF9F9F9FDFDFDFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFF373737000000020202181818969696E5E5E5
FFFFFFFFFFFFF5F5F5FFFFFFF9F9F9FEFEFEFFFFFFFFFFFF3B3B3B000000
0000001F1F1FE6E6E6FFFFFFFDFDFDFFFFFFFCFCFCF7F7F7FFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFBFBFBFBF7F4
FFFEF8FFFDF8ECE6E4050100DCDBD7DADAD8101115F9FCFFFBFFFFF6FBFE
FBFEFFFCFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFE2B2B2BB3B3B3FFFFFFFCFCFCFFFFFF
FFFFFFFEFEFEFFFFFF030303040404F6F6F6FDFDFDFBFBFBFFFFFFF9F9F9
FFFFFFFFFFFFE8E8E8181818828282FFFFFFF9F9F9FAFAFAFFFFFFF9F9F9
FFFFFFFFFFFFF2F2F2898989232323393939B4B4B4FFFFFFFFFFFFFFFFFF
FFFFFDFAFAF8FDFDFBFFFFFDFFFFFFFFFFFFFFFEFFFCFBFEFFFEFFFDFCFF
FBFAFDFFFEFFFEFEFE2A2A2AC2C2C2FBFCFCF9FFFFFCFFFFFFFBFAFFFBFB
FFFEFFFBFFFFF8FFFFFBFFFFFFFDFDFFFCFBFFFDFDFEFFFFF7FFFFF8FFFF
FFFDFFFFFCFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFAFAFA
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF7373738A8A8AFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF454545686868626262FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCF7F7F7FFFFFFDADADA909090
6565659F9F9FE9E9E9FEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFAFAFAF8F8F8
FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAFFFFFF919191585858FFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFCFCFCF8F8F8FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFCFCFCFFFFFFFCFCFCDEDEDE1515150000000000004A4A4A919191
757575939393EDEDEDFCFCFCFFFFFFFFFFFFFFFFFF707070000000050505
080808C7C7C7FFFFFFFBFBFBFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFF6F7F7FFFFFDFFFEFB
FFFDFAFFFDFAFFFBF8EAE6E36361607474746E6F73FBFEFFFBFEFFF8FBFF
FCFFFFFAFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFCFCFCFFFFFFF8F8F89B9B9B575757FDFDFDFFFFFFFCFCFC
FBFBFBFBFBFBC5C5C5000000A1A1A1FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FDFDFDF7F7F7B7B7B7BCBCBCFDFDFDFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
D4D4D46868681212125A5A5ACECECEFFFFFFF9F9F9FBFBFBFFFFFFFDFDFD
FEFEFCFFFFFDFFFFFFFEFEFEFEFEFEFBFBFBFFFEFFFFFEFFFFFEFFFFFEFF
FDFDFDFFFFFFAFAFAF393939F8F8F6FEFFFFFCFFFFFEFFFFFFFEFBFFFDFA
FFFEFDFEFFFFFBFFFFFCFFFFFFFEFBFFFDFAFFFFFBFEFFFFFBFFFFFCFFFF
FFFEFDFFFEFBFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F4
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDB9B9B91515153C3C3CC5C5C5FFFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFBFBFB
FCFCFCC2C2C2353535000000FFFFFFFFFFFFF8F8F8FEFEFEFFFFFFF8F8F8
B7B7B75050501212124545458A8A8AE3E3E3F8F8F8FFFFFFFCFCFCFAFAFA
FFFFFFFDFDFDFBFBFBFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFEFEFEF8F8F8ACACAC454545CECECE838383656565
A5A5A5F1F1F1FFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFF4B4B4B
000000030303000000070707020202050505434343FFFFFFFBFBFBFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFD6D6D68F8F8F696969
A9A9A9F2F2F2FDFDFDFAFAFAFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFEFEFEFAFAFAFFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFF9FDFCFFFFFDF3F3EF
A7A2A20D080882817CFFFFFBD7D6DBF0F0F6FCFFFFFCFFFFFEFFFFFFFEFF
F8F6F7FFFEFDF9F9F9F4F4F4FFFFFFFFFFFFFBFBFBFFFFFFFCFCFCFFFFFF
FFFFFFF1F1F16C6C6CD3D3D3FFFFFFFDFDFDFBFBFBFFFFFF1E1E1EC5C5C5
818181989898EFEFEFF3F3F3FDFDFD989898AAAAAA8888882121213D3D3D
A8A8A8FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFAFAFAFFFFFFFBFBFBFFFFFFCECECE
191917F7F7F5FFFFFBFEFEFAFFFFFAFFFFFAFCFDF5FFFFFDFFFDFFFEFEFF
FBFCF2FFFFF6B3AFBD474455FEFDFFFEFFFDFFFFFFFFFEFFFFFDFFFFFEFF
FFFFFDFDFDFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFBFEFEFED2D5DA767779
26231A252219747472C4C5C9FDFDFFFFFDFFFFFDFCFEFEFAF9FFFDFBFFFF
FFFCFFFFFCFFFFFDFFFEFCFFFFFFFFFCFCFCFEFFFFFEFFFFFAFAF8FFFFFD
FFFEFDFDFBFAFCFAFBFFFEFFFFFFFFFDFEFEFBFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
F8F8F8FFFFFFFBFBFBC1C1C1373737FAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBBEBEBE7A7A7A686868BCBCBC
F8F8F8FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D4D47E7E7E737373AEAEAE
F7F7F7FFFFFFF5F5F5FFFFFFFFFEFFFBF9FCFFFBFFFFFAFDFFFDFDF9F9F5
FEFFFAFDFFF9FFFFFDFFFFFFFCFDFFFCFDFFFEFFFFFEFEFCFFF9FCFFFCFF
FFFDFFFDFBFCFBFAFDFEFFFFFCFFFFFCFFFFFBFFFEFCFFFFFEFFFDFFFFFB
FFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFEFFF9F9F7FFFFFDFFFEFFFBFBFF
FEFFFFFCFEFBFEFFF6FEFFF6FEFDFFD6D4DD0A0610010005040205000000
2527225C615B979996B1B1B1DADADA686868EDEDEDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
BABABACACACAFFFFFFF9F9F9FFFFFFFFFFFF939393D1D1D1FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FEFEFEFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFDFDFDFDFDFDFFFFFF
FEFFFDFDFFFCFEFFFFFEFFFFFFFEFFFFFEFFECEBEE141414E2E0E1FFFEFD
FFFEFAFEFDF8FFFCF3FFFFF4FEFBF0605D54969590FDFDFD54525D9A98A1
FCFCFAFFFFFBFBFAFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFDFDFDF7FCFFFCFFFF
FFFDF3D3CFC37878742C2F341A19266A6873C7C5C4FCFDF7F1FBF6F6FEFC
FFFCFFFFFBFFFFFCFFFFFEFFFBF9FAFFFFFFF5F6F6FEFFFFFFFFFDFDFDFB
FEFCFBFFFEFDFFFDFFFFFEFFFCFCFCFBFCFCFBFFFFFBFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFDFDFD
FFFFFFF8F8F8FFFFFF686868828282FCFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFDFDFDFDFDFDFBFBFBFFFFFFC8C8C8
7B7B7B6C6C6CACACACEEEEEEFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAF4F4F4B7B7B7FCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFBFBFB
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFDEDEDE
8686866B6B6BA9A9A9EFEFEFFFFEFFFFFDFFFFFBFFFFFBFFFFFDFEFDFFFC
FEFFFAFEFFF8FEFEFAFBFBF9FEFFFFFEFFFFFBFCFEFFFFFFFFFCFFFFF9FC
FFFDFFFFFEFFFFFEFFFEFFFFFBFEFFF9FFFFFAFFFEFCFFFFFEFFFDFFFFFB
FFFFFBFFFEFDFFFEFFFFFEFFFEFEFFFFFEFFFFFEFBF6F5F1F5F8FDFBFFFF
F3F7F8FAFAF6FFFFF6FFFFF6FEFFFFF8F8FE75717D0B050F0E090D2E2C2B
333935EDF3EFF9FAFAC1C1C1777777FAFAFAFFFFFFF7F7F7FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFF
FCFCFCFEFEFEFFFFFFFFFFFFFEFEFE8A8A8ABEBEBEF7F7F7FEFEFEFFFFFF
FDFDFDFFFFFFF8F8F8FEFEFEFFFFFFB4B4B4F4F4F4FFFFFFFDFDFDFFFFFF
F7F7F7FDFDFDF7F7F7FFFFFFFFFFFFF6F6F6FFFFFFFCFCFCFFFFFFFFFFFF
FDFFFCF8FAF7FEFFFFFCFDFDFEFDFFF8F7FA8E8D90565558FFFDFEFDFBFA
FFFEFBFFFEFAFFFFF6FBF8EDFFFDF3FFFDF48684836F6E7116151849484B
FEFDFFFFFEFFFCFBFEFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFFFAFFFFFBFFFF
FFFEF6FFFEF4FFFFFDFEFFFFD5D7E182828A3432311818145F6765C0C6C6
FFFDFFFFF8FBFFFCFFFFFDFEFFFEFFFFFFFFFEFFFFF9FAFAFEFFFFFBFBFB
FFFEFFFBF9FAF8F6F7FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFAFAFA1F1F1FD7D7D7FDFDFDFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFD4D4D48282826F6F6F9B9B9BF3F3F3FFFFFFFFFFFFF8F8F8
FFFFFF8080806A6A6AFFFFFFFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAF9F9F9
FFFFFFFFFFFFE1E1E18B8B8B6B6B6B9C9A9BF1EBEBFFFCFEFCFFFFFBFFFF
FBFDF8FEFFF8FEFFFAFEFFFAFCFCFAFFFEFFFDFDFFFEFEFFFBF9FAFFFEFD
FFFAFAFEFCFBFFFFFFFEFFFFFCFFFFFCFFFFFCFFFFF9FDFCFEFFFDFFFFFD
FFFEFDFFFEFDFFFFFFFFFEFFFEFFFFFFFEFFFFFBF8FFFBF9F8FFFFF4FFFF
F9FFFFFFFFFBFFFEF6FFFBF5FAFBFBFBFFFFF6F6FF1B17210C0107898383
8389850D1611757676A3A3A3FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFAFAFA686868C9C9C9FFFFFFFCFCFCFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFBFBFBFFFFFF6666660F0F0F6F6F6FDCDCDCFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFBFBFB
FEFFFDFEFFFDFCFDFDFDFEFEFFFEFFF8F7FA0F0E11DAD9DCFFFEFFFFFEFD
FFFEFBF9F5F1FFFFF8FFFFF6F9F6EBFFFFF8FEFCFBFFFEFFEAE9EC070609
ECEBEEFAF9FCFFFEFFFEFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFAFFFFFFFBFFFFFBFFFF
FEF8F5FEF9F3FBFBF9FBFCFFFBFEFFFEFFFFF3F1F0E2E0DF8B8F902C2F33
171514666060BBB6B8FAF8F9FFFDFEFEFEFEF9FAFAFEFFFFF8F9F9FEFFFF
FFFDFEFFFEFFFFFEFFFDFBFCFBFBFBFEFFFFFEFFFFF9FDFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
F9F9F9FFFFFFCACACA2B2B2BFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFCFCFCFAFAFAFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF2F2F2E3E3E38B8B8B6363638F8F8FE9E9E9
FFFFFF222222C7C7C7FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFBFBFB
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFE8E6E5A3A29E6D6D6D8C939BDBE2EA
FCFEFBFFFFF8FBFFF7FBFEF5FFFBF7FFFDFFF8F8FFFCFEFFFCFFFFF9FBF6
FFFEFDFFFEFDFDFDFDFCFCFCFCFDFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFD
FFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFFFEFFFFFCF8FFFDFAF2FBFDF4FFFF
F9FFFFEEEEEC4B423D372E29171717D8DDE1FAFCFFA6A4AD0D04097E777A
FAFEFB525854131414959595F7F7F7FFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
FFFFFFFBFBFBEBEBEB595959EFEFEFFAFAFAFDFDFDFFFFFFFEFEFEFCFCFC
FFFFFFF8F8F8FBFBFBFFFFFFFEFEFEFFFFFFE3E3E37F7F7F0F0F0F414141
B7B7B7FBFBFBFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FBFDFAFEFFFD454646E1E2E2FDFCFF959497565558FCFBFEFDFBFCFFFEFF
FFFDFDFFFEFBFFFEFAFFFFF8FFFFF6F7F6EFFBF9F8FFFEFFECEBEE222124
B7B6B9FFFEFFFDFCFFFDFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFCFEFDFFFCFFFFFEFFFF
FFFEFBFFFDFBFFFFFFFEFFFFFCFFFFF9FAFAFFFFFBFFFAFAFEFEFFFEFFFF
E3E3E18F8E8A403B3B121011555354B9B9B9FCFDFDFDFEFEFEFFFFFBFCFC
FEFCFDFEFCFDFFFEFFFFFEFFFFFFFFFEFFFFFDFEFEFBFFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFF777777787878FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFDFDFDF9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C5C5999999
505050181818D5D5D5FFFFFFFFFFFFFFFFFFFAFAFAFAFAFAFFFFFFFFFFFF
FBFBFBFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB9E9E9E
4A4A4A1515154444448D8D8DF9F7F6FFFFFBF5F5F1FCFFFFEEF7FFA1A9B4
74737684837ECFD6CEFCFFF8FFFEF6FFF9F7FEFEFFF9FFFFF2FAFAFBFFFB
F9F9F5FBFAF6FDFDFBFFFFFDFFFFFFFBFCFCFDFCFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFEFDFFFBF5FFFCF7F5FDFFF5FFFF
F8FFFFFEFFFDFFF9F49C938EF1ECEEE8E7EDFCFFFFF6F9FF0000024B4B4B
5F5F5FE4E5E5D6D6D62E2E2E636363F8F8F8FFFFFFF6F6F6FFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFDBDBDB636363FFFFFFF9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
F8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7FFFFFFABABAB
3131311B1B1B808080F1F1F1FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFCFCFC
FEFFFDFEFFFD40423FBEBFBFF3F2F51C1B1EC7C6C9FFFEFFFFFEFFFFFEFF
FEFCFDFFFEFDFEFAF7FEFAF6FFFEFAFFFFFAFFFEFDF9F9F9E3E3E3A6A6A6
B2B2B2FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFF9FCFFFBFCFF
FFFBFDFFFDFDFFFEFFFEFFFFFBFFFDFCFFFBF9F5F2FFFDFFFFFDFFFFFEFF
F5F7F2FFFFFAFAF8F7EAE5E79C9A9B3737370F10105A5B5BAAABABF7F8F8
FFFFFFFFFEFFFDFBFCFBF9FAFCFCFCFDFEFEFEFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFF222222CFCFCFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FAFAFAFEFEFE
FFFFFFFFFFFFFEFEFEFCFCFCFEFEFEFFFFFFF9F9F9FCFCFC111111EAEAEA
7777776E6E6EAFAFAF6565657A7A7AC8C8C8FFFFFFFFFFFFFFFFFFFBFBFB
FAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA040404030303
000000010101000000121210353332F8F8F4FEFFFAF9FFFFEFF8FFF8FFFF
FDFBFEFFFEFDB2B8B473756F7E7468CFC4BEFFFDFFF9FFFFF6FFFFF9FFFD
FEFFFDFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFDFFFDFCFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFBFFFAF2FFFDF6FBFFFFF7FFFF
F3FEFFFAFFFCFEF9F3F9F0EB7C7376FFF9FFFCFFFFF8FCFF595F5F0D1110
F0EEEFFFFEFFFFFEFFF3F3F3595959303030CACACAFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
ABABAB828282FFFFFFFCFCFCFFFFFFF9F9F9FBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFD3D3D36767670C0C0C5E5E5EC7C7C7FFFFFFFFFFFFFBFBFBFFFFFF
F9FBF8FEFFFD626461939592AAAAAA454447FDFCFFFFFEFFFFFDFFFFFEFF
FFFEFFFDFBFCFFFBFBFFFEFBFFFCF9F9F8F4FFFFFDFFFFFFF9F9F9FDFDFD
FFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFEFFFCFFFFFEFFFF
FFFDFFFFFDFFFEFCFFFBFCFCF9FFF9FCFFFAFFFEFBFDF6F9FFFBFFFEFBFF
FCFFFDFBFFF9FFFEFDFFFBFBFFFEFFFAFAFAE7E8E8979B9A4243450C0D0F
525154A5A4A7F3F1F2FFFEFFFDFDFDFDFEFEFEFFFDF8FCF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
F7F7F7D6D6D6242424FDFDFDFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF3C3C3CC2C2C2
1C1C1CD7D7D7FDFDFDFFFFFFF4F4F4BABABA7070706E6E6EBCBCBCFDFDFD
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD606060050505000000
03030300000001010101000004000024231FFCFFFBF9FFFFF7FFFFF9FFFF
FFFCFFFBF6F8F8FBFFFFFFFBFFFCEFCDBCB07775786B727ABBC4C7F5FDFF
F1F5F4FDFDFBFFFFFDFDFDFBFBF9FAFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
FFFEFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFAFFFCF2FFFDF4EDEEF0EFF8FB
F6FFFFF9FFFFFFFEFAFFFBF9F6E9EE726A73F7FAFFB7C0C5707A79F9FFFD
FFFDFFFDF6FBF9F7F8FCFCFCFFFFFF8080800B0B0BFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6909090
AAAAAAFFFFFFFEFEFEFAFAFAFFFFFFFFFFFFF7F7F7BDBDBDDCDCDCF7F7F7
FCFCFCFFFFFFFBFBFBFFFFFFF5F5F5FFFFFFFCFCFCFDFDFDF6F6F6FFFFFF
FDFDFDFCFCFCF9F9F9F1F1F18E8E8E202020333333959595F6F6F6FFFFFF
FEFFFDFEFFFD7A7C797A7C79292929BEBEBEFBFAFDFDFCFFFEFDFFFDFCFF
FEFCFFFFFEFFFFFDFEFEFCFBF7F5F4FFFEFDFBFBFBFFFFFFFFFFFFFDFDFD
F5F5F5FCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFDFFFEFFFF
FFFDFFFFFCFFFFFEFFFEFFFFFBFFFAFAFFF8FFFDFAFFFCFDFFF7FFFFFCFF
FBFFFFF9FFFDFBF9F8FFFDFDFFFEFFFFFFFFFDFEFEFBFFFEFEFFFFEBECEE
9D9C9F48474A141213464445AAAAAAEEEEEEFEFFFDFCFEFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFF8282826D6D6DFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFEFEFEFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFCFCFC
FEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFBFBFB5454547E7E7E
323232FEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFEFEFEFAFAFAC4C4C4707070
6D6D6DB4B4B4FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCBCBCB040404060606000000
000000000000020202030102070101120E0BB8BDB7F6FEFCF8FFFFFAFFFF
F9F3FAFFFCFFFEFEFFF8F6F9FFF5E7BBA99A76757191969AB7BEC4787F85
767C7CB4B8B7F1F2F2FFFFFFFFFDFFFFFCFEFFFCFFFEF9FDFFFDFFFFFEFF
FEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFF8FFF9EE8D8077030706566065
7B8688F2F8F8FDF7F4EBDFDEFFF8FD30283180848BA3ACAFF4FEFDFBFFFF
FFFCFFFFFCFFFFFEFFFEFEFEE2E2E22727275B5B5BFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE696969CACACA
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFD2D2D21B1B1BABABAB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDB9B9B95050500E0E0E727272
DADCD9FBFDFA9C9E9B3F413E383838FAFAFAFFFEFFFFFEFFFFFEFFFFFEFF
FAF8FBFFFEFFFDFBFCFFFEFFFFFEFFFCFAFBFEFEFEFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFDFFFFFDFFFFFEFFFEFFFDFBFFFBFBFFFAFFFEFBFFFBFDFFF9FEFFFCFF
F8FFFFF7FFFF8E8E8E040000333132AEAEAEFEFFFFFAFEFDFCFFFFFEFFFF
FFFEFFFFFEFFEEECEDA9A7A8434343111111484A479EA09DEDEDEDFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF6F6F6
FFFFFF3B3B3BBCBCBCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF747474383838
8C8C8CFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDC8C8C87D7D7D666666ABABABFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFF
FDFDFDFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFA1A1A10F0F0F000000010101
0303030000000606060200010400000D0707999B98FBFFFDFCFFFDF7F8F8
FFFDFFFFF9FFFBF8FFFFFBFF917D701100009A978E676B6C080812D2D4E0
F6FAFFD9DEE18488896A6A6AB0ABADF5EFEFFEF7FAFFFDFFFCF9FFFFFEFF
FEFFFFF4F8F9FEFFFFFEFFFDFDFDF9FFFEF6FFF2E7190B00D1D9D7F2FFFF
C2CFD3CCCFD3FFF7F7A29293160D12222126C4CBCFF8FFFFE6EAEB030303
D4D1D7FFFEFFFDFCFFE5E5E51919198F8F8FFFFFFFFDFDFDFFFFFFFCFCFC
FDFDFDFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFE5E5E55C5C5CEEEEEEF9F9F9
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFD4D4D4111111
B2B2B2FFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFDFDFDFEFEFEFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFDBDBDB787878
15171445474482828011110FD5D5D5FAFAFAFFFEFFFDFCFFFFFEFFFFFEFF
FDFCFFFFFEFFFEFDFFFFFEFFFCFBFEFFFEFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFF
FFFEFFFFFDFFFFFEFFFEFFFDF8FFFCF8FFF8FFFBF8FFFBFAFFF6F7FFFBFD
F7FFFFEEFDFFFCFCFCABA5A5E2DDDFEAEAEAF9FAFAFCFFFFFCFFFFF7FBFC
FBFCFEFFFEFFFEFCFFFEFCFDFFFFFFF2F2F0A4A6A3525451101010454545
9C9C9CEAEAEAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFF
E6E6E60C0C0CFCFCFCFCFCFCFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC909090040404
7B7B7BE1E1E1FFFFFFFAFAFAFBFBFBFFFFFFFEFEFEF9F9F9FDFDFDFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFD2D2D28686866262629F9F9FF4F4F4F3F3F3
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF8686860E0E0E050505000000
0000000404040000000100000903030A0404828282FEFFFBFCFCF2FFFFF8
F8F5FBECE8F6FFFBFFFFF7FFC3AFA2E7D6C2F9F9EDFCFFFD96909A44404E
F9FFFFF8FFFFFAFFFFFEFFFFE5E0E2938D8D7B75759D989AF2F0F3F5F6FA
FCFFFFFCFFFFFEFFFFFEFFFDFFFFFBFFFBF3FCE6D92C1B11D7DFDDF1FFFF
F7FFFFFEFEFFFFF4F7F7E7E85D565BE2E5E9F8FFFFF6FEFFA5A4A7010000
DEDDE0FDFCFFDEDDE01414149C9C9CFDFDFDFDFDFDFAFAFAFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBCFCFCF6F6F6FFDFDFDF8F8F8FEFEFE
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFD2D2D2
0F0F0FBBBBBBFEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFF5F5F5FFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFF8F8F8FBFBFBFFFFFFFDFDFD
F5F7F4A4A6A330302E11110F818181EAEAEAFFFEFFFFFEFFFDFCFFFFFEFF
FFFEFFFCFBFEFEFDFFFFFEFFFFFEFFFBFAFDFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFF
FFFEFFFFFEFFFFFEFFFEFFFFF9FFFFFBFFFFFFFEFBFFFBF6FFF5EFFFFBFA
F1FEFFF2FFFFFAFBFDFFFBF9948F8FD7D7D7FEFFFFFCFFFFF5F8FCFCFFFF
FEFFFFFFFEFFFFFEFFFEFCFDFCFCFCFDFDFBFEFFFDFEFFFDF6F6F6A9A9A9
5858580E0E0E353535999999E6E6E6F8F8F8FDFDFDFFFFFFFFFFFFFDFDFD
8C8C8C686868FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB868686060606
6464641717172C2C2C7F7F7FCFCFCFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
F1F1F1FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFDFDFDE0E0E09595956C6C6C
8B8B8BEFEFEFFFFFFFFBFBFBFEFEFEFCFCFCFFFFFFFFFFFFFCFCFCF8F8F8
FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFBEBEBE111111000000040404
060606000000040404020001040000140F11BAB8B9FFFFFAFFFBEC989186
00000400000D0E0518D5C7D2FFFAF1AB9E8D00030000010020141D070008
E4EAF6F5FFFFF8FFFFF7FAFFFFFEFFFFFDFDFFFDFDEAE5E59A989B757678
929599DCE2E2FAFEFFF9FBF8FFFFFBFFFEF6FFFAED605247969A9BF3FFFF
F1F9FFEBEBF3D9CED26D6163FDF8FAFEFFFFF9FFFFF3F9F93939390A0809
CBCACDD2D1D41B1A1D9E9E9EFFFFFFFFFFFFFDFDFDFFFFFFF5F5F5FFFFFF
FEFEFEF7F7F7FFFFFFFBFBFBA3A3A3929292FFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
CACACA090909B6B6B6FFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFF9F9F9000000616161131313555555C6C6C6FFFFFFF4F4F4
FFFEFFFFFEFFFEFDFFF6F5F8FFFEFFFFFEFFFDFDFDFEFEFEFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFEFDFEFFFFF9FFFFFBFFFFFFFEFBFFF4ECFFF4E8FFF9F2
F1FEFFEBFEFFFEFFFFFFFDFBFDF8F86E6E6CF6F7F9FBFFFFFCFFFFFCFFFF
FBFCFFFCFDFFFFFEFFFFFEFFFFFFFFFFFFFDFDFDF9FBFDF8FCFCFCFFFFFF
FEFEFEFDFDFDBABABA5555551212123E3E3E929292E6E6E6F6F6F6FFFFFF
3E3E3EAAAAAAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF404040181818
FDFDFDFFFFFFC9C9C97070702525251D1D1D6D6D6DB5B5B5FFFFFFFDFDFD
FFFFFFFDFDFDF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFBFBFBFDFDFD
EFEFEF9090905B5B5B8C8C8CDCDCDCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF0B0B0B030303000000
0101010000000000000505050503041B191AFCFAFBFCF7F1FFF5E4190F01
9A9FA3F0F6FF877F8A1A0B10F4E5DE0E0500A8AEAAF8FCFB7F6F700E0004
C3CAD8F1FFFFF7FFFFFBFFFFFFFEFFFCF7F7FFFDFBFFFEFBFDFBFCFEFFFF
EBEEF2A6ABAE6D71728D8F8CD7D7D3FEF7EFFFFCEDECDED3030205D6DDE5
D7DBE60A0A12888184FFF9FAFFFDFFF8F7FAFAFEFFD8DCDD080A070B0B0B
A4A3A6121114A4A3A6FFFFFFFAFAFAFFFFFFFAFAFAF9F9F9FFFFFFFCFCFC
FFFFFFFFFFFFF4F4F4828282BEBEBEF9F9F9FAFAFAFDFDFDFFFFFFFFFFFF
FEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFBFBFB
FFFFFFC6C6C6212121BBBBBBF9F9F9FDFDFDFFFFFFFFFFFFF9F9F9FFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBF7F7F7
FFFFFFFFFFFFFFFFFF212121DFDFDFE9E9E99292922626262D2D2DA3A3A3
FAFAFAFDFCFFFFFEFFFFFEFFFEFDFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FEFFFBFFFFFBFFFFFBFFFFFFF7FFFFF9FFFFFFFCFAFFFBEFFFF4E1301F15
323F50DDF1FFFEFEFFE2DCDAFFFDFD7A7A78B1B2B4FCFFFFFBFFFFF4F7FB
FAFBFFFEFFFFFFFEFFFCFAFBFEFCFDFFFFFDFFFFFBFDFDF9FFFFFFF8F8F8
FFFFFFFAFAFAFEFEFEFFFFFFFAFAFAB9B9B96363631111113737377E7E7E
111111FFFFFFF9F9F9FFFFFFFCFCFCFBFBFBFAFAFAFAFAFAFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEEEEE151515050505
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFD2D2D28383833D3D3D020202595959
AFAFAFEFEFEFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFEFA8A8A86161617A7A7AD2D2D2FBFBFBFDFDFD
FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFAFAFAE1E1E1010101040404
0000000606060A0A0A000000020305F6F6F6FFFEFFFFFDF6EED9C6130500
E7F1F8F4FFFFFFFCFC978984CBC2BD0C0C0CECF6FFF3F8FCFFF8F233211D
939AAAF0FFFFEEFBFFF9FFFFFCFBFEFFFEFBFFFCF9FFFEFAFFFFFDFBFCFC
FAFEFFFBFFFFFCFFFFF2F3F3BAB8B77E7971897D6DDFD2C7E3DCE164626F
3F3E4C4A4C56FFFEFFFFFDFCFFFEFFFFFEFFFDFCFF4A4B4B000100000100
121114A09EA1F5F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF2F2F26A6A6ACBCBCBFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFCFCFCFDFDFD
FFFFFFFAFAFABDBDBD101010C9C9C9FFFFFFFDFDFDFFFFFFFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF3A3A3AB7B7B7FFFFFFFEFFFDF9FBF8BBBDBA454744
10120F6D6E6ED7D8D8FEFFFFFDFEFEFCFDFDFFFFFFFFFFFDFBFBF9FFFFFD
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFB
FEFFFAFFFFFAFFFFFAFFFFFFF8FFFFF7FDFFFFFBF9FFF6E7FFF9DF685648
6D7C91CFE4FFF8FAFFC9C3C12E292911110FECEDEFF8FCFDF8FDFFFBFFFF
FEFFFFFEFFFFFFFEFFFFFEFFFFFDFEF8F6F5FAFAF6FFFFFBF9F9F9FFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFBFBFBC0C0C03F3F3F
0000002929298A8A8ADDDDDDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F4F4F4F111111
E8E8E8FFFFFFFFFFFFF6F6F6FFFFFFF8F8F8FFFFFFFFFFFFE7E7E7999999
4646460A0A0A4646468C8C8CEAEAEAFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFF7F7F7B4B4B46E6E6E757575
BCBCBCFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFE0E0E0474747
0101010A0A0A030303393A3AEAEEEFF6FAF9FFFEFDFFF7EFFFF4E1241405
A9BAC1F0FFFFFFFFF3FFFDEDF7F3F0161A25B8C4D8FBFEFFFFFAECA99588
4D5665EDFFFFEEFDFFF8FFFFFFFEFFFFFEFBFDF7F4FFFFF8FEFEFAFCFFFF
FBFFFFF7FCFFF9FDFEFBFCFCFAF8F7FEF9F1FCF3E2574D41766D723E3746
D8D5E48B8B95D3D2D5FFFFFFFBFBFBFDFDFDCCCCCC020200040400070705
0000020A090C000000000000000000FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
E6E6E65E5E5EEEEEEEFFFFFFFDFDFDFFFFFF5D5D5DF5F5F5FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3F3F3FFFFFFFFFFFFC0C0C00F0F0FC3C3C3FDFDFDB1B1B17A7A7AFEFEFE
FFFFFFFEFEFEFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFF1F1F1FFFFFF7F7F7FADADADFBFBFBFEFFFDFEFFFDFBFDFAFEFFFD
DEE0DD7A7C79191A1A454646B3B4B4FDFEFEF7F7F5FFFFFDFAFAF8FFFFFD
FFFFFDFBFBF9FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFBFFFFFB
FEFFF8FFFFF8FFFFF8FFFEFFF8FFFFF9FEFFFFFDFBFFF8E9FFFADAB7A694
56647EE4FAFFFCFEFFFFFBF9FCF7F7FBFBF9FCFDFFFCFFFFFBFFFFF3F8FB
FDFEFFFDFEFFFCFBFEFCFCFCFFFEFFFFFEFDFFFFFBFDFDF9FFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFBFBFB474747
AEAEAEBFBFBF6D6D6D1111112F2F2F787878CFCFCFFEFEFEFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4E4E4E9E9E9E373737
CBCBCBFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
FEFEFEF9F9F9ABABAB6262621111113030308B8B8BD0D0D0FDFDFDFEFEFE
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFF9F9F9
C0C0C06D6D6D656565BDBDBDFFFFFFFBFBFBFCFCFCFFFFFFFEFEFEF9F9F9
FFFFFFD8D8D8FFFFFFFCFDFDF9FFFFFBFFFFFFFFFBFFFBF3FFF8E679695A
3F565CEAFFFFFFFFE7CEC7AB7F80805C64774E5E7FF5FAFFFFF8E2B49E87
0A1322E1F8FFF1FFFFF2FBFFF7F8FCFFFEFBFFFEF8FFFFF8FDFDF9FAFEFB
FBFFFFFBFFFFFCFFFFFEFFFFFFFEFDFFFDF8FFFDEFA4978C363135F2EFFE
CFCADC605C6AFEF8FFFEFEFEFBFFFFF9FFFF212222030100060000040000
030404080E0E171818757575A3A3A3FBFBFBFFFFFFFFFFFFFFFFFFC5C5C5
767676FDFDFDFBFBFB9A9A9A242424E7E7E71F1F1FDDDDDDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFF5F5F5BBBBBB161616D5D5D5BDBDBD3E3E3EFFFFFF
F4F4F4FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF
FEFDFFFFFEFFFFFFFFFCFCFCFCFCFCFEFEFEFEFFFDF8FAF7FEFFFDFEFFFD
F8FAF7FEFFFDF7F9F69EA09D3739361B1D1ADEDEDCFFFFFDFDFDFBFDFDFB
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFDFFFFFDFFFFFB
FEFFFAFFFFF8FFFFFAFFFFFFF7FDFFFBFEFFFFFEFBFFFDEDFFF6DCECDECF
061123EAF9FFFCFFFFFEF9F9FFFEFDFFFFFFFEFFFFFAFEFFFCFFFFFCFFFF
FEFFFFFDFEFFFEFDFFFFFFFFFFFEFFFCFAF9FCFCFAFFFFFDFFFFFFFAFAFA
FFFFFDFFFFFDFCFCFCFFFEFFFCFBFEFFFEFFFFFFFDFEFEFCF4F4F20E0E0E
F5F4F7FFFEFFFCFCFCFFFFFFC4C4C4737373232323252525797979D6D6D6
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9E9E9121212F3F3F3AAAAAA
D4D4D4FFFFFFF9F9F9FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFBFBFBFCFCFC
FFFFFFFCFCFCFEFDFFFFFEFFF8F8F8C1C1C16B6B692020202524276D6C6F
C0C0C0F5F5F3FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFC2C2C2787878676767B1B1B1F3F3F3FFFFFFFDFDFD
FBFBFBFFFFFFFFFFFFFDFEFEFBFFFFF7FDFBFFFEFDFFFBF5FFF9EBE7DAD1
00050B617979D2D4BC49442C565757D6DEF000011C707384CFBCA92B1A06
000510DAECFFF4FFFFF6FCFFFEFFFFFFFFFBFFFEFAFEFDF8FFFFFBFAFCF9
FBFFFFFBFFFFFAFEFFFCFDFDFFFEFFFFF9F6D1C7BD70675E4B494CD3D3DD
2C2836ECE5F2FFFCFFFDFDFDFBFFFF69716F0608050402010900000D0503
4A4B4BC9CFCDFCFFFFF8FAF7FFFFFFFFFFFFFCFAFBFEFCFDA6A4A5969696
FFFFFFF7F8F8FEFFFDFEFFFD8E8E8E242424424041B8B6B7FFFFFFFEFEFE
FDFDFDFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBACACAC171717BABABA1A1A1AFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFDFDFDFFFFFF
FFFEFFFBFAFDFFFFFFFDFDFDFFFFFFFFFFFFFAFCF9FDFFFCFDFFFCFBFDFA
FEFFFDFBFDFAFEFFFDFEFFFDFBFDFACFD1CECACAC8FDFDFBFFFFFDFCFCFA
FFFFFDFDFDFBFFFFFDFEFEFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFDFFFFFFFDFEFFFCFDFFFFFFFBFFFEF6FFF8EDFFFEF6
1E2125CCD0D7FDFEFFFDFDFDFFFFFFFEFFFFFDFDFDFCFDFDFEFFFFFEFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFCFFFFFFFF
FFFFFBFDFDF9FCFBFEFFFEFFF9F8FEFFFEFFFFFFFBFFFFFAA0A19B4E4E4C
FDFEFFFEFFFFFEFFFFFFFFFDFFFFFDFFFEFDFDFBFCCDCBCC737275232225
1F202278797BD0D1D3F7F8FAFFFFFFFEFEFEFFFDFCFFFDFCFFFEFDFEFCFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFDFDFD9494945A5A5AFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFBFBFFFEFEFFF7F5F6FFFEFDFCFEF9FEFFFDCFCED3818085
30322F151712595957B3B1B0F6F4F5FFFEFFFFFEFFFAF9FEFFFEFFFFFFFF
FEFEFEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFF4848488080806565656B6B6B
EFEFEFFFFFFFFAFAFAFFFFFFFEFFFFFBFCFCFEFEFEFFFEFBFBF3EEFFFEFB
DDE2E5505858030400302F28D2D2D2FCFFFFDBDFE85D5D630800008F8A84
7D8084CAD1D9FBFFFFFEFFFFFFFEFFFDFDFBFFFEFDFEFEFCFDFDFBFFFFFF
FDFEFEFEFFFFFCFDFDFFFFFFFFFFFFB8B6B58C8885FFFCF9ECECEC000004
B2B1B6FFFDFFFBF9FCFFFFFFCBCCCC090A0A0000000707074F4A4ADDDBDA
FEFEFEFCFFFFFBFFFBFCFFFBFFFFFDFFFEFFFFFCFF7A7378BBB6B8FFFEFF
FEFFFFFBFFFFFBFFFAF6FDF5FDFEFE7A797C1B16188B8688FFFEFDFDFBFA
FFFEFFFFFEFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFF7F6F9FFFEFFF9F9F9FFFFFFA4A4A4111111090909FAFAFA
FFFFFFFEFEFEFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFCFCF8FFFFFBFFFFFBFBFAF6
83827D8B8B87FFFFFDFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF9F9F9
FFFFFAFFFFFAFBFAFDF5F4FA787681D8D7DCFCFCF8FFFFF6595A54A1A19F
FBFBFFFEFEFFF8F9F9FFFFFBFDFBFAFFFEFDFFFEFFF9F7F8FFFEFFFFFEFF
C5C6C8797A7C1D1E20262729707070CDCDCDFAF8F7FFFEFDFFFEFBFFFEFD
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFEFEFE
FAFAFAFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF393939B2B2B2FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFCFFFFFAFAFFFFFCFFFFFCFAFFFFF8F5FAF3FEFFFFFEFEFF
FEFFFFE0E1E193958F48474208020050494C949399F0F0F6FBFAFDFDFDFD
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9272727D6D6D67D7D7D626262
929292636363909090E3E3E3FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF5F5F5
FFFFFFFFFFFFFDFDFDFCFCFCCDCDCD909090FEFEFEFFFFFFF7F7F7DFDFDF
F6F6F6FBFBFBFFFFFFE4E4E4030303000000131313BBBBBBFFFFFFFFFFFF
FFFFFFF8FAF7FCFFFBFCFFFBFBFBF9F5F3F4625D5FE3DEE0FFFEFFFCFBFE
FEFFFFFCFFFFFAFFF9FCFFF8FEFFFDFAFAFA3B3638201B1DF7F5F6FFFDFC
FFFEFFFFFEFFFAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFAF9FCFFFFFFF9F9F9FFFFFF7B7B7B000000BEBEBE
FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF2F2F2FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFAF8FDFDF9FFFFFBFCFBF7FFFFFB
DBDAD623231FF8F8F6FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FCFDF7FFFFFBFFFEFFFFFEFF3C3A45151419FFFFFBEDEEE411120CEBEBE9
FCFBFFF7F6FCFFFFFFFDFDFBFFFEFDFFFAFAFDFBFCFFFDFEFFFEFFFFFEFF
FEFFFFFEFFFFFEFFFFCFD0D27D7E7E2526261F1F1D6B6B69BFBDBCFEFCFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF7F7F7FAFAFAFFFFFFFDFDFDFCFCFC
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFDBDBDB131313FDFDFDFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFBFFFFF7F7FDFFFBFFFFFBFDFBFBEEFCFFF4F9FDFEF5F7FF
7C7A8D494855F3F9EDFDFFEFFAF1EAAA9FA15F5F67070B143E3F43898989
DDDDDDF9F9F9FFFFFFFFFFFFF7F7F7FFFFFF434343B7B7B7252525C2C2C2
FFFFFFFFFFFFDFDFDFA1A1A16A6A6A808080D5D5D5FFFFFFF9F9F9FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFFFFFFFE3E3E36E6E6EFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
E1E1E1FFFFFFF8F8F80E0E0E0505055A5A5AF3F3F3FFFFFFF8F8F8FAFAFA
FFFFFFFDFDFDFBF9F8FFFDFCDEDEDC626461EDEFECFBFFFEF4F5F7FEFFFF
FFFEFFFBF9FAFFFFFAFCFBF4FFFFFBDCDCDA0E0F0F202121444444FBF9FA
FFFDFEFFFEFFFFFFFFFFFFFFF6F6F6FFFFFFF9F9F9FFFFFFFAFAFAFFFFFF
FEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF979797151515232323171717
E4E4E4FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8F8F6FFFFFBFFFFFBFCFBF7FFFFFB
CCCBC7080804E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFAFFFFFBFAF9FCFFFEFF97959E0403089E9E9AADAEA6393A34FFFFFD
FFFEFFB7B6BCD3D3D3FFFFFDFAF5F5FFFDFDFFFEFFFFFEFFF4F3F6FFFEFF
FEFFFFFBFCFEFBFCFEFEFFFFFEFFFFFCFDFDD8D8D8888886323230141412
6C6C6CBBBBBBFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FAFAFAFEFEFEE8E8E86A6A6AFFFFFF858585616161FFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFCFEFFFEFFFFFCFFFFFDFDFDFFF2FEFFF6FCFFFFF8F7FF
F2EDFF656370F9FFFAFBFFF4FFFCF9FFFBFFF8F8FEF5F8FFB4B5B7676767
1919192A2A2A737373C8C8C8FFFFFFF9F9F9616161818181242424FFFFFF
FAFAFAFFFFFFFBFBFBFCFCFCFFFFFFE2E2E2ABABAB696969808080D7D7D7
FAFAFAFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFBFBFBFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFAFAFAFEFEFEAEAEAEC8C8C8FDFDFDFFFFFFFFFFFFDDDDDD131313
0F0F0F1919191616160303039B9B9BFCFCFCFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFB9B7B87F7F7DFDFFFAF8FCF9FCFFFDFEFFFFFEFDFF
FDFAFFFFFEFFFEFDF8FDFCF5BDBCB520201C7374743B3C3E585858504E4F
FBF9FAFFFEFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC7A7A7A262626DDDDDD5A5A5A5C5C5C
232323E5E5E5FEFEFEFEFEFEFAFAFAFFFFFFFBFBFBFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFFFDFEFEFCFDFDFBFFFFFBFFFEFA
CAC9C5979793E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFF8F8F6
FEFEFAFBFBF7FFFEFFFFFEFFC0BEC700000404040063645C90918B9F9F9D
18171C000004F0EFF2FFFFFFFFFDFDFEF9F9FFFDFCFFFEFDFFFFFFF9F9F9
FEFFFFFEFFFFFEFFFFF8F9FBF6F7F9FEFFFFFEFFFFFEFFFFFAFBFBE0E0E0
8282823737371818185E5E5EC1C1C1F3F3F3FCFCFCFCFCFCF9F9F9FCFCFC
FFFFFFF9F9F9FAFAFA050505FBFBFB323232CACACAFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFFFDFDFFF9F9FAFAF8FCFFFDF8F9F9FCFDFFFEFEFFFFFCFF
FFF4FA665F62D6E2E0F1FFFFFEFEFFFFFCFFFFFEFFFEFEFCFEFEFEFEFEFE
FFFFFFD0D0D07676762323231A1A1A6666666868682F2F2F7D7D7DFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFF9F9F9F1F1F1ADADAD
6B6B6B6F6F6FC5C5C5FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFDFDFDFEFEFECDCDCDA8A8A8FFFFFFFCFCFCFAFAFA4C4C4C070707
000000000000000000A3A3A3FCFCFCFFFFFFFFFFFFFFFFFFFCFCFCFAFAFA
F9F9F9FFFEFF8B8C909F9EA3F7F7F5FFFFFAFFFFFBFAF8F7FFFDFFFEFBFF
FFFEFFFEFFFFF8FAF4ACAFA417180EAFB0A8EAE8E9110E14F8F7FA3D3D3D
656565FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFBFBFBFCFCFCF6F6F6575757363636ECECECFFFFFF8484847D7D7D
8C8C8C252525E9E9E9FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFEFEFCF7F7F5FFFFFBFFFFFB
FEFDF9FFFFFDF8F8F8FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFD
FFFFFBFFFFFDFAF9FCFFFEFFDEDDE30F0E130909050102000C0C080A0A08
070609AFAEB3FEFDFFFEFCFDFFFDFDFFFAFA8E8C8B090706353535AEAEAE
F8F9FBFEFFFFFDFEFFFEFFFFFEFFFFFEFFFFFEFFFFFBFCFCFEFFFFFBFCFC
FFFFFFFEFEFEDFDFDF9191913434341717175D5D5DB8B8B8FFFFFFFFFFFF
FFFFFFFBFBFBFFFFFF191919BEBEBE1C1C1CF8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFBFFF6F0FFFEF6F0F8F8F7FFFFFFFEFFFAF6FFF6F6FFFAF7FD
FFFBF6AEA5A0A5ADB8F2FFFFF2F7FFFBFBFFFFFEFBFFFFF8FFFEFDFFFFFF
F9F9F9FDFDFDFFFFFFFFFFFFDCDCDC8C8C8C383838050505E0E0E0FDFDFD
FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFDFDFD
FFFFFFFCFCFCBEBEBE7171715F5F5FC1C1C1FBFBFBF8F8F8FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF606060F5F5F5FFFFFFD6D6D6080808000000
0000000606060101014A4A4AFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFF6A6B6DCACDD4FCFFFFFDFDFBFFFCF5FFFDFAFFFDFBFCF5FCFFFCFF
FFFEFFF5F9F87E857E151C12DBDFD0FFFFF6FFFCFF0B050CFCFAFDFDFDFD
3C3C3C626262F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFF7F7F7FBFBFBFFFFFF
FDFDFDFFFFFFF3F3F33B3B3B595959FBFBFBFBFBFBFFFFFF959595626262
FBFBFB8585852F2F2FF0F0F0FDFDFDF4F4F4FFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFDFFFFFDFDFBFAFFFEFD
FFFEFDF6F6F4FFFFFFFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
F8F8F6FFFFFDFDFCFFF9F8FDDCDBE00706090000000202000B0A06010000
A6A4A7FFFEFFFFFDFFFFFEFFFFFDFDFFFDFDFDFBFAA3A1A0D8D8D8E5E5E5
FFFFFFFCFCFCF9FAFCFEFFFFFCFDFFF6F7F9FCFFFFFCFFFFFAFEFFFEFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFE6E6E69090903A3A3A0606065F5F5F
A9A9A9FEFEFEFBFBFB3939395C5C5C757575FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF8FFFAE8E0D8CB00030E2A394CBEB6C3070004AFB2B9FCFFFF
FFFDECF1E6E06B6D84ECF6FFF5FFFFF9FFFFFFFCF5FFFCF4FFFEFAFFFFFF
FFFFFFF9F9F9FEFEFEFFFFFFF9F9F9FFFFFF8B8B8B101010FAFAFAFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFB
FEFEFEFFFFFFF7F7F7FFFFFFFFFFFFC1C1C17171716B6B6BB0B0B0F5F5F5
FFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFBFBFBFAFAFAF0F0F0707070FFFFFFECECEC040404000000
050505000000020202686868FFFFFFFAFAFAFFFFFFF5F5F5FFFFFFF1F1F1
555555E4E5E9F3F7FFFBFFFFFCFCF8FFFEF6FFFBF6FFFCFBFFFBFFFFFCFF
FCFDFF494F4D353F3AEBF4ECF4FBEBFDFDF1FFFCFF271D26D2D0D3FEFFFF
F8F9F9BCBDBDDCDCDCFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8
FFFFFFD7D7D7262626727272FCFCFCFFFFFFFEFEFEFFFFFFBFBFBF3F3F3F
FFFFFFFEFEFE7777772E2E2EF5F5F5FEFEFEFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFEFD
FDFBFAFFFFFDFEFEFEFCFDFDFEFFFFFEFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFBF9FFFFFD
FEFEFCF7F7F7FCFBFEFFFEFFDAD9DE100F12010100010100070602514F4E
FFFEFFFDFBFEFFFEFFFFFDFFFFFEFFFFFEFDFFFEFDFDFBFA919191E0E0E0
F9F9F9FFFFFFFEFFFFF5F6F8FEFFFFFEFFFFFBFFFFFCFFFFF9FDFEFCFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFEBEBEB979797
4343430D0D0D5151513A3A3A141414D1D1D1FFFFFFFDFDFDFEFEFEFEFEFE
FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF6FFFAE29F9989485468EFF8FF2616201A0A0BACB3BBF0FBFD
FFFFF1BBB2AB0B091FECEFFFF7FFFFF8FFFFFCFBF4FFFFF6FFFFFBFEFEFE
FEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF4D4D4D0E0E0EFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFDFDFDCECECE7E7E7E
6464649F9F9FECECECFFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAFDFDFDFFFFFFFFFFFFFCFCFCC1C1C18D8D8D9999991F1F1F060606
010101010101000000E9E9E9FFFFFFFFFFFFFFFFFFFFFFFFD5D5D5656565
F7F7F7FDFEFFFCFEFFF8FBFFFFFFFBFFFDF4FFFEF6FFF7F4FFFCFFE9E3EB
3132325A5E5DF2F8F8F8FEFAFEFFF3FFFFF3FFFBFE463E47BBBABDF9FAFA
FEFFFFFCFDFDFDFDFDFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFF
C4C4C41414149D9D9DFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCE5E5E5414141
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FCFCFCFEFDFFFFFEFFFAF9FEE0DFE20A0A0A0503040402013F3E3AFDFCF8
FFFEFDF3F1F2F4EFF3FEFCFFFFFEFFFFFFFFFEFEFEFFFFFFFDFDFD6A6A6A
F4F4F4FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFE4E4E4A3A3A31B1B1B0101014B4B4B9C9C9CEAEAEAFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FDFDFDFFFFF8FFFFE9C9C6BB090F27F8F8FFF6DFD9120000D0DCE8F0FFFF
FCFFFFFFFEFBFFFBFFFFFAFFFEFDFFFCFEFFFCFFFBFCFFF8FEFFFDFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFBFBFBF6F6F60C0C0C050505F7F7F7F9F9F9
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9DDDDDD8D8D8D5E5E5E969696E6E6E6FFFFFFFEFEFEFBFBFBFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFEFEFEDFDFDF1A1A1A949494FAFAFA919191
1919194F4F4FE3E3E3FFFFFFFFFFFFFEFEFEFFFFFFB4B4B4828282FFFFFF
F9F9F9FFFEFFFFFBFFFFFCFFFCFAF9FFFFF8FEFFF5FDFEF8D2D1D41F1E23
807E7DFFFEFDFEFBFFFFFEFF8585780A0C00303030AAAAB0FBFFFFFCFFFF
FAFEFFFCFFFFFAFBFDFEFFFFFCFCFCFDFDFDFFFEFFFDFBFCFCFCFAADADAB
121210BABAB8FEFFFDFAFCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFBFDFDFB
FFFEFFFFFEFFFFFEFFFDFCFFC0C0C00F0F0F0100000B090AE8E6E5FFFFFB
9998945A5857A09B9F5B585EE5E4E7FDFCFFF9F8FBDFDFDFFDFDFD7D7D7D
B6B6B6FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFE3C3C3C343434A9A9A95757570C0C0C3D3D3D909090
E7E7E7FAFAFAFFFFFFFBFBFBFEFEFEFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFEFFF9FFFFF1F0F1E9101026E2DAEDFFF7E77B6A58838F9DEEFFFF
F9FFFFFFFFFFFFFDFAFFFCFCFFFAFFFFFCFFFBFFFFF9FFFAFEFFFDFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFBFBFB292929DCDCDCFFFFFF
FBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFBFBFBFFFFFFE5E5E59393936A6A6A828282E3E3E3FAFAFA
FAFAFAFFFFFFFFFFFFFBFBFBECECEC191919909090797979E4E4E4FFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFFFFFFF9F9F9919191A7A7A7FDFDFDFFFFFF
FFFFFFFFFDFFFFFBFFFFFCFFFFFEFDFCFDF5FBFEF5B7B9B3161717A5A5A5
FFFFF8FFFEFBFFFBFFFEF8FFFFFFF4A1A395DCDEDBE8EBEFFBFFFFFAFFFF
F7FBFCFCFFFFFEFFFFF9FAFCFFFFFFFFFFFFFFFEFFFFFEFF898987191917
D1D1CFFFFFFDF7F9F6FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFCFCF8FCFCFA
FFFEFFFBFAFFFFFEFFFFFEFFA9A7A60604030604077B797CFFFBFBFFFEFB
8B87848B8686FFFDFFDEDBE2090A0EFBFCFFFAFBFFBFC0C22F3032161719
EAEAEAFDFDFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF0E0E0E383838FBFBFBFFFFFFF9F9F9B4B4B4676767
0808082F2F2F878787DCDCDCFFFFFFFDFDFDFAFAFAFCFCFCFFFFFFFCFCFC
FAFAFAFFFFFDF5F7F2FFFFFDB7B3BD332A2DFFFDE8978E7D363E50E9F7FF
FBFEFFFFFEFFFDFFF2FFFFF4FFF9FFFFF9FFFBFFFFF8FFFBFCFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E3E3EB2B2B2FFFFFF
FDFDFDFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFF7F7F7EEEEEEA5A5A5656565
7E7E7ED9D9D9FBFBFBFFFFFF949494ACACACF9F9F9FFFFFF585858EEEEEE
FDFDFDFBFBFBFFFFFFFFFFFFF4F4F46E6E6ECECECEFFFFFFFEFEFEFFFFFF
FCFCFCFEFDFFFFFCFFF8F5FCFDFBFAFFFFF898979014130ECECCCBFFFEFA
FFFFF4F7F6F1FFFBFFFEF9FFFFFEF7FBFBEE8F8F8DD9DADCFBFFFFF7FFFF
FBFFFFFCFFFFFAFBFDFEFFFFFFFFFFF8F8F8F5F3F4666465343231EBE9E8
FFFFFDFFFFFDFBFDFAFCFEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFEFEFAFFFFFB
FFFEFFFCFBFFFFFEFFFEFEFE949291020000110F12FFFEFFFBF6F8FFFBF8
DDD9D5120E0BF3EDF4FFFDFF79797F898C91FCFFFFFBFCFFF3F4F8F2F3F5
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFEFEFEADADAD343434272727FFFFFFFCFCFCFFFFFFFAFAFAF6F6F6
FFFFFFC1C1C16A6A6A1919192A2A2A7C7C7CD0D0D0FAFAFAFFFFFFFFFFFF
FEFEFEFFFFFFFEFFFFFEFEFEFDF8FABCB4B166604E61615400000BE7EDFF
FFFCFFFFFEFFFBFFF3FCFFF3FFFBFFFFFAFFFCFFFFF9FFFFFEFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFD
EDEDEDA8A8A8717171707070B1B1B1FCFCFCFFFFFFF7F7F7FFFFFF494949
E7E7E7FFFFFFF8F8F8D5D5D5575757E8E8E8FDFDFDFFFFFFFFFFFFFDFDFD
FCFCFCFDFCFFFEFEFFFEFFFFFFFEFD6864602D2724E6E0DDFDF9F6F8F7F0
FFFFEFFFFFF8FDFBFFFBF9FFFDFDFBFFFFF4FFFBF86E6C6FEDF3F3F9FFFF
FBFFFFEFF5F5FEFFFFFEFFFFFCFCFCF3F3F3484647535152EBE9E8FEFCFB
FFFFFDFFFFFDFDFFFCFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFAFEFFFB
FCFBFFFFFDFFFDFCFFF8F8F854534F0100009C9A9DF8F5FBFFFDFFFFFEFB
FFFDF71F1917E2DBE2FFFCFFA6A9B0454950F9FDFFFCFFFFF9FCFFFEFFFF
FEFEFEFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE
FAFAFAFCFCFC6363638F8F8F000000FDFDFDFFFFFFFFFFFFFFFFFFFDFDFD
F3F3F3FFFFFFF8F8F8FEFEFECACACA7373732B2B2B262626616161C5C5C5
FFFFFFFBFBFBFEFCFDF9F7F8FFFDFFFFFDFCF5FAF3FAFFF9555754AEACAF
FFFAFFFFFCFFF8FFFDF8FFF8FFFFF8FFFDFBFFFEFFFEFFFFFEFDFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCF6F6F6FFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFC1C1C1F8F8F8FDFDFDABABAB7C7C7C6F6F6FBCBCBCF0F0F0FEFEFE
6B6B6B7575755F5F5F333333FCFCFCFFFFFFFBFBFBD8D8D8525252F8F8F8
FFFFFFFEFFFFF6FBFEEBEFF04343434F4949FFF5F4FFFAF9928984030100
7C8067A5ADA0000019DEDFFDFEFFFFD8D5CCFFFCFA857E81B2B6B7F9FFFF
F4FAFAFBFFFFFEFFFFFEFFFFE0E0E0312F306C6A6BFAF8F9FFFEFDFFFEFD
F9F9F7F8F8F6FEFFFBF9FBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFF9FAFCF7
FDFCFFFFFDFFF7F6FBFFFFFF0F0E0A040300FCF9FFFFFDFFFFFBFDFFFEFB
F9F4EE746E6B1F181FF4F0FA878993515860FBFFFFFBFFFFFBFEFFF6FAFB
FFFEFFFAFAFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F90E0E0EEAEAEA151515E6E6E6FFFFFFF6F6F6FFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF2F2F2D4D4D48F8F8F292929
181818616161B3B1B2FFFDFFFEF9F9FBFBFBF9FFFFF9FFFD64635C544E4B
FFFBFEFFFDFFF8FFFFF8FFFDFFFFF6FFFEF8FFFDFFFFFDFFFEFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF4F4F4
F8F8F8FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
777777878787FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C58C8C8C707070
7474746A6A6A808080FDFDFDFFFFFFF8F8F8FEFEFEECECEC101010FFFFFF
FFFFFFF8F9F9E2E6E5222625716F70FCF5F8FFF6F8FFFCFA575048C0BEAD
DDE1C4000300555674C5C5E9F7F7FDC5C4BD342C2A0E070AEBEFF0F0F9FB
F9FFFFFBFFFFF7FBFCD0D1D31A18198E8C8DFFFEFFFBF9FAFFFEFDFFFEFD
FFFFFDFFFFFDFEFFFBFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFAFEFFFB
FFFEFFFFFDFFFFFEFFFBFBFB0100006F6E6AFFFCFFFDF7FFFFFCFEFFFEFB
FFFBF3D1CBC8040004605C6600020BBFC7CFF0F7FFF9FDFFFCFFFFFCFFFF
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
F9F9F9AAAAAA434343F8F8F8FFFFFFFAFAFAFBFBFBFFFFFFFBFBFBFCFCFC
FFFFFFFAFAFAFFFFFFF7F7F7FDFDFDFBFBFBFFFFFFFFFFFFF9F9F9FFFFFF
DFDFDF9292923F3C420B090C5F5D5CA7A9A4EBF1EFEDF3F1B3B1B0A39F9C
FFFEF7FFFFF8FCFFFFFCFFFFFFFFFAFFFEF9FFFDFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFFFFFF
FCFCFCFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEF5F5F5FCFCFC5B5B5B
414141EDEDEDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFDFDFDFFFFFF0E0E0EF2F2F2
FCFCFCC7C7C7151513929290FFFEFFFFFEFFFAF5F7FFFEFB6464588F907C
FFFFE49A9A8D0B0527FEF7FFFBF7FFFFFFFAFFFEFBFAFAF8FBFFFFF8FFFF
F4FCFEF6FBFEB7BBBC141517ADABACFFFEFFFEFCFDFFFEFFFFFEFDFFFEFD
FFFFFBF6F6F2FDFFFAFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFFBFCFEFB
FFFEFFFCFAFFFFFEFFBFBFBF010000F8F7F3FFFCFFFFFCFFFFFDFFFFFEFB
FFFCF6F3EDEA231C21F2EEF8FCFEFFF5FCFFFBFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFDFDFDFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA4A4A4CECECEFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FBFBFBFFFEFFFFFEFFE5E4E797979550524D0206034B4F4EA2A0A1EEECEB
FFFFF5FFFFF6FFFFFDFFFFFFFFFFFBFFFEFAFFFEFDFFFEFFFFFFFFFEFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFB2B2B2505050
F4F4F4FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFFFFFF
FEFEFEFEFEFEFEFEFEFCFCFCFFFFFFFFFFFF797979989898212121D3D3D3
A6A6A6131313B8B6B5FFFEFDFEFCFDFEFEFEFFFFFFFCFCF8BDBEB43D3E2C
FFFFE5FDFAEF130A27DDD5F8FFFCFFFDFDFBFDFDFBFEFFFFFAFFFFF4FCFC
FBFFFF9A9DA1101113C8C8C8FFFEFDFFFEFDFFFEFFFAF9FCFFFEFFFEFCFB
F4F4F2FFFFFDFEFFFFFDFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFDFFFEFDFFFDFFFFFDFFFFFDFFFFFCFC
FFFDFDF0EAEA20191CC0BAC1FCFAFFFDFDFFFEFEFFFBFBFFFDFEFFFFFEFF
FEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFEFDFFFFFFFFFFFFFDEAEBEBABABAB525051100E0D
41403C94938FE5E3E2FFFEFDFFFEFDFFFDFCFFFEFDFFFFFFF9FDFEFCFFFF
FFFEFFFBFAFDFCFFFFFCFFFFF9F9F7FFFEFDFFFCFCFFFEFDFEFFFDFDFFFC
FEFCFDFFFEFFFEFFFFFEFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFDFDFDFEFEFE
FCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFCFCFCFFFFFFDADADAFFFFFF
F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBF6F6F63E3E3E1C1C1C979797
1E1E1ED3D3D3FEFFFFFEFFFDFAFBFBFEFEFCFFFFFDFBFAF6FEFDF6605D54
959287FFFDF9524E589B97A5FEFDFFFEFFFFFEFFFFF8FBFFF8FCFBFCFFFF
71727626272BDFDFDDFDFCF7FFFEF8FEFAF6FFFEFFFAFBFFFDFBFEFFFEFF
AEAEACB3B4B4FCFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFF8F3F5FFFDFFFAF5F7
FFFBFEDDD6D9A69FA2C4BFC3FFFCFFFDFBFFFBF9FFFFFEFFF9F8FDFEFEFE
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFCFBFBF9F8
B2B0AF5C5A591917162E2C2B858382DFDDDCFFFEFDFEFEFEF9FDFEFCFFFF
FFFDFFFFFEFFFCFFFFF3F9F7FFFFFDFFFBFBFFFDFDFFFFFDFCFFFDFCFFFD
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFE5E5E5FAFAFAFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEE3E3E30F0F0F4C4C4C
EDEDEDFDFEFEF8F9F9F6FAF9FEFFFDFEFFFDFBFAF6FEFDF9FFFEFAFFFEFA
8F8B88726E6B171516525154FBFAFFFCFCFFFBFEFFFCFFFFF3F7F6525451
3F3E43ECEAEDFFFFFBF8F5EEFFFEF4FFFEF7FBFEFFFCFEFFE8E6E9A09B9B
8985822D2D2DD6DAE5F4FAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFBF9FAFFFDFFFFFDFF
989194D9D2D5FFFBFEFFFCFFCDC9D392909BFFFDFFFEFDFFFEFDFFFDFDFD
FFFFFFFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFDFC
FDFBFAFFFEFDF7F5F4C8C6C56969691515152828287B7B7BC9CDCCFEFFFF
FBF9FAFFFEFFF3F7F6FBFFFFFCFCFCFBF9FAFFFEFFFDFDFDFAFEFDFAFEFD
FFFCFEFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCFBFBFBF9F9F9
FBFBFBFFFFFFFBFBFBFFFFFFCECECE747474FFFFFFFEFEFEFFFFFFFDFDFD
FCFCFCFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFE6D6D6D0A0A0A
C7C7C7FEFFFFFEFFFFFCFFFFFEFFFDFCFEFBFFFFFBFDFCF8FFFEFBFFFCF9
FFFDFAFCF8F5F9F7F8010003E9E8EDFEFEFFFCFFFFE6E9EE363C3C5A5E5D
F4F2F5FBF6F8FFFEFBFFFFF6FFFCEEFFFFF8F4FAFFF8FBFFFFFDFF4F4840
DBD4CC666463D7DDE9F8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF8F9FFFEFFFAF5F7FDF8FA
F2EBEE3B3437FFF8FBFDF8FC2B2731E7E5EEFFFEFFFFFEFFF6F5FAFFFEFF
FDFDFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFFFFFEFDFFFDFC
FFFEFDFFFEFDFEFCFBFCFCFCFFFFFFFFFFFFC9C9C97475752324241F1F1F
726D6FC2BDBFF9FDFCFBFFFFFFFFFFFFFEFFF9F7FAFEFEFEFBFFFFFCFFFF
FFFDFFFFFCFFFFFFFFFDFEFEFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFF
FDFDFDFFFFFFFBFBFBBBBBBB151515CDCDCDFFFFFFFCFCFCFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFA9A9A93C3C3C
1F1F1FE8E9E9F8F9F9F5F9F8FEFFFDF2F4F1FFFFFBFFFFFBFDF9F6FFFEFB
FFFEFBFFFDFDF3F1F2202020B6B5BAF6F7FBE0E3E81E2126767C7CF6FAF9
FFFEFFFFFDFFFFFBF8FEF9F1FFFFEDFFFEF7F1FEFFF2FCFFFFFDFDFAEBE3
83796D8A8683BDC4D2F7FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFAF8F9FFFDFFFFFDFF
FFFDFFA7A2A49A9597979296ACA9B0FFFDFFFBFAFFF4F3F8FDFCFFFFFEFF
FDFDFDFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
F6F6F6FFFFFFFFFFFFFBFCFEFEFFFFFEFFFFF9FAFCFEFFFFFFFFFDCDCBCA
888282342F31171B1A5E6464B5B6B8F5F4F7FFFEFFFDFEFFF5FBFBFCFFFF
FFFDFFFDF6F9FBF9F8FFFFFDFDFDFDFEFEFEFEFEFEFDFDFDFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFFFFFFFFFFFFF7F7F7FEFEFEFFFFFFFCFCFCFBFBFB
FFFFFFFDFDFDE6E6E60F0F0FC8C8C8FFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFCFCFCFFFFFFF3F3F3858585FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C5303030
7B7B7B363737FCFDFDFCFFFFFCFEFBFEFFFDFDFBFAF8F6F5FFFEFBFFFBF8
FBF6F6FFFBFBE1DFE09D9D9DBCBBC0CACBCF0C0F149DA0A5FBFFFFFCFFFF
F8F7FAFFFEFFFEFEFAFFFEF4FFF6E7A19893000A1DC3DCF0F8EFF0FFF9EF
FFF7EC221C195D6675F2FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFCFDFDF8FAFFFDFF
F7F2F4FFFDFF2D282A444245FEFBFFFFFEFFFFFEFFFFFEFFFFFEFFFEFDFF
FFFFFFFCFCFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFFCFCFCFEFFFFFEFFFFFBFCFEFEFFFFFEFFFFFDFDFDFFFEFDFFFEFB
FFFAFBFFFBFBD6DAD98C9292424347111015555459A9AAAEF0F5F8FCFFFF
FFFAFCFFFCFFFFFEFDFBFBF9FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FFFFFFFEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFEFEFEFFFFFF
F6F6F6FFFFFFAAAAAAD7D7D7FFFFFFF9F9F9FEFEFEFFFFFFFEFEFEFFFFFF
FBFBFBFBFBFBFFFFFFB3B3B3464646FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFEFEFEE6E6E61A1A1A
FEFEFE535353626363FCFFFFF8FAF7FCFCFAFAFAF8FFFEFDFFFEFBFFFCF9
FFFDFDFFFEFDFFFEFFFFFFFFA9A8AB0E0F13B9B9BFFCFFFFFCFFFFFCFFFF
FDFCFFFFFEFFFCFBF7FFFEF6FFFBEDBAB1AC3C51649DB3C8FFFCFDFFF1E6
FFF7EBFFFCF9636C79EDFAFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFEFCFDFCFAFBFFFEFF
FFFEFFFFFEFFE8E3E5E9E7EAFEFBFFFAF9FFFEFDFFFFFEFFFCFBFEF9F8FB
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFBFAFEFCFBFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFBFCFE
F9FAFCFEFFFFFEFFFFF9FAFCFCFDFFFDFEFFFBFCFEFFFFFFFEFAF7FFFDFA
FFFCFBFFFDFDFCFFFFF6FCFCEFF2F6EBEBF197979D4245490D1517424848
ABA6A8EDE6E9FFFCFCFFFEFDFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFBFBFBFFFFFFF8F8F8
FFFFFFF8F8F8F6F6F6FFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFBFBFBFFFFFF
FAFAFAFFFFFFFFFFFF5A5A5A919191FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFF303030
F3F3F3F4F4F42E2F2F8A8B8BFFFFFFFFFFFFBDBDBBC0C0BEF7F5F4FFFEFD
F7F5F4FFFEFDFFFDFE7F7F7F242326D2D3D5FCFDFFFCFFFFFBFFFFF7FBFA
FCFAFDFFFCFFFFFDFDFCF7F1FFFFF1E9EAE2080D1EEFF1FFFFFDFFFFFDF4
FFFDF2F9F8F4F5FBFFF8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFEFFFFFEFFFFFDFE
FEFCFDF9F7F8FFFDFFFCFAFDFFFEFFFFFEFFFFFEFFFAF9FCFFFEFFFFFEFF
FDFDFDFDFDFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFCFCFCFCFCFCFEFFFFFEFFFF
FEFFFFFCFDFFFCFDFFFEFFFFFEFFFFFEFFFFFDFEFFFEFEFEFFFEFBFFFBF8
B6ACAB0E0808DFE3E2FBFFFFFCFFFFFBFBFFFEFEFFFBFEFFE5EDEFA8AEAE
4B464A140D10454040999796EDEDEDF8F8F8FFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFEFEFEFBFBFBFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFF4F4F4969696
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFDFDFD101010E8E8E8FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
F9F9F9FFFFFFDBDCDC1A1B1BB9B9B9FCFCFCA2A2A05A5A58FFFEFDFFFEFD
FFFEFDF5F3F2676767353535DFDEE1FFFEFFFEFFFFFDFEFFF9FDFAFCFFFD
FFFEFFFFF9FFFFFCFCFFFEFAFBFCF2FFFFFA27232DCAC6D4FCFAFDFEFDF9
FDFEF8FEFFFDF4F8FFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FEFFFFFDFEFFFAFBFDFEFFFFFBFBFBFEFEFEFAFAFAFFFFFFFEFDF9FFFEFB
FFF6F7635D5DF0F4F3FBFFFFFBFEFFFEFEFFFEFEFFFCFFFFF6FEFFF6FCFC
FFFDFFF7F0F3AEA9A95D5B5A131313383838898989DADADAFFFFFFFFFFFF
FBFBFBFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFEFEFEF4545458E8E8E
FCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFC3C3C32E2E2EFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFC2C3C3151515DBDBDBBCBCBC444444FCFAF9FFFEFD
F7F5F64341424C4C4CF8F8F8F1F0F3FFFEFFFEFFFFFEFFFFFFFFFBFFFFFD
FCFFFFFCFFFFFEFFFFFFFFFDFFFDFDFFFDFB94908D767475FFFEFFF8F8FE
FCFFFFFBFFFFFCFFFFFDFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEF9F9F9
F9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FBFCFEFDFEFFFDFEFFFFFFFFFFFFFFFFFEFDFFFEFDFCFAF9FFFFFDFFFEFD
FFFDFD9B9698B7BBBCFBFFFFF9FCFFFEFFFFF9F9FFFCFFFFF9FFFFFBFFFF
FFFDFFFFFCFFFFFEFDFFFFFDF4F4F4BDBDBD6969691212123131317B7B7B
D2D2D2FFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FBFBFB353535686868FFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFF8F8F8
FBFBFBFFFFFF717171858585FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FAFAFDFEFE9B9B9B292929D9D9D9191919FFFEFDE0DEDD
2A2829706E6FFCFCFCFEFEFEFFFEFFFEFDFFF8F9FBFEFEFCFFFFFAFFFFFB
FCFFFFFBFFFFFCFFFFFEFFFFFFFDFFFFFDFDE4D7CE190E08F1F1F9F8FFFF
F5FFFFF6FDFFFFFFFFFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF7F7F7FFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFF7F7F7FCFAF9FFFEFBFFFBF8F5F4F0FCFDFDF8F9F9
FFFAFCDEDCDF6B7171F5FDFDFEFFFFFAF9FCFFFEFFFDFEFFF8FEFEFCFFFF
FFFBFDFDF6F9F9F7F8FCFCFCFFFFFFFBFBFBFCFCFCFFFFFFC6C6C6727272
2020201F1F1F757575CACACAF8F8F8FFFFFFBDBDBD7C7C7CFFFFFFFAFAFA
FFFFFFF6F6F6FBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFF181818DADADAFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF646464414141090909DCDCDC1C1C1C
8F8F8FFFFFFFF9F9F9FFFFFFF8F8F8FFFFFFFFFFFFFDFDFBFFFFFAFFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF5FFFFFCFFFFFFEBE13A1D17DEE0EAE9FCFF
F0FFFFF3FFFFFFFBF8FFFCF9FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFF000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FCFDFFF7F7F7FFFFFFFFFEFDFCF8F5FFFDFA9A949114100DCCD0D1FAFFFF
FFFEFFFCFBFF545A5AF3FBFBFEFFFFFFFDFEFCFAFBFEFEFEFCFFFFFCFFFF
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF6F6F6FAFAFAFFFFFF
F9F9F9D1D1D17878782A2A2A1B1B1B6D6D6DA0A0A0FFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFF8F8F8FBFBFBFBFBFBFFFFFFFDFDFDFFFFFF8F8F8F
666666D4D4D41C1C1CFDFDFDFEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFAFAFAFBFBFBFFFFFF444444080808585858ADADAD
FEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFDFFFFF8FFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF4FFFFFCFFFFFFF1E733140F9FA1ABEEFFFF
F0FFFFF4FFFFFCF8F5FFFDF8FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFF
F8F8F8000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFFFFFAF8F7FFFCF9FFFDFAFFFCF7B5ACA5494541B1B6B9F7FFFF
F7FAFFD2D2D8171F21C6CCCCFBFBFBFFFDFDFFFDFDFFFEFDFCFFFDF8FCFB
FDF8FAFFFCFEFEFFFFFAFEFFFCFDFDFBFBFBFFFFFFFEFEFEFBFBFBF8F8F8
FFFFFFFEFEFEFFFFFFCDCDCDDADADA8C8C8C3737370B0B0B616161B1B1B1
EEEEEEFFFFFFFBFBFBFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEF6F6F6B4B4B4
5353538585856F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF1F1F10B0B0B666666FDFDFD
FFFFFFFFFFFFF8F8F8FCFCFCFCFCFCFEFEFEFFFFFDF8F8F4FFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFEFFFFFCFFFFFFFEFFEBD7CEB7A39EABADB7F1FDFF
F4FFFFF8FFFFFFFFFBFDF7F4FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFA070707FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFFFCF9FDF5F0FFFDF6F7ECE4110B08EDF4F8F6FFFF
FBFFFFFBFEFFF7FFFFF4FAF8FEFEFCFFFEFBFFFDFBFFFDFAFCFEFBFEFFFD
FFFDFFFFFEFFFCFFFFFAFEFFFCFDFDFFFFFFF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDA7A7A7535353FBFBFBFFFFFFFBFBFBE3E3E39E9E9E3E3E3E
0F0F0F5858589F9F9FEAEAEAFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFCBCBCB
2F2F2F2F2F2FC1C1C1F9F9F9FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FCFCFCFEFEFEFEFEFEFCFCFC4F4F4F060606CACACA
FAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFDFFFFFBFFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFFFEFFFFFEFFFFFCFFFFFBF6FFFBFAFEFEFFF8FFFF
F2FBFEF9FFFFFCFCFAFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEF8F8F8FFFFFF
FFFFFF000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFDFBFAFFFBF8FFFDFAFFFDF6FFFBF3FFFAF22C2623BDC7CCF4FFFF
F4FAFFFBFFFFF2FBFDF9FFFFFFFEFDFFFDFBFFFDFBFFFEFAFEFFFBFEFFFD
FFFBFDFAF8F9FBFFFFFBFFFFFCFDFDFFFFFFFFFFFFEFEFEFFFFFFFFEFEFE
FCFCFC8E8E8E191919EBEBEBFFFFFFF6F6F6FFFFFFFFFFFFFDFDFDFFFFFF
E9E9E9A0A0A05454540404044C4C4C919191E1E1E1FFFFFFFEFEFEF1F1F1
070707111111FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFF0F0F0FFFEFF84838658595B17181A
E8E9E9FDFEFEF6F6F6FFFFFFFFFFFDFFFFFDFBF9F8FCFCF8FFFFFAFFFFFD
FEFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFEFFFFFBFDFFF9FDFCFBFFFBFFFF
F4FAFAF8FEFAFEFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FCFCFC050505FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFEF9F3FFFEF6FFF9F0FFFDF394908C747D82F3FFFF
F9FFFFF9FDFFF9FFFFFBFFFFFFFEFDFFFEFBFFFDFBFFFEFBFEFEFAFDFFFC
FFFEFFFFFEFFFCFFFFF9FDFEFEFFFFF5F5F5FFFFFFFFFFFFFBFBFBFDFDFD
E2E2E2272727E5E5E5FBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFF3F3F3AAAAAA5E5E5E0D0D0D3C3C3C8D8D8DE4E4E4
0E0E0E515151FEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFF7F5F6FFFFFFFFFFFFFAF9FC99989B5C5D5FB3B4B6
717272FCFDFDFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFFFDFFFFFBFEFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFEFFFFFCFFFFFAFFFFFEFFF9FDFE
FCFFFDFCFFFDFAFBFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFBF8FFFFF8FFFDF5FFFEF4FFF9EEDDD9D50F0F17F8FAFF
FBFAFFFEFEFFFDFDFFFEFFFFFAFAFAFFFEFDFFFDFCFFFEFDFFFFFDFFFFFD
FFFFFFD2D2D2A7A8AAFEFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
CFCFCFEEEEEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFF1F1F1B9B9B96464643B3B3B
0D0D0D8B8B8BFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFBEBEBE444444FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFDFFFEFBFFFEFAFCF9F0FFFDF2FFFEF4FAF6F2221F26DDDBE8
FFFDFFFFFDFFFDFCFFFFFEFFFFFEFFFEFEFEFFFFFDFFFFFDF7F7F5FCFCFA
FFFFFFECECEC141316F9F8FBFFFFFFFFFFFFFBFBFBF7F7F7FCFCFCFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFDFDFDF7F7F7
010101A1A1A1FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFBFBFBD5D5D5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFDFEFFFEFDFFFEFBFFFEFAFFFCF5FFFFF6FFFFF4F3EFEB1F1C239F9DAA
FEFCFFFFFDFFFDFCFFFEFDFFFFFEFFFFFFFFFFFFFDFCFCFAFFFFFDFFFFFD
FFFFFFFBFBFB2E2D30C0BFC2FAFAFAF9F9F9EFEFEF5F5F5FFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFFA5A5A5
2121218A8A8AFCFCFCFFFFFFF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFEFCFDFDF8F8FFFEFBFFFEFAFFFFF8FDFAF1E5E4DFA29FA6C2C0CB
FCFAFFFDFCFFFFFEFFFEFDFFFEFEFEFDFDFDFAFAF8FAFAF8FFFFFDFAFAF8
FAFAFAFFFFFF7C7B7E79787BFFFFFFD8D8D82828289E9E9EFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFBFBFB606060
555555696969FFFFFFF9F9F9FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFEFFFEFDFFFDFAFFFCF8FFFEFAFAF9F5FFFDFFFDFCFF
FFFEFFFFFEFFFFFEFFFDFDFDFEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFBFAFDC3C2C5343336EDEDED1C1C1C999999FEFEFEFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC131313
959595525252FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFEFFFFFEFFFFFEFF
FDFBFEFFFEFFFFFEFFFFFEFFFFFDFDFFFBF8FFFEFBFFFEFDF7F6F9FFFEFF
FCFBFFFFFEFFFFFFFFFEFEFEFEFEFCFFFFFDFFFFFDF5F5F3FFFFFDFFFFFF
FCFBFEFFFEFFFFFEFF0B0A0D858585BABABAFFFFFFFFFFFFFFFFFFFAFAFA
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFBFBFBFAFAFAFEFEFEC5C5C54A4A4A
E5E5E5717171F4F4F4FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FDFCFFFFFEFFFCFAFDFFFEFFFFFEFFFEFCFBFFFDFCFDFBFCFFFFFFFFFEFF
FAF9FCFFFFFFFFFFFFFFFFFDFFFFFDFBFBF9FEFEFCFFFFFDFFFFFFFCFCFC
F7F6F9FFFEFFFFFEFF535255191919A2A2A2FBFBFBFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666666888888
FEFEFEFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFEFCFFFFFEFFFFFEFFFDFBFCFFFDFEFFFEFFFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFCFCFCFAFCFCFAFFFFFDFFFFFDFFFFFDFEFEFEFFFFFF
FFFEFF9D9C9FFEFDFF98979A4C4C4C181818A7A7A7FFFFFFFFFFFFFBFBFB
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFEFEFEFBFBFBFDFDFDFDFDFDF9F9F90F0F0FE7E7E7
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFEFEFCFFFFFDFFFFFFF5F5F5
727174535255FFFEFFDFDEE1171717D6D6D6171717999999FFFFFFFEFEFE
FAFAFAFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFADADAD414141FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDF9F9F7FEFEFE606060
3C3B3EEFEEF1FEFDFFFFFEFF252525C7C7C7E5E5E51D1D1D979797FBFBFB
FFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFCFCFC989898BDBDBDFFFFFF
F9F9F9FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFDCDCDC4C4C4C
F9F9F9FFFFFFFFFFFFFCFCFCA2A2A2B0B0B0FCFCFCE0E0E0242424676767
F6F6F6FFFFFFFCFCFCFDFDFDFFFFFFF7F7F7F8F8F8FCFCFCFFFFFFFFFFFF
FCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFEFEFEFCFCFC
FFFFFFF8F8F8FAFAFAFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFEBEBEB646464
1F1F1FD0D0D0FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFF8F8F8FCFCFCFEFEFE
FFFFFFFDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFDFFFFFEFFFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFBFBFBFCFCFCFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF
A3A3A3181818949494F8F8F8FFFFFFFCFCFCFCFCFCFBFBFBFFFFFFFFFFFF
FCFCFCFDFDFDFDFDFDFFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFAFAFAFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF7F6F9FFFFFFF9F9F9
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FAFAFAFFFFFFFCFCFCFDFDFD
FEFEFED8D8D83131315C5C5CDCDCDCFFFFFFFFFFFFFFFFFFF7F7F7FDFDFD
FDFDFDFFFFFFA2A2A2CECECEFFFFFFEFEFEF696969F8F8F8FFFFFFFFFFFF
F8F8F8FFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFAFAFAFFFFFFFAFAFAFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFE7474741313136C6C6CEAEAEAFDFDFDFFFFFFFCFCFC
FFFFFFFCFCFCBEBEBE2B2B2BFDFDFD898989666666FFFFFFFFFFFFFBFBFB
FDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFDFEFFFDFEFFFDFFFEFFFFFDFFFFFEFFFFFFFF
FFFFFFFEFFFDFEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFEFDFFFFFEFFFCFCFC
FDFCFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFF9F8FBFFFFFFFCFCF8FDFEF8
FFFFFBF9F9F9FCFDFFFEFFFFE8E6E9716F72121315808181F5F5F5FEFEFC
FAFAFAFFFFFFFBFBFB292929C1C1C1323232BFBFBFFEFEFEFEFEFEFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFCFFFBFBFFF8FCFFFBFFFCFFFFFBFFFCF9FFFFFFFF
F8FAF7F9FEF8FCFFF8FEFFFAFFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFFFDFFFFFBFEFFFBFEFFFDFEFFFFF9FAFCFBFCFEFEFFFF
FBFCFFFEFFFFFCFBFEFEFEFEFEFCFDFFFEFFFBFBFFFEFFFFFEFEF1FDFEEC
FFFFF6FEFFFDF9FDFFFCFEFFFFFCFFFFF9FFD8DDE15159591A1A188D8C88
E5E5E3FFFFFFFFFFFF9696963D3D3D202020F9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFBFFFBF9FFF8FBFFFBFFFCFFFFFBFFFFFCFFFFFFFF
FEFFFDFCFFFBFBFFF7F4F6F0FFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFEFFFFFEFFFFFEFFFFFEFFFF
F7F8FCFFFEFFFFFEFFFFFEFFFFFDFDF9F7F8FBFEFFFCFFFFF9F9EDEBECDA
0B0C02414542293038F1F3FFFEF8FFFFFCFFFBFFFFF9FFFFCDCDCD605E5D
0F0F0F4A4A4AA4A4A4EFEFEF101010CFCFCFFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFCFFFFFBFFFDFCFFFDFFFEFFFFFDFFFFFEFDF9F9F7
F7F8F8FCFFFFFCFFFDFEFFFDFFFEFFFFFBFDFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFDFCFFFFFEFF
FDFCFFFFFEFFFFFEFDFCFBF7F1EDE99C9A999B9EA5A5A8AFFFFEFFFFFFFA
DFE4DD9FA5A1E8EAF4FCFCFFFCFBFEFFFFFDF9FDFCFCFFFFFFFEFFFDFCFF
FAF9FC9D9D9D4C4C4C0F0F0F383838717171FFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFEFFFFFDFFFFFEFDFFFEFD
FEFFFFFEFFFFF8FCF9FEFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFBFAFDFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFDE3E1E2101115D5D5DBFFFDFFFDFCFF
F7FBF8DADEDD8E8E96F9F9FFFEFFFFFBFDFAF7F8FAFEFFFFF8F9FDFFFEFF
FFFEFFFDFDFDFFFFFFE2E2E2919191141414EEEEEEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFEFFFEFFFBFCFFFAFCFFFBFEFFFDFFFEFFFFFDFFFCF6FDFFFEFF
FDFFFAF8FDF6FEFFFAFEFFFBFDFBFEFFFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFCF8F5FFFFF8FFFDFDFBF7FFFEFAFF706C69A09F9BFDFDFFFCFFFF
FFFEFFFFFFFFC4C7CC95989DFDFEFEFEFFFFFBFBFFFEFEFFFEFFFDFEFFFB
F5F5F3FFFFFFFFFFFFEEEEEEF6F6F6515151969696FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFFF8FFFFF6FFFFF8FFFFFBFEFFFFFEFEFFFFFDFFFFFEFF
FFFFFAFFFFF4FFFFF6FFFFFBF8F9FDFEFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFEFDFFFFFEFFFFFEFFFDFBFC
FFFDFAFFFEFAFFFDF5DAD5D500000E2621318D858266615BF5FCFFF9FFFF
EBE6E8FBF6F6E7ECF03B4248F7F8FCF7F6FBFDFBFFFEFEFFFDFFF9FBFEF5
FFFFFDFEFEFEFBFBFB151515E6E6E6C0C0C0272727FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFCFFFFFFFFF6FFFDF3FFFBF6FFFCFAFBFFFFF7FFFFF9FFFFF8F8FE
FFFFF8FFFDF2FEF3EBFFFDFBFBFFFFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFAFEFEF9FB
FFFDFBFFFEF8FFF8EEBBB7B4090818FFFBFF2A1B1E18100EE2EEF8F5FFFF
FFFDFA685E5C00010989929FFFFDFFFFFCFFFEFEFFFAFEFFFEFFFAFFFFF8
FFFFFDFBFBFBB5B5B5393939FDFDFDF8F8F83B3B3BB1B1B1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFBFFFFFFFEF8FFFCF4FFF9F6FFFBFAF9FFFFF5FFFFF5FCFFFEFFFF
FDFAF390877E1C0E0B352D2BA3ABADF7FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFEFBFFFFFCFFFFFDFF
FFFDFAFFFDF5FFFEF3CDC9C5100F1FFAF5FFFAEAEB070000C7D7E4EEFEFF
FFF7F9FFFBFAEDF7FEF2FFFFFBF8FEFFFCFFF7F8FCF8FCFDFEFFFBFEFFF9
FFFFFDFEFEFE5656569C9C9CFFFFFFFFFFFFCCCCCCA5A5A5FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFAFCF9FEFDF9FFFDFAFFF9FAFFFCFBF9FDFCF9FFFFFFFEFFFFFDFF
FFFEFDF9F8F4AEA5A6DCD5D8E5EBEBF9FFFFFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFBFFFFFDFF
FFFDFAFFFEF6FFF9EEF8F4F011101ED6D2E0FFFBF49289847B8A9FEEFCFF
FFF8FFFFF9FFF7FFFFF4FFFDFFFFF8FFFDFAFEFEFFFCFEFFFEFFFFFFFFFB
FDFDFBFAFAFA5B5B5BF4F4F4FEFEFEFCFCFCFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFBFAFFFEFDFEFFFDFFFEFDFFF9F8FFF8F6FEFFFFFCFDFDFFFCFDFFFAFB
FAFBFBFCFFFFF7F5F68F8D8EE1E5E6F6FAFBFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFBFFFFFCFE
FFFDFBFFFEF8FFFDF3FFFBF7B4B4BE16121CFFF4ECB6AEAC212B42F5FEFF
FFF7FFFFFBFFF8FFFFF7FFFAFFFFF4FFFFF8FEFEFFFCFFFFFEFFFFFFFFFD
FFFFFFFEFEFEFFFFFFF9F9F9FFFFFFFDFDFDF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFBFEFFFDFFFAFEFDFCFEF9FFFEF8FFFDFAFEFDFFFFFCFFFEEFF4FFFBFD
F9FDFEF6FFFFFEFFFDF8F8F66E6F73F0F1F5FFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFEFDFFFFFDFFFFFDFE
FFFEFBFFFEFAFFFEF6FFFEFAFFFEFFB1AEB4685F60696269373C50E8EDFF
FFFBFFFDF8F8FBFFFFF9FFFFFEFFF8FFFFF8FFFFFDFEFFFFFEFFFFFEFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFBF9FCFCFDFDFFFFFBFFFAEF524944BFBFC9FAF7FFA3939B100406
E6E9EDF6FEFEDFE0DAFFFFFB7A7D82B6B9C0FEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFFFEFBFFFFF8FFFEFAFFFEFFFFFEFFFEF9FDFFFDFFFEFDFFFAFCFF
FFFFFDFFFFFBFCFFFFFCFFFFFEFFFBFEFFFAFEFFFDFEFFFFFEFFFFFEFFFF
FFFFFFFDFDFDF8F8F8FEFEFEFBFBFBFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FEFFFFFEFFFFFFFEFFFFFDF8FFF7E9B3A49D474A59F8FEFFA9A2A94C4143
BEBDC2FBFAFDCAC1BA36312B00060EE4EDF8FCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFFFBF9FCFEFFFFFEFFFFF2F0F1FFFFFF
FCFFFBFAFEFBFEFFFFFEFFFFFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
F7F6FBFFFEFFFFFEFFFDF7F4FFFBEDEBDCD5000012D4D8EFE6DDE0170D0C
FCFAFFF9F9FFFFFDF5F8F3EDF2F9FFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFDFFFFFBFFFEFAFEFDF9F6FAFBF9FDFEFFFFFBFFFFFA
FCFFFBFAFFFCFCFFFFFEFFFFFFFFFBFFFFFBFCFFFFFCFFFFFFFFFFFFFFFF
FAFAFAFFFFFFF1F1F1FFFFFFFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
FFFBFDFBF4F7FBFFFFFBFFFFFFFFF1FFF8F11B162A1B1129FFF2F42D1B19
CFD5E0F4FFFFFBFFFBFFFFFAFDFBFFFEFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFDFEFEFDFEFFFEFFFFFEFFFF
FEFFFFFFFEFFFFFEFFFFFFFAFFFEEFFFFFF4F8FBFFF8FAFFFFFEFFF9F8F4
FEFEFCFCFFFFF9FFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FFFEFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFD
FFFBFBFFFAFBFBFFFFF9FFFFFAFAEDFFFEF6776F824A3C51A28D8A2D1E19
B5BDC8F1FFFFF8FFFFF9FBF6FFFCFFFFFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFBFEFFFBFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFEFFFFFFFBFFFFF1FBFBEEFEFEFFFEFEFFFBF9FAFFFFFB
FFFFFDFAFBFBFBFFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FCFBFFFEFEFEFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD
FFFDFAFFFBFBFFFEFFFDFCFFFFFEF2D3CEC45E5A68958E9DC5BDB8040100
C3C9D5F8FFFFF5FBF9FBFDF8FFFEFFFBFAFFFDFCFFFFFFFFFFFFFFFBFBFB
FFFFFF000000FCFCFCFFFFFFFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFDFFFFFAFFFFFBFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFBFFFFFBFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FBFAF6FFFEFDFEFDFFFFFEFFFFFCF1FCF7EFFFFDFFF5F5FFFFFFFAFFFFFB
FBFEFFF1F7FFFEFFFFFFFFFBF7F8F8FEFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFF000000FFFFFFF9F9F9F7F7F7FFFFFFFFFFFFF9F9F9FBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFDF7F8FAFDFBFCFFFDF6FFFDF8FDFDFFFCFEFFFFFEFBFEFCFB
F9FFFFF5FDFFFEFFFFF8F7F3FFFFFFFEFFFFFDFDFDFFFFFFFEFEFEFFFFFF
F3F3F3000000FFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFCFBFFFFFDFEFFFFFFFEFDFFFCF7A09895C5C5CBF9FCFFFEF9FBCFCDCE
888F97F8FFFFFDFEFFFFFEFDFFFFFFFCFDFFFFFFFFF9F9F9FFFFFFFBFBFB
FFFFFF020202FCFCFCFDFDFDF6F6F6FFFFFFF6F6F6FFFFFFFCFCFCFCFCFC
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFEFDFFFAF8F0EAE8343336FEFFFFFFFDFF28272C
EEF2F9F6FDFFFBFCFFF8F8F8FFFFFFFDFDFDFFFFFFC8C8C8FFFFFFF9F9F9
FDFDFD000000FFFFFFFCFCFCF9F9F9DCDCDCFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEF9F9FFFDFDFFFDFDFFFDFDACA7A9979598939498A4A7AC
FCFFFFFBFEFFFCFFFFFCFFFFFDFDFDFFFFFFF9F9F9000000484848FEFEFE
FEFEFE050505FFFFFFF0F0F0101010696969FCFCFCFFFFFFFDFDFDFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFFFFFFFFFDFBFCF6F4F6F7F7FDFDFDFFFCFB2E25263E4549F6FFFF
FFFEFFFEFBFFF9FEFFFBFFFFFFFFFFFBF9F8FFFFFF959595040404545454
FEFEFE000000D7D7D7141414000000E9E9E9FAFAFAFFFFFFFBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FBFFFFFFFFFFFFF7F5FFFDFBFCFFFFFEFFFFFFF6F5F2E8E7E3ECF1F7FFFF
FFFEFFFFFBFFFBFFFFF5FDFFFBFBF9FFFEFBFFFEFDFCFCFC121212000000
3434340606060D0D0D060606707070FDFDFDFFFFFFFBFBFBFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFDFBFCFFFFFEFFFFFFFBFAFFFCFBF8FFFFF7FFFF
FFFEFFFFFDFFFBFFFFF9FFFFFFFEFDFFFEFBFBF9F8FFFFFF9B9B9B080808
121212000000030303030303F0F0F0F9F9F9FFFFFFFFFFFFFDFDFDFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFEFBFEFFFFFFFEFFFFFCFAFFFDFBF9FFFFF8FFFF
FFFFFFFFFEFDFCFFFFFBFFFFFFFEFDFFFEFBFFFEFDF9F9F9EFEFEF030303
0000000000000606063A3A3AFAFAFAFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFBFFFFFBFFFDFFFFFEFFFFFEFAFFFFFBFEFEFFFCFEFF
FEFFFFFEFFFDFEFFFFFFFEFFFFFEFDFFFFFBFFFFFDFCFCFCFFFFFF434343
000000000000090909A3A3A3FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFDFFFFFDFFFCFFFFFDFFFFFFFAFEFFFBFFFCFFFFFDFF
FCFFFFFBFFFFFFFEFFFFFEFFFFFFFBFFFFFBFAFAF8FFFFFFF5F5F5A0A0A0
0E0E0E010101080808F3F3F3FFFFFFFEFEFEFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFCFFFDFFFFFDFFFCFFFFFCFFFEFFFBFCFFFDFFFCFFFFFCFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFFFBFFFFFBFFFFFDFFFFFFFFFFFFD5D5D5
0A0A0A030303191919FFFFFFFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFCFFFFFCFFFEFFFDFCFFFFFFFCFFFFFDFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFEFBFFFFFBFFFFFDFBFBFBFFFFFFF7F7F7
0A0A0A000000585858FDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFDFFFFFDFFFFFFFFFEFFFFFFFDFFFFFEFF
FCFFFFFCFFFFFFFEFFFFFDFFFFFEFBFFFFFBFEFEFCFFFFFFF8F8F8FFFFFF
3232320000009E9E9EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFF
FEFFFFFEFFFFFFFFFFFFFEFFFFFEFDFFFEFDFDFDFDFFFFFFFFFFFFFAFAFA
616161010101BDBDBDFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFCFCFC
8D8D8D020202DADADAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
A6A6A6000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6F9F9F9
D0D0D0000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6
FFFFFFFDFDFDFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFF
F7F7F7FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
grestore
%%Trailer
%%EOF
\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{373, 274.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"q1final", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 AspectRatioFixed->True],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF2Xc8lt//B3BCZvZKZM/svd/2Xjf3bcuom6y6SZJkNMxIkqQoaRElqYxy
KdkjIQklM1lNK+R3rs8fv+9f5/F8vM59ruucc13nOgfRgCPO5B1UVFRTNFRU
eKlgePOb5J0PBufMvtrwu81g9Tt58o0rlw0Nw4r+c4o1pcSwkg7qKjwtcHPW
W++2CGQA11Jec9zX5cUv2AsyA+mJkBFu/2k2G8JxFojJFQXcUkWbtKS+XZA3
0muIO/Vv5MRgAivAeOt/nnf9hrkrsMHLZ5v/2eGJb+HwMBsMWIjq4R6iDzVQ
NGMHzqJQDdy6B8cFKn8ib7H/58JGtzWVGxygrF+ijrtnifPrr2UO8Nq//J+p
hHreP7HjhAS+S/9ZxTbtTVQJJ/RUZcvjDjhh9kTjLyf0/3kuibv5fV3283tc
ED/U+Z9lVFUO65C4gf27/n/28Fvw/vuAGx6N8UvhTs+6Z1u/gwd2JxwSx/3i
RYBunAcPGLnu4MW9OCcka1DJAyXZ1my49Q28tdzCeIFk/fo/p18oMI+Q4QOb
e9h/flxTaxefzAcOVy/+56HxIZeMKT6gVo78x4e8zbTmmW/CD/uZFn/gllLn
C7hzkx8Wo6d+4o5KJlEw793Q8ovrP78euhT/kV8A/IQZf+H+Rv3k3Ey0AGjo
i3/Gzb6v7/zvAQHID7vRhluL+PMSldoecIhe/s/7T7Ff23VxD4i6iLbjPndX
6ZbA9z3w4332f3n5W4dSaXtBOMlA9Z/718Ir1R8IwkutgA7cf0UznxszCoE6
sbMat6hteYNDkBD0/S3MxW0V1dns1SwE+bzRl3AfKZzrOiS+F3a0Rv2X57Uw
DhxL2gvCce3/5S+/y4ycHtsL61+E/vMUv9XEBQNh4Fs5koeb2STo2/VrwqCy
vzsRt2po8o/SdWGY5D/hgrtxf8D2uKcIWMdYEXB/TUna+b1GBCJOPXfEHSvI
kb78VQQue3f/V5/18c1dm7yiIOfsbIT7lrnyxR0WonDV3G8nbs1hjJvxmCh4
M5et8yL70Izt4e0XhWIJy03cZ+X/iYmriEH31bFt3PyvMu/K+omBz7DBT9wP
SEJyyhfEQEWosBS34Vx5hWaDGPwJO5ONuy9eX8VgUQyq+NIv416/56VtYysO
v5KPX8It8i4W3ErFYRdB9CLuajJTk8+QOOz+StTDbfn3qsVBegnYuCTJgXs4
S7YjRFMCBNgy+XAfFq+1jyBLgKOiHy/uHTVW747nSoDxlioP7st2Q8T4JgnY
sf8lP26Z8aChs78kIPnQnf/qvzi26pUhKgnWlNO1PMjuAlEx2FUpoDrr3syN
PFvi8Sf7pxRITO3pxB2jAJQAa2mIUnJrw230S0XR9pg0/LpD7sfN8FxiQa1Y
GmJ6bcpx957kKxPslgbvZAVR3FeMmA7RrUsD+86nC1z480m3JbkkIQPuO+nW
cEt1fJ8cdJKBCNuTK7iXsiaKsTgZyLb5+Qf3M5f3vvfvy0CJx99l3PH8bUIX
B2RghiF6G7fFp7qRE1Sy4J4fU4Cb9VbF1QB5WTDmVKXGPRh4083WXRYCnONW
OJGL9l3iUT8rC9aE5W3cgT/O9QtWysLuZ8b/cCs+jblINyoLSwOZm7hXToQ6
LtHLQdEJO3q8vQbD/bs+qMnBSVnqLTxPpiF0Yr5ykJte4oDboc007X6GHPTL
rA1wIPNkalpefC4HVKJPPuMmPunS/MArDzuyl66wIwvGYH8wE3lY1Bi/jHtK
v6rq/mF5+HS5/xLucuo7lIsF8tBKycvHHdVyRTG2RR4K3ty4hVs/I30h4Jc8
7DfnWGVDpnU6VWa7VwGyhQ0EcHdxUw6p2yjAb35nDtyXPgZICUUrwGou017c
nkWkKbpbCmDL270Ht9gBq1tL3Qpwh3BhN+45aT2/D+sKsGPMRR531YLC3kZJ
RTjhOMWFO/axyOh9giKECqRu70I2ieYquHhKEYIPJnrjZtLb6R5bqgi2VrkU
3H3bazwH3isCvXvkfy54M99vS60EO4p2HMYdkPb5orqCElAX5YTilnN45yjk
oQQ/LKlTcP/kfLNr5zklAD6XbRbkmg/POpcqlYC8a7GBGTnxemnah1ElOBu6
cRT3beUecT9aZfjJYJOJm+FS62migDK0mNxNxy1zNyd2tV0ZqodXghjx72f4
06unxpQhtk6OjHtGfaiGZlkZrt34kITbYvPvhzQmFWikeeWO+06T0CqbiAq0
1XAN0OPjn2HEm6ehAule8nM7kQ86H9AQtFWB1fsbNHjetDuZeMtPBcaP0NDj
Fhu/f1QmWgVe6FDR4t4jiIV5iKmC6k4bD1p8fCfHM8a0VIEovcsV93AZ7QOy
vSrsUaZLwq0TKd0xH6AKpcTrF2iQ83VsvkXEqMIbP4/b1MirVOEMa5mq0LNY
b4zbte2CdHyJKigsnAvG/fRClQVtrSrwiLEG4uZ2e09O71GFOu68ANysOfP7
62PV4AopWuCf6wwW7sEab5ytBrS/K3Vxd4moFLbeUYPZPy3yuOVnXV7Y16vB
iZxG6U3kjEfRI/29ajDnVRXwF3ku+upfjxk1uPO+OBy3jeGL3V821OD+C80z
uEvpxrQDOdRBbc44ATdDN7X7gpQ6nBywO4l7BwM/QahfHYJrbBNWkP3f6lJK
ZtVB3Poehrsxz+eC7D91CKomfFhGFtmf+PARlwaInV9a/4WcIFnSrSGrAecj
aBd/In9eaF6oN9SAi0GTCnhuWD3LbELUgPdFwbK4C08y72sL1oDBnO8SuDdN
FG0cEjTgJPNjMdzLp8xME/ZpQgTVaPQiMqdZ4qEhE01IEJNMw63I9CJTxVMT
7H93XJ5Dtu1drUqP0ITpvLjlr8iH8tSGJlM1oaZtTXwW+az3kS39m5rwvtNV
EXex2AOxvOea0OY9IYO7YXbG8nuPJqSQKqRwDz8UC7ea0QQD1kEK7tWo/TnF
W5oQXro2M43MrVfw/C+3FlDyVgMnkJWpB0dd5LUg4amgN277Vo4dFaZacC6K
9yzukEx76Z1eWnBYwDked7JLmp1vpBaoRGTG4C7Z3RxRk6YFpFuy73E3jlFd
4SjWAm1tmdEvyKN39F+E1GhBVG1X5ijyemjMeNNbLSh8QMePm1e1eqfQVy14
9DrcB7fq2vd90f+0oMfMzQ23Y8M+wlsebWg9bkTAHXY2KFpGQRskSa8e4k61
KbmWZKYNo++ogkeQ77CPNQ57acOhdbXyQeR045dzJbw6EGqfxNmDfJd+nW1L
QQeWzjIk4G7qVtdwNdcBNR7LGNxfLlE8H3nrAMH1XATuTY/yBIYoHRi2n7qL
e7fI7G3/DB2YnYi6iVtzRryj7pYOZG+e/tKO7Fzu+52rTgeoAqodW5CPRF7j
Dn+nA3RrWo9xE0tOGGqe1wWyrpBzAzIl+OmBCyW6kHf3ng3uTKWfqbN1unCr
ScUUd9my/EPjPl1oemTdgbul/lB/wTddSGynRNYjTybdXvtNpQeEXaqEp8hU
Vl+E7Pn14GLN8mo1siCroOldJT14VpH1X64z4HZo20IPzIfrrXHvpdPMaaPW
h82e8SsPkEkHSgZy+PTBl+vvrnLk86/Y+XwU9EEbAgrx/LVwvIe0qT6473bl
uYPP56n5az/d9cG1ZuTNTfx5GnX/XH9YH1jQilSMHKjbIpJ8Vh9s03itcRfm
qx1wKtAH4e/cxrgHVm7eEajUhx3sXDq4M2aZa8P2G4AE3Q3jPPx6Fic2NKMM
QOHC5hvca7dnDKjTDeDT1dHfF5GVaIiJnTcM4JxI2MF0/Hr+r15ffmoAyjvv
Dqbh18MU6fw6DYCbR8ofzweErlvKjRvA1rcgd9zMcYzpf1YMYOVEqSNuk+Ho
rgYWQxi8e6IV91rn+Bh7vSH0n3oWHo9fT85RDB2F4Imnsk8cfr3UFwfvzBhC
3dOVwKPI12dk7x3ZNASh8vjTR5D7za580+EE4NDccKIgM5XQytPKABQoxlji
NqKOPNxjAKA+8ccA93Hfscp8FwBWh20N3A9f2v0OCAbgOS7LHIE8vadOQyEB
4NjAo91h+PzGSses5gIcOrRRGoA/f0O5da/KAK4/bQJ/5DTNHVsZjQAj0PwP
d2PuEXAdBAjNGP2De+XXaJLIAgBTzu853HkykgHLVEYwtPeLB95e1QevM8PM
RhARo30Ed09yzm2M1wioJweDPJG/abQ33xY1AhqtOStnZNrp7Zk0eSOYmRsh
4hbJ1WQ4omWEvjdarbj1TcNliSZGEH/i6wvcbr9KbHTsjcCwMa8Kd2TxcOhe
dyNQOH051QU5y4kjk+aAEdDvuc6M52Xblg9nw42g3DsvxBK5+WH82+4YI1At
a6gzxt9fn6c/qs4YQVyixR0T/P1lWeDIzzKCuaKVm7j5XoipnbpqBO/c9PNw
q4Z6EANuG0F7Z1IGbgeB7GOWj4yg6IxyrilycHtLnnydEdwo5WkwRJ5aZdTb
aDaCpq7QOFXk/VL2Y+3vjMD4XWeNMvIQMftM/icjODPTna6Cz8eZfumgb0bg
v14Tj7vrMW+XxrIRWNWXROK2+OJBoaU2hj/7807g7TWyFnL3sxjD3WvrzxSR
dQ2+1BTzG8Mw+7dbosjVoeI+FAljSA0sj9yLf08KAqlB2RhAJ+yIMPL9ttI7
u/SN4ZDBlwDcYqsL1qOWxlDww8UV93VJ5aUyF2PQaksmiODrL/FozglfY1BX
EX0lhJx9+pmmVagxLIX6LLPh78fj9WHe48bQEa0hw4yv/2P6CdOnjaEtMMGK
BV9vWBPFq7OM4YNgrB7uWP2m1tMF6PdJUYq4/4TsDCPcNQb+03Xsu5APX7Vm
F6kyBrWMum68vdnW89VLL1F/mX6HbJHQfm/lrfvLdmOQtmTqX0EeleDaynhv
DPUVi8xryBX58sLU6iZwvPZw8QSyTOuRprdgAtxvjlzCfWu5KqjI1gS8iiKF
JpEFJVaYw91MIL9L3Qh3nrNOpd4BEzhykif/PTJ7UhyR6YgJ+I9r/uxATn+E
rQ3FmgCTJj9vFzLt5x2F95JN4KLUTgHc8SwWxtE5JtAikcKMe003bdqsyARO
5Ja44Y4M7krjKjOBWgYnjm7khStsihNPTUAx8K5OI3Jgi3Nf5SsTEEhl9nyC
/OXP5eiEbhPQLchnr0b2FP8o4PDRBPZkpvngHiAIYoLTJkCBVAfcjom+B+Z/
IHOcc8bd8fAWfd2mCRhS/Sh4imz2afpBKoMp2FZo9ZUiNzDLOrlxm0KHq2FJ
AbK2btgfSRFTYLtR0oK76tCj/D/7TEE4VNj/GrL8lV/6TVqmwJ9zlYD7brPG
+EVT5ENcJrhF/sSc83M0BZoT3O+uIxeIvZBV8jKF+V/SxBxkbsJ291agKeR/
/9WWiJyVYBLZFWkKOdqLSrgZHp7jvRZvCpJ2DbuTkE+PttUFp5uC4f3HjLg3
mVh8tfNMwefJ7XW8frSOIw39LVOId+m9dxr5Z1DOvfcVpnCW5mblCeRZq7l9
4bWm8G/9r3MgPp6yJpW0zaZg8ea78kHkIaYC9eu9plDLxnOKjNw7/7NGbdQU
jg50heFu67I26PxqCuK2Z71xN1YUvwr4bQoOOqW/8fZqstbN//4zhbbPJsQA
5EdHCB0Xmcwg6oREjT1y+HH2RfsgM3BytHSQQT7ofihiOtIMfKP38sohe+s0
LsfFm8G/gte0uIkC/LHc6WaQExH4WxbZbuPIvweXzcDF8UkAnpuNtp42LTYD
LXFx/33I+i+F6UfKzeCr2mSTALJ60fGMyBozaLa4Os+AvC/hLRvTGzO4Oy8Z
x4j8LTlLtUXEHOwui9XOEtF4BM0885E3B+Jq6V3cQ1aGesta5uDErJKLu1c2
Dztvag7089FX5pDbmJZMJRzNYcfLleeTyI3z5m31nuZw7C5nVwdyTVehnUug
OaRIBNY1IVdWLPfORZjD19DvWDPyvSx70ulT5vDddLocNzmPJcZw2BzqcxR2
FCN7Hz+4+X7aHM685n6Nm+j+IjH8pzkc7zQ+cwvZToebjm7LHF6bTVpmIpsJ
hKVdZ7CAVn0NiRPI+htNu9S5LUD6/Kp5LLL66J6cTmEL6Jd/P4Bb/uVR3gP7
LECFprgRt3hRZ8FfTQs4kxFWjlsgQVw4x8QCenlnGU8hc/qdLJF1sIDFD+tc
4chMxv3SrzwswOU8S4Iz8g6xfeXuZAt43ZPnTED+u+OM8g+KBVDvtf6E578m
h6tT4izgaUdcG+65N6o6wqkW4C1b+QT3+J30l88uWcD9v2HKJOQZ55O9yUUW
QGv62Noer78dOulaagErQYfDVZC/l3uvSFVbgH03KV8K+Y+HPeNqgwU48VHJ
yCKv7zQUbG23gMAqRm7c/54oKl0ZsIBLjFxUuGn8hU2Cxiwg/T7jlgwyAys7
SWvOAlQDjJP3IStGX154bmQJDw77krZdZjA18eTtFFtLmMmu3ppF1u6N5nR3
tYRvzxzp3iIbnAqSlPG3BBvl9kM9yCZy7tproZbQz2K9txfZ8oOVbVu0JTzR
lmfEbXdWZ39+kiWUirD9wX/vpCIXcei8Jcy/mxfsQyZ9FjirfcUSPtnP2+L1
4yxu7qldtIQFBhrJa8hJv7MV09YsYe83WbNY5OSbScYeNFZQaFcaGYacYR9J
lGW1gjsnN2OPIGf/DQha57eC24aPD+K+fM8ltl3cCmpfkh1wFxDNMq8qWsHk
2m5t3EXUGjeDdazAY5PFNRK55KHkEx0zKxB+ePOFP3IH7wObugIr+DrbziOJ
zPf16Yl6S2u4XHJEocQZfd+4nrAdc7EG+bLvrReRP0PlHUVfazCrfuNyGdkk
rEJvNsQa3lIvauO+m1/2rjjaGk5tc+/FzdR8L8jrtDUw/vU1vIIc/vP2FneW
NUTmHqHJQ+4VunWp56o1LMxuBh5GVre5IZt6xxpUuTpfk5Dzo69jxo+tge2T
jLMH8satq6SNF9YwNHlTE/f+t3nz1W3W0FzAvwf3641LSYcHrMF/0tnFE1lK
5iKfzBdrqMd6U72Q04hZFePz1vB3fY5ZG3khMcP02qo1PCuXmuNDdqpI/Uik
sYFpNzZTAeTqj+eOsLLZwItOx2ncfDvP0LUJ2ED1Nnc77ljVxGtJUjZQruS5
iPvz/lMqeqoon9I33IuPT0Zs6x8DG/DM+rG0TUDntefHfR5a20Dm9zLCEDLD
VNTvIJINhKaOH8Mdxh6ZJupvA0R/Ks1h5LSjXjpLDTbwqHxiIw954Yb723sd
NsA5qPcZt1MXiew/aANvc2s5riFXrzlvCEzYQMOO29fSkPklnS4OLNrAgv7A
WTfkOIK9dNa6DRht9LbbI4+dsnlpSWcLHE+zEwnIJmWWLtQcthC1ohyA++6g
2bc6QVtY/9pripuJxiQhSsYWIjVTREnI4UrAo6huC7OYyLwNcq+X/oOvYAuh
lUwbvMjqqTrGxba2YJCvu4MOOb9a84Onmy281s30YkTe+KIWzn3AFobpI/Vx
79+lQtNz2Ba4z7kK4X6to3g1JdYW+m5qmLMgSwXuUzJOtgWXGjMRPE/LkWn+
e9EWMjhGJgac0Pg0SHpVF9qCVisfbR2y07zYz/BSWzi/+qagAbmaTyRF+qkt
fOFaiMXNZyYkNN5oC6QvnF64YykCTwq6bKGF5vvJRuTP1/msiUO2QH9PvBC3
STv32K4pW2hlYGS9iHxnmeNY63db+GTaNRmGzCDGxpy0YQu/fn6aoSCHObAU
69LbAaPs010RyL2xjFp/OO1AkUFwEc/V7+3srthrBx/ma1rxPL+f5kCQnB30
H09tiULe2KZaF9G0g8qSr5a2eHtreUJcxnZgN90RtRd59Ie8CZ2dHTj9u2eI
2/7b68BVVzuIcfeYF0FuGHfP+OZvB4XnNLpwKw4vPRoJswOJcI4K3Df6zg50
H7cDLKRwlyQye6fAOnbaDv6djKwQQk5sqhSqyrSDP7Tvjsw4zmA7U/xMTKft
YJK05188MjtrYwY51x44KA+FGhxQ/Z2ulW437CFVXKK0Cfnnv/kB6zJ7uOvH
m4I7YDVpXe+pPUi6M5Bx933n26vYaA+0TH9NcJvOVpiIdNpDelK1YDty9RfT
IM5Be9DSoit8gCzx8WMG7bg92BUmjYYiX353pHJl3h5ePZmL9EUWuCz8PsXU
Aap1bzzctkf1BRP2lv1ygE/j9HYayJytsuLkLQd4SCiVxk0VOSAtwuAIufE2
NLiXBBPkRzgdgbczK0QL+VOrrEqekCOQUjw5dJG7Igc0CDKOEBW8MEKPXCeU
oMui5gimNu21rXb4eUQWWg0c4V58wcQb5LyjA6anrRyB5+uFlHZkhk7ZYM8i
R0gP8/XyRF7Rn/Ogk3SC9F3fTkfYovcpB0YD5Jwg2zbcC/fU19z9jUpOUGrx
Uw23l8HcFyENJyCPD7+IQe7LgQMndZ1ga+ydFRHZejZ3egicYM2b6QYNcqPB
XJCmuRNo+/CU/bBB37tLMHfJxgnOmmx+XEV+NJsb9tPRCR67Vj/GfSgXEj7F
OsGDiG+Kscgj87m3n/Y6wTHjG21HrdH+IIkymzLoBK3VpgW4ZXjt5D1HnWA7
K5k/DtnxgTRFfsIJOIRsfYnI0UY01f++OsF8YGrtLyt0Hnv/ebV30QmYZbfX
J5GbQur0Sn47wbr6pe05K3x/cDnh2Dq6P19CL272yxFNlttOYKzHVoxbU86e
XoCOAA40Vh54ez6YjO0CEwH8x94OfUI+S6S90MBOgAdfNt7FIJd9G+vL5iXA
fvFCCgm5N76e94AgAcZb/Jn2I69yXfHUECNAqbDWsA/y3tLIInoZAtySZSnD
bWboMPFRgQBHK2V9DyCH9MtKlasR4OeZK5K+yBcP0YXE6xBgd/65+1uWaL+4
9aXCCQiQIs9h8Ab5c86Ln2LmBGg4/4ymG5lWJl9j2YYAMR9v9nUh73t59ESr
EwEOfEgvxu3s7PjyqivKBbcPvUWO+SpHHeZNALnguj99yEVxO80NAwiwYMF+
KhG5mWMilf0QAbwF7g8pIy/cfdk1EU4A+eVCbw1kTv2r7E+PEmDswMM7Wsja
76KIKScI4LTnwVHcvoFO+R4JBPhx5p4x7uSNfaP7zhGARcDQ3wi5PJte5F86
AaTc+WOokPskJw/0ZhOA3CPUcc0C7c/qGu7dyiNA7PnS4nxkEaeC+ajrBKBn
c4QiZIvpY0qWtwgQae7NgjsslnB0933UvkLwx0LkS2wKz+crCGCdun35HnLd
bYaNl08IENKRUhqH/EVnyjC7lgCWoiwTzMg732KnAzACfDjurbRmPoMpHLzW
ot5MAI0i4wwqlBPXo5noO9H88Pu44Y7Ncnb42EuAEbMYcdw3xRVzHgwS4BF9
ShsDcmsN4+CpUQLcjD1P/we1t2Q/vdtpggDDLPdZE5G5Jxt9xGYJcPHCWjQR
WTfmevGfRQLEG3Mf24/svytmuuU3AV426xnhTr3lInt1Hc3XRgAz7odaSuGh
2wRgp87XOYg80MX02IDOGURrHuf5IW/4z/xhY3aGMnP1D7/M8L9fvNKeYHeG
lSXD1Qpkq/OFcdW8ziBxQWL2OXKcRuw1C3NncD8wlM+CXKp8S+qpjTPc2V9P
xj24r+OxuJMzOPEUqeKmkf6ln0Nyhktb3du8yMpiAm1UXs4wVnOy6acpen+E
TFyO+DlDUPYjh5PI6fwhnz+RneEHny2HM/Jzrpxgu1BnmMn6tOaNPMVa96eO
4gyvOwbf4LafXbdXuo7qHxbQvW+C3p9rJ6j4fzuD98yNMmXjGcw2rzgjec0Z
mJ17juKOudjOu7zlDFldV0r0ke+c/1l8gMYFpE/wMtMh96XsVuhjcAHj+eT1
JKMZbPu0cY0Rqwuwkr57BSDLxwebPuJygSNiO+fCkT1OXOwR2u0C2y9NqnAn
R9V6nN/rAt+4E2JxL9mvV1HZuICT9Gf9OzCDYVQnyN9uolyrsZ/OEK1HetJV
XXdd4HvktWAO5Jjo9/8elbuA9T4xo3ID9Dw9PmN7qcoFbsTrmEkjKy+o5EfX
uECNei+vDDKL9JcpjwYX+KGmsqSA/M0/S8XgjQuU/MqswN1yXT9epMMF7vnN
heG+9WGug6bXBSz/HWTTQ47nvMr39b0L7OBiOjejj9Z3e8uDHSMuMMwf2emA
rJ26XFkx7gKTqe9prJC5m0q2sr+6QJBywjMn5B9bBJuoRRcYYumIwt2tTXXF
7bcLXM3nVsNddvThpO66CxxjNLDfj5z80Ft577YLLD1z6tqDHPCN6RQ1HRH+
XC9MitGbwUCitn2KiQjVOnavA5AFfYN429iJ8OhLAPVh5LWrPAce8BIh7srV
hnDkgYGmR1mCRMjfensSdyVb5GaEGBEmuj7tPYl83kbEmiRDBOnPVypskYPP
9VzWViRCg93Ih1u6aH1ojJvYo06EZyzqwTHIYhtySts6RDAfaXh+DvmfxseT
E0CETzJjR3EPU1Lams2J8EpyWwn3swcaPKW2RMgZWjx9EfnSzKT/eQIRfryL
qzmGTBHNeXjEjQhu2plV7TrovOZttOHsQwRNqkCuNGSZK0uWmgeIEFBh9voK
Ml3f9dzdwUSgcrA7hXuCxXZ88zARvhW6aONusFxX+BJFhGszEieLkQtO34tt
iiUC88/eFjyPfklqvZtIhK2KuZYFbbSer9Fwpyej/oS8GMtFVlKr8gs/T4TQ
d1GMt5E5mSRaUuqJMCp8WLFMawb7+Jz+4ovdJKD90pt4WwOdh20b7c8Kk2Ce
vZPrKTL7lxgmO0kScFPrPHFB3hel0sq1jwRRB77kXlVH48kwd2ZEmQTnFTv8
MpH9r98yKtEkgUBIyEE8j1P22grRJ0FGqsoe3FfecNWpmpBA3mPtXT5ylXtX
9F9LEqgLuHfcR+5eOKv22p4ER5eTjkYjzyYa/EhzIcG7nktlVWroe8azUk7w
IIEoxvUvGlm49GHwbl8SMPkdiEtRw/+eGyQ1fpAEbrcYVXG7vhOevB9Cgv68
R1+TkSPIQzcoFBKciztJzEE+v57trR1Ngo96ObfTkO9lWu+miiNBe89Kdbcq
Og+I7hhsTSJBnG2F+X7kz0/rci6koPG5ZWN0BHnd+qijWyYJjvd0/zmMzP15
H4vwJRKolDuV4laOnGqbyScBx4Xa6Uhk252F5x4WkWCY66xbHHJgAckk+jYJ
ahf+Eb+qoPO5Iuu2QRkJ2DZm18yQr79uqaerJMEVtflGa+Qa14SY7qckSHxz
18YJuX9OS+NyPQluONH+c0Reiv/x0/sVCeay/B/jZuIqfSjRSgIGZYsNf2TJ
e/6hC10k8B9wPLGpPIMZ6QnIVPeR4GZi2ZQistfbvqmTQyR4aKvnJoQcfSCj
2PQzCR4PZAjsQ85ZNd3PPEUC8YFXXXLIFRmbAv3fSNBwbjUed5vw0w8F30nw
JpdSrIc89SQ8N2CZBIvfslsZkbctpQhyG6h935Qbakpo/zz6edcvKleIb6zb
WlBEz19cyW8lJVd4pePX1KWA9rcN8tiDDFcYdpSLd943g3XUqDSxXXSFf4d1
VXAvVGm2Hs1zhUqTvSn+yKwVep0frrnCPv5L2iRkpXtGb/WKXYGwflosTQ6d
z4rN+2/cdYXOG6MKf2VnsMhrNh9oyl2B99PtSTqU5152HAl67Aqa/HvcmJGf
XSCOdT5zBYr9Lkbcb/zitufHXYHvU17kCxm0X9jRBfLabvBOtPc4oxTar271
mmYbuMFXMLnHiyyx+t7yj4kb1FTq8HAjW/wctnW3coN9B2Uu2UnOYEHzY44v
7N2g8/Gx4TwJ9D2fnnIRcXGDQuEOnWvIZWPf3M66uwHzlvOZO8hdH5e8Zn3c
YOXLc2XcS/2/fe0OuIFwkuDn28ibt/ckhmW5wUaZVY22+Ay22zK0sXzKDaJ6
+wtdRNB+N3Hl3Lk5dD8f+vXdkF/UJdnu/4Hy0NEfR4RnsMw/LBxaK27Qb5xg
XrUXnY8V8wfZNtH1nqSJvkFWOiR+fZbaHXLvqva0IFPdeuj/it4daHiSj+B+
N6IjXbDLHcRXtWbakG/xNC9EcrlDzFR73gjyUUenKtvd7rArjVi4B9ksbeS4
hLA7kGicBBSFZjCepkCDLQl3mFv5rqaCPLP5c8egnDtkrhhm6iE/1zzV9lDZ
HaRqLBVwp1IYslI03YFKzqlbF9mz7JKLn747qP88ueCCvG9q724dE3fY0KXc
bBRE4yNU9pnDyh1shsHg3p4ZrMdN4/acvTukaQ9/zkO+cbExuMnFHUye2mvd
R6Z02ipd93AHpbOMg3h9Y7oPf6J83cGTpjkKNycE1NmT3YF7yfVqI/JkzGKC
VKg7rO7lCvFBrq6KMd+muAO79SuyusAMdm6Bhnko2h2WT7Z0L+9G65PUhd7K
OHeYttCuZEG5tJ9AXtppd/g7etse99rVO14Bqe5gK84xz4zc3q8sqpflDh6D
bXRiyAW7Xsxw5brDzt4y2x+ovTBLy/KFq+5ApFaOfs0/gxkk9UU033CHQoEj
9Q7IrPU+WkV30Hy8uDNyiB///8jsZvQDd9DqbzyO+7Fi1GvHx6i/BSNcuE8f
2k6Ree4OWMGLezHILrfS7alfusO/LbqEcGSJUR6u4dfuQIgWibXnm8GWeYqH
qtrcYdjfPvIWL9qPOMoXZfSg8WxiKnyB7Lg3uYOw5Q5yHwQi6HnQ/t2dI1uO
xgOyOzKYcP+6eJ1Ew+gBVDq6ZbibOqX3jLJ6QMznDwoiyLl0T75Uc3tAyYXW
q0TuGYwMhnczBTwgQDTouQEXOq+daA8NFPGAw/SpB/SR6Z8QVUDKA76/Ldtp
gzy0MLbCJ+8BoYebiqyRS6VCX/xQ8QC+lyOauGP9VpLatTygMuP4SzKybUGS
5S0DD+AN5Evt5kT7kwGWXSdNPeB0PfWHdI4ZbHFXfp+LtQc8nl14cpgD/16L
58s7ekDGbt+RM8jZSQ996EgeoLFHKBK3f72O+GdPD2DtHmbAbfdY1EO0xhNq
Ofm5VKjR/Fy6+iNX1RtYQq1K/BamsYFOaqUD2t7wrZhjP8/8NFZAGxKuYugN
225++XLIfgZ9D7ZNvWHLYrtfDVkqWneu29obNLNfEXAvPLwlc93RG86kn3mr
ilz1lSkohOQNjb/5T3kgx4gcvaPt5Q2jDlSL9nPTmIHHyOROf2/43BthfXd2
GtuRYyr2PtAbrgwH2uQjt3U88CsJ8wad/r7KSuQsGu4bEZHeIFrEoYCbqB/3
CWK8QUDAqfQRssCxqT2s8ej+r3lZDCF/qbDzHD3jDaEGZTeVkO/OVOeXpXnD
8k6OR54z01iYsNCHmAvesOLMpvRvehpTdT/HY3kZ5RRdbzGUr2UvuvBc8wbu
iN+DosgN7aScyZveYCxWTsB9ZkdD7+O73qAoPVFkimylJ8WWWO4N5smM8VTI
rFFZ9g5V3kAn+JkoNYXGt3wlQ7DGG57vetm3fxKN7/T+jrmX3rBnY7g6Fbn9
wc2X3gveUOvTyT75BfV3imFT7pc3vL0YkTqBTBSK0F1f9YZ/pp92ziILuH6M
ad3yhsGNM47046i/WcbPL9P4AFYzwl47hvrbWrp8gNEHYhg1QvZ8Rv2l4lRX
ZfOB/AgtaWFkVZ3YSCoeH/B5Ee6jirwWMVHZI+ADuw1S+lWQpbQlbhtZ+8DS
JOtI1AiaX8r5CVZHH1CpMpgrRK4q/SPyiegDhpt7aCWQYya8fR94+kDGuqSR
xMdpzHBPc+EJPx9gunbC4vTQNEZLVBi1DPQBXQPT8grkjvOXBXjDfOBXiL4w
7uzmLfepCB+4Y62RU45M+ke+UnXcBxieOEx3IJ99cy9d4q4PwP28lLX305jT
AW/2Cw98YKzymE7KwDQmtIMjb73SB55JvS6a7JvG5m427zn4zAeaOq+1jiI/
g9jinnof6H3VU7SGfPqzorTOKzReH234cTucmiwvafGBL+UtF1eRBQTzVVm7
fIDttNvKnv5p7GudXU3MOx+QTC+U20C5zeOf012bPlBVlGl89+00xl6kZ3zM
ZT8sJRv5XmmbxgqPv11tpvKF6/fEGDnrpjHLDNNJW30/cPW7dDi+APV3j3z1
y3k/SDpa2s8UO4096fdNfnnFH4Jpj+q8JU1jr5O80kjOAfDAxv3UlPQ0duvH
5LFoqgMQL/LEJ+TvFHaYpH5J6eUByHDAXOYbpzDuibePo6MPAru6/YJY4hSW
obRWayFOhpzuGJpEmMLyf4x4qkuRIezjlSthOlPY3cfYhqgsGdbLWi3faE1h
1ZEl19nkyWDzoCDBVHsKe62WYrClSIbX0zdcTZDXtHhfPdElw2KelfS8yhS2
c33dv9iADHncEzeMlaYwrrpPOy4Yoet5Vm52IIucfFUSZ4qu5+z1rh1ZUf+O
WYgFGY6u0t1tQ9bfSp12syaD4kCzOo/yFGbdEJZsbkcGU3cv5TWUuyY4Sas5
kqHYZWQrQG4KO2ik3ibiTIYX61lMT6WmsEhq/mBWErrf4pR5bekpLOH1BuOm
GxmKSt+/1EI+f2as7JsnGTh8xbM1kQvMmmw/+JBhsOAZy37k+3T3Ft74keGA
4uZiAfLTlvTMqgNkcNfbZOkRQ/1POax4M5AMthQTDrG9U1ivlfPbzGAyuN2P
FA9B1idQBv8mkqFVQZC3hWcKs+EkHp89Q4bw5XuTb5Dd+rX4B5PJwB+i9rgJ
+WDuntqmNDJ8+OdQ4cKL7p+07fH4PBnaVS0lDnJNYYm8k3+LLqD7ccuyZt01
hWV+aLl2PocMIoPDCbEs6P7zy/RjL5Ph+R8D3hnk+x5Zn4LyycBXd3B8Cpkn
oHxq4BEZuAotTL7RTGFi4tnnXleRgV70aqof7RSmPHVUqvIpGa2X1+iPo9zw
jltrYQ0ZsqR/MSxtTmJ2gXqHMurJwNjxZNL07yTmKS3MeKKBDMIuyo8GkYNm
d5QFvkL9/XX22HvkqNIZG+IbND7oRDOAfDqkY964lQziT81/yG9MYkuRs78e
fiYD2Y5mlP7XJLYdGPk8ZJwMdkQ2E8XFSYzda/Ok1BQZJh4ncDLMTmIijslG
EzNkoPU0IzAjq5iy0xV9I0OqoxSnF7KJVkG7xwIZ/p3tnvVAdt4nkcXznQzz
EVGYO/IB4YfO736SYeTgu32jyFFc2nyZf8jAOnH53ubXSWzjSYpeKFMgKE9u
ttwencQYlqXOSmsGgn/8+xnm5klM7DiZ52ZmINBuT6UlXJ3ElEsUdIR1gkCA
7wl2xWwSk2t+man5OwgiAxVFGoYnsOV7w52DNw+B5dJ64I2oCaw8EdNl8wmG
V7QJwy0r4xinpahRj28wtJPlLZqRY3adMc8MCIYjE3/9M1fHsc/9UzZ25GCw
7Cv76o9yswILJ+ZDweCgt6vt7MI4VuZ3n9QREgxDuo+8FL+OY+zSTF5p4cEw
rXRVjnN2HIteDPWzogTDvo82zNzIn550k+mPBoNhv0YUnrN+HcneTkXtJYap
an8cxyj2azPfq4MhZ4Q5VrB+HBvk8lx4+DwYEn/x8Wwj6w/X/wyvC4bRj2Fj
xs/GsVs3hVblXwYDezCjNH35OMYQlLA5jwWDsZrcy82yceywwjj1g9fBcPrF
olvbg3Fs4LcJfUhzMIxxP3zagqxbd5tFti0Yrooc5mpGLk7cyTnbEQyaWY+O
+qH2+p5wG3z5Egw8TXNVFoXjmLqAyqVelhCQez5oxXcK/X5Xfm8SWwgotFlR
+I6OY0C1vUuNMwRMr+vMKoah8fpNtp3iDgHF/M1LLcg2M12pl/lC4MJtKjXm
8HHM6aNai4VACLh2dGUyIpO6CmjWBEOA+m7+LD2yJ0ZtXCocAgKri6P/kP2q
DsV7ioVAgNe6dXroOHbe5mbwlFYIkD/LniF4jGPTsWxGawEh0O8LIhNq41je
yOKCcG0IvF49/7r66xdsKifyOH1UKNQGeEdn2n3BaJjPzh8XC4Nbq/STnYQx
jPWET3biWBj0vMw1Ig58wn6zntbkuxoOGqYcYZWqo1gpWa1F0+IwHGVZsa+9
O4zZVpUnL1EfgYtJ4NzWOIQ1YFXKSo+PAPO/xUtc3wex5L/US/GKFEgz8NWX
/DSAjcrX1f9WooDb775rCxUDmJpvZNohFQrIBNTf0CobwNIvyrl9UqWAwIvA
N64o/9I0IeGsToHZRvfXTsiaKwW/WjQosOuSdaMNcqaMS6OeFgV2L8epuj0e
wKY8mbMqtSmwV8Wbtq5kANPNbPKS1KXA2TrPY7RHB7Bs7KRsgR4FsNLX4r/I
A9jXn2qrrAYUKHq9JL8SPIAZSiy8OWNIgYQdDkI/kHNdb+esAQVid5bvmkOe
S/X2CzdGv7/8JHJf+ABmVM+tOGFCgcwkrHf00ACWt9i14WpGgaeHI3cc0x7A
FoXPtXeaU+DTiwvlsaIDmJmzwRUjSwp88Vt/8FZyACs4u3zwqRUFPlOcstqR
fzyrUJWzocAb3buUJmSLb2SqG7YUuPbwyXiL9AB2fc/eHi57Chz2y1ahlRnA
ftsPXkt1oIC+8cXXk1v9mE1iVvCWIwWac8XvbY/2YzerLLQiCRTQvfIxJOxL
P0Y0Z7jD70OBK/cd9nNc68fKjjdGZu6ngOcEtTgzMnVZjNEOPwooNDz5Sovs
PqrMetyfAgc8VbYTb/RjD1m/jcwHUKA/155NP6UfozUuLvU7SAHCvxRWGVI/
5nXU4/h7MgXEbV793kvox6rucJjbBFGAato/OoLYjzEMtXNihyiQOOm9LxS5
PiQjkRxFgajnsnITLP0YZ6Gpw/AxCvTeSHtMZO/HDr3d2ON4nAKOgjvHRpn7
sQbq6m9NMRSgHuZ/dWSoD+NWD3uuHUsB9YrBT9NYHxYSKHGu4iQF3rk1eia+
6cNe5Y86i52iQMTZvUsnkPk7c0WuxFMgR/xk0lHkw1t2S8yJFCh+cvTLpZY+
TCyb1bsqgwLtV+7kySX0YX9HruqxZlKA16hCjdG3D+uTltwTkoXGJ6LY4pdS
H1Z2tPJv8wUK2Hysitun0IedxvSGRS9SIOSQ2YtHyn2YJ3Nr7akcCshyLhaU
Iqu6OV/9eIkCdPq5J0qQmUo+xWhcpsA308CadrU+bGLpkPvFPAqQO+cfuKr2
YSX2TURKMQV28jpQGD+/wySYY+wVn1OAfVWk+Z7kO2zTlUYhvYYCf6zSnfXW
e7GBW1ksM7UU0D7IJv5zrRcrX9q9YFxPgRbTWuWujV7srO6dzsIXFAiTPljf
jOydrPxg/SUF6jh3WWDI6n316SSMAoYpyYPftnsxlr2WIY8bKcDWcCJIEuXT
wX3Wu15T4ORqyzpvSy92t03eYqGLAmXfNTZ8yb1YPHeNpFUPBfpY7Ap8iL2Y
q58p3e23aD7267PEefRiiuU9U9u9FMgbOut/DHnnmscbrz7U/u+OZ4eRP5tO
lzzvR/Mj+eB6kmcv9uwC5QzXewqMpbdXiu3vxbJGNgKODKLnqdvx06huLxYo
nWLS+YECitnnaXzoejHp5HHDsgkKVN0wvrro/hZ7I5x/SXGKAnEBDu/MfN9i
frUOs1XTFKjReLUo5/8W23SmM9D6SgG5Edfje5DzF+ov1s9S4MWHy60/DrzF
1JMjZ2AO/X7bdEfFobdYr7Cs3pt5CqzdzekfoHqLhdWOXbBaRO9DnK7zlfs9
GINL3lTXEgUGmS6Jm1f1YHPCtunf/1JAMNRfe/pfN5ZcSz12dJMCrQe1twaQ
xVxq1Na2KDB89WUsma4Ha1g4nBq3TYH8sUKLVOoezCtZ8hMVdQRM7gtdnkno
xtaER1XO7YgA/u/jxlK63VhubU4yI20EvFL1Jk6Zd2PKLtYjmXQRUBN060o/
ctfCthInfQRQYSPDr5EPJT87m8cQAeJn/xEVHboxWpHwjwJMERCtyxcabtqN
3awVV7zBHAErRpxiZ552YQYuw6fFd0XA5/sea70nurDhhewP91gjINHbxuvP
uS4sOtlSXp49ArIPyqxPIHOK/Eus5IiAmxeW894hP6ytfq/OFQF1IxcVebO7
MBuXULla7ghwepBrahbThc0siCYY8EaATKIG+46JTux08lD/K74ISD+198rb
yk5MWOSCjMXuCMAWrcuYXnZiL2rNT3UIREC+3i7y2otOzN1l852DYASUO9UI
zyD/WaiS6heKgKShN/Zc7Z1YdnLwSTfhCPAJa2ZcLO7E5EVEekdEIiDA7SZz
IHUn1lY7KOEnFgE9BA0hzpEO7KBL5okp8QioHslxVPjagVEvmvYckowAog7j
vd3IRcl/xRalIiBUyvUfHbKuyOPjETIR8J37eGTicgc2WBvUtSwbATwXzuVe
qOvAIl32isbuiwDJmt/iFMYOjHVx4Ng/+QgIdvLx1Vtqx8qSMzpOK0aAcvN1
O4O/7ZiFiIkwvXIECDXRPJRCnqxdO5qhEgHsfWus7MiJLo/a2NQigC0ov0Hh
QScmuEgWylWPAKtYO4uHDk1YTbJgJL8mej6qmsa+mx8Eokh/y3WtCEgu6lRK
08iAH7Vpe0R1Iv6/PO9iRLmj+79SZnHljaz+/8rm5IrdDw3+VwaIHDysCv8r
/9UKND0z+l9Z4PKOT8/kf6XmYkoYZvq/8v8A9s/B2g==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.512439957338458*^9, 3.5124413777992496`*^9, 
  3.512441676851988*^9, 3.512442131484829*^9, 3.512442451579328*^9, 
  3.5124426848524113`*^9, 3.512442855907671*^9, 3.51244311001926*^9, 
  3.512443371140317*^9, 3.512443556222324*^9, 3.512443716548561*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"q2final", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF2Xc41e//OHCFElEZiey9915Pe4vjnMORkUhG5BghZVZmtiSUJA0reVNG
RsMoKkmTFImjUEahyPe++12/6/PX63pcz/vc5z7P571eCHsFO/pspqOja6en
o8NPeYPL0+IVb/STTaes9zhPQusWrkKjup8GZ1+s/HOyFbXcoI4Rioc3bLBL
5ESz7PhYQPRyvB32261H9BVMd4IhkdMB+2Kn84py6S6oLzL9Z6/jpv+p/2YH
tacjRGwpFeWj2mROkAz5/c+zX/ml9eu4YNHZ1AVbT99N0zlwN3w3kvzntKwi
sxApbnCa+H++3dRsG5vEDUtrKv/8duwtMX2CG+7wEt2xN5hX9hca74F39Oc8
sSXUuL0qLu+BqcMu/xyeRKZ2uPHAtqvp//zgbV7suz28MJrj8M/Tm/47MxnB
C3of9vpg75QdPLs4xAsCn60DsDVJ83l0qnvBVUrjnz1idhaz5uyF+QLZf65+
vu+mpB0f6FuH/PNv4Yy7Rtv4YWNiVzC2sE11+z5ffmjNHIzAtgzv63Lt4oe9
73gisYMvfu33ExWAXSdH/sULurcNHUsQAJP7jP/ibd+lhhM/CkA/j+I/T+yx
HM/SFwSKlde/9izGvtMlxYJQ1Vx4AlvlSNKPm6uCEFF4Ogm708NrY2y/EKRW
sSRjTyUnbPneJARVFoH/HM23K+3nlBDw2VD/tWe7fZl1bbcwLL4RTse+YqaU
s9lcGOo/cV/A1njfwbntmDAszEmWYLvTf9y7+6UwhDYnFWOflvsrIqosAm5L
N4qw99zPuCbtKQJ7ghUvYVeR+WWUskQgzivkFrbB1+oajXYReJER04g9GKun
rD8rAloZFg3Yq9ddtaxtRGGHV88/C72IBueboqByyvlf+wYf5ofub0XhfQz9
E2yL3xfMD20VA8kj8kPY7zOlnwRoiAHZ/8og9lHRZrsQHzHQm/r6z5ubLF9E
5otBdJTqS+xztm9JsQ/FYILb5V9casz37ekFMfDQfv/P944tu6YLi0P1M+tp
bApveFTHBQmQLRIQ40GmlbssZc9LgIdIqwh2lDxQvawk4ea4jyi24YKygs0x
SciZaxXCZrorNqNaJgkPP0nKYA+c4K7keyoJjQ7VNtjnDZn9GFcl4fN1Bwq2
xJPvn187SIFN908y9h3iqwM3bkhBzBtOJ+zYPb38OUNSkDbXR8Q2/9AyfJxO
Gh6PCwVis12pueAlJw1nO9lysF8fvuxsQ5GGWlJ5HvbhH2de8tVJAzA++hf/
dfyI/dxWGXAnFGRhtxt4sL5RlQF/w1252En0hL6OAzJQP8NxD3tfr0nqjXQZ
6N9/6B02V4aGRc5dGbitsv0NNum/fo03u+Xg2mC3OC+ez3r19TeOykHytkcS
2OHd5xWiu+XgvrOqKLZeetqM14Ic1N9NscVmcIiptBGQB06htgTsfk6qn5q1
PNDkP5/CznvnJcEfIQ9HCwbjsUW8La/MPZWHhY3Jf+3rZ+QFOsUVYEuh6b/2
0beFRm4QFODJrvdd2MYRHEU5MQowdVp4FptZdwsl+qYCGErZ0LAHN1a4vF8p
wEky8Z+LHn17abNJERaLp//ZK3U0R01eESwW46axZfa9sOd3UQT51c/j2PPs
j1i3nFGE+VP59HuRm97c6ZurU4StMt0O2PElN1PfjCjCrbwhL+yrSs9EPRmU
IK6m1Q2bKa8nkcSrBDtiPdyxpa7lRi8/VoK7W7jGsJODGi/EfFSC1az7/zyp
9raJ/qcSnJ95+x7bfO33m1RmZWCS7ZjArnjIv7xDSBnUVryN+XB+0w13F6gr
Q3BNezT2IUdvdT4bZTjUmxSO/ZAniXTFUxmWP/aFYYuM3QiTilCGq7Vn/sX3
8nUEuoiowMrTTTz8OL+fx9I/aqpAR/zjf35fyVDlY6cCAtbBO7C1QyWffPNS
AZ1XhVbYhdrW0yFRKrC3dKkDe5kuiGklQwWOL955g+3UmyUZW64CpSNCz7Ab
s+rNGZpVQPL+r3/mdH7lk/ZMBT439j/HZsv95tEarQpNBupFAshBLmyxRtmq
wBkRkovdL6R8sadCFdjL+85hy9GI9+xaVYFN2o1dEDn9VsTwywFVyDE4FYf9
NeLCb5dJVbDu+XQS29rgHs+nP6rw51ZNJPZNxo9ah3epQfF/ZVHYTE83UWYk
1IDac+449mamPQT+l2pAVCcFCyEffK5DLaepwebRwQPYnQXuWdJ/1eDbwf7z
2EIe8bW3ONTh4p+TlsLIceLlT9Wl1UHksnkq9uhM10yrgTp4Xq44jm3QQGMx
JqnDh6rmaOyLJ1hke/3VIbPn6QnsNWMF631x6uCqQjmJ/TPG1CROVgNCtEJL
RJDZTeP93hprQG0IcyG2AvO9DOX9GkATZ9wnimwzsFyfFqKB9on179h+Bapv
P6dowLaFJxPYp92C1/Uua4B1ms04dplIlUjBXQ2oWy7+jN1Om7T4/kwDxPeI
/Wv/vlYkyHJSA1rJ5oPYy+EeuWXrGqDY+fqoGK6nbtHd35ya8Pf5f+biyEqb
Xo8Q5TRhw5pghW3Xs2tzjYkm2PTfAuyADDvJLa6asHCcwwg7iZhqeyBUEyp1
Io2xy3m6QppSNUHirKQcdudHuvO7yjTB4NSLCuyRCr17AU2aoDx86JYEPn+O
RI09fK4Ju1oe9WHvVmnYwj+lCcl7t7diq6x8l434qwnE3FP3sO3bZQnPubRA
ge9PG3bgad8IKXktOO4dfh07xbq8OMFUC4Sezf3Ertj5sfO9qxYsrPPxSiGn
GbV9Ld+tDapmyXIyyNe2ru5Yl9cGtpWD7NgPn6qpO5lpQ0PxZk7sT3nU/bfc
tCHAsZwLe82lOo4pXBvinvQwYfMI0a4eTNeGF1UkZmyNSdEnLVe0YR/BRFEW
2bH6wHeOFm3YWirDIoccHFrMGfRCG4ZuVi/iOKn8uIHGWR0Qsfu1LI9M9W/0
zirXATrSg1XsDMX5FFqLDswFZf7BrvwpV2s0qAM/memHsbtb/V4WTevAoonS
TQXkzwlXVxbpdMHzpraoEjKd5Sd+uz26EP6jSQubj43P5JoisrPov7j2kLPf
hrkuFLxkFMcWYNTI7d2kB8cnJ6NVkMne5UO53HqQtS3cA/vs/Z3c7vJ6YHIp
7zj2A8FYF0kTPbDV8diuhusZ8614nqIH7QzBu9XxfBqhjLYe1YMKtgtrOH5Y
p1so6bQekEPzf2FfLFT1dijSgybFxBXsoV+XK3jr9KBxPfg3djqNpTnQQx9U
Ze5d0sTfZ378j0a4PshLccdhr1yd1N+Upg/GeqI3tJAV6UnxfaX6UBLjHq2D
v+/g/QfnGvUh2v10CfbFDgVGzz59aHOVPIE9xF9iITOmD3EJxjHYLCe3pS39
0ofhu+5x2MbvI/rbtxvAJ90EL+yVvrGPO1sNoIRJ2E0ff5+MvcjwgAHEPKMO
Yx9OuXeoYtIACFUcDIbIJZPS14PXDKAqc+8S9kvT89Pa7AA6Rz0eYDOXM8gx
SAEc/33jEbbhptCjz/QBCOcXu7EjD3ysKyQC/Dk82otd22a76OUPwNx85hz2
l70t6vJxADU5lG4jXN9oyajlfIB7/+luN8Xz721+y/1KgLWKE97YqRqb19M7
AUZcj6tjd+YHg9NrgA9eI5rYvxZGEoRmACKiQQe7QErc6yedITzKSBbErn/j
euo9iyGw7vfmxX6WlHu1Y7chLHdGbTNHnlZ/3HVV2BAsadp/LfB592VjMlXO
EF56ufzBFsrXYArWNASDkqcfsfVMgqRJxobonm41ju28UG6tbWcImre6JrBD
y94fEaAYgpeLzm3sTIddGfTehqAxv77dEq+HDYtaWpAhdNr6lFgjd9XGPn8a
ZQj1ljv+2OD16974o/6UIZysyXmAvbZ9ZldhpiFsZBY/xOa+J6Iac8EQHmxT
7sZWOeJC8rpqCALnunux9/FmH7O4ZQgrYltSsf0fdxfItRgCvYXef7bIE8vb
dP90GUIW5+9r9sgeEnYfH78wBPPo+xwOyG9J2acKPxhChancGI47nnop6Ttt
CLe1uSaw+2/v7lf/aQg6xn8nsc0/uVAZNhmBpPzN69idbBc5X243gicfE7Nw
fzr6n5rK9hjBMO90IxG54YioO1XMCPKPJkST8HlSdHgTKBlBhlSZPvaN3psV
rHpGcKfrmiG2yPKM1YiFEbhFVJtgl4grzVUSjWBCS24r9m5SWO7xA0bwfsGk
Ajs78Y6G5REjEHL9vOyM18ft1fe7I40glTYr6IL3/496cV8SkR/Evqfg/YYt
XrQh0wjacso+YEfrPexJLDKCoPBHn7CXArYEEq4Zwe4As0rsoxesdgrVG8Fz
jZ0r2LSesw1zbUZwuYwp2A3Z69dzSttjI+gYz2D0wOeHGMd6+isjUDqj0uKO
XFMoJ7hJzRj0efPHvZCleoIfPgdjyPy78AX7ys9630s2xsBCvvMIm0/sF0uQ
szFs9ne+h13gqF2n622MFtC+LYeRdyacJDEHGwPnZ/rzfvi8uNWx8jbaGD4o
n3DAZhjdfPF6kjFsm0mxx47dbm4UkWsMr0u3ELFXdFK/mF4yhoKD9YbYof79
qRyVxhB6/g8H9sz5HQrjjcYwEtQkewTvF92Og3X3jcFp0sPsKJ6vS+ci4p4a
g0+BHw/2ftF3vPveGcNfkbEt2EMEvg6+L8bwRzGWGds+/oD3tx/GcMwzZRv2
k9orW1vWjGGDI7QlCNn0w5eqFCYTiGeazqYit7NIOzhzmkBk6LxWOLKWTuCS
uJAJtLseUcKu97tVuCRrApYtmizYcucX9B5qmgB35RIb9rUu9bEcExPwrLnN
ji20FHXG094EnraU1IchF4nck1Z0NYEyY0ntCGROwsbT9cMmINJ4PTQar984
49D+UBNQ/Rx/Hpup9szu4lj0/VtVD2AnjvS2+KeZwIL3Tm/sNebtB7QKTODy
y9nD2BHa9vRbr5jAxHnKxnHked/c669qTEB9H4PUSTx/LL/KBjWbwIhn34t4
nE9p4zqGLhO4GGlBTsDrkblIrWTABAKe2DJiD3ybb1IdMQFKhNY27N5+K/2+
KRNgURdjxe6sKbvvtYjG67G3CvfXlLlq9vuvCXTnsPbi+K1gwpMcZlOIH4ls
T0IOitw5a+drCnmSRZ1ZyIcofiFfQk3BquWtI7abdufPk7GmsL12izM2iXdP
NGcaat+g5opt+yf4b9U5UzhY6meIbTrSk2hSZgpBshL02HptgluHq01hpkyR
Pg9Z7VJkemiTKUS+Yrc/jywb93wH8yNTyHc1k8OeTspU6RYyg33TJ3aU4nz4
Tt5xlzODJsc5Duy3lga6PzXNYPKZ5x7sAemCjrMmZvDDk1RyCeeDec5EzN4M
zu36ZnIZ5+ObWW/rfjPQYH9tcg3no/+iLfGwGRymxS9fR66r+TnwNcQMBOZo
0djXM+3IiTFm8M0xNg7bp2B7lMF7M2C+LEesw/mIPLT26osZiPf9FsMmUe7F
B82bwZ6k6F+3cD60ORkZ183gZNYn9kacD97A1BImc7iysPCtGefjz0NWNU5z
CHigcg1bbWRvbp+gOTB3PDuFLdcWtttb1hwed1alYIte6iv6rWEO1q9SMrDH
KtLa7uSZQ62/W94D5EnHEwNJl8zR+aIZ/Qj568aRz043zWGWb0qhD/l7tdsv
iQZzeLTq/uQp3s9c7LYtt5vDtdwMOezVLQZ8PY9Rf7muyth//1NQPD9kDlvK
pTWw6Q8KGvt+NIe6rol/ZmLbSdb8ag56HFeL+vH+HXFu5q6hBQRsPaL/BllV
NGkj2cYCjpV/vziC1+tABDvFyQKcmJc/jCPrx/iKSx20gOiUK/SfkY1lKFor
R1BcilKE4xZvLG16IyzA8UNgKbbtaW2PwgQLKLmScBXbQVkmxO+sBVxhihDE
Jo/yntY6bwFmm92zsE+aX97bPGsB8cuDLt+RExazFVJXLGBKXdlkGe//lxOM
XOgtoULzaMFv5HS7UJI0myV0bysdXsXnx28v39U9ljDmtPYJ+9x1YvRjUUuw
bHCZxC4imWZcULCEdeG737AvbVK/7K9tCfFud2Wxy2vF/9M2tQTmDWWZdby/
7a6ybimyBEFtngcsFHR+TzUeb7WwghtOI5tlkaM5/ttxjGgFXgOqKorIo1BX
oXDACiZWnjsrIBsH1ujSAqwgdNXUA/taYeWLsggrkGBtOYTN3HXd1zXRCj6o
PR2TRw6av7rOmWkFHu8y5XF8gP9K3rMLVqB172GDJrKadal0SoUVvJ2WuKKP
XBhR0mF02wqeLM926yH/uXKB/OeeFbzTzXiK7fG84FtDrxWw5skNYT/4k5dw
dMgK0q9zpGJLSOVwS32ygizVcgPsVFJmzdg3KyCG3e8xRZ6JTzcpXrYCz1e6
ibbIDjUp70j01vCk+L95G+SGd2eC2XZYwyBPzRNs7i2nGHt5rWFeJ/IFdrRK
fHGChDWsqLf3Yo96xCjrqljDwPi5NWucn/ToniV9a1j1azB3RK64G+lea2UN
8u/rnroiM02EL/qSrcFL8c8j7MCdoanCB60hjVfdBTs1zFV7rt0a1ObGTh3B
4y2lPL/+xBo+W9KnYzv0k30OvrYGs1jflAA83hXHP7zj1nCK3rT1KPIecYec
oVlrmCQVdkcjnyTYSWauWkOZXh5/DPLHGOs2C0Yb+LDxU+skHm+lBXHTLhvI
LzcxxL722nS6hc8GjuzPscBmpjeOC5eygS1Pi11O4HoqApeCmg2In1J5hvsb
cNWrmgIbyLJnsEnD9UzRNiqzsYF0gtrFTFzPBo03+51tgFkrKScD1/OTahCn
tw1UtNFdwPZgVaZ/dtQGPJxOXMZ+oK1wITnaBmRNTUbP4noellU0SrKBZ/I9
pTiemivV9TvHBnKtPygU4fy0i7s2XLQBMin/6mWcn28i80E3bUBMSj6tFOeH
WyhZshH1x/UqB5vblJ9/rNMGHLhiLmBHU3n/K+q3gdKTp3Zjj5ZwW5He2oCh
fAobtvFjzo+sEzbgTtaJqcT1/LnrWM93G1C9fl/hP1xPkR0sCX9s4FL6B816
XM9928t0ttrCacNkBeyB6G2aS+y2cETeXQNb7fqWpzUCthDY8GITduFLem9f
GVv43p1odRvnZ4NuVUjDFuhOtBm34v5WCvg5jGyh5f4oUzfyyA85Y0ZbW4hp
H+PCtpt+cHjZyRY+HLUP6UJuH6OkTx+0Bd+Avihshfdzt4YDbeFChEU8dung
6aGnkbZwzuV36CPknX28qx2JtlBt+lAL9xf/sI6/PsMWXkwGxb1E3pLsaWzy
xRby+XRdZ3B7ts50n3w7COb0red1Qe23ONU5l9qBUbWXOw/y/N9vQ1aVdqA/
l+2D7bWcsKrbaAfvDDuCsAe/cwsodNrB7quzx7BNaDXGQn12kFQuybYHueGT
iS/7azuoNpMVE0QWe/cunWHMDrSFcsMVkM+9CK779c0Olk+MBisj854TfJVs
sg9uxShQLXF7vjiByoV9UFgXve04MnuPtKjP+j6wFtZgx6YLHZIUYrKH+bJ5
Xuw5vji5YXZ7MLbXTY5C/tAjrVzAbw+FUaYTkcj9oUPqBCl72H2Cb+EUcgt/
nM52VXsQ8H/knOeC3w+koUffHhhEXbbkIxeEDZkkWtpDrfwULReZqU/af/8l
ezgakV9Yg/xL76sLo7gDJL55evwLclAujHjJOMA5eYtT2BNT+R6dish5nWex
XfW/fuJXd4BahqW2zzh/ueB9QscBREVXTs4gW9Hyv7wFByD6Br3ZQO7U/+qr
YeYAVU6PvRn2o/MuD77mWTvAqzjnys3It2j5gfP2DrDst6kB2y8f4j5EO8D6
hUfPhZCHv+VfbRxwgJxrd9oOIG9OoNKSXztAEwz1YkvttpXbP+IAz9hTO9yR
7askqXLjDsD6qtbMFznCkL7h75QDrJ7huBWLXPJqdHlgFo0/y0orEflhQItu
+aID7O+1S43fj+8H5+KOrTpACOuVfOyd50IeWmw4gK7Pr1JsDRm7rbyMBBi7
rt+N+3PvkLKZYSZAyla3ulPIp0kMWe07CeAgtzpVjFw5/XEwezcBjJOEvK8i
D8S27vbmIwDRzIl4BXmZ4/x+dRECmPaOeWAL3Ay9tFWKAFPuQQHYpgb7xt/J
E2DI1XB7GXLAS2mJalUC0HlF7sDxHD/GgFhtAlS69AY2Izetf6pxAAK0MdxV
7EEezb03L2JGAJFJM64uZAapQvWf1gR4JL5NGFu2Lex4jwMBuKL65bAdHe3b
LjgRYHEbMfERctSUzKZANwI4Xnlx4yHypZNbzAy8CLDHMeHIG+SuXeMpO/0I
sGl1PP4r8sy1tv7xIAJ0yk4emUZm17uwszGMAId3NX6k4fq/CCclHyfAyKW6
b9gHDjsUusQR4K9B9TJ20h/ZEdkzBLCpFu+dRK7O3ir0N40AsKeJ+xfyoPhn
74FsAgjbW2qwuaL7WUv79SsFBFhL/7mMLeRQ9C28hADn6M6WsiKbfzmmaHGF
AOYWnVXYgdGEMJ4bBLh8eekudt4O+bvfalD9tBa8WJBbrjL9afuPAPxabyu5
kD9pTxhkNxOAfuhPjRLylucdiV4dBEgO6fFRR5Y/VNyt1kWA8I/6PqrIpNUI
5q19BGBzrwrBjs503PdugAD7ZvfEYl8WVcitek2AukXJQGXknqZtr2NGCGBd
6X9IA3nO7guPwzgBWF48knZE5vzc6S5CI8AO3t1Fbsg6USVlS7ME2LJ+Sn0/
8kHWqC/diwR4riBrjJ1yhSh9YZUAemGD+7BrNRWDjmwQYG5p6xAFeaif+bY+
oyN0l36pd0H+c3ByaQeLI5y0llsNc8V/T7ivNb7TEUznfSJOI1uevXiyYbcj
jPwS4kpEPqkeXWxu5ggxDWtcVcg3la5INFo7gpyJlgj2a9knt0UdHGHXeJgC
Nr3kgl4u2RH09z0ovIGsJMLbS+fqCCwf+hJuI7vzGxODPR1hcMr9/VPktD0B
ox98UH9Q3/QG+S5Hrr/tEUd4FH+L7xXyBFvLUgvVEQi6ItLYdrRVO8USR0j2
I++nc0Prp/g43Z5FR+C3OCuzH9mmoCw9acURhiKva2JH5Tze/XPdEXSUR+2c
kSvOzpd50xOB+b104SHkwWQe+UEmItgOys2eQt5INGoyZCPCsaNLJ9KR5WL9
TW5xEEGx6EVTCrLL8Zxn/DxEYL0t3o2dFN7sclaACLveHn+JPWe3Wk9nTQTv
S5a1TcgddMd9pi8TYaDp1Ne97mg/0pWs779GBJnbRAke5KiIV39vVRPB4Y3E
PmVk0u1TNnn1RGDSUtpBQFaaUS6MaCJCbs/kiAPydslPEy7tRCh5MBRpjzx9
MFNZ/xERxpxNkrG7S/RihZ4QYSddfQH2lTdfn9APEOE/1hiyLXIs+wXuqVeo
v793T3kiu9pZHHoyTER1zW49jayV8rOuZowIb7aPuiQhcz4sX8+eIkLxdmdz
HP+xTrAOnyVCQj+jE/ZTLbrzzotEsCtt8MGuDKv9rLNKBE9xFaYE5KRaNyWB
DSLEHFmczEb2mmaO2cRIgqWw7NG7yCDW/HiCmQRRboI72pD5Dvju7t1JAsLu
XZ4tyCsXuLyrdpOA/zgdFXto6OGtTD4S9M19j8Ou2xG6FiJCAtVlPsD9nbUW
siJLkSCwJTb7AbL/mWfntBRIICJ/8s1XZPPOk+N71UhwN3Ls1xKyyB8ZxQ1t
9HmyxpN55L/q706MAwnyBg+/x35PTe7tMiPBgNf5r9h3qtS5btqQoFFR5fcc
ct7k54NnCSRI9/pY9BOZKpxbG+yMvj9UvkzAA72vuRn+cXQnQb4plVkBWer8
nIWGNwm6VDanySAzDpbk8/iT4KlReBH2+HabsbWjJKjxnqzEbrdYlf8UToK9
FTe0pJCLEq9HP4wmQWH49xQcj2gj91yLJ0HPfms7IrLjCj1nWhIJHDtEjf2Q
FVXrPYPOkkD2+92rh5DZmcW6k1tJILbngtJl5Hd3t+bc4yGD69po3N4D6H3Y
ptPutCAZ5Po6M7iRd36KYrYVJ0PtueP3FJBlw5V7OGTJcKTuPIsrsjnT11PD
SmTojHRadEc+WHLFsFyDDObJgtw4flLJdT1AjwwOlhlS2OcfcbSoGJMhaO8f
bex6Sn/Ebwsy9MowBTkjP505rfrAjgwau975eiPT4vV/pBLJwJ92dSMHmYHr
VzXBhQwGp8RVLyML3qz15zlAhrwvDuYlB/DfV30lxg6RQfu/TRRspxeCn28E
kGEmt94fO8TnbSmViiw5c/sC8tnVbDetCDLoFa48KEa+nmHFQ3cSjZ9LO6oX
+YHw5tc9CWT48S379zjyaGNLblYyGdpMzv4YRV61CrN3ziDDwcz4zR+ROUdl
twvmkYHtWzgntlLoRO9kIRliiefZcXubLRfP1F4iQ8qbay+HkQ8XkY0jrpJh
/4lu4w3kBAW2Df1KMjTxnRsV90T7xYPuVsY6MogcPdUqhtzkFBf1tJEMb53j
5UWRX37VVD/XSgb5sibAnov9Me92nwxn1n4QsJk5btaK9ZBhtG/7qgCy+PWD
R2b6ybCzYZlHE9lQl1eqYZAMhwcml32RXZ8PTpx4i+otsCEaiBzhnV5mMkqG
8gOxo37IucsmHiwTZChg+PMDuyZ9jfflNBmSWyPp/ZF7BRvfFH0nw31T7flD
yBP/BeV7/UTjVT71mIq8YSFBkPlDBtm9f6rKkXlHRlkX6Jwgh3VfeAPy0sny
RUVFJwitTqetIN9ol+uoSneChXs64VkHJ+FJk/LDHTlO4Jh9Igl7pl6jJ6zA
CX5kWH5OR2ar0e17U+wEudvPPctEVrxu+Fy3zAmyNwlodiA7lJm9LL3mBDuz
agTHkEOLrd/QVztBy9cSyihy/jn7Yd/bTuAVX8L6AflOFulj3x0nWN4iKIT9
yPPkxrcxJzjW3xIm54XuC5v7QU7LGbLiH0kNIPNYHOmsnnCGvplj69KH0P0y
/teZM1+dYbQ8VAT7XkuCjccPZ/iwU6/3AHLG0vZdmr+cgfROq/AssodC4esd
a84wa7JxIAVZ0U+0hLaJAuI3dNqTkemu1B68v5UCXf7nh7BfDGtLFrFSQDGq
ErCvcHXNhHJQYEDz3atE5DB7h3obHgrsiqOXrUM2TR2OFBOkwIOK34Y0ZK6H
h/XXxSggJJtzZgp5cm1+82sZCrw/v8TxBfmuRkxvrRIFYuxKZLBTqEyZyRoU
UOYyNcLeX5lH9NSjQOPdcOJHZNkJAR5tYwqIPpnevdlnEtb4K0d3WVJA/edE
nCnyM2f1q1/tKCCSPuJmiVya0+n/kEiBvpcfTHGc2mejWOJCgc5PA67YRoxv
lsIPUODexsNQbHbwarHzocA515TTBsifo2bjJI5QgG3h/jQZuaE+ymyDSoFt
+esrxchnZuhZ3kZQQFi85l4lspNE1kDdSQoY3etzqkCW9OQtSE1E+UpkPoq9
cqHC1SuFAgdcrc5gP36pJKybSYGLJBv7y8hFrPcmOfIp0L1GZKpGDrSwqJ65
QIGJdwxKi8j6CYMhXaUUWD1vE8V2GM3HVnfNSxUU0Gg8b890GP9/gLYWUUWB
qwUivti3FcIf2N+mAEtaTSx2ot9GstRdCmSFPCtgQCZeSbPb1EaBv/6jmluR
xUa4ON4/oICsSgOHDfJPrrK39b0U2BnpdSAMudte7lL6MwrcWBJQD0K2F0h6
QlinQHvSYfEhZCHKrmwZehegPk/Tx17IKSHTb3MBIt8qN/bDPsm9I2wukNWp
RHyGnM/436cGThf4RTXU/YvsAwbXMnhdYLPWt2HwRe9Hxx8fOSzkAqV0E7KG
yFv/IymDhAtERjr/0kN+O/PxF7ecC0St9LLpI9+UOHLvh7IL7E/XkcSO9vyV
8FjTBSoevQrRQLYpSrC4ou8C5Tfz9fcj8w1tZz1h4gJ/SmyEryHPshYOEq1c
QLrCsqPaF5+PooVy9i6wVFTXdR05O6HWnZHsAnA7eBT7YKu26Oh+Fzj0TmEZ
2/a2sItw0354uavK+8QRVJ+8Cz/yVdxgqnbSm0RF94u+TYreWm7Qdf2wSRly
EUNAkLKBGzg0EZ1KkD31B6s2TNxA/dKgchGyRITO16dWblB3kMkBe6b2ilSJ
vRtwaxgcxa6fYvYNILvB6kZGRA5ylFBYhZarG2SRkuKeI+u7DH/ectANXrfr
NymHoPfdXBORV4fdwPD5r19qyL1PqjzLA92AXrNhnyJyJj1naUioG5xf0AvC
Jumd/IAuT8DS0ZWOzXtsYi9brBswrLmKSiB/qrHdP3LKDYbaXNXskK9NNhRW
prrBxH3bV83IgYL8b6Ky3GDa47rxc2QVyhkui3Nu0DREGutGXsmeJXIVu0Hq
EyW6HuT2x+Tcz5fdQOnFdkHsU5vbB25fc4M4tV6FDmRLXYkd8dVuELOwevcZ
Mlt4pt2+ejfwff80XC8U5bf6VzpfkxucYZEqC0Au+uLx5GubG7QN3vzuify4
6nKb24wbmJ+RLl1HzpxgWpNZcIOczup2bBJ/iM7qshss1vcfX0PmdXoX1bOO
xvOsG34if8o0unuO3h2qmPkjjMPQ7+25+dN7mztIDO5juIIcSMeuprLDHeb/
akqWIatoR4fScbnDPT32uyXIKyHjdc943cEpePo1toSW2FVDK3egyL0tMQhH
9aWeHWezd4cwWR9xdeT6m0tCH0juEKNJMCQgR427Haja745+T4pBD7LB3q6L
xz3dQVJirGAGmYEkP2Jx2B3Y8g+eG0d+cvYc7+5Ad9DzHWvEzu5ap0yEuMNm
m4Ovscl/fc7XR7qD3YbN+2Hk04+up4ldcwe6Yx0GicfQeebttjOryh2St/Jr
v0Hm37yrYLXOHQ7G+HRrRqDz53LX3kN33GGOh+iijXwHosuetbpD0yPHeRXk
xFEFSe377sCbbrxTFXlfzOfq8m53eHtARRGbl69Qha3fHb4zlb+QQZ5qsW2K
eoHycTfTFX/e+vb8l/41dzhXNez9C3nnJV2jY0QPePDZ6Ht+1CRcjHy+3EV3
APi+Py+ZPDEJFukmn230PCGJNcRxxyn0e/fKNbR98wRnSekuctok/PfyQFLb
+YMQuivIzi0X3b8SXFPJjl6w+U54s1cJOt9+fD4WQecNrqEkNalrk3CUrJan
2OYNh6a27beuR/ev8ee3IyIOAWmhUbu6YxLSFVeazUV9IHb3kExLP7ofhdIW
akd9gPVitevfYXT/j/ThupxxGNqz355dmEH3tXJ5bUFtX2i8ysXaujYJMl1t
GRqLvpCp/Fuvd8cU/Lz+vu/1ZT+Q3Z92L0V4CqrjO3R2uPuDPFsUX4nGFLBb
CBs+O+APcksvPLCjWE+ZZXghB30sPoE8+nLC2tbHH6y8l8urkU2LzB1Y/Pwh
9dLmHdZaU1DpeYP8JMAf0m2zuqS1p2CnJLNrapA/HCbtO86AHDF7xNOS6g9P
7cJksD/899Rna5g//I6ZD8RmmxrO3kjxh3y90q1U3Smg2q1Mfm/wB7Ndnar2
hlOgxqucN7A9ABzvEhpVradAh7VwIGFHAKQ1Vgj32EwB0G2wqrIHgAY19u0H
WzS+RR+bCc4A4PZUne9Ctp7sTznHHQBjV1OEWpEd3ql2m/MGwNLTTi9scn8R
/QpfAKj/XrmKvb9jk9FNwQCoc5f4mo/sWe8Xu18kADL2LMcuI5+1vuw/oRkA
4xEqBwbtp+BL9A7DFa8AOO36PaOcPAUFw7Mzgs0BwJN72tby4BRM5IZGbg0/
AsFr3hx6UVNAz3L6W6RIILzx/8YXnYV+/3H37PiPgTAnXmhw9uYULLIlanBf
CAKdH/JuWl1TcNNHtVvD/ChIbLRe5fo4BTb11Ulzm4Jh8tL1M4obUxD/hJRa
xRAMhwb2DGPfGV9L99saDFd405SUkGd+X80UZw4GHXNZ3cW/UyDCYZczvj0Y
WgRq+jpQnCL7M690RzAoh4gIuG6mQabJxQI39mC4sN5SaUBPg0euZhd4uIIB
hOU2bUL+HTZb/Jo7GBbNO52xb6gr3G6XD4bVniGpz1towNB8azjTJRiyrP3Z
htlooPPCedTGLRgyHbPp+pCp0xufmA4EAxsllXQF+dqmG5+7DgaDAcvQYMRO
GgzzOEwmHgqGPEcNM3oOGuxUWaGBbzDw/p2VFkY2t778bc0f/T7Gyp4Fdhqc
9LKcaw4MhldutaKLyPXRP35EBAfDs9f1cdgH9ZS3HDgTDJ//ctUKcdOgvaNe
SfF2MGi/2ZhLEqRBHoPnkdH/giGC/SbzHWQ/K9ZrGXeC4Q/jZOppERoYZLZ8
0msOhoESoTSqGA04XvrunWkNhvCc4l3myDRuLqfi9mBI234xXwW53e1BtvX9
YLgZ+f0ndl5ZcN/qw2AQ3WHsrIrsN8m35WZ3MCS3F7TNitJgF2vysMhIMLxp
jN0cKUUDlRp5k3R6KjgHajswqNCgxP70p3EGKjBuns6KUKPB1oX3MTpbqJCQ
trfUVpMGofnKe3O3UoHrTLu3B/KIRkrTNBMV6N72c8oiW7wbJRsxU0H/cUsc
dv0J9cVCFipI/rrxFZtP4Gz2j+1U2EwVFFrQoEFy57i8JRsV3hey+XLg/l6e
38PIQ4VGv2XBeD2U/4i5RjdeKnQasTstAQ1u7zEjNuylwh+/L719Rqi/1uIf
LPxUeO57gy0OOcl9IcNbgAoeueys0cjzG5ayrYJUCLNmjcV2u1Layy5MBUFL
pu/Y3aa/fAJEqJCVea1EFFl5ypb+gSgVSk4zBlGMUT5Syy/ziFMhMcys9JcZ
DbbI/dYPkaCC/GMVZ00LGoQ8cxjulaRCX8bOxx/N0fip16OEpKlwsypM/xOy
OcdfrigZKrzgfHMb+3Yj6b/nslR4LFFy8AMyH6XKQVKeCqudP9+mICf93jQX
q0CF19QnZ8MsUX9yLa2LilQYu6O/4GtLA9UDoal+ylQIZbMNuoucliPj/EGF
CttYGxLCkT89HBdzVKPC6NI6/TFkjV9FC93qVGjWs0zCzpAidupqUsFJfu0G
H/LEfpbMOi0qCLMdDLOwQ+sn46GruA4VAsctE8IJNMjuOCFdpEuFub/xh/Mc
aTA1r7rMpk8FBXVTM11kA7GZR6cMqDAl/q0PO9/pau4KUOFVbK6jHvLXFDfP
ICMquErJ7FxE/Rm2ciqMG6N6g+cqEcULZvv/OJmieuc6ypxzosGs4JnHfWZU
0Fh3Viui0MDUUf+8oQUVFovN72khF53+eajRkgr3aTUW2sg/7tSoyFhT4d01
rpfY5tM+dKU2VEjr67NhQS7ZK/CMw44K1hum9xmRF+1eF6fsQ/3Tl3C/dKWB
dXym/7o9FYQY8ln6PGhwud5cM5RAheSnf7+dQCaZMVXscUf5nyA4zRyiQWVk
Z2iGBxVIeXkz2Jsqoww3e1LhdO+rxFlkyogSW+RBKvRWl/8Xh1zLNj38zYsK
136rjr04jPYro7KbnoeoUM29bb74CA1cw1wiX/lQYY1yu/Mvcn3FLjNrX1T/
ZgisQWZ6+5i9w48KHL53mWqRWwPS433C0fw7ZHO3LZQG7BdN9r0/hsav43fJ
G9nv+Z+99pFUIBy75f4WuX1Tw/TDKCpAc4zGnigacKoF3tWKpoJB9s+wC9E0
CDgsdqbmBBXEzh+RFUa+XzjiKBJDhRPjuq+x9/TlC52PpQL7p+0JIshH123n
WOJR/pSo07TjaL9WZLwXn0AFccvl15+Q93q1pf5MRPPDbyykJBbvF8ecA06j
+RRek0VMpEFvt7z4xzNUUN4eWzufQAOB1S8LxGQq7CRvVviCfEz2UmdvChWM
H4iNYfe7O2Xqp1HhwMfn594gi2SzudWnU8ElmGAdivx7+IIuWwYVbrjRP1g9
TYNBSfG9AZkoP6r3R8XTUL3C6n53ZVFhu1fhUhhyYofue+EcKvywV9q9C3k/
S09zTC6aH/d+dmGrODteeJeH6jHZeowdmbn8Q5T6OSrwSFw0vZNKg/E5P0pO
ARV6IpaqPyGX2z0kUcuoYDWaJZiRh86HC/vU+q9QYVeEl8HdC2j+fHnHIXUV
zRcDTzH/EhrIKfssnqqgQtmtirNDxWg+xPwY/HiNCvvP9zm8Qh7pPVGve4MK
m4IWOF8jN3BuzT1/kwqFSrzvsM965oYsVlJh/kFAui7yoWp+gn01FWZvZvvE
X6KBGEuUncJdKvzdk1XsX0mDNSd6+bQmtD9OZ/rq1tFg6Erm9slmKujNTYiZ
IVfP8cwYtVIheIL78JdbNDitU9F38R4VpuVlTSeR3ZKUqlbbqJBxA0SmkNUG
W9PIHVTYzWq2TkTeLmARcLsTza/cHvs15C/+g1asD6jw9EPCK7u76LztlTOf
6afC3qCFcuUuGkgmjRlUjlOBu5r+aek4mj+ChXkKE2j+evh94kH2bN5Hq/9C
hcrKxf75MTR+R0Z9zSm0vqa/CCwiF8605rTSqDDISH5Vj6yWhF5qvlJhy7O/
RyyQBwSldR99Q/P3xsjA8a80CGz+mGU5i9Yfr2mk9QJaT8SCif45Kvj75HEE
z6P9SdAm7ftvVK+1abXizdOQ1LzpY9gaFZZtqC9LkEWITaor61RYD9TRn900
De0zR1NObqDPB4wcJ6G4a5L4B7pNIfCCSdlsdMc0rAiOKJ/ZHAKl80H6ktzT
kN+cm7SNIQQkBT4enOWaBiWi1XAGYwgUmTVqfEfun9lQZN8aAn5L2SzzyH5J
d04XMIXA/Y/XzFc4p4FBKOgdL3MI/Ozn7VLfPQ2Xm0UVSllCQDimeTFfYhr0
ie8TRVlDYF/2TaYo+Wl4P5P95jpbCPDw0qp3yU1DRJKFnNzOELhz6vkTDmR2
ob/xdbtCgDenncaFXNvc8EqNIwQy9vK0dspMgzXxiEwzZwh0BSy3v0H9Tc4I
x+nvDgHdlEJrJ6NpSEx6+/I+dwicvF52uMliGgSFsqTMeULA+hhlv4j5NNxr
Not5whsCA0sy42LIFOLai318IaC2fVuAJPLSTL3ES/4QqGp9MONoOg3ZSf4n
nAVD4Ot9Pks162mQExIaGBYKgZoS09MEr2nobX4t5ikSAkOf2Cs5/KbhEDHj
+IRoCKwSmQ4ZH56GTbMmz/zEQyCF/mCxGfKlpN8isxIhsNbybNASWUfodmSI
VAh8z6F+LfaeRvuqb/9PaTS+R2ubY49OQyhRQDhaNgRCX32PVM2aBrbZoWN/
5UJg0jJDQid/GiqT0p8kKoRALd2wKH3uNJgLGQtuVQqBuAtdX7cif25eCUtX
DoEdf2Zvb0eOJ97q3aEaAoz8zUerlL8B36wPf75aCPS2sXoYyX2GpiS+0D0a
IWAZxmOwWyEJSEIvu0s0QyCq5eHKSa/Sjh/NqXuFtUPg/z/PEg2pFTr/e0rN
/nokrfe/Z1dSDU+t/v+eXkKHjqrA/55/m3kf3jH837OI+IJb1/h/T43Z5MAO
k/89/w8FCsBi
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.512439977279294*^9, 3.5124413916331997`*^9, 
  3.5124416901694803`*^9, 3.512442146413392*^9, 3.5124424591285257`*^9, 
  3.512442691914583*^9, 3.512442858468005*^9, 3.5124431133436527`*^9, 
  3.512443374394174*^9, 3.512443559512765*^9, 3.512443719194914*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"q3final", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwU13c81f8XB3CjIQpZIUpk770de2/XClldK+MmK5GRZERWklRmyUqiZHze
SjK/JSsiK5tEyUr5fX5/3cfz8Tr3fM773Hsfn/s54xZgSaQgIyNzP0BG9v9X
UbX8Rd6Sz6pkZPRRrozPmvql3LVyq+vUdlsooh7OpTVnOp/Y8aluU2PYcrl+
91NR83iGmpe2dq9axSmGz4Eaz5t/Ba9bWVUPqq1kh7ZnhjY0U9kXgxvHqNp7
kmJzxsTbZtqH5XcUtCfVZv92XaR73NmcQ3eDRn13Wm3yP/tr+jO9zTwx52P0
qmfVfp0vjZDPHWyu+im/ZeqxoCZ8t6lkbe1Ls8KF4342HMtq8ayDe4pBk81v
B5emnfq+q2Wzyze5tHxrfszjViGlvaYm7UGRvuI433xxzNRT7tG6WlVbXO2P
zq/NEneUuZV2f6pVVItMPk/tad40Efiqar2hxnRcO/JXx0xz4yHmHI3q32pC
EijCiHQQi0bkVjo0W2qUb2SvXi5nwnTDVo8ZeGyrNS8sW9f0s2A0kqMdxm92
1B7mxJFqfE5gvYvt1805/qgl5/je5e5ixe4U1qoRQvfUrIcpXB9Js2PnHAp2
bPv+qp0QFRM2ImfHTjOl1jqI7qu963SWL7x0Egv0aH4lrk0GLVYX24i+wtjA
W+k7z9fJQML7mMS+uwwmf7osUPoROWzeDwrXX5DBcq9ymdcZU8CncTmDPAlZ
bO9ztqj8LgXQCa1JTAzJYs4yx2heP6GEuU5rjZIoOext2vUFJesDcFTtVBj3
K1ns7PedtiaKg8BmGmmuWqWA3TQgFalVH4TBWVbKlYs62FLJXHSL0yEYcLzg
PVpsiBlTOJ3XpDkMjcvunr2ehtiz8/3K7+oPgx2B1b7wqyHG0GjAputBBfMG
VwerXI2woBMtm+2MR2BRQXZub84I+3xZbsDgzRG4P8lwxWbUEFPqrXje7U8N
pgq/PmED5lieCM9tEw4aUP90XOU30R77l3DP92MnDdBPMwjynHTEXGfpDC1C
j8Lnnc6R268csHca8fz9Z4+BetHcQ10WR4zv4d4B675jcPeauNjDYEcsYTdw
eiiKFuS0RCLfJDliyzaLyE6UDuRcjoQ40jpipi+cH3z5QgeHHNJ4HqS7YcOH
L6qKadODTZbgqJmhN3ZEjk/kRy49qN7rU/b65Y0pXZhir16nh+IH4ffI6rwx
34y8I5f0j0PXz6PJgb+9sQctttuSj47DxmbdlIycD/ZhlWH+5+/jcGwnzCNu
0Bsj4/ww+MKYAQqj2f/IGvhgkkaJ74KKGEDGuTg4cvQS5nZF+4XsLgOoRJbG
iHwLxrKe7BdsmjNCqocI27fJYKxtsCHt1RNG+MxWei30czC2SRkSFfaPEWaJ
yjWB5CGYgJSkv6I1E/BePceaLRyC2busOO6WM4Fx0/VUrrJgLCn1iVEjBTOw
s7y1NYdQrKnJTSnCnhlebobJ2XFHYd+XOAVVq5mBTa9yNTc5BmNiUpUwpGWB
kKursoFGMZiKqqO8rS8LvFnLiGH0isHcPa6qXehiAfaFcN+euBgs6XauziWB
E+BRf3xqBM+f1782vhZ/AjgOrzd5hsRgw1PDVskzJ6COTmUwNDoe26fePpej
yQrVi0lB7FeTMD6ZE24l+axwKev4tr5UEmbiJOdd848VXtlRfXAwTsKC4q1J
yJENmlqCjz0JSMLuPwsK7Wlgg6e2K03qpCTs7XDmtRFWdih5JsgQxZ+ELZK/
uDEXwg5VYbTUBPI0jF6479avAXZw2w2+/kk4E5MnrGeSSZ+ExTXO8wKnM7Hz
kfT3j6WfhLrRNspa1kzsxmPxQvYfJ+Gk+D2mLdFMrOKj6VN+Ew4oHqf9raOV
ifVv+1XLlHOAvvbg/auLGdjumZRXGkc4gV1SvaedJRs7Y1SBmXpyAi1VH8dq
Xy6mH9Td5tDGCUslPVVh/3KxgAdLPV48p0DptK7Gv+FcLPv9kYHgmFMg4ctB
Lf0zF2v+ITAaO3EK1BLuFF6muY/NsOpP31Y9DSFjHcccU3MxGk3Pxbz7p8Hw
N6esa/MDTOpi/NrTndPgFjT7LFKmEBPp6rs6KswFSQVR9kM3CrGW8277U+e4
QOFhm2+zUyFG+LUeu5DIBY/iK3vDfQux+Zsxh37Uc8HcaU8OtauFWDjH8aTf
81wwNfDyuqFYIUb7PP/YHssZOGqzYqLwoAgr1JFIp9A9A7UPysRKJ59gcl8Q
05HgMzAW/zTgRG8p1uVvlkNXfAbGf3Yf7UspxZwoJ06y9J8BkHiZOfawFFu7
6/+Ig4IbNMIDKb4/K8XiRP5x80hyg9l2kzyPQynG+iblsaALN3BGFt9u8n+K
lVtzCknc5oZ/rmKN315UYWpLFZVyGDcIO2+WWutWY33XVCRVv3MDhDqxkZ2o
xjwYe2q1OHjg+y4H2RuuamzniYOCoREPBDW3fYkTqsZuqSw3mofzwNrSgJAm
eTXG9SkcbJ/yQNNmaGW8ejVWS6RudRrmgQDXzUO3vV5gerv3dC8cPgvj5Z++
DP+uxb6kCnb5yJ2FB8j8dsLrWsyf57XJJeJZuN8rLJz7rhajqNf/FJp1FgSI
aw1VH2uxO8bDhGutZ0FrY6DYpqoWE5jyHI77eRaA20mK9m0t1hS85ZB8hhdS
LmdES4nXY3bsQWHoHh/oE59fs73TgnFNeMiVtvFB6eTeze9xLdhCkf1G2jof
OGRgrDLhLVi1l3HNFU5+kF9nPl4f3YKFiQLJzYAf2sJ+WarebMHUf0qKGQXz
w4oG57qIVQtG9ersinQBPywG3KewoHmD9V49UcbxHz8UhvI/vJDbit1Vp/Y6
uMMPHCYx/8LS32HnD/7lXT0rAJGVu/vSju8wvq4f34bMBcCXvfNIoPs7bDV1
ugBFCIDCNKfTc5932EurQefSUgF4Ypii+In4DrvG2sGZPiAAVWVXwgUV32G6
XxtGr5AJAp0jx/ZLpvcYbWHlPTcRQZgtO5B7Za4DG/LItzWyEwSOXgX1BdZO
7KFwJrNMnCBw3d0XMlnpwDzWbvRzVAsCQzmjh/lGByZWF5Z+cEwQ+ghVS4S9
DmzzykWz1cNCYO4r4dLU2YFhauePfZYWgpfxTwZldzuweEqLbuQsBCoqVTH6
4j2YaYdWYmmyECyUBn+S8/2AMafI6aW/EgLt6/foiGofMMKLHrnPLCKw18xA
d5urD+MIQxtIUwSolh/suvP2YTMqNTWl/iIgUrGSpCjUh1WQl5DSc0WAosm6
m/J0Hxb0/q5Y+HsRCHDi8nY73IepJCetuP0UAavnxH7T+/3YAfPIMqNToqDu
RnNPtWgQ62EieckYioJ/ncSsSv0gljnixscZIgqDPIv5BrmD2LmH1jMHC0XB
62jB3O1Hgxi3u37h6n+isFnH8WmoeBBb4ld2+bwjCuc32ssehw1iNSuip1p4
xSAy7j9B8ZpBLPw511iphRi43SRZflUZxjRDGHPTI8XA48aROy+bRjBq5UN2
4U/FQKqiaIaUMoL17W8zuw+KQdLfU/+14M59t9xvRC4OfeRqdpGZI5hb4ni6
jKg4cO9yJSjdG8GETD+ZcdqLg8c1mZkiuxFsneHdsUM3xEFOI4jEmvMFq//8
snu1Why6VudehyR9xaLzniZ+HhOHWOH06iWlcaxY4gOPywEJ0P/qv0/Y/4pR
ZbbHEtgloGsokOXWwXFM4HFG+FanBPCk6M3ax09hN/3q7kVOSIB/AvPP4sQp
bE5muJ7ytwR8+cSzOe05henu7X5OpJYEMfKxcY2cKayklXOLjksSHvMcyutz
/YYdSFZnyZaVBI7Uw7NiwTPYBUt3WQ4jSRgPyYzvsZnBWtniCYUukrB6IkVd
2WoG454qvSwQIglF90/zt+P5SQ7ka88tBXsrJhHXwuex8G9TyRPyUuCebadt
em0e+1J2oJxoIgVenOnJ9UbzmGIgf9eymxTc1/sru+y5gOUoGi5eCpOCGRWW
EfWyJWyLzI9qO0UKWipbZuxOLWM2Hbf5rxVJwR+Op1ExP5awuts1ugdeS4Fq
xk5x9q8ljMl2kJj0QQoSPa+wVWwtYbQZy+cbw6Xh2gL9g9qBVczPnvaaRpo0
CJdvZ7RWrWI9XJIP2kuk4bN92/ezaBUTWbBqMmmUhrDLid/nb69hyc9CRvt7
8Xrx+K07uevYUsi9Xfs5aXBat+Hiy1rHDNWa2Cb/SMMUw97hwJvr2NODEwoe
x2WgQs5Z5n3iOkb1H7ndCp8MzKmcS2C/tY5RULFacPbLwNkct+CYmV+Y60cl
UtGCDCS84Ap5hP3CWrKdbgv+k4FPPh+qXfU2MK7z0VXPGGUhUuIWJ+PWbyyK
t+g/WUFZuMgan+l0ZxMbX2lbaVSTBT4zGlWxgE1MrXaBRpMgC+rhQVW9lzax
B1dphDu8ZeHZu2C9y0Gb2J6mmKFplCxQvn4U0ha8if2O1NaKEpaDKzGnf1TI
7mAM2tFew5pyEEmeH7wotIOJUTelSJ6Tg+3+PxWJ87uYUe9WTdIlOdjS7S7W
u7yHeWVLD39LkAPpVpauJds9LM4x4K9KvhysF/fd6rXYwwq4y7mzX8lBhYFS
0iHrPQxbmNP78UEO2redua1s9rAvVdx++nNyoDobS1UhtIdtBZ3PKPgrBx6C
x97JPP2LMSnnvtplkoer5KVh+fX7mAT50JiViDyU9P9ROID2MZP24xSVWvKQ
+OyjdsSTfcwnxYT/kIM8FA6KmU6V7WPxVonGzoHysFzOG69btY8VsbVdqk+U
h3uqBj/fhu5jLRNkd48XyIPz5YLE6+ZkaKxEpcmnXh6muYazfmeRo52LYVOt
H+Uh1CO74NErcsQiVXuIcx6fJxm4pYrIkdT2D+GQf/JA2PYZ2CsmR2aYsMVH
ZgV4ZTv9oP0xOfKN8wwREFWAbOOSCM1kcpRgWHQ/RlsBND6eqeReJkcl9BMt
XxwU4LYfesBiTomSNJqXilgUoSUEeNmGD6LHh3fo/ooqwkvMdYG//iBq/U9G
1kZHEYoJTCtnGw6iyUzSuWeOitDIyniYu+kg2rOviKIKUoSip5MVvhUHERvX
QrFrsiIgirpbFlUHkdwcT1dDoSKcN6lOlmY6jCwrnH8wNiiCRuHRrTEuKhQQ
eJ/J75MiPNSWTxM8QIUIRVfU5G4pQdRc2bUf4dSI5F3nfrtICa6JuSWeiaRG
KeLrCQsNSiC+RCy3iqJGZb9FqjT6lGDfoeFBmi01et/o1Z+7qAStI07ioVY0
6FtM8fYvMmX4R7lOYXvmGCLTn+Q0YVWG2Az51lzlY4iDlkPrsbgyxBUNtCjj
ueKArde+rjLUpL1XS+Q5hk4dlMvoIFcBfy2/wYP/6JC1e9FAxgkV+GDPHKQ1
SoduvaE/4SSqArTyJ/Q89+jQ29PX7Pm1VOBGN5ams0GPdiKX76/bqcCcZVdY
b/ZxJDFmN97orwKVsa3fD988jjyU3nPFx6nA02HzN+euH0cPcqTdzXNV4NL8
iHtC3HE0sJlfwl6tAunFCfQvbxxHyQs0r33Pq8JRHXrqKW5G9Fb3yh+5IFU4
KHqhK5mOEW0Xz6mSJ6nCSy9Xo0NtjEickhDd/UgV1GwDe8ammJCH65u3d+pU
gb3jsUTDJhN6gMQOunSrArPZNrfdNBMa4MzTE5pShZYp65sF35gQTcSRpI1N
VXhsMvJ7aYYJaX4J6cGOqsEve8k5/X4mtN09NUHfqAaRpnbducUsSFzIjHu0
Vw2Y1I7ecf/JgjwSmi6UzKmB2f1FwhFtVpQ3J/gkYE8NNI/l3qgeYkX92ncX
FRkA4MuVGeN6VkRddEDkgAAAq1+t1ovXrEidPND/gyrA9hHmSrZGVhTqPFGd
YwVAJlGXotPEiqqajX+5eQOQH7aVn8tjRbMnG2RFowDCkzA2Xls2xBHOH7aV
BTC0pvuhooEdWQ5nNbwpA/in5v37zw92lChH8Te5BUDY7FnkRD87askKAJsh
AMOKzwOEQXa0+XMshmsFQEOMT65riB1lC/C6/SZThzc74wsh79lRzWeH619o
1KEjUfaZZSs7+hCfUYxY1EHT+nVq//pJtCjb2VZ8Rh06Sazh3Tyc6MDs/lyi
iDoEf1EPPsLNibiy5KgC5NUhurP6tcxxTqSi5SdI0FQHtkgm29cMnMj2Z5Gh
ook6HA58+E+ViRMFFny5eMpOHf7xOgiiDQ6Uan48hdJdHXQiSpw+iXCisn29
qgU/dXBYz6Mxaj6F2qquffwvTB3MuOjR7czTaNKpbq3mujrs6/yRoLl0Gu0d
XTmek6oOdc2mTytxn2jilo68pw5XH8KoxuXTSOqiPcGtWB36x21ODAWdRqbs
acF6z9ShvXzUZsrkNPLufJ8t0qAOxKJC32MUXGhm64jynzb8/GJRnBsLXOg8
n8lE5yd1sBcON5egPoOGCWnXc76qg0tmz0bjLheyvN7P77moDtKpbOmP/nCh
nucsPbK/8f1ccpS+vseFdCftSQfINcDLxtRfcJELtdA+YOo/qgGnI+/7kUmc
QUqqk/UFrBpgW9/e687HjWov8jiRzmpA+YVEqWA3biSW60EOEhqgypSaNmrG
jUo7npYcU9EAm/ev19rNuRH31orBmJ4GtAeN2tRacKM8XonVMisNUPvR/Fke
uBEL4XLGFWf8ehPyZ+IDuFFa7Es5/YsaMCN9+FzAZR5E83znC0uoBkwuCivN
/MeD4idUomZjNeB8fd9WRT0PIqON5qlNxefntdYtfM2DwlVa22NzNWCs6L/c
uw08aMPnkK/FY3yeUK+Ha095kP89A3quGg0orNRfqXvDgxbab9WuNmtA8VcJ
h+bes8ht86Ndc6cG+LfLxP425kVjZxn/Jg9qQE3uTO2qLC+qzBE5TS6jCWFK
ZUk+nXxIoD2g9SNoAkFbWzmwiw8V/q7xfGikCQL1JRSGLXyI4+wmjZ+tJmz6
pXM3NvOhbEvFamV3TWhQFLCiQvyIPiaCQB2gCdIbb43rbwqgpGdoezhcE8if
XFAXChRAB8YpHjyJ1wQthliFyUsC6NpRXY2QDE0okfxus47n20qJs9oPNcHc
q93K1k8ABXr3JDKWaQLZ4TKaSmcBtHKXTmy6ThMuEFdXiiwEkcd7y77qN5pw
ZWchUEJbCE1u3AmJ+k8TTBKCyN/ICaFzPCPspiOaoE76z+GEpBAasOBAHLOa
cN41lUFKSgiZRTu7L69pgjLLqbU5PO+qKjzcsKcJklxGLI1sQkj762x5ApUW
uGZFGb/dEkIYjaC5LZMWyH9tMhtiFkEKSr4bvFxaIFtq5a3MKIJqvJ7lbAhr
QfGDKw1jh0WQyN2fKq3yWpDTxCpDfkQEPW6TnUrX0gJO76oXvNQiiGsj7IaL
mRasl7c1t68Io1zuJkFxBy045Pk66UKNCGKy2P/vr4cWhHix7fzcE0WpUZqB
PYFaYDmkJSlHJYaoqm6w3L+mBUXnqMrJtkRR7FhHg3eSFlgNHGcQ3xZFe9RH
nRWytSBi+3iU044oClE0ozxcqAVk+/mna0dE0bpnxpPBSi14wyx9tzBWDC3o
Lwn7vdaCdLLKpzd/iKNJQc3qA21aEN8WKTJGI4GGqXNl8nq14Etd9p7Ovjjq
XV6vlx7TgsO23BdUyCRQR4+Bave8FlzgGukZxN1SWfDG7ZcW1I8VLrz4Jo7q
U3d0dv9pwZPYF4KenBLoWYBFVzq1Nlx2FdHKnJBAfqH03008tSGusP7acXUp
dMHO69JsoDaES1q0GopLIUfFlt8R17TBgWzXbBU3gZ01nClJG/42xk6kS0gh
4z8B/8rvaMPWGy2FKyJSSHusPVarQBu2h3J+n+SRQirNpw+PVmjDYNpN8xIk
hWQehiYH1mvDF4cni+89pZFw1Ec66nfaIHeeaz/ITRotxqdKvefSgRfPyc6e
vSuDJj3nXjqJ6EBFGJVYH+5hfTXl3/I6QGO2phSdI4N6BbPRLS0deCcpzpt4
QwZ1UK9qnTXTgUG7q++N3suglmWdjsZzOjD1aNyW87ksqu95YGzloQMG9zde
1/+SRdWVv3uXLumAiLC+ZcWkLHqSamIdG6kDXX6b9c5TsoiYfTRM7YsOHI2Y
t5pQkkeOoRf2Bmd1QHHs2JGP0vKIYNcU7beO52/eohoReWSsyHTw4F8dqNwa
/dK6IY+02X0T86h0YWiaLiyxRgGp/Gk9JsOkC6kRH09MPFFAMmMnM7pP68Ib
vdGpvEIFJNJ8mcVdWBfqBtK1HIoUEM/D7txdOV2wKBcoZStWQOxRPKczNHXh
10w2TW+KAmJwuVokaKoLrzsUWuTOKiJqjX7+N/a6QKN9VP7FKSVEwS1cYUfU
BYZ+hfi3gkpol+K6xBpJF/7Nn5JVPqmEfn77UnszQhfWyh2l9nEvvZNSPJ2g
C40fwqVaOZTQVElS88tMXVDL5hm1PKiE5iyv9sY/1AXiu1XZDjO8fv/iN5un
unCmzSLBykYZ/ahw3OSr1YX3FRR7nk3KaMPe5MgWpgvSVav6OsXKaOeQGkd7
py48U533JC9RRv9eiInfHdCFh3ddEptxU7qe1vScwM83SOL7gpuKlt5afkkX
gu1i/vxKUUZiIXdWXqnrwXmNeHNPMVUkzRO/f9NID7T225Y2ydSQQm8Ig52N
Hjw6O8746rcaUo305BVw1QMxmTL58D9qSFPITmH7oh7InAvkdF5WQ3qf9Y06
QvTAMXOOhW9FDRnHKZ7PidGDoy2jDN9xm0sKXfK6pQcXdjJSMobVkPU4e5zC
XT2w60k58HxRDUXo5p98/V0P/sVJtZoHqKOYX2liidt68Olbm5gGtQaKz4/R
sKfUh2X/lApnIw2UbBJIEKTVh5wzMmrMqhoobdfNc4dVH/I6uU2v4b7zxCq8
k0cfqsktnedx5xK0U+6J6cNo55tL5moa6CG5bL63oj5s/vuw/khcAxVV8b5Q
1NaHxu3Lsl8iNVAXS7lhQ64+HOgK7a6+r4lOzNddadQzgPvLdfub+9oonPEF
XbCVARRhjAu/LXTQOFSXiDkbgKpW0q6ahg7S9K1UXvAxgOl46uhm3I9zyj4V
hBjA1V+Uh1U0dRB12xNPh1gDqD8tEySnoIP81ov/MqUagJGh9jqFmg7q5SzM
/HDPAFwU97vqt3WQjOEjwYQSAzC78mZ/3FcX5YTkIY3nBhAndVH6hKMu+lN4
z/pPkwEMjYTu5OA+/zF7ubbDADwa/rawO+mit38yY/wHDKCvPH/znK0u4hNI
PyEwaQBrbmvHSy10USIhtXJq2QDc9lJq1rZ10Up0stb9LQMotBxK8EzTQ+aV
CSMESkO4uGb82+aGHqoduRFAS2cIUHWH+1ysHjpx6PrBDnZD0G60lZ3AHS4V
fT+GzxComC0UZXCPn4+UVJYyBLuEkZiMQD2kmRzevqFqCMlhcpeCyPVRyatQ
pyoDQ3gl8ExCukkfUc0E/fK0NoQDvuZXExr1kS99YOIZV0MIX6ml0H+hjxIv
OyiuYoYggkKt5dYM0Moju49Pugyhzkib6y1u8x5rouuQIfQcSLv3a8wA1W5b
/mGfNgTxJxomuuKGiJXXPH3guyFIxZiP+Z40QhEWJvypO4ZwV7/4gImBEZqI
NGzWO2gEH0wq87rkjZBmmZ4V+XEj8LM698lewQg9HtJebOAwgoWR6MOLuKkp
NaOCBIwgIaK5qIrPCPmJA7OYjBHIZz2FQRsj1OugUj4PRtAecmrkpZExkklQ
1CgwMgKS1ZbY5XxjlFMr9/mcrRF0L9H/W082Rn8mpf2Y3I3g6J1PpXG3jNH5
Y5KUH/yNoKWfxvpEijF6qyh272a4EVxJGKSXu2aM+DyExTXijWCY2SnmCJ4n
Zgi07aYbwbEr7+44XDdBKxivQ+0DI3gq/ESWlsIUmS9zr/s9NQLxktseF1dM
UO0Jrpv8dUZQG8CVQf7dBJ3Q5uScajGCnWkhdBd3OIn9RW6PEVwayA9J/WaC
xvNOGBCGjWDr25vJ9WkTpNnJNHFsxgj6e/rcZFtNUcnv48HtP4wgLKg+GPMz
Q1TcdDQxf4zAZ9vBpv+cGfI1PVqgdNgYOjvSJThw94Yfkd9gMIb4d8KLdbhl
nhz6r/KUMfgxdm9X2ZihnH5Kd08hYxDy+/g5Vd8M/dkn2+GSMwbTcuOoU4fM
ke92NiejhjEEvdYp+RhgjsbWRDQPGhvDEYUOIzOSOTJZfOuxZWMMY4dGxsh8
zBE2ZZe86GoMT0aVDA1xi31ZfTbqawwTBI36TNyP+uIG/gs1Bs0/4R4aLuaI
vpt9B8Uag+rJtI8ll8xRdGs1Z02KMfCxtT1a+GWODt100dSaNYbP7iIhI/MW
iJ62JZmYZQKho+V/sCorFH3Iptr2kQkkbv1kLC+wQuv/lgcMykzgSYaOxx/c
blsxO8p1JpD0R+W1UaEV6vtx4pRYiwkoSo0czcOttVCpydVtAv0nz2p+zLJC
tZNangxDJrDmWzHn/sUKnR0ZST4wZQIXGdd535EI6M6ngOrNZROgLd60pkkl
IPY7pwdvapnCVTVj0kaANTrLEXWq7Kcp9BR58QSY2CKGdkEe4l9T0Lpn9usd
brLAAX4uKjNQOTXYym5qi1Y5okRGGcxA653Hvr++LfraLiiZzWkGnuXGBFFN
W9QTOCBrIWAG24V9oyX1tqiBM0rpqLQZ0Of6p+6Y2eHPI4LQrmoG3P0ZxEob
O5R9eUArVt8MHjcI77wyskNU3YLe5x6agUI+/QSdpT3aVFmyP8hrDsfWP5nc
D3VAfhkw5iZkDt3dDVHbuGfms863iJtDjLdmjXWYA3JQXZrklDWHnyZJibc8
HFBfBrhfVTKHOxQ/snOaHJDBQtbsMJiDjerE8n64I2pRXfKU08Hfz8utgJ44
IoVMWMo0NAfWR3miHdmO6NlClu+6mTk0YQta/HcdkVcWRH0NNweT7GDey8gJ
jS5nFdf1msP2203faGYXRBFDWrg5ZA7FG50Cr3ALsBiLnBszB6a80plnNC7I
rJyfJDJtDpm/vyndVXJBIeqUtf/mcR/1d/1W6YLyBse3er+bQ6fYy3MmyAW1
+jQoF/0yhxZ38a8Ur1zw/wd3ooJ3zEE7P7lMCTf9nUutevvm4HxVJywQt5yQ
yWH2gxbg4MH7jlDlgk8oYLRCbQEct2Pzk967oDjCgdsYPe6nQe8/q7qissWJ
vjQWCxi4EprwyNMV9V5rZHHnsIBDXR2RoU6uaIvx7jlZbguIz+t0rsZ96mng
w8MCFsB4QkBzEbe2mun0iKgFvHPOLhC2dUU+/YJ8FdIWEPH3/L6AoytK9zro
c03RAlbIsliMP7qi+r+TleZgAQFzn/I4GN3QeEbTOreOBVi63dVAVG7ogECO
7G9DC1hg2VPawS3cfPlKu7kF6EdiMtJH3JClpVnzPRsLMJSWGlk66IbC5oXI
fR0toKZh63EDuRt6GHFIR83NAt5MvtHjcXdDbcenE+i9LGDEK+GB7Bs3tPK4
uWfazwLCbcIUJxvdEIPKPfq6yxZAefuzoOhrN6TwKYhw84oF/E7BVL1wO3uY
59hHWcBrfUrLItzxf4THhG9YwHSlt8JYlRuqSDvM9S/JAk5XvmNz3HVDfbzf
3HvTLECOnDXf6JI72mnAnhRmW0CDUVPloWB3xGWeuxyUh38+ocj+gr870p0N
FtcrtABZvpSkfNy+4RaX2UotQPx+feMY7kw60VfLlRagHNHb7uDujhqKqf40
v7CAqF9zwQzZ7mhScUYt7bUFzCkqPrA4eQEd+ohi3ZAF6DTnhdyVuoBEL9x/
L9NmATnHaRVeCVxAhJ0Q6sPdFlC5dyNhA3d4qqXpSC++j3qHEUnBCyifRyyj
fMgCxhOH/ts9dQG11x8ZihyzgKXrB4ai5S+gVZNZNvNpCzgonRec1HIBMX1r
ceJesICb256yxzYuIKWwvIKN7/j5nc8Hqi1cQK7Hwmbf/7KA4Ayd2QjcCYVW
gvd2LMCiIMmuEXeVvLjfxX0L+FWjd9Vv6gIa6KF+rnrQEmSPeDx8PXsB/XGd
26CjsYR3glf3fT2JiHvrjcI0vSWkQPfNvnoi0r/1IKKWxRIIksObDJVEFCEb
fl9XxxLQtXu1qaEe6KlEIV+doSWMxX4+3Y17SLjrOY+5JVhZeiYfDvNAlPw/
VTKsLSHnkHy15kUPJMHN3kHmYAmO/5Vq6931QE6cmlYBLpbwkIcr3YzHEyWx
+ox/JVpC35fUH3QET/SKMcPb+KIlkNkdmhPW80QztA0bDSRLKNiY8fTGbbKw
YyKeZwm5TY6fxjm80Kn7V8hYf1nC7cdFc+Qj3sgouyA5fhs/b6VtsybusPRO
lt9/LeFwhwpxuMsbldxaL3CntIJ9Wf2394/6oL6bbKJ9VFbQ2a5QUvLEB+3H
atSr01pBovRfL5r/fJDINW+tZ4xWsFMyaeeCfJD9lfQPnGxWwBPoYF6IOz7o
tf2tU1awBgL6M7hXTXZqyAytgFJ4t7ur4iJCZFeIi/lWoPt2dNk1xw/lKfPX
9Dy2AhU2KpXyJD8UFjL471mFFcQaPj7sQ+GPCM+vG2XWWIHOYEdL/yN/JLEi
mRNSbwXBgUkRXx76o6P8kzP2mBWwxMT6rN31R4uuqZKq76zgd6faD5Ucf/Q+
T+UaVxfe/4lDUCLuws9LXZS9VpCfeZmSmOCPrjHcOzE/aAUnbcObrq74IwcT
vQtdo1bglme7xJEfgBQSfldXTllBxvEbzTylAYiptehv2rwV+P9gSP/8IACt
/bUwDPpuBa75TU68DwPQfwpkd21/WcHfjfdCl3GXXa76prRjBRUPpJVbUgJQ
fJWjxKl9K/jq0sgaPRaA3BapI8kPEsBj/jzvqikJwdnXnTPUBEi4ruz+wYGE
OJw9WTroCXDS+2YbrzUJbd9jdi9nIUDaNR0LE9wDA63PUjkIUP5d+msQ7mq6
wL1L3ARY3p247mpCQrcMuQysBQjw+JEudsWbhLxvfLijIEYAJ9O99aD/SEi3
JWL6pAwBbLeYCu/MkRD3HyHxfUUCsP7osakdJ6F/siNXp4EAWt88E8dwfyHd
7GjTIQCbonTTgQkSelkuy/zUiAAbcWT09Z9JKHPum+stCwLcS7z4U3SBhEhn
MqoCbAkwRvIoPm56CRk7qv+xdCJAivQpIbugS0jg7qqenDsBKv6+7Sy5eAkd
7MvLYvMmAE/Gs+IPuKePGk3t+RMgPK0nags3prcjOhlEgDNvL5t/I15CubFP
wlvD8Xo/jLEIz0OardsfRxNgSXqjd633ErLcpmRKiifAavphoQMHA5G4dI2L
3y0CkJtNp1LtXUIM1Gff32wkQIbqpDdzWiAaeXU4vYnNGjzdu759f3sZbRi1
mMSdtobZj3Os7K8vI/rJMGpjXmuYv3Nob+jnZSQcJNnOKGwN9bxuy5KuQUiX
aun6qIQ1MFI/N/D3CkKueYXqRXLW8EQGPTXF8wgJh78+KtZAmXeBORz33XeM
DVKa1vB8SCGmBHeNXU/Irp416NLoDIjYBaH/VuKk35pYA0EuJOVwSBBaiFZd
S7SyhtZdu5izS0HoAPNmhYW9NXxVFQ1JOBaMTj+t8mZztgbmiRNOLZTBSEnV
k2/qgjUIGxWErOC2+XT6W6mPNdRk2qexHghGl4jDj0gka/j97f5ti79B6NZO
mqNCCD6/uFFnGEUwepJiwEYWYQ0cgaTXG5eC0dszFEPtMdZAZXddkq42GI3X
NWTcvmkNpedC3+89DUY7BpfNbFOsgU7D4bZgWTBiGhc+ejrTGjSO+dvZ4JYI
nOmYy7GG0w98F/ueBCOjQw9uVD20Bv+ALUuFwmDkkWutGVJsDZoS5daFu8Eo
Rox2X7XMGlbvGJ/dPheC8t6+bzxYbQ20Yve+nbELQfU2UWH/1VlDsGZOtzoh
BPUvycveabSGjvOROv64V6+trTu+sYYrPunoPm5qxqdVZ9ut4aN68Ik3BiGI
94nrxZUea5C8eDVk/0YIUldmF6jtw+dXlN0mJwtFDh/7Zq4OW4Oo0+57X+pQ
FOKeXKA1bg0/Hnk1aVCEoowtrfM0M9ZwT/7eQgDuyuQ99v5Fa/Dq2GZ6iLvj
dN3n3B/WsMg6zB64HYJmXvhluf22hiiHWUpqllC0r8dnIfTHGr/f1aQL3wlF
7GPjx36S2cBesuldNhSKNiKKfomL28DDrOkG8AlDpZgIKk+2gfRHzjQHv11B
XfWSrXTpNhD4TP+tFO6VGrn2y9k2sOnliTF/uYJoK5W7P9+3gRWj+j3i1BUk
/kT9o3KBDTQEU3+pPBeOzAt0+h89tgFqNv2vBc/CUeB9w8+UFTYgkv7To6I0
HGXdMRv1fG4DTUuePAEl4ejlbcJE90sb4OwJufkA9zuXiP3lKRsIq1+bj/a9
iiYpekBEwRbsDV9v+RyORBR/e7XSVG2Bal3qTcZ+BDq7Nai3oWkLdUNdquzk
kUh3/YuRnb4trIvNx/aERiLP5QmzJhNb0LfeaF/8FokSZmesuKxs4a+R+ojZ
VCQqm1i0jbOzhfhp/qOSo5GoZ2TVYcHJFgyPeku74V7t/+Vs7G4LQx795zJx
7xWfjPZNtQVK+Uxqw9priE3vYkvFjC2YsN8IaJOLRkvRmzduLNlC2KwB4bls
NGpqiDE6v2YLwczLenfCo1HKxtHj8pv49ayolBhfRKPzYjlDdHu28JI3+cqb
ymgk7sWTt0BuB4JGT1N/V0QjssIq1zeH7WB67Pbb43j+aVSRP/eYHbgvyw9b
43khc9tKIKMdfJ61NH/3OBpdNjOvMWKzAyez532bE9FIO3E09OxpO5A8V/+g
gS8GMbd6qP49awcKww+EPvDGoLm9dYohITv4G3troJ47Br2Si+yokrCD1WQ3
v0HcCSSq1JtydlD/w/zQT9znyjKtXFTsoIOgrBl8MgYJz5xiU9S0gz+xTcMO
ejFoj7Ns/Li+HZgq5boo3o9BH2xli5dM7CCZi9OYPT8GPUpv8W61soM+Bf2x
1dwYROo2Es+ztwPyf8NfaPB6jYOfN4Kc7WDnbOyIAG4GcGswIdqBdJLDp6eZ
Mehb2Pcovot2ILv5g0HleQyqrQnT2SfZwXB179fOI7HoxgolzXCIHcxNHCZc
5ohFNny3e6sj7OAFHX1FPnMs4ndhz06Mxfv18x/HcG/fK3FwS7CD9H3bkFHc
nf0SZ5RT7YA3aapFiy4W5R5rmmPMsgOuT1YRrKdika+eXsXKPTsoc1f4wxkW
i1Rj+i61PbID6qpSzsLcWETb6CT/sATf/+dA588ZsWhyY2EvpNwOXn4dF/6N
+7lY0Fuz53bAR3DfZsiMRbFe+zcFXtmBy43SDq7UWGRVmGRC3mwH39bzTgSn
x6KzY8yMX97agV92X5H7fCz6zVwwXNNhB7pt95AP+3X03kzkYfIHO/D1SOXP
Y7iOzE7Fd1n8tQM95rYFljvXEZfd8TQhSnuQZzwfL4v7Z3qeNeURewhlr/p8
EHdrN//JMVp70JcIYq9NuY6yDr6YrGWyh0Y2h6yIruuICGqPU9jtoZjnKO0b
zjgkd6XzogeXPcxTJifynYpDh18QJIEPz5VrxZjY49DwysTmCRF7eHGXTk4a
91O+i01rkvYQEH5d1RJ3uMtmTKe8Pfw8bEXz3/E4ZJQbo1eoag/eVNdCtSAO
cQwcPXZVC69nqasoeRSHvh/L6bMysIeuJr+zx0rj8Ps1T46ImT3k/tnObyyI
Q2kxVU4Hre3hkMoCwyhu10ZFnvFz9rBBvRa3i9v4+Rn7M/Xn4J90FrNFXCKi
zby3liXlCLxD0apWbbfRQDe5uLuCI6BDCX5JTGko94CPn6SaI2TQ1sviq0Mu
qn3l+1qOMHjX3XqDLg3xhSgt/WfgCHVFoz8P06ehlapCgTwzR3h/yiXtJO6a
eWpPH2tHcMwJWdKjTkNhXJdLFBwcIey3TmG2VBpStR/9dsjVEf65897wCkxD
FBla3IMejlC+X2QcF5SGOrrKXYp88fkquUw+k9JQKiXTo0uBjmBvX8O/jJug
EvEVwhzBKNycYh83e/DMSdprjvAj0XR8wicNTVYanxu77ghS9d1uRnFp6PFc
bU5ZoiOc+qVltduVhnxPc34Ou+0IYs0n7y4PpyEpuxvMenccQbiquTy0Pw1t
p323Yr7vCK9vjrcm48Y6rTO+5TtC2SjN2CPc1ymw3uePHcGPfCrx8oc0pK/M
Rxdd4QgWIwEKmXg/2qBUE9MaR7j88dM9Zq50NFCxmcxR7wg7YwVyImrpKHf2
fNdSMz6fgqjkqHw66izPb3ZccYReSwF1jofpKHWGak/opyMoUg4PSOAmcF5S
2tlyhCTh1HDHB+mI3WYkrP2vI6hafDIqyklHk6kar+5QOkHg271Q9u509Lj9
6W/3I05AT4Z9Tj2SgXzJGGSk6JyAmcDp8I8qA0kphgeSMTtB1MjbrhOHMtD2
penqD+xOsH3B86EIbj6Fs8XqBk6wYSCvwEDKQCukW9O0Zk4wf0WL8NU7A9U8
3eD6SnACU5dLVw0jMlDYtKNz+TknIMtT9HncmYHUTrY9uOLiBB90zX25pzPQ
AYLomJ6HE2Q5R9Fljmagrlt32Fl8neCJ9RW3UtxpbX/tZi45wdq3qLpm3Nb/
iHdrQp2AgnPmOv/nDBT37knS2cdO0Cd7VdpbOxOZuzvS3y53AhVR7UqTiEzE
SXE8e6faCXyvq2x+aMxES/ltJy+8dIIE9e//PjdlopcQXvCh0QkuDvDZFNRn
othxMX7FN3g/45AXdbhNI79VFL13Asv3vfRduNk5cqRoe/DzuKkL6b3IRPMN
xvVhn5zgKeehXDU8N3y+Ptuz5wR1P71ZLypmIfqHyhrBVufh06XdAmejO+hB
6MetNjJn8Ha+I60TfRfpJWt9M1JxgYv1z8u7LfNQ2kmR2uZlFzC99X2VqzQf
veh3jm++6wrUrQ+f3QopQm9jHBKtLd3AZ1Tg7sFjT1Dh2rfgEDJ3ePP928MH
RWXI31omU7zZHTyCucz6FJ8hpumPz0NCLsDrdxaOrMo1KFl8+7UuDxEkIPza
kalalLM2ek6Gjwgcd32s1M7UocfP0Z8zgkQY2pxVfCtVh2oDi/LoRIjQKy01
HiNah95K31T9K0aE/DFjnlTc2/Isb14oESE8P6S+klSHDu3suBaoEkFIlL5o
7FYdYmz4SnFbHe8v/TNc7GYd4rr6pihCiwjqeQXjSrjFVEq0fXSJcEfFWlMP
t8rfhFlbAyJ4fjQ2PxlXhwww33gdYyI4/npJY3ajDtlEmfNLm+H1r176xbXU
oQvqMh1clkRodRgyS5qvQ4HkrN601kRYOClXxThdh6Le/jmyZ0sEB8s3Ely4
b12fKFs8R4TiNvMXIrhztVuNPjsRYUtRkTdxsg6VHnyy8s6FCClqEQYU43Wo
7n1SSo07EX7Uc9FSHn+J3t70F8v3IELB4nWLx5ovUa++5ccUbyLo/3XIKoWX
SMWCNLQbTYS5ecpXRfdfIkMGQujCdSJkLfGEVeO27ZdnHYonwmNZfcVm3Bey
Tr5uTSTC7f3UiuY7L1Gg9b7981tEuJbtFXa07iWKZvm2+/A2Ec4s/hjN236J
Uj6/v38rgwhcm+xb7/69RLk5ZSrhd4gQ25Oea7D7EpXap371zCHCf6FeV21w
M7tVzAw8I4Kp6WqwxblXiJsn7cbbGiIYY8QsgvUrJDFzma+6jgjtr3QMWZ1f
IbUS2/YH9UTQjjDgpS15hYw9lL2SG4lw9ZFxbdabV+gc/+kjVzAiXOxwVL3U
+Ap5LlCUebwhgl9o7PlruIOezhkS3hFhILoiKhl3rE/XskY7vs8s8SMDr16h
1cCFn1XjRNjOXvZeYKtH+x6Br3ymiPCJz2HzsGk9onfYu8o3Q4SxI4mZ52/U
Iy6zePXpOSJcue7yUhm3pBb9wYeLREiS8MqbjqlHmvK5nfYrRFj5zH/yB25L
4bOpzD/wu7L18r0/uN1PV1l+WifCk5Ix56CIehTEqHAiZYMIO/IcOqN4vz8v
bipfpPaA++XLB2nJXiOq33xx/HIe0BqZd1J0/zXiDiUy56d4QLr+WKLlSCOS
KBJVPK3oCSMBjTevxiIk1NacIvfLE+oZhH6aML9Fv5986R7K94LVM38f8bi+
Q/hfUCU6J29wP/R3WlavHTHonVH/4OwNAY2UVoA77Nh1nRQ3b3jwRfBFumY7
Gu+fMTQmeoOx67v9dIN2pJ2ra07j5Q1RtPI2uXHtqMyl1LrLxxs89tbYbxW3
I3p+aodEP294OR3ZpPCoHYV8v+iiT/IG/l/+10Vxf33xH/HwZW/YtbxJI4+b
dn40bT/BGxrOlTG7bbcjksn23I9ab3D2HMwmq+pAQ4znVqpeecPYRfUjRaUd
SOVL47pfgze85tj18e3uQIX5nFsizd7gLSpA9DvSiag8o/aWkTdUu/KrNNF1
In/RKfLyt96wxuDGvUTdiQZ+aR72afOG9/4lxzZwKzUUHxXs8AbOyOXtv7gL
og8xLHR5w9BrkxMmhztR3wsm1clJfJ5TpRc43DuRDLtkZu9RH6C+aBPTzd+F
lI7l9MbQ+YC6YUK6HLELAdn+MWkGHzDY/6VScrsLaf8iGs0w+UDRxp+n5Le6
kOFcT8KdEz6QQwqXckzqQuYj0u912X2A0XbTwgO3dU8u5TaHD8R9D7pEwn0O
kWs8Pe0DPnodPtfiupBLjde1c9w+YGL72Dk/swvdMsz3npH3gTmy/hfkB7rR
bDid+rabDxBO6ISqrHSj7NHvK6df+4DfTHp0RNd/aCYjMPRw0EXgLCikuD/c
iyhp4pZDuX3h6KrYi7adPkR7xSktesIXmh8e37uROoh+0cbKnbjnB92yA1uh
14eR6UBLbfd9P7jPxWpAf20Yld7bl4p+iHvgiBcrbkpntecyBX6wMfQ3ngv3
+bOR4otFfsDDEK5eEzGMXi82Vj547AeEfo1VpSvDiOnZrrDlUz/QbrsSrpk/
jAKCFMsOVfgBXW4xZefwMOpSDBNorPID7keSKYJjwyj/gj+78zs/KL7IRk+S
HUGmDef+Pf7hBwYSKz2Pvo+gp0Tp93K6/mASr2ofHDSKxgxlS3gN/GGNMo0l
CjethHwck7E/qNgamLpfGkUazIrulGb+UJriKBCHO2hXSfOnBZ7TfLV1fD6K
Hk+onJki+INFRZ/w8sQoGnmnRtZr6w+njBtI/F9G0dEy9QnsnD+kMekVHMGt
dlsTq3TyB67E7ChG3H31Fi/PBvuDT0pZr6XGGNqlIT1mKPaHqlODdCO8X5HI
+qUb5E/8QfTQ/u3CoK/IeejyhbWn/hD30PuE+c2vKKMxWGuiwh9yeG+oHYv5
it7lh3J/eOYPodMsT0/g3rxxhby5xh/4eSoYuXELXrw6WV6HX9/4br3t1a/I
0TwS5db7g/uPuzpleL9U2aiHiY3+kEfkZ9X7/BW1sMdEhmH+4Pov59zZza/o
136so+cbf3CZy9qW/PEV8c3GKdu884dP/lEJKrjtuuLZddrx86b5serhTnqW
sCPd5Q8P2XlDWpa+ouaspGHu//xBdcoggHb1K1q7cuvV8V5/6OzXi2hQGkfc
zqnZZP14vqm8K+4xjgjaacE/Bv1BU9pYSMJ5HN0UzCCMD/tDO336pBLuBtos
6f9G/UH+4Ui2Du6VX3cYmsb98effd4JujuPo1Mjd9bIpf6D4j1GZwWEcWWD3
eu/N+EM3iUtW/dE4iiu6/yxh3h98RetP2XweRy8THqSGLvlDouvK+8VP48io
piJ+lTwAtNn8qre1J1B0FyGx/EAAfJVS+0OhM4FeTu8lex3GXcmgewz3ym5x
Ki91AFA8p6WoVZ1A3Iwm6dNHA0Bj7+dpJ5sJZCf8O/MRXQCoHxxO+vh4AqVq
Pch2ZAiAQTF+CrW3E+idg849NuYA+LCdeORjwwTavfz9/tCJAOjgN7g6grtU
Vuw5JhoAY90RLB5sk+jA62ejqfYBYNv9WygraxIpfbIdN3IMgPU3BJ68zElE
WtyfpHIOgPaBiHf86ZPoMXnptzbXAODqPTPtVzmJRtnM52IvBMDRCpcjHwYm
Eb3U9gJ4BoC8ve/U/aFJpGuYv7znHQBK3tsaH/snUYSb/upr3wCIFZ/5MIC7
JnxtLSQgACrmPzl8we2qInnI+QZeT1Yabcw0hTBUIyH+PACun3J6H31nCmUe
cLk4/iIAlM3Qb4ucKeRlcOxxyssAeJ9I42XQOoXUUhsmVV4HQAnbI9+6ySnE
2O95cqUxAIgeWUrC41No4QSzzX0sAObTjCfIvuL9Hd+mGb4JAItui6pDuDML
Arp3WgMgmc8+8ihurzmOQ0/fBwCjQbzn/PAUOn7s5ij3WAAs8Am4Mp+aRlKV
olrJlCT4tuXJllc1jeJ3yVeviZHgkDz5Hardb2hMpKHxlzgJ5j65kiSkZ5C0
c2CilyQJDKgbOSrlZ1BSupDtVykSmK30fJvF88nW6bOWMiQo7PKV+Y5bbjP3
53tZEqDT9Dc2cKcIWLUoy5NgSeLg3D+xGTRzjia1WoEEWUddNsthBimltDrw
KpFggbbSwObqDEpDVwVzlUnANPbYyj55Bs2vS2/RqpKgYXWK3T9+BqmdXXl3
XY0EJNMzmcG4s2yKM7aBBNvmF2gicS8lOLr4aZDgzzQl6XLsDFJvZBKb1iRB
xqHsL103Z1D2954/Ntp47nx/sq91Bn0/faOzW4cE7B7qNJaTM0jbUvWuuh4J
mmMA+/llBuXG/b5Qp0+CyK8qLru4115WSgkZ4j6qRkExOoN0F4lkj4xIUH9U
PDR8eAblnTz1gdGEBN/NfYmiuH+ZDN1PMCVBUmfMY9Zjs8gwOtX7rxkJHvQr
LHjLzaL8Gl35QAsSNM52ZnFIzSKCDlUJqxMJrhKiT3knzaKy0JbAlPMk+Gen
fvISbvKyMHUKF3zfBQdYr+C2G5OgDXUlARXHKeZncbOoinZxdNmNBN1l02UU
xbPogEbBU5cLJKCOP1T6eGYWOVy2Dx0kkuDTHyaVscVZVFNyXMfQkwSzJgkh
GbOziGq4kwF5kWDjfX9xLu5Gn+RoYhAJotXde/S15hDDAy3TL8Ek6HlVeumF
2hzy+vjnpFkoCa4/uXm0WHsOYeS1i61hJPBuOx1HkTiHmGR8XymEk+CSmsTx
wqdzyMfj7I3Kq/j3ITHO/XrRHHqTM2bJHYnvr2zzXzJu1u4srrvXSND3wy83
C7f/X+NVmmgSxPm9NanLn0PcabSONckkOJEuY0RPPo92R+8p06aQILmWbFxM
dB718fOe9Eklwb1vJnuf/eZR2eXq3bbbJMjmnqMvvTSPYpHylzPpJKiYmd3p
951H52jaX0dmkEAmRzN0DLeUreW9kUwSxIQWb8zgpi76GiZ7hwTtYYdsr3nN
o+lVL7v0bBJUX5h6Feczj4pMWgmkAhIIujV0XJucRxH3TGV6Cklw+vbfPSqh
BUSYHWEUKMZ/P5uudOKGC0hEkvjr+v+KptegKKswgONelkvcRGXk7i4iyuq6
cdk0EXoQBkglIBcFMm0TGMDUzgFNwBBEek2RQLyhGakzkiBQECGvoA9yi0Fg
uCjiLSZCWth9d3FUhpSw86n99J/fzDkzZ85zzlUCXU5BoQGBahRlTPQNlbB5
eTsrNzE/aT9Yve4agZOxb2IimWtsTArPlRJYUT6k2s58QlVIX5Sx9V3ENMJX
jXHlzh+HlxOIWpasjtipxqXmqR/JbxCwj45NBI0ap7fOXXW8jt334PqZeavG
8N6V7yxGeQKPTo3NOsRcrrPXrq8nsKDJyyxQOoY5Plfv/tBA4NQxt9pQ5k85
j+v/3GL7fxXv3Mqs6Ks/vgUJVITfR2PXMbRYHLKrqpGAhYOPD6wYw2dJfRss
mwjciXiuupg+hiXtsmBtJwHvijfh1+aN43Luzw/Khgl4VoUl5q/VYIu46JR8
hEAq8R3ZodCgig9TVz8jEHk/cmWvlwanNxv5rfmbQEuRp+gP5iJt/cl6NQHd
0QtRaR4aVHDJozBOoMbkSHaaTIM9Yum6Fg2BxtD8cGmOBnfzQ/kfCgRiVF3L
y7s1aKo8O9KpI1AZU+2Y1abBcfGm4/rX7P8ENxVHxmqR42cPpUwT2N8bZBPL
vERZ5z31LwHH7xNtd23X4m3t3m+/fsvef4PdZUGlxW2c29NZsymU8tLWwQEt
TomfeH4zh4KdQ/+u0EUCnuYLuXdEFCrF1huLzQX0UG54nGdE4bzV8GAFc6f2
7bsLTCi88O9JuMWcyNXmnDWlcC5gjseNuQKKJHseOphRqHowNfzKUsBLvKv8
R3MKJ+6mJ8vPCOinfJTtaklh9LOHltbdAj7SFjz4yYpCR6RZbWaTgF9xITKZ
NYUma9FvBcwLJDNZv8ynkNLhWnOZuZKvua9YSCE4XxoWUifgRuUXK3gbCvEi
R7ONPQKOal0y/RZRSN3RZt6coMNsbrD/ji2FL6Pev73tvA7Fknz3YHsKh7py
jUzzdNjAB2V0OFCwTYs1d2SOVk73hjlRMPJImS9nfqmtXtbvTOFlQ/PhqUwd
FnBJB6PEFOyN45P2lOlQJpH0PJZQ8HpPdJaL1mM7P7BUtYRCxsylTrtsPcYp
89JGXCmceZp3ZWqfHmcLgd2JbhSMrydqrPbrsZh7vURYRqFkVYnCjdlHUnWA
ulNofbldeiVWjwN8QucrKYXNrTf7Rsr0mKxc7JK+ksLnB1Zf5Pwn0Eq4t39G
RmGhOsjidcQElnG5HdlyCqG5Fx7XbZjAYEmA2MSDwuF9nxT9zvwXP5WS60nB
+2bJlgHmLOXP7fO8KSS5FfS5bnmOTkK882kFO29L3GRejBrrOKdku9VsHncH
0+fWUIyU9LddXEPBZdKl8Z59KUzwxxxd1tL/e0LpT676GOouTLZIfQ1t5Srs
K/0M3SmJ2+sFhs7wDs21/oZeUPbargswdLVwdDcGGvofRXcbCw==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5124399898083677`*^9, 3.5124414033235693`*^9, 
  3.512441701197465*^9, 3.512442160972492*^9, 3.512442466900836*^9, 
  3.512442699166891*^9, 3.5124428610327787`*^9, 3.512443117071538*^9, 
  3.51244337804418*^9, 3.512443563187545*^9, 3.512443722297085*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"q4final", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF2Xc81e//P3AjJSQryt577/209zrOObasDlk5KKESKpREVlZmKopKygqn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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5124400146027327`*^9, 3.512441411464862*^9, 
  3.512441709041613*^9, 3.512442172443388*^9, 3.512442472549622*^9, 
  3.512442705371307*^9, 3.512442862950585*^9, 3.51244311975486*^9, 
  3.512443380803259*^9, 3.5124435658145533`*^9, 3.512443724955936*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"xfinal", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF2Hc81d//AHB7k2w3K5tsIvP1tvd2jdDH6CpSXSOEjMqOkIQkIykkq4wy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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.512440029227377*^9, 3.5124414185897293`*^9, 
  3.512441716214676*^9, 3.512442182899589*^9, 3.512442476786838*^9, 
  3.5124427102132587`*^9, 3.512442865146707*^9, 3.512443122550871*^9, 
  3.5124433836398077`*^9, 3.512443568643964*^9, 3.512443727792965*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"yfinal", "[", "t", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k0Vd8XAHCSoUR9ReaZqEhlimKTECKRoQxJlFScq4SiVHqKSIgGlSFp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5124400473279743`*^9, 3.512441421804619*^9, 
  3.5124417195104227`*^9, 3.512442188015747*^9, 3.512442479623082*^9, 
  3.512442713205009*^9, 3.512442865805977*^9, 3.512443123050639*^9, 
  3.512443384145256*^9, 3.5124435691541767`*^9, 3.5124437285782833`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xfinal", "[", "t", "]"}], ",", 
     RowBox[{"yfinal", "[", "t", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxN1gk4VekbAHDk3utuIluWElOoQUWlks5LZJQSWZLsrRhZoyJbSVKMvRLJ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     "]]}},
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.512440077554648*^9, 3.512441425715259*^9, 
  3.512441723240572*^9, 3.512442198343034*^9, 3.5124424830006733`*^9, 
  3.512442716451871*^9, 3.5124428669615393`*^9, 3.51244312397978*^9, 
  3.512443385105624*^9, 3.5124435700874023`*^9, 3.5124437299308033`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
For this animation we will draw: two circles center at each end of the bar and 
two lines tangent to the circles to repesent the bar, lines to represent the \
box of rocks, and lines and a circle to represent the sling and payload.  We \
then animate according to the time solution above.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 4 4 377 279
%%HiResBoundingBox: 4 4 377 279
%%Creator: (Mathematica 4.2 for Macintosh)
%%CreationDate: (Friday, April 29, 2005) (19:01:02)
%%Title: Clipboard
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 283 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def

%%MathematicaCell
%Cell[GraphicsData[\"PICT\", \\
%\"\\<\\
%000000000A<1M@0A0_l<0?on0000B00004P0000000014`\\
%5e0000000N00402P00
%00014`5e038000000A<1M@0OP0200800PP000==H00000@000000000000000000
%00400000000000000000040000000000000000000000@00000014`5e00030000
%00X02P0000014`5e0000OWAYIVH0000000000000001QL71/000000001001M@4C
%04P0001800000=:<004:E4U6AR0XC5YG:@00000000000000000000000000000H
%ool0000<LgAbL00001d0000<JFiTN0000040000<M6UVH`0000D00000CDd0:P00
%dHB0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@B6AB>BBFCBND
%BVEB^FBfGBnHC6IC>JCFKCNLCVMC^NCfOCnPD6QD>RDFSDNTDVUD^VDfWDnXE6YE
%>ZEF[EN/EV]E^^Ef_En`F6aF>bFFcFNdFVeF^fFfgFnhG6iG>jGFkGNlGVmG^nGf
%oGo0H71H?2HG3HO4HV=_g6@=oHmli63?c:H[;IO<IW=I^i?K?@Ikj61iikIcCJOD
%JWEJ^P__G@W:?cFK?JKGKKOLAK7_kB@?6?gG?_OkWRLGSLOTGimL^4l7TloXM7YM
%>djC8_UXMT0M_ZMg_Mo`N6NL]m@UCNO]P37HoaNggNohO5o_j9k7Mk56oT1O]]Og
%i?o040`4_[j?VPD2X90/48;1D3@M1<3WjnKO`TP[b33300`dG/>=fgd:@[1;M_I0
%LBa=4lD:G0[I7o5R2@[4<7`ZnTFAM0/IWfPAm/O5alAlPHIB2m9?B8RD@AS5<TbD
%P3oPD3PT5Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMP[nPClT<6TCoTDPO/UT
%d2O[oOL2O<3T3oU[oOd_Ud/OLkPKgW`:X00XAHXSmXcnY59Q=9XdeSe?Z5AZECZU
%EZeG[5I[EK[UM[eO/5Q/ES/UUSTcVLRV/]T/WUeZUL[W4aPDcYdhW5>PKE_U01@3
%`0I`D3Y]=YEVa69aF;aV=af?b6AbFCbVEbeU]5eVT/^=>ODPUlU]T2W4fcFTdSjO
%ChPKeebPf0>f@1fP8fccg4bY65XfGgfoh71hG3hW5hg7i79[nIPMhcNVVcjdU8Td
%Pc;mVO@Ode_;lkd38OQXGS009lbSm5;jT8`o:mg_n7anGcnWengg/EYdldUlgk:d
%^TOYm[XeR?YBe2jYJVjK7jO<77O23006lRQ0=2`M@`eC?_FPSf_a3l@A34DAa94/
%CA>[;m>PoSn9:k9m^TOQm`:NjI<h^JI@DWIl`:Oi=anf`40U8Ka`U2AhBA1bj88g
%RmAA9lXBS:DYbY:/[?c1227^N/F_fNajWTM1cW6MQhaZdjGY`NZFafVcnYBkdQPT
%lHJC[2`30K?<kSQ?RV^JWRF:?3T[d9@]3D?A54dDn[//8OIn7/NQk9m?dI1L4XC1
%l8XTW]6d5Wbd22`77Y:e:0UCRYE:T_6JmFPYEkaWCFD=Cnd[2=kAMLeeGMNEkGeO
%ZPOd79XU[NZ<EQCUBBi:T`BI:4`DQCUHTYmY0]]0ZM9CaRAKRTZB0]`8791h0QLX
%dg>kbE:KFUPGKMeggQN=iBSMT4WneIh7DM0J1V6c/YJ50CQHMai7bNdf94O65E^Y
%aTHLPLU:JlJ1gC9A^H_FZ4bENN>HkSf?i1T;laTUSo[HNi@4`BYRV:IIlY>O9mVN
%IYW4@Ai;`:k5k92_F=]9@1oP5XEdZJNfS87Xe>Y3M>V9ETFWjQ:Z0X0oh50h91H=
%1hA2HE2hI3HM3hQ4HU4hY5H]5ha6He6hi7Hm3Wk0Wg0Wjmg`nWjnghogjmYHn7k8
%GhoX4oWfoWhngc0W[8IXog`mgW0io<I3=Gm?gnljH0:M2GYDHOAXoEJ]EjaFJeFj
%iGJmGk1HK5Hk9IK=IkAJKEJi8nge;WloKS=H4o7Ro7^kiHogZmH6nY5=gnlG^ojD
%ogg9WaQh8m/M1ZL086nLXml]1/XnGgVh=E;IWm1XM5Xm9YM=YmAZMEZmI[HYLgkP
%<i=7k:l<lVVcV8GRdJ4ZSTjaEj^080@0`fBeGa?9dngkbiYKYI]X;Vi70/Ro>e1^
%e<jCgh7A/mIioS89AoA98Ki_30/1R<=M8;Ah9iH9el5LZ9l_I[_lol0@30D1`90/
%3@>ZZH/@TIm<hOjMWnOAm7J`ak3^=i12D7PXU4AY51J3`<UZGYT7RPCU`NOJG=/f
%bJ?0P[_P36D1::mCh/<Xkl>S7JF?]6lOA^n31/fMbT/<j9l_NjkH^/^ZmWnUaoWY
%1T8BNUJLb>YC^^jPLV`A;l`C3<Dac9</c@?7:DWXNkl894al7R3H;1D3H8QBOii7
%X5X=PbIiZW0NRAB4U2AY`^TG_ZY<I036TK:>l/L_LVQm>R^BhaLoSmb2`1o;e:Al
%96Tjj7bO1j:BkL7bLXlXbW2<ZZ?5/8`TXTS8:c<ceaG=MEgGUNemGkhW^Ne2[XT]
%0WfMYeVhJZW0TJQ/7NLa^W02h6PHOS0<XTQjW`NIfWTWLDAKF]4WmAM6bOAkfb4`
%Cld/YDOGSB9oDXOYlW]1Yl_e@JE^UE33_a5R4@Tmk1WS4c0^^PV2F1Q^7HOR68hU
%RJ<da8:R^FNidUVDQ>R>9@//FOiDU4E8V228IO5jHBg7jIAPUd6`HQF0030LLQfW
%aLKcAS6L2B1MLL]YN==Alf[3BD_JM9VnAi7QQ1ogkBS1Ao7^[J[MJ5H8Xe4HY[f_
%k1/>aK7M2@jFOT5?POAgRT98R5nGiTWd`YATVCH8080ac7BMYk:BKi`6dT@m3j@A
%K5bH3bg9FUcIm<KdbO65<a^kJKA?Y6ZWmOBm[VOCZAcPCh/5BV[j0URHWae;_^][
%W5k9eoHMSfGImXSBO_c2:hYVWIo>Ff:ijR`agf?NbiBRfWDW/=`gSWYjoAMed/g?
%<?8LQC?P?A5e2dh^5>7nF9G5X=0_S0=8a3B6hN2PM4:?Pim@8522JAA55mamFoJo
%coGmoio_o4YDhOXWa8EB50KlGE1CJ48U^<fKHNhmAk2?4J8hL8iAc;hJXedY3SE6
%85NZSIbB=eH:2JRKA@[_RQV95X;@G`5P90LBT>`F`[QF0Q1F48NY?c2W`A@HDmjP
%BP96EReUA3n7CSm;jGiodBhVA=RM4m01?g?3i;RC/f:3c04iGd?a:Z=DL:T7X:hD
%XYUUSH7:>/MKlX=T6Ik1e0T7g8We?Ti19I97^8?7LZDN04@80N6/=8L1R1j2B4B8
%@?HRQ?S^=/RPWL>e0U7MlY@VSC604a;LQ8;LVBXZVE>ZR8lD9@BQU5:>DQEROX@H
%DkeZ:PEkV87dQ29@mBEU57d?<B0Q`o0L0L0/6X;@ERS5F:f7K>hf::LLP>>1m8i@
%R<<MLfaj30A8<<?<IXbARP@0N1lOAOQm3Z7F0LY`aa[STB:@8Ni>bg3]7^?hNA8V
%A4[9<?aWAnS18@GN5JO0W9m466I?dD/oiBd1X5@>PU0YCY>86BhO/:DEX=W<o54k
%8RP4/7T?hNHjbF8>G56]64aXgC8DM22ILGSKBB<eAT`abal3^5f;LFP2@40H?PW@
%3`6080>757V9A;1m1X2l5`000@4R94T9m:bAgLWa?NoDj`]JW0iZPDIe8n0MeE5S
%ENP]FJ]EKZhk5XSUdXEPPc5hYD?b19A7f?QOB]GX<lXlV:I<LWP7f9BB^:jm2F3e
%6d=EIP0070V1234AXQA11V325^FBZAoS[7<>Q5@mQcS/7P3/8@B9h[2>LXDfR:Ao
%A:GNMH2]XAcFS61JD4mYj^fY]EJ^eR_ee7A9Fiha5VdJSl7/Ch_HnRH@7M9IUReK
%IR`LC;724=Gc^ShRDkhU9QJl1`3H6TD0Wa=`9Dd@8HPaaV2E4`9eMiPJT=3<@GdX
%I1AgGU<L?H:=jA;G[]KNfmekkhAAVFj5N2=RiZG?TcZ:SW3iDLG:m=0KYUdTR_0e
%QU[F6SehOL?dLHhAa0@0R1F_Pfbm]7CH?PK@gQ^R>4L9IKC]cHTVM8D1cMM6dSo7
%5RTB>:`:H]_:>jn><LIHcaXFHna?cK4SJ?KQ9lEAlVFMB`:0B=cW7aPdm:HioX_;
%ZA/SZfKYdG]7?SU9B1>AkSa7J>TCPVQ<RK4m?lE0[e=SO78=dChYA@SX7D?@kI>B
%RaK>XKBf8nAn2Mc/4c?03lm0hch77?a0d^Hed5X?@VQB8i;b8HQL98bAhiX@/EOY
%8akSd7/?1h:@[PDM^4P7A2?e8e9]kEn7C>V/55G/BH`A]S:;97H=X1H301112:48
%58<0L3a:7:Yh9ed83=el60;`GLm0?2E/DDVaagk90Q//IncC`hWd=]4P3oPD3PT5
%Pd7Q49QD;QT=Qd?R4ARDCRTERdGS4ISDKSTMSdOQ[nPCmTKoTCoOSoOKkOkhU</U
%<ZU3iPShOCgO;nUd]TCjU42UTVTcnTl4XSn0=9T5;QdTOm>Tm5YckTEDYlWO;jOS
%kOU4X4YTmKXm4OTTZ//Z;nN;mOc/PCfTCmO<T[/2V<dK3ML9A;9I3@J32=AR8L[U
%LL6Bf97^;46=O>?YVAbFCbVEbfGc6IcFKcVMcfOd6QdFHZ=6ZnW/dUXD6^=aT^UP
%M7eU4Y81Sn`QN]e6j]Vkgd2f6hQCm/5@U3l//aPCjiT3i7:O;hX?7O5/O50aki/^
%[M3VM9a=ib2@C2Z0@:1N_Y/W<We0UHYn31n@bnRoneSo43UOCPKmocA`10<1@70T
%2`=0l4@C1D5`HdCI8:XkJ]^h2@]lg/;]i3;F@XeKP`hd[WXFYbW7nmR1_I4:A_nh
%2R3Y5`9aP=TI7E6SoA95;SWhGdMQG7/K4C80cB4Pcma/oBEaa8d6bG9TVbM9lXBS
%:DYbY:[LZm23J:Dc/=@`gl?8M<3BW^NbJ84k<7XDk<C;/i4K:>K4hQS>H^CZKTkX
%BNlmA]9AoU5?iWD2PIgd8==37aA23D@jlfZk;2WaG:e9DWBU:d]Bm<DcCC=cBf<]
%=];T;@e3/?XU3ao><Pdm7_8TT>A=<L86DMIPaFY:E_AKW>Ni3mX<ilnDRPM5cC=T
%LckCbRdgIEUfII]WFOJ5XdiAmT@U1<a8C4KEA8PdK?fXlLDGH[n_mHYeg><UdPoM
%IXGKGB]YFQ=LXFimNX;AKWcC?[meSJEoGoP60h5PN2BIC/F:A;L2f`eJ3fdYm]XI
%>i^2IR[/eli4oU4F6>>NL6?Q9T8ci6NfBgO?]Eg`i6<>EEKIWmRj4COAlnf?P^Ki
%aW>MIgWVNhAUm[8hgV8`gDVSHIQfRHOYK7W^Xh`JP7PMQlMig7SE4:1;[ASjh`Yb
%Pk/1;k5NaoiRPTKAaF6EXA9;o>NC6h5k^B1c@o:2gkWflke_NnKk_d2H>XN4e1XC
%DJ925Bj?a=TX;YNU96/SE7nm9jST>8j2V:@ZZ4Ki_722o@6]dG@0^C?CFAH]Rf8i
%[UmHPUaX5bR35KfPPm]LU^G_A>omig_OMoh7PXQ`<8hDSL^]MX]CYRdYnZhdjAKK
%4Rb>@[An?KYM>Y4CY>4o[1<4^CF:RIFX<5?lmF^W/R:Z??ZSb;H3/POnIco[I6G`
%1/gLIIhGnolon040GS[DH@d5hjXV8?::Nl`U0nSDU27lE^1KcSU527dMYVA8bETi
%PRi8ijI2J6ULb5D3<9F==TCBh4S1ngeT;B46HA4<HE42ILJ1H[nSg7lP53/QQ0B0
%?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN<AV=A^>Af?An@@=oB>3B=o06DAio?
%mnb^FbbG@BE_nIbimb^J`:I_en_mm_RJ?^J?ek_IlcAo_bQDRABIo?b1CfF?Ej_>
%X`>UCRM?l5PX6XF`;Za@UmFFC?^dB6NBfAfQmfEmBIRg<UGEbgLhgUjG^3?boB67
%bJ1g21fj3?W4H35H_6Hg7Ho8I79I?:IG;IO<IW=IC1@FCBP0bZHJ>Ge^VCWCe6LC
%en_ZTd1oFEl_FFBbXJVTF_>e;NEOJ`:g_eQ/9RS@ISIflT>L]<lfcfV@HB2gkK`[
%Z1?/9G]5;^HGXI^Vc>6ig`NGcNOdNWeN_fNggNohI3bN7@J:GjGaJSmCAnCal=PX
%CHX4O3FWRLYb6nDA?U<HAP6FOSG7jfkEYXTJe[:O4<:S33Y7n?PmSl?8l3fPI/A<
%54D4m5C`Z`_j;[Fl;iX:^2g316`Za`=<M86a1l/<c<H>W5ao[Q7[hb?94TbE9LVB
%K9dWbPT4I@ZTjDXjUd/=<g3D9NObNWm0;G7hfQoW/PAj7VMiePn3PATnCYE:NZl9
%:7;B1`U23O:TWbd1L5XH60GiQB:a1gd<;m48<Nm5XljSb;M8b45;BH@dZAE;^XPK
%oWa:K8bVTe<b4j/Xe9D]CE?E5DeEEMBDnTKjb^dSDBfdbJbo<9n7bN2F7TVQj7dN
%ai143hC6jKId=neT9ZfgJXdFNZo=LPAfFX2P9P/O9l:FPRgDFNm@X98:<`j`JbX<
%]befld1@gI>jNAKDK9Y=LC`[LJ]keIO=mGgOUngmOn0AHceGb/SckeVoKLCXWl1Z
%WGaoWbMa^VbJX7PN2l<YlebBGNVK2BlfdjfBPIYI:DiDCRQ5`>lOIWiLMfH8gUKP
%>nN>K5cW0bId7NN0KWa5j0gBB?K7ioUmXhRJCVJ:cfg26?gQ>0jUZNZJ[Zc;hBlF
%AjgE3b?8jP2k3YLG]lVEJeZTV@C0OalZ/OdcEdUQiTXB163X?Y1:]R217bWZSYlT
%EKYI0:K]RWZX9bfnnj6ZTbFh]2eW5b@ClX^ibj;L]YBX_/QWWcaEM0;gAIl1XNM<
%A_D79e@7MH:?G:MXJTb6bZEW^N/cAVO9n4bC1=Rh;X_UVFQK3R>@i?kYZXWjYL_]
%jWbHjc>jV=_JBElFZ4j=J]6]J_k__Nol7`k=FWYJgi=BmPOe=X<07fgPS>eO?j=`
%[NWbP=JUTc7fZam7T5P9PARm6><`NRIcG5;7T?/O[Odj_;L6C@^;ccJ`:7d?Q7a`
%21?88<XHMihCZ2>Q01V4@jhB437]2LPbhQd`[512d:T;`2@a2I3<B<=A``g?2cHN
%81hN0AQldEc3F4k3`R8DP@PPa31H2b5/2h60=3XQFFb4k^7b_;FbGhX2A3E4RK>n
%>1C44952:F[n2Y/F?;VO56V=DJhf<1NLliP1L8N07GXAQn99H^TeKBh9G8oAjZk7
%j?HNhk1b0A0F0PMXm1l>h:FCLOhmh3:LCTV21i[An=[=ZE8UKe9=[_84hdQQJaCb
%S2W:F81J1abYAD9h7d[F;0?2a;4Cl/aeBe8B^0IL^@GbkUh<6Gb?Beae<TSeAc/3
%Z1?V@0JI@bYV;T9dk5D9DRU[BL:DU;AZ3KSkOdG4ULFH4]/PbWU`3g8fcUW=>NM1
%khg]UE>n^IihU=_]00YdR/Mc?AiWNH<O4T5LT/C4?LFX[1BQ92:44F8]QLb@TNJi
%TXf0;PO12<HIPc33;_HjmTO1BQn/IT^ajC[bc_W?9nOmP@oaVdW6eBTAU:`Kd]0G
%Bl<=<AHdcIP>iURkTl7E9=5<FU?IBQC;08D=m@cg;PQeBl1HIZUC2DfMBHY>co`5
%RdlnCLGJM3o7F=LI`]aARN5F:dFhlBNeBRbL0XT1F@CY[EF^]UKJg4DFlnam/m2:
%Ag[Bn@VIoI7Z<L2?`O1]3FRJ4X942P406S<6P=5cDVbQ1D2d5XNKfdkU?7dhE>De
%Tm?S8C5=3Z?AXfO3aJ45EX`=fU3KJN5XX7<T<DfFiXZhQ7faZD6HJU]CUPLJ4V0k
%iU4;UUJ:dT8P2;QBa2`:fha9T>YC>TE:;<eFQUJ7oE8jXlAcPc0X0lChXAEdf7n[
%^j<6JoT/O^nN]miKcGW_@eMM=O23[PDRAN^ccH^Eh8:]i21Ai:4o7Z?@N3b8;577
%d?`K`g1_Q[;b?DWS7WM6iVjB<j/2Y0V87_AU8IKU`36``lH>@8<>0O`l7G44c1UC
%^7n;g4`O<DF[855>8:hI?4/aN@H36<jDSJV4NEW@I0Phk0CSdKV?kKfa4NS`a:0j
%B459i=<h3JBLTcC8MDMHh@M0M0^=hL0jQdU@^lgYnaBBSha_CV7<FHfY_cc<WIEE
%CdNg_a_?FnDmWaTc7g9MPi27hgg:^b0WPVa;2H5^;/GQBl5Tc<BhZ31_T9Vl;f?C
%4`_DM1Y0UY46>T`mjEI:=8QSSBg0edh6SCa36RXMJ;JdkiN@he1?:?T/YK1=j]1C
%ZlK>/HA0I:6>0K`g@E0X1B70=`KjWU8I11I`[e3PCIPbUXgPoAbEJ0b0h13=U/bO
%aFlU]FI=[KGf`Zc<mm6W:UVL@Ym;l<ggbW^`XUMUCBU^^A6PXMn2QB2365d;Xl4d
%B=9a_Nc0mRESf;nCdNhl1iR^5B:T;XF`]7H0V3SQ@RN6HeG>MmLFgh>15hY20Abh
%<BDUDeTMcI0QQlO1Mb7SBlR132hn1GU0fnE2liIL3?2GWK3f26448D<`V:K7S`3H
%2MWV6gFFm:R`nfj2=3/7@>YB3ofG:FKLo6fNWM?jQ>Zj1>l7@;`VKE22GfcSjd6E
%^H<WXhKPc@_nn9@jW5nHCGZ_C2D^]YS4?PF`[1Ek>0@=lLHh^U/d@[18LXkAgRX5
%L:h9HAPU0D0J108X@0P2I4^9Hi8kN<ciH7KYKJh[gj;4]iVW73li^c8;Rd]H4?A3
%Xm8f<Rj=;M]lb:?lKN?`=FUI`;TjPXQA2P/N5Q>[lBZSb3?kgCP=A_SN73c/dKOL
%0Ved9>626LeNY41>2<5XbQS3DjbUiaJW2FB:L0DcZ?gO_OO</F`oZ440]W7@><LX
%jAcSZTYeaTES6f;J8Af4Q:/f0?;;RD[g;l]R]/`2=@eD;l=H9FcV?b7dTPO`od9h
%=^gh7h7N7T7/Q87R4^4^4j242:2B0J0Z0^242@2@5F5<5@7J7<7BMT:6fni68Da8
%Y4hf[:DfRVoZ96m@Fffn/N2dQZ4R8fV4G01Q1jLl7VdF1LUf4DJ08<a<5f60605l
%M/[@:8_fPJ7l3o2T18161<6T6V6ZkDd>7^;Njb/a0F7^7R847R7B7D740@0J0l7O
%34FBP:7j7TFb7X7Z:4RbGRo13_3a3b8/JP_l@RTN7U3L7n1J1@1D290^TX_X[^MT
%jH/b=ng:W8J/Y4m=4F=A0:BhX^:2B8S47f6/6d6b4H4T4T24262>0R0P0Z2Z2X2b
%5B5D5L7P7ZXb<6:PdB;@PHLhN@OU1TgHBVgDMS1P84M05D6_66b87bJlMR]L>n5W
%6F2=6J[X8NDPmF9<7=6X0e6/9<Yn343636=^@bFn@P@dKD:4Wk4`Jd5B5@kV0N0V
%I`5nilf>I2:@:DTPKN9l7J5d5R5H1h2R384j5V6@:B9j7R7<TN7Fbl363H3b7JP?
%3e8I8K8L8F?fPZbn/b5>54584d4[0X4T4/5H5B5PPV=LC@@8FFSZWG4LcRJW4V9;
%5lQ@lnXj==02Jd7j6J6F6D4@44441X1N1R0^0f0d2lId5Z5/5`_g7V=73VcVj0:<
%7ffRaP`BMP]blhV4FlJn;l]N9i6X7<UN6A:hlhY^W2>[1nZ2cJ8/@j;V6;1j1PdZ
%3f1/YJN@ilT`bBPZ7/=X_bFdQ@;@726n704k;j5i2@6D6F6N0H0N0X4j505:kb7n
%WfHf@ZHfP:7/7>524`4V000D0j666h7P7`7NEf7bPjT6140h0b2j3<3ZnJFg8O=D
%80oh50h91H=1hA2HE2hI3HM3hQ4HU4hY5H]5h<oX56XM78dnW`nGo7gZmgjn7dlW
%FkQf=1^og`ni>o1F9aRig:kY76gnmWZnYfoJ4o7i@7noH5B:?BH?7XaCjQCgmDgg
%EJ8o:KB7kF7mB:joWhnj_1VCICXMCZ8a890oKCTKCN`Uj_gcFgg6GnnG^nZVo[^o
%jaC<117kDj5QJW3kk0j[Ol9@[kRjC@/IEEgU`[VFKVh7EgeWh=Qh<nM9HjQY951E
%CZai[KJ7g@jGC8GbmGbn8doGTm7S0[o<WbmY7MkmAgjlgRlQ1be/]EdmW^ng0hg@
%7Q29S/O3hmWe8XiBWg^7c_GnkI6mgS6WUPJ4nWFhd6NCJRT<Peja6Tmh5PJSoOlo
%l0@30D1`90/3@?144`E1L2ZLSZN9fOIlZ0YBT4`B9:6bJAZWnOJ=:`IYTVVBA84f
%YJ^Y6[C:?fX[1@Z`B2`M1TIX@bB7:fXin7jOJP:jNijWXI1S6:=<R/b2XDBB?LUV
%BIYV8i2DNWnNIkW/_j[bRX;fZj_RT7hg:28hQRn]4Q3D8bZL/:Ze36/ZaaWCP>Ti
%876c3]<`2[Z8olbAFTJYSK@05D4Hm2@L`;Lbngj]W`hK094OYm7hO3K7^O00P00I
%dW@M[4/2LadWL6cFRd;`^WXNAjWfNe6>:W[09dV1j:0V:V2N90P6fJQV3<<PaV^K
%[I_g6UQf9H]SF?I5TfEIMV@C6Da`PY1l7VNZUWdT/>WlKY[6bDa?U4HQOV6`LM`j
%e:==^a4aAMMRU[`WMVfM238/C6:``TO1I5PEh^2d;8<P^2`G1H5I2T6@A_VjKTD[
%j^Z`86YD?X4NJm:HZ[S:B[4L:e65h8C?S3gESjZ:[<Z6/nXb27;UND8=U/HgZOij
%iVZ<K;jLNL0OW@VIhM^O<@fS^7bg;LahNb^^m7Ym4NAI43T=`eP^2X;2T:8ZAi?5
%//7:LZRT:PXQn7`QWHMCc@kBJM7lNSc`l`2=7ACi@4fCI4T:@@Fk`Ja]7;FF?GS_
%o0L3`G1l9`_3@?XTjGW6:_HiMbUCdXAh7DM@@0b3QP5dH<F/Xa>;/:WS9AOan>l?
%12=A@PYnWDMIeUGehY2P:880L1XPR07Q:4VAibW6LDDn177D[b`[n8e7TLJfdSmA
%A?B_ha;lM9gIlo<RQnGnZd>@gE>n8Nfc/m84KGaX7<lF?i=b<;jaYkOJ7ggPin9;
%oV3gjVWnjWDPZ/dZCXb^Sf305d:PUA927:>?T:@CP/2K4^:E523UJ3h;2H4>8LPk
%0V1>2/Kk2B]_<=`?XhA7bkXkM@?lE`[QF2c5X;@`:QgC@_QQ366D<hJ9QLFgi6<=
%d7@kQ_3YV/?G@5R>:QlXa6QOa7D^00O0mai]K?HA/^ho1k3c7J>X4H70@Sb7M18S
%@mB/6oF53PdD3g6_0M8^i0HY8e9`6L@=k3gRU?I8:mR=iThh_Y:L>DLPigiRE2P5
%89X0P3032F4l9`XQ@2Q7L>`MI0UZZ^S@KhTJ?B_@f:JQ2Bj=Ta/aAXmdSLW242bU
%452DPm9C<^=19mjdMTj;d;k9hOhNII2HUX26FcmaYRVUd1>GP^3V/<AdSHXPn1NR
%n5X3d7`;213UDP>l2H2PCSM6ZXaSB>bQ=]7nDHNQA2oRJ4j:4204@9S8W8l21lfA
%lUL96F6D`lRTWOU13FNDlijCeW/P27T>9;CiWi3eN3e2;CiGLGa3Zl68XM:[4T=h
%KPe;T?dfiAXnaiSA6F<P0P0021P2h6H000P5Ro6><lN1nRja>LDV6</I5f^S:N?R
%UaZ1EDa27C>UbS21<XCJKhZchI/bY7n?NX1QjLT4O<?n3Hga9E91n3`8@2`4P<2n
%5d;PYaDRT7F?4MhkCT2c5R;0DHWa>7W851:<==bAZ?Ta@5=:NCnE/?hbI6TVYF<`
%7lc>;aA0]ei23G]WcIZR6TC@F0XUAG`7lZ:bH1eRAiF;:^X@HiV@9e94Q?nK:f2o
%1T385PAhT0n42789XC@S@5P51>?ho@nj7cI>6ImFQ<21CK7lUHO`]aMRl0X1D2h[
%AER/NVm8SdID>_]7TDPOEa9kg7^ALViEbinXeQmIBj2cj1?ZR0^QB99XWYE<L0l1
%`2P20300?`e9h2_8B7X>h>SD0?PH0n?@N0nQ3R94V54;0H8`=J>hLBWYAWAd/Y>^
%]01Z;4P>LX>Y8hi/443OJL:^UL24F;7T=C2@Sl:0Y`/1S30HL=EL5TRLdQSCDZ?E
%j5`:PCPU]JFUF=Md8E68_N6@ZEeLR2BV7YCEl]P5U<X`MO/Q>2`kho4?T4Q;f1Ri
%54ITL>6BDi1d3ETd@6CfCDe;j>c:P4<[46=X>8L`i@A0V1:74=hL1n3eDHZ/`0nP
%[Q@2@<0G`[A^SQ68YP00E@[1db:>VX8aAR2m1X2`5@3P3P:7F>lN0l1lXBTUCl/@
%d1XSC0d1P38SQ62=@RQ>LeoGS_7^GY_CVWM?>1^K9Nj=ckYgC8_?`YE12a5o:dER
%VXE0YQ?RB9bKbThAa@:>?L3k01a3KMnEPD`ZAH152B52TYPIdcoU1Oe66YR:V=;j
%bPZhHmZHD4N03K6>hh3cfh@?:ADaUKQ3W^<5Ni@CKW`d678XaDg5P7jG[5[6BOSc
%:0?T:XE`Z@X5OJX`N;E6DfaKOZgn<5j46:_P/QUQ70B`SZ@@H?3jJV7MN:/k@O0g
%lG5iaW@Xl2nQ[hlFP>XGnA0ci8WLaXf>D1BiESI25/]1S`YV4<9hB@T/bKFMdB@R
%A203D^7`@0IaBR]51]P38gQ_^P7n=PJXc<cR53l84F@]QKVYET?X_j3Q`MI1R2l6
%0K0e1[90Mia[bjG=7G<N7CoJNeM[kHPCD=e;X@ikSg27IR2SGj;2j4ZHU192A05]
%P283`98Ac<N4KXfAZPB0L0^:SJbTBb3n8TAPTC0URBWSDNBe5XJSkVDnXYOAFnQ1
%Yj<4oYK2a^<o`PPG3aPi=3D1Wf0:_ILE6QkGQ[=YE4W7d;`FP/@c1P2MQX:Vf05S
%WK=2h^hlb/A=;nD3I5JBVcaNe77QA19H8;aU:g07eRR67[j:Sl0LOaI93P;7lbMj
%PFYiX4TLokM_D^6[o4:oladOeafWKkYG8BTK7j6P<P<05X4h4PL`L0K[MiEHNhN0
%P@Mj/IL[A2Jjei/h=`=P=j[ARSA8MiVI@`XSKPNH908`8h:H:8:@MIC@/3EPbJR2
%>k]/5T5/5d5iMkI`R/6D6@RSE2HHXQ:A[2bPE8DhD`0bkl800h?H?:cYRh_`AH@h
%@PAH@`@`YHKcG`181@1cbcZ`OhGhH0HC[P6@2`2h3;0[7JiZ5[]aV;0H74<jXHe2
%5HFP<l=X14=h5l>;88@hKT>Z>3JBWPcbE8OXTZM`XhFhFHGX6H5@5XXhM0BhA`?X
%6`7`:3?1[@X8Ol?a]K4:PZecbd5HRImh7bDC3Z>bXKk91DCiTPa`PKm8MdDhD/E8
%</EH?dEXK<EjXHBTF@ETFRXX;4FlDhMbXARhP[6P=dGj=SkB`Ye;Eb;a7HX`O0C0
%BhB02P2H1`I`IPIJBJei:XgXhQLhj8OHMc2PAXK8K@KP_jQi:jVhVC02VXNXNHNQ
%GP<X6P6@6<4XM15`VAB9E/64NdNlO3CS]kDjObokj2P:7BlQLZ7Q70H4PaW@1j9:
%Y`1A^0LXg`C8C0BP;@;0:i^@Ch;H;0;b?@Li70fhOJXh`h?/T@FdTTObj4<JT`oX
%ZiV`ZHeX7SdH6PeHE;nH:h1TV`7/W0B4WCmXLik3J0`a?Z>0_0e8N8N0N8M;:`4`
%L@K@l`NhLh?H=@;0@HAhCYF0e8`Si`[0Xb;hP@TBPR><D0ha7HaXZ[2`5<>YQJW@
%acjYHY=@aaUHLXBL^Ce`@D^YW0LIU3QXa[:PMSf03<W@B2F@?8LT`SP`XS6@e0B<
%a@DlaSK@l2<8[Y7AE:^XFhG8FL;X2lE8D[5@hXhRV`OhNPD8DHBXKT:0M3@KiXP@
%j9l8SQ2Im4O`A8A8@kf02hJ8J8IhY8Nhh9<4O<NhP820?n1@>2@F3@N4@V5@^6@f
%7@n8A69A>:AF;AN6?j1AYoab>AR>a^A@J?B>@BF@bUo_f1?enBmoBb@_Yl_i`=ma
%0ZM0D1P@2080SlO3ZG?R>_ei_5i?Ag_=o?bCAeoAmneDeEMjEV1bRDE1oej`B2Ee
%F3>Bc:>d1^e06f4^g9bh>Zi@ImgF7eFlC:2GR1DIo^UT/IMPT7RMlDIk=m/Q8001
%X=ad?21Ej>_]oiIo_ZSen=E1me1lAYne?BAnjGEkJT6J/2jekjmlk64jBaAKH_U^
%kU6k/_Ke;KmcL6]e>jiRmeGJA^Y]oV1[W9CX?[Y97Z1W[4o/>?]BBY`=JMm1N61k
%NDiRX?bJGf=?GA_QY=5Z1l?2=07hndMoIR=8E2WP50H00H@4EAE5Plb17dc/47fd
%K9YN_SA<nUim5JEYEPT2@85dGAL=4OAn7bf/AA74TBa=4lDAC5DEaI5/G;4[RXXP
%Z[<9HV:SWjOK=9FdQn>@TJl[8RDHY2^/@ahYkGW^OQmXdSA]6bK`80N2Bf01:`3P
%<0@XRN9b@ac9bFY76jHabOCZ4RL4e?8TIjW/d:A`>Oil]6[cTX8dRn8@MLn4_?`Q
%d01]12S@PMD<2U46SAB1[`d[^`@jCQ]=8Ik<bLA?TbA8T2X=1gZ<4`;103@50FEQ
%IUfN4684N9MUTEH5PB3if7NOik[jbImWXPE:/_Ae9/^^b2RKHH7F:PJGWi>llb4P
%mTF@dkSCeH5XZZIe[3mK0bFdCm^7IKe6B3Ij4>TOEYF>UiPgBgI6TcMX?gN0eh[I
%NH0/J01dg`QQZgf<]nbE1]TWnO3S</O]M7mBYkedZ1dW6MHHQT6@]2l;Yi<>d<4W
%nNJ1Hg9XS1l8iMUdGYl^TSTO;cLBYC:_B369Um40XC^I]VZMT7;W0PieL6FX4hZ3
%FLUlGj7XVRj=XnTJCYFSB9Gj4>;WjEYK<c=YRe=MC6bMV8=LcIjbUBI7j`mN:ZZ1
%lW`OY^6fL4/PCN`104005PD0ejP0DaB5>U:I8h/RlAdDI@U0K72I`L]ca13nCYHN
%akWb/;<c3UM98<h9c4Qc531eN832ocaDm0dSRQcdP^M<>_DJjPmOC^RIo:<OAd70
%K1UP00H71D78V5lFaQP>0025NFAL/XOYf7RLa`3F=Y27IBYjX58j_nPOV3afPSKc
%_=QoTGkX8NoLR1o2Q7]mDh/kbDPedV2>?fSGmiHORN_ilA[V]XAm:2^;LQhOj>3o
%b1[N7HCh0RmSFP5KNg0=42ga:A84o=j2ZahSa2[1DLPiAdScE/NHOQAV46GDZT`b
%iTb_T/2B4l9X=@OPj7F?@MPm1mS[:Z?4[ho`CPM1<=8J0db>3h=R;`GX_A^A38Bb
%XPK5b1SGRD2J9PLXW<ZC^;n:@?hZ:B3_5L5dFH8;:DNEmXCBh`AQS56><TIHc93J
%ndhQ;HFK6_PRIQ9XoDS]R<>BPOB`DlAM8Jdf;aGRI8e9XE0S@gQ^SS0N0h2H2@4P
%502g4eH22M08KJ:lE`/db8n;6ITO@SQ62;0BUT6/XAGBSQlTdU[TTR8B8hQ9BAc1
%_YX1Y;42l/`^be5a;LQ;DAoWF0b;jG`79PA88Ln<RinAoSf<T`PN1QeK4R7dYDe9
%VAkT/7f?HE`YA@2U5J;PNA0Qi@K?dIR3aNSK^ZR6=`ATj@LC[P>VXL2dUTBjDU<8
%hiNUTBn5lnd>;WP__[>;?@kQ7eO>DNRK8Q2M``D9PP@<Je3@4D?G/_IcRl`UDEJ1
%5lQ@JWUS:6J=B?b>GYT[<dSTOPmCcTR7ZfL?`Q@o0E0h18KHgaX:kQZ0/0X33d5i
%1iC/<E?G]a684TZGBdQie51gDL;=BFXAh4[DfWXHSRWl4:2nZSoAh5h:beR?]@8c
%eMZmEn/5HJaAX9BBPS9CiCU?AXchSXnQU396:WhBKQYE<nX`oDQlO8SSh7/E>>hn
%eK4U60;hHiSH200366@;PT18R;Fh9d305`>F67P>nKZh1o6b9LI^PY=F_bULKIj/
%Z2amc^?2886mZ@<F[=j5imMAAi]1A0K5UA]eb@7>:a46@b[NC4WTY1ji5VnT/=RM
%8O1D6aFdA/bLP@m1m1V2n68J`hQ`@d:U2@T;=Z1T26QMd>eg`AgQ>L1X<eiH5QXZ
%X2l?]jb6Fb8<KN2HlD:R]ON6/=mmaRgiDTjfc]12275ZiAMhYb2YS=`<:S13R5b1
%<`H0O1e4L85X57P51aj3Y7T8d8/APT1?RN576i13?Qm3hE/SHoA:Al3j7X:`EhY0
%;PH0L:lF0Z1e3X7B141`5<B3j1kSeOXIKgd6_o7QlaMET6Y7/5O9@=/V@2868C:5
%j`ncY4H2G:bn1dglSc@:?EHl_IOc1V7<B;:m4>SX[b>2C9VSk6H</Hm3`2Ed9QGH
%bUN27EjEnS]7CSb@RG4Z9h0P0`42N4l9XEX[QC0i1d3A<A6QKRf5h=?BA;Am?d;8
%BDNPle:^B<nOUI9GBZ^46`8PA0QV8P`D@18=VZaMj]][T;>d3D4UC7A[DZhJR1eB
%33[]J50CJjM9CAlUPlR=3f:mR@OhlQfSo3:6<>28HkSoHFR4bdMAjU65X;DFhIm^
%Bl1E]l>NhATKS?6K7GHHA0kY19^_FA0l0DH75_4ENl`dke41_N9@eiRK^;ZWNGE_
%dI_gSk[8dTXaGKS6@jXg8g@9l=0O`nGP5^903hX9_Rbb7E4:8d;TFh^0oQo3jBc4
%J8;T4N9H?e7JCVa4^7Z;dGP]@@0P0h7<>PM0MPl1l5SW@D0W1?7fbE;o0W]YgX0@
%QI0N^TA<1=`/;GCGC1L_22=`b_[OAhbeV?[7FN]MKjhE^=:<kS5EB>In`3?Q]SJ6
%]N43kHhkAh_m7_[i:XBi[]63`7@A@:PD0bchMXkQb0A0T0a?PjHA3gf<^0bb=cYD
%TAiJ=8PcaX3B3j]P4/C5gPMON6TGo;RW[DIj@A9Da2lELDK5dKOYn6PCb:LIWQ5I
%Ee1VW2<bj>AmS^:P?A>PoQjZf3h7XAXB@T1E7V?TMY;1gSj7R>XE@Wa@^N3>0L1H
%50O0o268Wjg2g]T3Ob?m@0@aKoOb/2DHGhb3B^53nOFnma0;k6[^EjG[B2kk>D[n
%GGlXnbjWYUXk@h`gOmoP8>7302[f7`F:0LP>jJ2d]Q06m4AXK>9F7h6l6l6h3438
%327J7N7HlB7XmfX4<^j0<bBHJ`7fR66d0LhN101212291FinY6LT8:b@oLgJoVj:
%8>Cl4^0[1bjRUV0^;<78kNIlkL8:nbjk2;2=2?2@JBc:8JK29N;lSPAd7/46443j
%Nj4>U>96I@SFh4MFkR8dCHAfS^G:7Z^L3`3/426`6^6i2LEf2b2d2Xo>4n;/>jQl
%k6JXC8CV7^Pl946:6<6@3b3d3h0j0l101<1>1BOn3P`<6Ja6/2a</hbfhc22><=8
%o]1ZM81b5U4dO/;bon[8:lPL;0Af7`7Z7d:L>D9B71024V4Z4N2@2>240@KR2P2B
%2H4X4V4bOj7/Ad;bbdFT=^1?62XJ6/bTZN4U6>376BL`4Pofo/IZ8nG94T;6;dh1
%1VLV8@XF8:m69O4G6FO@=NULb@Ue1lhX06G/mBeJ5f8BaBBF<^<lB<7Z7V7X342j
%2n766l7092BHDO50CV=0@l>T1f1/1`100f0j7^CM0N]6G8C_0Hlo2jT31T843g8X
%G/Wa7F<>nd=N8<7U8k2C8o919394A92FK2C52`T`[HPn7`fFH@0l121:6H6P6^@J
%FT^69LAn9DSDjl]6BncZIlk57f92K?1N<`7d50524f2L2L2H@J[<JTJTC:<n6J6F
%6H3V3T3Z16141:0n10143`3b3f6P6R6W3dN^=X/f/f9Rljem6d`8oXSa6Rh4;`>P
%4Y0@_l`X8X8e3V8e8@df9L/b=46N6L6V42404:1P1T1N0Z0^0TZB2^5V5R5P7]0g
%8F/l=<M4gjbj882A<joDan_Z7O=56/UF9P>j?b7f7V7L<Z6j747:2Pid9j@21N1@
%6U=/:lYR7@UZ360@<J4N4D483j40486D6R6ba>94[G;F[DY0[BLFln5`5/5Z4H4@
%4::n7bP4/<5T5R5/JTin<Y:Z6H0B9dG/`L0>2NXZ6jk>Aj[H<nmTA/Q83d3V3`5f
%5/5`^b[HQ6VN7j?H:V3d3b3h0f0/0`4F4<4@A`Ae9jJV;dj^^08<l<A32nb459@X
%0S@/TD0BV8^fFVb2NU6M97A1A3A5949;9<Ej<bE_A@Z2VX8lH:fF7/6h7H6l6N0<
%0R167DA2C/=TA^96HbLPKjiD8:<jT2?A9>TdAg2JJ4<jU<:XI/:b7U0;38/2h684
%IN68g23VjRo23cBi67<bmHc0b`@`0T]P@85D6YCA8U6_BXFVIDFAAh8dH^OFlbiR
%101:181>3J3H3N61CjOVHf8b<gCL[^84o6643aD@fh3>5SDI0E@Fh0=6V<EZY0A^
%7fNP7b7F7>6d6R000:0F33Bh6T6X5h2B281H2/bD6/6l7PB^0h3P3V486N5h5B1F
%0d0=Dj0P6d7HfTEfT4_n[J9S2N@n7bSP@@<jd^NR7/6R6>5j3P3>2l2G5ZdT6j1H
%1@1/7H7:Vj^@[F7n3B3R3N0<0@0:9n02KL000J9h2D;L6B6N6Jf>7dVJ88?@BJAl
%K`5:=n4/ndSZlJ7j4MGlgF18242023>R5^DTm:MH8IHA20FV5IHM1h@f5d_6gm25
%6Vm8Jg;fG;4l@@A09HT`BHi@@SI3Gh@H7d6N6R6L]hhC>J9MB;6VAZI]9?A=IWIU
%A7I]I^jf=4=5?bU<;mIl92;l]4Y07`7B<b6d5^5<4X2/383l78<dH30l7h=NB=Ho
%?b7VH79[BF:OBD8fSnk58`;mCHc/>:2?K:h<RT5n3KKE@/0R_CD@3`6OKSHX@I2h
%c7:F2Ld84l]B1^6GKjFG8N^0h0=8=^gV5FZOKH@41PNj4F^j6QHFO8ePEf=BNd=S
%Cj61KD3JanR25jgh@T<YL6b4e4F?JnmU?JHf7`7<3b3B2d1n2/2h7D887>6L6>5F
%3ng^2h383^2L2l3o5:;j745X4l4>0D0V1472:<^/7T<]3dT4lCIlk4@BF2CTX4i>
%:<7j7N584^4H1/1R1Z7T7N7l6N6D6h302h3DMNIF<`B>12141406G[E^N0<J9j08
%0@F:aN0`M@3Z`U6Z84_b6:^n3/Kn;Z4eP;H07?P@GN0nhF[bDM4iHH86PQ7BhT0/
%oILf1mP`86ZcLjUc<dEoCQGTJ2=:9G7IIeQ9GP=4LL7/4l504j1^1b1]8<0e0R6i
%DOFiIKBAI[:QIYQgB=IaQoR0[3Q=A<U=32a3ABmS0lV>7>CV6n3@2/2@3J3h4R6O
%1naB7n6B66621L1B1C@/0N7I0^^>iFmT[<9@?J7]5:VNIlNfnf`5KWL/RX1nG]Rj
%1B4ES_PH8G@g2:Fh4n>`2OKHeZ7@8=1R;k8b8;P@7>GJ4b2=TJ9d0ETJ2<bX;UMQ
%@L`[PhmQGS@N=N>n5Xoj3MOd5iU48=8L8<WMK:2>GWTO7:dD1d7D7L7N7/?BA^7^
%EX7X72180X0:5B5d62<T86Hf7j7J7^7V7P0/0d1:5`686`U<<b7H5B4Z4@2J2/3:
%fF7n7L9IK3AJ7jHD?D7l@o?c7Jmb@U4J/b7R7h7V742^2J223/3J3T1l1^2<6`6Z
%78Nj4Z6V6ToK4V;`6IWlKPN0P:`LP@00040D0B@0`PG/c/nfL/]J7MXPonUZ2jRg
%<fX3@J8?DL89L/hN0N67Xn;aDH5Rj@3dRh8n=_;cCD_R86hn3n_VO?I9I67k7`6k
%423b0b>L2;TJ5V>oDRa0Y4a7ITB=QeQiZ;QmR3ZAZBS5R7IU;gIhndNRF><d7gU/
%721P0n0Z1T1n2P6jQX>j746h6d;6j@3`5R5T5X:l<`7X7^AdlBjmGV[E9?KXNTWY
%8HRjG85c[c6B37KIKfF`3mKICDWR;ZG9[/Eo6TbmXP7M1b0ZP?@j8==/6T47/Vaj
%1jKP04ZB2b5O/g=4EX8;CNRkX`8=/j`@5@g?Y9/R>:MD_LoR>U0272GV/><JLiTN
%KN060;1RKj7/7L6b6<0VP@7>7R7`Zd9N4^4B486F645j=F0HNLHd^>H47T1V120j
%4V4d5EUn7L</B?:4V<A0[J9KW9ZLQZfBZ:@h5^3l3b3R4B3j3J6n6T6>766h7238
%343N:42H2D2H2/KgEm9l7oGD2FB^<JGZ0T0R0X504l53BT8a8j7Te_Kj6G6/IiY<
%bdEm6fI@;dG9LfNn0P6C`nonO?X/oW9]PLX>RjLdnoH=>CF87`5f5j5d2:2>280P
%0T0N3Joj6^L9B1>I6eZ7Qf@WZ9b5Qkb9ZEb=b>J?ZIb:C`@JCW?b<ZfUEf7YT67b
%7T7R8d7G1NAbSXoj3H]2CU[B?>KhAU6WF8K4RP:V;aHRPZ2[C7P`1m6>4TL]T:7o
%cOC=PQSd>9HZj`21cj]F0`FU`n6C4Bo20kd=L`5[dBon;`O:h4ZGKYN_=56F2gdX
%bXW>ejJOHZZh0Gdi7:G/GWXDP>9h080gYaGWJTQX7Z780b0N024d4n567PDZ4>3n
%4D0d0F0P7X7:6m0<005@5L5D^>7f3n3N3P0LN0666D6`^/kX95JTa:lB@Hf07n7F
%7L7T5<5F5L3J3R3T4J4N4HRDQiUZ:n7KAT6V06040:6/6j7:6^6f7<9d0T4@4248
%CVY6H47^I<7n6`6h6jTPnQdh58565=`<0Yh45=6/G8YoD8fT:b]>W`]/lFh5Ko5l
%AYHZUd6=hc1B137BW:j4b4WQhHo/>;SL8;hfULbacRjD1KiH`U6RC/95D[H[Y<`5
%bAi]i_R5GiQlAR8hk6:f</VZ7n7ZEXAeb^fB@FVX7b4X4N4Ngb^Ij4^?iPJb[Dh`
%C1Ghb@M05Bid2a0:U21[TFL/H^MD;`bX_?;Jbg]I2<>:4=kHLhFd391h1IkUYKKR
%6OPf8GYF8;i;6VWLZJ4ZeF3ILG/kLjAkhHF@H_;bC^WaKHG/P8LilJ9lKR02P:00
%0X0N0R@h5ba27f7H4`4R4</<<J0K0<0`6Z6>6T<b7R5F4l4JM]`800100X0jMn0@
%787ESCR@iBJV;67DI`4d4`4f3Z3/3`4T4Z4b6hgRHcaK9DDZ7d7J302T2>4/4d4g
%D07RA2Ch7V6b6L6T3J3236K4HcbLHd=S4`0D0@0B6FXh?N6X0f0d0kKcPNPNOXoV
%nf>:`UcS`WB5a<WZ80oh4nh90X<ofE2@C2e]3H?0Wa4H<oXY3go17g4h[0Wk7Hm5
%XXoX=7h4nI<09@HID4iHEILaYQ1WY<go8Y[=Gjog/mGa=i_7Y35Y91giAH]AjABJ
%EBjICJMCjQDJUDjYEJ]EjaFJeFjU=X?=Yc=i4oIjo9k?GgJ7e>W_5gkKGnkYcAGh
%Ze:YG4gFnj[hnGdnWi0/2og^ngiQY5RL2oWiHGnlWTl58YU6DRXD@QVB;VdiWKhj
%[YC7[Xh/i]<3=AM=EAJ7C:3G=QC]Fo4Q]@9]cg^G3^h=Oge68doY<nMK3mm1VUbD
%=bc5cDociVm7WdmkOh=/h=6>;Aha[h?bd<3_41O9:?<0=^1?<0I@2@60`E]d5li5
%QWhlXPn7ZngHj7/Rj1;JHIGU4Li[64Taf/2OY;4PC@R209alXPPBeYlLY`74BI6T
%J?HjSZCY<4db9iWZNc0<4PBK;6PJ;WVOQc6b5P=PRJi_VjN<0aDVaj7^NicW@;X[
%2fLAbWBWZM94DYB5>mP06lKY`7j`<X702T[/jCR?8lhlMZlY:<6O<@gc8Sb8W`kc
%PY0SIo]6N[T>B1li5g>TdX6PS@X5=b;>1>j<XO<lnWnSajW^NS9U660H1L288PN@
%=8<nWba/75Io/>RR`d/OImBg>bSdnf=AE7DUBe=DmDECEEBD/SUG;5@J<X:]IoET
%W9lY4`<T;PAeN_D00IQR6AGF8Vam7m:LE8WIAg7HMYDU>E0QfWAX8R@9@STlD1>W
%KK[Pe2TZC:BNeb8<7McUiM;GDc;Ing1EMB3YN@LGXAUk96S/n8:Qm18lI5oSkP8c
%H6EN2bjRmmZE?:3h>T;_GJac/hBD>:CT1keP20;gP6l`3Hl0@003Gh6P>0i<TfC2
%<fB]j9;32JdaJB8nSP2:D4dBi73>=Hf0@1096TJQ`A>Oi/VlL924@A8eJFF1EUJN
%YgWNOak[F^L9ePOij7aG5U8m2Io?nNAcPb1H06RK9[_`OiQ6NJIVKJ`QkU4BA9P/
%1X91448C68IIWb@Lae7GSIZ6RJjO/2L_4PcaI7lKO37;XXJ?D4Pg4W:;W<7McCQZ
%5O:T:6JW@fZFGBFoMS7:1=TO;PXn3lNPa]mR?7IPZ2h:2:8hR?V@56PNJ_O^?BUU
%L?IETFEC2O:ACo:GQi_WNOj7XnUjJZXla_T[3BZO8bjbNWj]O[[P`<o`VOYmWckb
%LboMeJYZVaeWHMa>ThChT2>9@:0T2HS288YE?oLd>iBSkCH<;8<O<@@KH54F=lD<
%kc[WW/;;X`mcaGdf4H2Y1T?d6`I@MPXjPSY8CO34Q8724d2PfRdQD^mjQBaU`_?B
%ah0aihJ02Q/0<080P3/I0T0h1H^1NRg7/Ha925QlScO0nhOhn1k8C7Z>LGHZA=1f
%3Z74B8UQ=2g5l<@?0Oa2Qf3h7`FP^1KSa<P@Mk:^BJW4D6lEhJUUg80RF?lO8kQ6
%R03^0<0h1P[1P3:7/@`R1i4A;N?@MHga_A;7j3050<A0244F:<EP[aj;8CnYM59H
%R:3RTh2NC`Fi@7G:<ELT8JIC496D^mb<5CTSB0g:mPXZgGU8PP@MiT]V4TN5c;/:
%4_Ca0>3U<4K@g1/SkNn9`C`V`OQ11l_@73`Hg[:7d?PS9Hc3:CD^KlT;TX:WE@]2
%fL4hIaCSW9>DQi@He?HELH`RiAD9Si<2[BHdCD0?]@FAU[i>B2TR=lT0M0Ua=RJ2
%44<8X306P?2T54:RBaCScS<Cme9Hal3lJ^EV0b0DO3FXd2BSS44eCWM>K6EAAHF5
%>>f3bU0`ZE0LYH=NUa@cXRjYU2H>0KZK;Y5i0iQbGic>O8j62X1i02WVHfaQS9:5
%OPT161mlKEbhDEO6?HR<Ub<Sl7N<dGP/0kQe3`6/>@NQMS46>?DW8lAjSd8jWmbK
%ieJ:_;1=5EYHdF3oO0OPOXm1fS^7P>nJQohj4C;FnLN`jAg1b3D7=ZPoaKS06:70
%?@NGba]7j?Ilhmj9bS7n82c@2k>46C>EPT:i1k6e4PolEA`IJ^[5kJ/KU[GE/;D4
%W/`A[2>fRLNG@hHlKM:m4L22g`<kP2E^5KI[YH`m1l3cLL?8:KV2n^LY`SYRbL[9
%WHCimQQakeW9a;M@QXf5WKYkN6lEhkbGUE0/ZN4kB1gCODm]@MCAjef[LVdNkJRo
%Sh7^>XLXia>2J4f3O003c<QJU0:YP]UTT=M<=Fab9[c1ZTX^?l4F4da3?UZD>FiF
%b@hALNL<gbWl=dTCHL<^ReC?QgaACH=`[lF1UaL7[62oaT9P88`e=UiR>4M=lNVX
%Y:6<Y>00182@40JPc1TA6B]M6[elSV[4a8oAI2h5X7<>XK`o1d3@<lHP_Xf]G[ln
%F^MJUGT?^VmZK1BD__L[]IA7@oaiclD^L8NHnAh3[3h7<>eOc1dC7n5T;hG`6PA0
%P?0M`ki/7C7V5WABRPHBXXnEK4>3iH`8U5PlhI6<>7i`CSJWS23kH?6WZ4<nXcD0
%<2mZLHnZEmBG7bFT/HHPb1Q4V9DBEYPRQ42>/VjddGc?SV[EDT`n1jIS>6M^Sf>=
%TK9fE/]EF_GSIV9ZbZBi=S1Un@/maHiRB13S76>4AhSQ510G?T<28E@YQDUf;Ta/
%8B=Wf<H^ijj[GQ_/V[QY=V4LD1gMV7S=2K:MJM:U/HSY`jBZGWL^8Z8aN52IhI;d
%:06>8>o6ZDTgd]C^dkfHUhS0W^>1:hl1GT0A>A8L4J?TNmOQmVS7RH<MaKA@RY5X
%7C?0Q11Qn6N=HIb^RJWoi<AEZhlRoZb9<O/O@mZdiS?][[NACB_?6iBYNk9>Dgi=
%AH?TNPW19R>7Ro4M0id542WXBP0@BnbIo2n>Aa=6Q[0^kH6?]eWn`;UddEEMk/A]
%m^36@IcQaS[Hi;8A:S3[23>[l6ShPd/@Hn9UN1^c@P;M8iCmg[Q71QnEbD6408@?
%aO2o5n?<N@m@>0K0l<LH`bLcV:OD^hO@maoM59ZQIFPoCQkL76:KfcY1IJ?hck_g
%W_OO5:O==m?jOao7jcT@CE[hm]I^7R?0L@h1_R;4N905P;`IPG0Z1@<e@1MRf5a=
%?<18M[4fJfe`SWbi[6788ZdhV3b/Bekf@PQ8:ojBcEGN3_ceRRlEkk6RKXP@b0NC
%fPAL0S_1aXAhM<18Pc2H4CE8HiRBBkOXaRc3PZL`^S^3CcC8PhM0L`LXDHD@Cb50
%APBHCHKHL@d20RJP`POHOa=hOH]XW8RCbZC2>POHoihaI3o@eT6SYHTHW47jLiII
%Bik`O@NBHcHJ_h^9IX9H8@7X6h5`582l:@K0KXL950D`DPEX1X0P18?`>h?AHhOH
%:@;0:P2I:jh@B[`PY433^Q=QPhS0ML>;A@;9Z8Mj1Z2[B:cbZIQ8kcfP?l?iR`8<
%@@Fl@RFl=CbQ<1kh/H8X8`8`L:CQI8BXBPBh:`:X;1C3GZjamBJY2a90NcThMilh
%WXT@MPMHMa_84PFhF`G9hSYBJ;dlEkglFDFLFQN3GB^Q5Y5D6l92>8OhJXJhL8nH
%A@6P6@6;R02P;h<h<XH0V8/<5@`J>9;hVclKb8nX_b9P]/JBC;J0[ACi;P_h3lL:
%U`JhkK38f0S2FXYRFYd8JR11<P=hCLN;A0Rd33aYYH=@Y8^TM;_d2ZlPgcn8P`gH
%L<0PAH=LPboXCHN<>;>8`KhH/PTA=2^ROSoJR29B]T7h_haSJLKJC;mZ^Ke<82=a
%hIV4D@PD92RZNXokU8giOILX3H2h481P080hA8@LV`A8@X1X2`28>X>`>`DLX3B/
%O:c0[Y=T=S_PO@=4Y@I<YTXBT478aa@APH<aRdMjeXKPYSPAlaQ8kY@IBQe8Vjo0
%O@1h1`28K@K<[15LCHO8N[b4C`O8N`MHR4S@VhM@M8MR?H1<DXM`OBm;9lEj^<`4
%F/`L`T`[3A;HNh`;1hOXNHJHIhHIfH>SjX6P3@384`=@=0>HHhHXHPaXNhN<6b8L
%aDG9kDRi?ALQmJ]<^QhaCCbPnchIhIjZ2XkB2/34Y@=2132<3Bd36k_bEI;I@C6@
%g8?H=ThXEThj0;B/3@g`j<@PFhfK40RSRkY/gZldXhOhKdk8l4P`=HE<kd>[GJ>B
%]CIjOTR0RTUSl`V`a0XPTY1J^0PHTAZiFQk@/<f471hZ^<6d]XWQl`P@NJb`_j_e
%0ClQ=2:X?X1H0//P181X5`5P5H6H786XMXNHMkJ`H=2kO9PieKo0Z0T<322LjXT8
%AE4Ji`GaeJ3l?A=1=R5@FPj;ne3HS/@hPbhTA3<T8KeKJR4<69ZPA`AXB4BX;4[c
%h;J;ek/0]8MY@HNI@HNP@cVP=h=`>82`2X3098909Ih`Vii4`<F5;T`e;e;m<1iA
%C0RPJ@JXK@>`>h?84`4H3@4X4@39N@>@HPHXI9c`/9:LlilZBh`LJ0V[mb2IhJnj
%MJ]8`0gii<[b0TKSB3S3^I?e2hH;006lOID4j[P;om6[Ce4[60?DfjW1<kHhYD?8
%QlgI;d[;MSP2lTMR3H?`>MEYHPEd@jfAIAlilI2ZmSXJOQFk<IjkN97H`:m=?[GZ
%j3JRC:J/nQ5/72m/F0T`^2mZOH`AFXTB8I98W8J`JPKX1@0`20mP0X0P0BXHU04X
%4h4@;P<8;HBhC8B`F=MHKEM/fiK]95DLXPZ8k`T:V@GCAaL<U0P@BMOXJ=OhRe6C
%<TfXR9Ckn3bHh=D0/H^KNABd_I:h2SihL<7keYI0/]9A[9FXN0<0;X:PB`BXB0S`
%:P:@;XC@C0D<RQQ1C];T7/8EE4`Z2ENMC1ChG5VY3h>/[DXK1iPm3QQMWUBlYb^S
%o]WZc5WiR=NEWMXJ2[29@C4UVCAjWKCYQLO[Cd2C6EVh4=[84ULECHI0HhHLG<85
%U/G[Y/F9E5UYDbKJ2XUP2LP@R`^QOZ2/P3_e]jfPaaeMNlhX=RH8>EAlL`ZJR8P`
%F]`H7m`X5U`lhhEU]EXimaQaPjF[2;n<j8[eDUXDURBhH5c;O8?=cPHMcd32Fm43
%P4eZMB=]deNU/`T4`@XCYUFMUI7KK8aIIDCmN8O0M0M0N1>@39T9SPliGmKh0H0@
%1P1H0j6P00P`N5i8U@<8LUiYdaF/?Tj/7DMQJX1EjcDX7]k:R<7DNhL5ka=MbRc4
%LY?5YhZmlKCialW`>e_@SPXZRH]i2XVXNhH0GhG1Lh5hP@N9c@M@2@1h50JPJ@M0
%T@^0NIl`n]RT_ii9FQG5IE@l`e`:Tb2[Q@HX1^2XLn2j4Co[EMNZ2iQ<263P[bFl
%jKAn4CmI=Pkf4/5V4n3ZHbj:c1@DjialOhTebN21@LfKi3bL3BeHG[5@3^7jC`4j
%<8?PK68]P@WC^EC5<8fE^e^XOUiJdR]L29;aChk0QhhI=`E^;C5EmBE5aMb/X/Z0
%DV<Mj`1BX@laWX10Dn=KnelmimW@Y=^J2aQei5i=NmmAP8?XI^?Hkd@l2k`2G6:N
%9L89kHOSU3eN1/K0N85h5h6j6dVEKYT8002h2`3MoX2X>Q<PEhEHE0M8LhLe6N98
%PdhMVXG5WF3:KhRcaJ6`0@m=h`>>F0kMOhJ;5PEk`YeU3Q[eQ4Y0[KPUBXQjCPL@
%e01AK/^DlEn:^P;8;@:AGX@CT`L`D`DXD3@@5Zb`Vl90MXOHNPS8W[EZ>@SI5Ikc
%X`RUAD`N:ea^>;bN2hLn7h3Y>PGHfJKQkkX9Q;H]BlKmbkb@hVNk7FNSEPTd[@ge
%Y^P6OVNNO=OE3QCl09cXadKeBm52fKm`YKcPGlfkDYLh7Ka/MU5>QV<6@MPMaUWE
%MHF;T@8Pd@dQ2^3@Qhd`L`C6Ue_Ca/Zll4YmP;``Zn8h7FW;7k7mhf</fR40acA0
%T>4NR<jmV<aNOYCXS/0<k`E:50@nZ3D8JIai<iMnWn9fSii@PJDLnbK<D@NH:h:h
%:HU00Xmh1H0@0`0h:`;@;8GXGPH:JIUDCJmml1QKSPC`BF_>QSCPSc^cDZXPmhlb
%cP1N=<>^Wn=HDj5hIMdAai<eP^GkbV>@[1@CB>Lj1@=LW`>Q?`^3l0NH;h<0;5c8
%F`LPK`J5gX9`:P=PG@H@JhT@NPK0JPHP?h>H?X1`0X30MPN0OL8b>@W`jeFPT/f>
%9Hj=4X4fhf8=`h5Um@Pb3X6AN@>U`HFX4^jNi>i:VQChQXFbh06LL83knP5K5Fk0
%Q^kNk^knl<j^k>lTL>lbVflFkBh6l[nVlkC^m>n6mNnBVbFkM>AP5jg`405702Gk
%2[S`9Cg6;@E^m@3nh`4finNE4X4O25[84;aN8:Gh6_2l0hD73D1RiP5>klNnSPPD
%ic]P5bSP4VmP=f[=BTZ3B^N`a`g`lfVHPkn9QKfRgP;_70BW7CfSgFT66`f=^0PW
%0050lbXF=;7X067Pgc2>QfT>GVR>FmN73@D6F0>:dUiXLVa^Y8kLODS<j/go5C=6
%[LODn0`hW2Q89YSX0X1@9fe0J8JXJdSHVjJL631m5eY1QN?HI]_EaK30S1Q>oQT]
%h]h`U3DX3G@iB0@?;3_4277_5J3mZQMKC/7BK`T=iXLBcP18jKb4f2^PAHAP@bXh
%A8@@>hDhDHD00H183XKPLZ]3=cHFD1=h78608HM8MXNPN8`7>FKbHcJ^hBWXP820
%?n1@>2@F3@=k`V3>n6=N7=68=J9=n:7j;0J<<^=?:>@i[]F@=2A>NB@=kBMnbUjB
%]UBe`bnA=1bC>CBREBbGC2AC=bCEkBUnb]jBeUBm`c6NCjPD:RDJTCB1BNOcNQcV
%Sc^X?mje^1_2_=V`=Ra=:b6Vc86d2Be=ZfAai=>h=fiFa]DJP@=mgUDG/[Gd;GlF
%h4nh=aHF1_W4??5F9/A1Xb1Z^[9@J4_O5?>H]k==C>>_?@O@J7AJ?BJGCJBPGOC`
%D]Je?jnPGUm`>:=m2kL/kUAk]dkg@d1nL63?[RK:3L7T?cEj?R?[T9_X0OY03ZMG
%ZP7/0c]>c^@=oMn4@Z1MmoMk_hQl`Kd@>N93g77h:3i>gjIF1lSS@GbL?RJRD^Jh
%kQ>G0L2@;0cbWo12D]VOimWdO9jQl7@KP2jP=Pf39/6^KD47dOYo^DOil7^OD4_6
%OYn@NPcE88i21ZfN[=6l</J<lMJl;boQm3=7SZPO7h8B2k00Ta8Z`6c7Pc099H[b
%JIlW]TlTF7a:S:`0P[eb`a438<lTG85;j3_@<@a30A144<klB`JOAmWZl/87XMZX
%WfO9l7XNYoa94aj8XJHM1T7iEU6Fak7bOd6@A4d6X53l47c555BiBM:>FXCo7jG=
%=0[CPNDlH]@=9:l4_0oCbE:OlF?gDeCX7EED?=E]6YCF<^e?AEGdTlMKeMFS@E6f
%CT65HHJf:jZ3BXO5Ea5:QKfL:5X0UJ@RfXAE[77K5T_^h=A]S7=MdDo;A<ZZE:g=
%Ll3G5KL@X>lUTUIN5Z2:Iej47NdJ3:D]m7SOS@_8i]Ue]GB2F30E:^1P`UhDjX1h
%Jj[Y0>0F90;RPQh]746E9PN4GHPJ96/An@[<=9Di:]bP>K5T`haF=AiIL3Ch3M6I
%iXlNK7oB4@WjaAgU>DAA0J10444@8n84OI[V/KJ_7]4<@dDlYl7/Nl4Wjm5;X;LF
%EX5OQhSI[jh6WGYng43fcE0HZd438Y<8HMk;Z1]QEKW<i413^hNkb_ID?3ZSUfG5
%Uce6i]PFnOmj6L38<P^Q<l`K=B1CFianlM3m7?:OIn7TZ9IUNGXSR8:YoDME:2@E
%VmD`GV_EiYMFS[c6G50bHOJ1mfaLM`lT/WoL[@>A5VGMlh?P?jdOOelOoPX?hl?l
%Sh[ANHPOUFdPGMh4iX8ncJ@9G4b^mRUl06o5R`QT]lacO@PN/89SVaiUPW3C3P^>
%c1PgFO_LdF=UefLBfPCJ0e@10G0=N0[2Y?_H`o`i9`D_?fOZ?amke5:W84c1Djd5
%aF`I5g1]R@0X;P0G/8<`koT@@;:0f4@4:@g@[Dd;Tnbh84?EQ8@I63PEI_=OPiV1
%ck3D`hOa3m;R2Sb/MLTlTOhha_3R7j?XMhj1d3N>X0LEh[QMZ@>LPeobSQn:>Qlj
%lOI@70?8?DHPAdIAJAWE6;2=@>8f:gH6NQ/8WHi2=SXHiI<6AF]i1jk:<XSQgAoC
%2LQjd3ecaQRj@MLAi0W1>2HTDBa`Al4Y?BXaaj3FYSg7lV]3jKAhW>7/>0Khk@k1
%e4:ZTlXoSdZAL^ZA4kAe6a0UPP=kY2ERPeSjD09T^AJbk8<n/m4=WC:XMg<1F/<Y
%9^YT?<Eo/aiR<`V<f=Od`XIb48:`1F10PScI0k=]TXZ@WcOP60/9Dhff7d7Je^I2
%jiP>mQb^]jkciPC=US?<djDdZAW5X7FOD:`g;364D2LHBQCd3SLR^<D=j3B7V10e
%nT4cPV@HPMLk0KJ::aKDMDS01SZRoXhChHm7`kdQY4;ZTRhY[<3WM<jH;Xj3c8V1
%>QKc6IjDc@8PR8Bod4XUNK3PN`B`U136P<lJX<`IPk7<>XM9bQnWPElNDhPn4`c0
%PTLe[D33_]kSX8dPHAZ^6_4oBU1YNHW3X3WFDf@bJd0H[E6XF531Ve_BJ5MkHLZj
%<OH`/^@L@I[`UGHD25i1j?S50n1l3[ZW7bITTNF7dVal3i4084?8F`^QHJ88lM8j
%1k=E84?RcDYk5>GA39ZVTm5Ac/866Re4R`W462aJeO@YCB@a]7K>fPo`RFg>Z56g
%@XKNCVWUKFh4b7g`;PPMn<5aRD__X:@EG=NB1ao7L:nj@JkZDR8d</d9ccX1E^i<
%ZgjTkUX]H=BLPco2Y0/_@`aQX:kfB1FhL@7mlDQWE0_OD<MmhDR0K@niFlj;IG1`
%1P5;[Ah6:=JNN=?8naiR`5F:dAPRQ6Y`6Z=LJ@F0]QRPPcRYHnCRDfVBP>QJJSR=
%Q]J5RnX5gm^687>Je0J7iW8BN<m/`7QIheVP@9K0h`lhk0WSfKhCj>2oV0Z>fC^e
%EXXAC6>HjRg<>6=UE`8Qd1<Z=>9IVDdFdCDfEC5/NjMD?FLDHiPlXmW<:;JLZjYd
%[l1<eI@lnfBb`^ia?T:2onJlkBaI6n81Y_AdZHc_?AoSQ7WX6d4V]SDj4`WL7H9c
%AT0@e2;dPf5F=9SR8/dESd2Lk<jde[gF0dTj4H43C86:3k3@1Y7H4D:2XVFQ08X`
%AR[PAT0[/E6V6l>OmLG1bdX]4`n[6X97XZTNHJ@aQZ7hClZ8m1kS^4B8TBHdQZ3P
%c>?eZHnfX;XPT@H<nf`DkM<L@=I>>@nKS^PJ5I9QAa7@4foY`c71:k_1E_45nlm6
%2Le3I]:V/f1?7f/?hi9_cU>SQi3R3H^kf0Y;c9=/RMGBiIU<PfBCI4h9PA<iUgVI
%D4IWDKVWQ^^GFB9E_GoKHIgc2F^?BSSg:EcjS_@2`EO;cT;MYKbYeKkEOe?BXU6i
%4Qggei>K^Q]VXa:M398>LZDj5eb6KkKL8P/NWGUaDY?Va1lfXN9C>SK90VmdIB6a
%@0XY^`7X^Q_FOTOCJRbk@a18L7Kl`SV?K9iG=>iA0@jGU3[aCISjf2?eZT37oKFU
%<NDN/TO08<`>jQ;Tk7MUB0Ehem0i^BQNlTO0>=M0iAj0iiUjF7C_g^XJLf_klcd2
%nm84;ddf`>QkmE>JhWFJn7VIe<0mN^hQn08:2kg46AE[LM<jQ1TV^1L=Q`Pc<1/k
%?B/cDPc3oLkHhRd=TXd=I@i[F4E[OiWed1[baKZ?k6Jm=d9eWGl^QkQ8;hZmWa:E
%bJmW=mMjiDHTOhHUkL^OA4T4ZGOd>`Hi2<U>0EPnX2oP4RWd3Z4W0:mHQf863Q0D
%>ZjleJXn6>[^EhYDnk0XIZefT^UND@EBYdA:7f7`7D7<763632303Y1<3L3N3Vl:
%JR=V]2NJi@=<FFC2FBgD[RID>2aB7fK@>Z]h52VRE`9B<ZFL5^5i2:QjXDN@<h6X
%aJNf=J2dL@kLG4^>IdER?8><mXI/AH^T5N1c2jBXc8hXei0dRFJZ@@l<>l=W38TZ
%TXGHh50dn30ZIRE@?8[n9l?8_b8/3lnK1Q3RkV<21J5k42HPoV84OG3jG?1b^bQ<
%N@FBPTaR494PdL594VKLKjF@gbPNND=TEbNDg@[D0a1^XJ@6j@Q^YRUnYJV01_5D
%>ZPk4ni:7;5PQX:hV<ON1g5/Pn/60nlNa^[h[o594?60=52`[2;b7^f27l/h7j7`
%7H7<780:@Z6h6f@f6d6`0P0R0Z7b>D@H7/f/l13J[e1P?8_H1FaZ5VdlYDe<BF08
%:TYS4888[74n457TkLE6[b;LfJ4B177e2j1bW`=6RFel/<VBmZU>bfCHM8?8gR1D
%WlQdTVGH@L[2hZ/fULEVA13BZF84Klc0hJba3i62ZRQk4_8f:04I9:l/cm62njFP
%2P86SH1`Y85e7LkS9B=:a2U@<@OhoB7j6I9h3e9lI65]:2Y>n/mNBdbF=0YNQfNH
%iK9PVDDX?`jR=:PT=T;X1e:/PnXbm85m957L[0=T[6Ng5HHU2M9VHe:M9Y;@`6Mh
%7^D>C0l0EX`D@B7/2d2X2T4`4T4TYbJ>8X7:7`=V@Hn8=W;lehG<IB9B61<A3ng<
%BY<<Q`Ub2HjllX=2UVKl7n<T7D1Y<b3a<g5h86<^iRNN<ZX65>M/1lMT]DI6hBbX
%elcDH8@lbbL/l>DTST4j_R1nDO32CI8Rc:A58XMBhPMB@A8dELC0M9;B=0XHIN_4
%^:7li:aJH5;?>>iX:0KE0D3P[`VW>T@8=T[bA/63>nl/l]:J8:WI52g^Qc5n?@oZ
%eX>8:<i:2K?PB20P9S3Z_0[fXI:Q0m<H>86A?jmD3g06<63jXR>XXb=^U:Jb;biT
%Q`AI?DZ/7l5M@S@8>/j64XAPd2d7>e>e66@N>28D7l7X7d7V7B0n0/0b706b6h@B
%T`I`?0`bTRTX7N7XZPl@IZa:I24N=>NHjL5R>d0H>Z69B3??>R:0?@g6J<V[@bT@
%L<<P3OBLNb0Rlb0iAlk@5PDJhBljK67hl0U?1O2b>DNHK^1268E0l?=nEY8:DHAA
%CD@n`?3==bM?<8ea6d/DbI32R78=<0MB>@Ea2bhTTX7ngZnhQPdk@diC2/;b<P11
%DFo`]6DLA:M6hb>lI_CACFA1DWC]:@lfd<:TS`BC@5?j6@YPiWBBnNXA7noDH6C2
%<Q4P48UZNfcR2jiN5F:l7PES5n=>i0D@L<FBh;@2<7B268:0ci7d16_D0621FBge
%@B7fKV5E:hEH86l];404Xb[N6K>RnoD=3RDN?j`lA07V7/7R7B0b0T0Z`X6//f6J
%6L6@[@6NCfA2444<4:2@2F2Q6cCT@<PU5P7:lJ0Ddd[fmLj:eN0<0MH<;M5hXGBl
%c4CHRn@LQ`ljAB7j5>5:5@1j1l200`0h0j3d3b3h71I087A`TF2HlkBbhjmjn2/D
%`?BfH79:4H2YIRH73M8@M98`n=><?eA[GbebJXfEA0hJc0f2M:CbA67n7V@KJ@A7
%3<@jhXPQ<7307k4V59ES;;FfnHC3BTdT8:BnYf@6IT=RcD=RM6/b7l7R@J7Z6Z6a
%;k8bKlNJ7hFD7b7VLLLLglLS0bBm<08H7Jk05<XX3J3oL2eAFI<j>FW@L6lhH6AQ
%0NY55cDF10Jn3Hh:V6NACh[g@aE<^4if:U@R5MLS3cJfYF:0O02TPj_X_[Gi3f?8
%B6jBE@Oh:41SMRPn1AMX;M4gL[@O1oL]8mJ^`11U@l?4@L@PC@4>0804062h2h2d
%;@3oHNY^61>n4l4n53Mh>FMgEJaK9djPHbidDE?THN>TGTFFOiCFJ/I/A:7X?B7X
%7F7L7TSX4V6h6l6f3f3d3/0n0`0n241h2<5B5J5X7TgjJ?=Nc67X7WBPj;4BEHi>
%VDC2:4a><P[nNDQO@HN@?@OhOhe`Cb9F7mJ@NJCFhD7oE/7Rf27LEB/hRn7V7_;l
%@@n:DHBff@7hWlDl1hOODKMj]ZXH?8WiEKDf^I=KAdPMK2n58X/h7h7R5J584j>X
%0J6f76l6hfJ>UB7d7[23B_0fI/F`724l4h4f3@3<3:nX:<ERAQ?C>c90QaL@7d[n
%N87eAh2oSNMT1?SU@48mEbk/EA5o2>K6<Z<[JV^X3FK[L688[b?A;`4TPnW37;:k
%E:86>[M^T>Y>PT6gTVd`_V>X2WTaNg2ZigMgQ^nIQ]5kSi<ZGF=Ti6j:^ML<H<<^
%0eUITV6fAHHh]T>@jI7D>[Gla;SBmkD_8P>EAX7/5PjM6/0V000800/T2d6d6T6j
%I`TXf@f^GFl]1<3Y>QE>HeU17`39Vb9l^Pi75o<JbEP`hl?BR^n=32`>/h7V>D/b
%A:7h7Z@4ZQ1JhY1J/hLV7j[6ojgg0ATliCF2U[VYJlH?HRABFhTU0f7H6h6d2l2P
%2N6L6J6P2N2b2l7DJh?6n9C`A07l6l6j764L4R4Z303:2n4d4h4/[7HUQk0VRl=>
%NEMnXJ^PZl^h2ZXb23YXZc5fQ^L:Of?AQcD:HdOV86[6i;>]AaI071FQ68[08mM=
%@:8`l/imLBeWMH=1Yo:<86Vk0HHX>ZeGZX=4WUU1WfYWTkJhPG>Dd:=T]EU@dhDE
%FM=]D@YUYE[73J>oLRPoGl0C[^]E<J?gCB6n70784@4>4DLF0/F:1B4f4j4P1d20
%1h00060>7<7:Lf>DBf?fRFJ]31D^7n@d6d@^0fFCNeVZ[0WTdDjlAT87425k7i>`
%DPNA[LkLVjn^RnFDhjC[1`FA;dh36e8bf>A0@nQdNZhfYH7jXbPU:9[0cF=TFB<Z
%oj;UVFjYQoUBRfK9K4nCKP7Z2j]d6b[NMB3i4PD85dLf/d6d6P6b4>3j3h3N3B3>
%4j50587@:mUj@nJXM?HNK77J84APXbO8IJNOPB[h9iIO5/1gAl]d2ReGT8<@mLo0
%>HWPN@6i`NZbI6In54ch=oE8NCBDJkST1>e<>[5D1_4<=6:UNj2ga;/o0U>FkLT4
%<A07FYF]^g5;`_TgN[^>^1]MZVORN6N@6=ai03J/>FAI:/1e=7FcH34`89EJHPeK
%FXjmQW@L7h5jm82R2Z2/0J0L0T3>383F6b<h847N7:7<6/262>2@3D3P3f2T2/32
%7ZKl]2ZDn<7f7R7T7Xl?=;FLEbdgNjg1b>KDI686ZmNB2icg8fXCGi7T45LO7ian
%cGDZ>1CJ>>A:7^/cdN7n7L9>ZE=o6bA330Ee4nacL;aZ`4PD>2:8gAYfE;X1[E^X
%n4IiI06iRh4/Tb/bf]6H7J2d2h3<3b3f4@322l3N5T5L5`7/7Z7PJRc1d89n7dTj
%7ZUB/eTN8<<^iJ>ZW<VD[n;86U3c3o4nGa2fj`o_aTRlZVNO7HYK2E<f3aSnSa<^
%eVb6>9Mf<_5he6B6e<W2aS4E?Hd<FFNEYIa@8<W=3nHPPj;D18]<PNWSECe3^A:R
%eWTNND[6Sd4_hRMI2ELN>K[5``d=;;T;;aAlPjojKEF:>[7D15i81H1F1L4T4V4_
%CF7i;IR^7l7J]d28;475G`3b40485V5^5]8i^1<8Rnd<VjSe`FHeFeZ@84g@oj9h
%nY06]U9P;j2]?Ti72Q0Xb`F30dTXCK;nTgdNl1f?ALUNA2DBQ^SdWm]1;=hB`2?9
%gP^IMa2YIA1S0Tb@@N7cKL`87g6h7`7J4H4B442@2>2J3P3L3f5n5d6DR=/bL/7l
%JJMiJ@7f7QSD:S;UDbY@?@8lW2>ZBB:0j>>3>n62e78EBTY5ah6=S8odPF^DoGBD
%Ad879h6IBMmP3O:e`EFS:<_mYj=f57ZF>/ZlGFZYhF85kH89H@N5KQb?Sf?489^K
%bFP_ES:C>IkBn^^8o`FCfNNMDh9>iFC8kJ=1B7mZWB85JV>[<NlT2mSN2oESGlAn
%0N_gDWY>Fn7`8T6B4X4V4I^V`b7RD<3B3J3D80ogfoDFQ4Bng`oWRl7ZogloGjo7
%`o7hnW_5`a6Fe6gm7Hloi18I348S5937Wg:I5:c7;Cg;c1<Da<i2ki/T9`9id<Ih
%U9ll:1:gnmZ8nZ=@ZABJEBjICGno7gCgi3X587]57e0gnnWnoGLljkAWdmWXoGnn
%978;<mgaFHLoYFGkTX;Y98o8;_C[eNkiOKmOl1Bh^mjK9:CIZkPHYDlCSGk=WJ/e
%V[cNJS4OcNGe>WDV0004W<m85DgmG:ON93KGflGc8:S3WjmZk/[PoM[S=M:EY^`3
%_@?_`O`FY`e[aIRH0QbAabd?cFOci3A=U:iC[jgAiFn>e7^e4i=QhPnO4^O8L_<M
%o@aoEQ]ce/GH^[NJKeI?7Xk8FSn@Wnmj0Ll00^`2T;Z_4eZE[4T<490/Bl[51BA@
%:nBT^Z/AE`/oh5@boi>@i0ZU@T]jh<34LBA;4dC_JYBk8jTT7ZDN<HA@XAgAXoH9
%WA73^_[4Bc^dnRE_HTA3B6oheb<6DT?nA<Uad_3ka4Tb8:jORh7g:Ze:XO1k7bfb
%Z@FO`h3L>8FQR61cWFM2^[<UDN7nl`i3W>:BB2_;5cXS/VcDa1oXfKDK2;@2O4X=
%520c@`VD@GU5@6UB[:96E8;hUAn8PZK6:hnj7=THaL66;`Z2D=`dRn7HRRHLIgXS
%:4_=[88heNAMH_]C=8e[FeKa<_:?B37jd/KBE6Wo6Qf5>DiBSD=@d48@Q1?bIZ7=
%4OAc64FQDRn=a0WJT1leFOcGa4f:@8V[ZXa5C1m=]KbEW1MPRGL15h05NCnPMNX6
%g^8=lYVC1aGkG/?Xk3bVH4Y2lZ0N1DHB>V5SmQYVhO7N2>ZaK2bTUN:ACKKa:4NV
%>QiSko_n5NAWKT]MEYFLNCWRd@U=UbQ>TXENF3VIm/G8`ei2cejPLK^OIRjUPeaX
%NRJ:YSg^`TFDafT>2AgULm/2AfYRiZZU>[G/@Ejo9XYd4knR[/9MK67fbiLDf9^n
%]DeZhO/[7m::f7`X1g5^FYJ58DAAbbNjcJR@I64:2H=0VN1e7DPCJWo0YclKNh6Y
%AH><CeYT9YBaJ?9J<KnP[cY0LnKo@Z51lkII8>SA>OE;=A2:]gBFAG683P9Q8XIe
%5`Ei?1B6HM7QLCGklg4m/GOHbN<XD@MAiGUa;bJ@lWX2AZaVGC8PMO[Tek8cnfA1
%44=d9^XkBVg=MJ2QW8>HbRd005Pl6`US<78O2NM1b7LZVg:hRD5WdQk64?=J@Q4@
%k1h3a3Q0L1L2CoWmGT08oh1X81JPT?:2SdGA]996baibCTfT[N^>]HXY`f@SFF8@
%Jl9e67FNHD9Ya:cd1gId000L<aX@e;bcD_K:CnXXLVH/aIg@Fa1QV0<ol@@F/M=4
%B]>[JXEa=RM4l_D;BY6hQBB44LEaUAI>RXlUIPd4]97[65/k7`N0GS<G8;h`8e91
%=f;@WP<H=Vi84E4OKoB^`18XFPdXK`fQ`2F4X:2SCJ/fBX?T]0nQDRb5D<DG``CC
%V9RlB1A0C1?BE:4[e?;cb:4T<G1l?TWhc0G21:<olB3DWJRQ4daQY1l[U=<?<X0k
%0=0K1Z<hI0h2]S_4d8X?@NQ12:7RnDOhmb[UDV8PI48/YUBCM?1bE<ciXAOGA1Y]
%AMc4=^F2^`L3Da7@S3H9JL2<1hY=V^BU0aR8jSeFd?<LP6`808428XBhlR@0O103
%0GX^AQV=8O<8OXm2:`Z7f><Khg0]d7<m0f1c>X6Wm?o0doh1J92KXY64Q[JfXTPL
%V`@TS11ddO4IB5h`I5mSIY<lQ5S;9XbW7`B@G5;h806XLIhBE=Ch/XEXT6:DdR@W
%oGnY15HoQYE309DEN023oQQZDAj2c6JEe?ZPdFRcCCaDgAh;J[0=j]DF@Ni4ma51
%cEQVlAT30Ajc2a[@?>]Ce5dWfR<XXGQB2EAe7lF@RK=S4Sn;0?/NXF0/1R5D:dGR
%E4_6i7hF@OXmHj3i7XFRU]0H<Sm<T;<7EUIC=1QEAPS``K>1D/lQT1@K[AE36T>>
%d`7;DDoZRd@d]6Re;URB>`IPcARP90L2]M@oQdST0LIhIHdQ[3ZSXR9:/icH4R6]
%LT55bfXFA]GLmF[TiVTRJPN8Nk?Q]R:^d6FkPZK_<U7JF9>iYAmD]O8HhSYYQm3F
%6V<`5h:`C_B7n4T8XDAJ2`5hA6jQ4:kV4;>B04X90@04<lOh0@0`105]@1a/X?V`
%QE9N7]chP0fhEF@6ZBI`@7da`SB`aJ_KY4@]<><iXQ`ghWQ31n]UK;YbYB2>c62=
%Z7[b[<4NB<Lk<U8B2PaFTVQn@kDQN:UAkA@i5?nKl0ioaEI;AET>j6ClX5>Tc4YF
%QR`XiGGgTdTXo;_2Y2EUmahM/a<n6jiDTB;X>;k2QV]YdoAmV]DZB0FH]AH1^364
%l<PG0XVN0Z>0M;Rb@3d7]<4OQH2QVe7_7EER8A1j=PnF83FTA/JCYfB1`hjZJRB1
%EY/5>WI`2FCbH^^0>MB4Q<6[_9fDC0=`8Ll0Z8o1hSm7`>8b@Z@3P=1:?Dd@=@@0
%S0n0d0i31ldG;D>9W`4P80K6<<DJDoB@eZ7WJ3<cbMEKE;lGT`I963RAfhTH=8[Q
%G2/9/>o5ICRB?0]N?^o`na6R;4H8H@8PB77J7X?42`6@@3K6j>LZPm1i5P;<M/]0
%ob6SnK:3`BKDa`SL6l[m4>8DiiVfP<kRUCLL4Q>6=AQXOVL2]hlPDjANLYXQ^W]B
%9iR`TlYYV01@`6J`SV^LT39f;E73fZ]@L;O8m[iERHB36kVSoa30Cd<KgAHOM7f]
%dWYA@ZYT[>T>GZ3?:[4Qa67gZ`6n/12jd9o[Q@/?^GijB:SIhSYBQ79fM3en]I;T
%5F:lG2I@JSo7P=`C8S@oPb1h5DMaL2bYI:jJ8Oeo[2g4Cdf<GDXATn9dJ8>Y@HBl
%jC6`6KbFT@=1Bl/<;c3V60X5HfB248G_@:miYd^7?Q4e42d<>`KPg1X6N0R243h=
%A5Qk4:5h:@E36L3gV?^F0G@]QXMDFm498K@K@c=jCi1BnVU8Z`;Jd@KYa5Z:<@UF
%TDZ;@]GBE3=khWbU61>1X48ha[SId294CHSPY1V3;^@ZPnQa3J6^1T1X6AZS<6hU
%_@3RedTWKM8JWPYSE2][ZIL@kB;8I@?<134h=jbHX@`IGZeBb942CS/9iQZ1F8AJ
%1j20ohGL3RU1U@R2Zb9Hg2[YFS=14a[;7XUKBh4/5S92V:iH53J11Z33i<6ZJ2>9
%?8?47AQH>PT8Fl7kb`:@1T8IW2i8Jb5PlCTaP23XTB5ikH<jjS>0M`N0MHLH2`3H
%5hL8Khd@O8M`@@>8<X?XAXCQa3o9SYg`ZY:JCHZH[9;[hHT3i[[03L3PGHi821/h
%6/?:D;2K4I7I426hR1j:><6`_I;PRASJJhdbH8OhNKcXZH>X=X?0EXDXEa9hnj`h
%L0J`JP>X>P@8NZ?AEY?H5lDHITD[7d@TE2e@`JUhG3[PClDj>hO8Nj>9YI0i1cPJ
%Jh]Bm9aHO8<09h:XAh@3AX@P?P@8A`@T<ZNPOhNPNXL[_h<8;0=0NHMI;3o1:b`/
%=9e@R/3``K6hX@k[iZG/L@?B^1U95/6S<iY8k[dHSccD9RE9QhIZXj6;SJUPYB><
%4`XCh`UJ2TIA6@k/0:58_8ihIj8KX:6K2X=[dLE4QSTh[2<2<:181JCh?P44R`64
%S0^PD3LJBhU8_8j[TJ[cLXTCUiajl1L@T0M0IHHPG80cG0N8dCFHLX1Xc`IXK`La
%K@dio8NXN8N@NPehO8dRjTGH[XSbR`HLY094Y@oj:h4KS`EYPP/DK`T3iKD`RkT[
%WR:TQZ^@/i:jEH]@fBOhO[HHLPL@LH2X2H3`I0HhJRliBhN`E0C@Bj[0H10dMhOk
%2kC<F4[L6Z:C29[1X@abZTX<2RYdGA^3jI;0Z//IaHN`O0M`MPMbbkPH^0d`L`K@
%JPH@<X=H?8Nh^0OS>10`ZIlPR:obaCMD`HYCBki[b@<b4/PP/CW@Y;/IKT59PXSX
%jZjL@IiJR`3dg`oZXX0RbX7DSPY8n4`;/A]A1liHXd6Hda4KdCE<ZR<8XC8XD:68
%ohETkDfD_TkYiP/A8H@bY:Y@H/lZ:/FbJJS8YId/m@TS6hjXjD9jk@A@[XQXO0Kh
%CPBX@H9X;@=HNHZH4H1P4P3P0h2`D0F8Fa=8OHL`LhJjnP780DU`GXHXJhQ8[Hg3
%PKF8OPNlY0HI08;Yai@P=1k8CB=kD;/90/54^jHHRlMdk`Y`Z<cdaI1H_0f`f8O0
%NXMPC`CXC8CXCXDXEHEXG9;aM0OhMhMX=H;h;a6SV`e1Y@S[CjkP<[hm5kED2@R0
%BM;9?:Vld4FD[43kR:oJljJl41l]3H/8ejoa7Te0OHLPD`D@B@FPG`HhNIL56TaH
%j`dbRk7:ShM:BXC`==@:T8APJM@/KjE4fHRT@4mCol=j:LgBCLjB5KW390oiWQd8
%KlTJjLkUAJlI/iB92:W0OaPQbHjZ_`;2R@0Xok3CX[Q]:]Eii29DK5FJ2lik7dYk
%3DO[TeAL?aFIR/mD4`I5H@3mHPQ2H8OHLhL0K@IP000@1`586090HHFHIJY01HEH
%G8GBH8O0M0L`JXYhN0GXH8I0=H>H@YLJ`QLDb0KX5@584SCX5;KPB:91bH4ENc2K
%RPIdfUF/_JeD9EEiaB_=9bjROa;9;Ro@ZPF39H1PghMHM@MZhP/`_8IMRP5URc[d
%`]F2Z9?8TT>R6XJ17JbH8eTH4eT/Yl9KWLM[dhQiEH[LX8f5H`;P;H:`N0NHNm8[
%]DJk`SkPPC/hLDEc2hAmXEC3V=S@_L2L[@T@kY/lPc0Xg[L0EaPUOi6B7@gZJ91k
%LLg`3eE8oj=mZL2=GeXaG2O[IeAP^3daL5/jea;aom9alK`Q:B`Q]`OXOCfh:8C4
%^@]Bjb6l=UUm/mAUU<_LZ`NiO888E8DhD`QaeCMEQhNEM8eXO5Vcg:e[`91HB0B8
%BHIHI`JLB`THLHL@K`GXGXGM:S70W0B3:h:82UeLSDSXjdZM<De:c5/@P820?n1@
%>2@F3@=n`V3?b6@R5@9ma63A5m_F;0j<?Z=?V>@N?An@B6AB>BBFCBNBaB3@Un`a
%n8NH?>I;2J0VK02L0:MCP0::OAal`>PBbD@=oDNFD2G@>;?FJ;08E5aE>5`f1=Z/
%9:]6N^:2_=b`B:S_jRfFcFNd@>U`F/=X6fnM0:N66jFZ[@AkGVdd2?aYm@>NBZdh
%=ogj1]340?5C`4Hf^6Ne`C8f?3HC;IO<B=o?f8@;>?o?`:bFAojCCJ:1?ZbJYo__
%>hFb?fajS2_al_[KK5I;AHS8J366Go@H;Binb?amdS1f?8gIn@=Fm4Lm?TJ?DIEo
%l7?IkP[QL;IF:aE@Im?UnNGWjC?Bb7mV6F=iO6K0URoDCOM<OV?dCADNB_hc<0`4
%XZlW/PKR:Zij?@05<6VA1l1`S2D9[4ocDXdUR:3I3J1Q_3`3A0WP0a6WP<a<O4D@
%BXbSYLRSIX;04G/T^joATJ<KT778gAfELNWI7j?YLiZ88U2TS@TNTTYLjHLYhWPF
%BQ0/G@/Oikb/c<JbXidAP38jB^`PI:C59bLBhElcX=99jAFmDQbm=l9/o>C]X<dk
%=]:fSI=0jdlCg2amWhOan<hfD;=8g1lPn48?6FIITXBecn_E0im<iBK<b/Nj9XR4
%U>V6HARc`Y/489>AR68HC_5/N=F;6URU^>i<I@?8Z3RoFi2ecEQhS]GZ:CLmR4c0
%PBU;_>5S`4_TH8CIC@?K6BF39JA;FYI5[F^_J>;6C=^7AK`EG1<P009LT^0GLigG
%BUUQ[?H/5B[:mR8ha1X3_N`jg`j9FZKFQm`1>ZT?K3=JfaP[BbXX3R3KQJN0EQec
%PGAYU^9:M;`S:B8[6;N=a@O62[7RR8[l:fB<D0JN0SU9`iFoKfh=Uk2CVd4j8:dk
%Zc_?5;idPE1cjOEo=??[B4FAY52h;P]AHUTIDcXC1Z1FJ2hjPI6JZ:PYR]?Z?FDO
%YO5lGRN2V:HXg`>Z7=2OM:jdOnYi[:QhKPIfi1?^VXWnX2VeMUd;WeYZ2`;V70Y2
%RUVgnPFfX9MQ6lF>76gi`G8B>iR6L0PYgl^[A95;cMb08]h6[RWSkQ<_Zo@a_J2K
%dd:EXC[aOEj>`imTGWJBcRdfDgB<IgO5G8bl/LI;6FWQlj0oS9hBOTX=`[fcLU38
%^a6EfHo:SRAnMP?NcLD?1_/jGAUDWOO5D^J91X;AbdXc2WdO1nkBccKd<R50ijdQ
%l8hM]dPWoMMen^j0735WGHgI0X4`90E6f=XKY0e<_BOHIi5QNDeZB<RBd`YiVc[m
%>LD`RbD0F2kQ11TP@gHB2XQ<@=jJlQlXbL@n=gcNDZ@]8:n4Hl=@F`gMa2j7B0f>
%SVQlF<=D@B1PaR8bQU89HTA96a4^1[jGDU7;lVhn8lQIAE3G5L?lFECS4QBDE_c1
%gK]lGM3]8af1eAWOf1<WSaP3Q<SLS8UbcFk839T?<PdDgaAO<S5]TbG02ao3;85g
%/H8b@jITB6<923AZF=TLPcZMbb8X=VJA@3CTn/T2/8VCBoD0?ORLFIh30Fd4ALN?
%l>HLPjQf3Z7Qj;jD<Yd?HkUYbk3/;/4_;L:<^F>X0:01nG`M9P46LZJdR<Gi2/`H
%B[FC`oUV_Q>LGiQ`2RTTMV?=DTQOQMCIHf5/34gAWcO;6lTBJjAg46KP?0PI?QA<
%Y0REhD48UW4];^iLMjnPdCg4=?TK<niT^jMHJ4YYTD2[=Pf//O/GI[6IF2?dX0A:
%7A[N<1ZRCehLTP8Y04U4]B=@X8e0hhBeef:INH?dB59FC6<<J;FUAHj2D9LRd4cA
%]3C:4<hA8Q@oSGDh7b?M0aI4[54J2oDe:oQUE5@J2VGKZ:<5UQU<BOa7QYeALk7D
%lU7IABU>8/fUXoiB`<GS60RQ568Cd;7:DM]Ij7142CF^;mFbQ^XYL/NY[07PC`87
%1j6Xajhek8m5T?h>[0>;4JE<LCZQdf7/4l69aKE`0Z2cHm=A0hO3V?b9QQHKG<a;
%6aAEg;R4Q;6DTkUJ5L;@W[MGG`b`R;E4lA00HWP`;HBQ?Dn1S<WbdFSURY8De^ga
%EK>LF<8m`IXTl0[LDLUai1fXF]C0/AZ7g5oC^@ZSM>3BSk7`?@N8hA_SN7Z?@eCj
%1oUiD6WbXECZSRo_AEFSmBbcW4]Tji/@Dif;D4]KnDA7kIDE]aNZcS?268k3L7_0
%Eo;C;f3_AEYM][UCFSTDMFhGa?HARjoiMlcRdHF89QQ01f80[/F0/lXiCADhSC49
%@PKR8YT^ARU@/HCLG<M/ECQFZV@/He^:1D:V>L8RNS>>Z;ZKW`hH`FUiibA5IFb7
%lGjKhcjCTi9d83:52hMFbBiT<LnE`>IIA4R<8FGC/AaVY8A`lT/5I39ALbA4S3Rg
%?=1M1]8mXkDh7H>PLX0BL2Z5B:loe=dn?a=8oDXhUM1He2aSl^n@KJee8lF=K`j;
%10QdP2kBF9Hj]fb4P/Q>AIhiWU3E4JJ9P<d5`bA4b>@624NPZlfd6IT1aM;m>9J@
%I7UiQM;MnA;cmEjUeGRM51TCR9^;m5nY9XIjCK0I/O;X@WGH4dgOhlkYc@S[fU[7
%GSkB4i;3c]T<ffaEKM/[A83@W=a9^V==NSNA]F;GEN@b[ITHYPMgPG6?h1DVEcFa
%Ki_QP2LJGV><?ObG5a1bh5Z:9ZP]EklgCOPfQV/e4]7f?USe><TZJ^XKH9`BPSSA
%6N=060;`J3U7:>^WkmQlYj>bYIBB1MSP<[>>gMIb5JR>iTa9S/GF@4Agl<>C6h0^
%lmHU@/bMmb2kUOFNGFSKV;<3b>I@SChE<PhjP:CZA1Z^fUS087[1cV:TD65edFoG
%mJl9@5R[41jQ[MW15fWE=Yb3gi@UQ`m[Q>SW^7i]8MHJNl3OkeAbSi0nkH=7mb0L
%]m:ZISHmdSDChIB/[72fG0gF10S1lU/0SFB`EnG;X66b?B>bCb=]g?XWHT_@`H/M
%QS/fkFa60R>3eT6W1>f@CUG1J;B8T`4>G4^9lhZRbf[?3X>]oAL:KFB5>A6_3d<Y
%hLDhX/1G2]4:8<@BN1W3=6T60<0ISoGUCdXLR:00aoO3in5=Q;;hTl`CjDSB^a8o
%[Q^2fXlVQ4Zk;m<<oU1gfA`/ncU@R2U9T/iZg>T>9:;6DbWD1o0<0g0@l4S`l@84
%@:>`2G0P2=0TV6K>bP40Wb4<GFg>n2CRdbeF;lbb0h;06hK/YHkVSV]^NZEZbT8:
%>`SZDj18Fh4b9Lf2B/W4^22>HPj8edfNXnO2kFB28HP0XFH4kRe>7nN^/N2bR81R
%6_2Lg/ZL[/gA0h@VbneFMDg44hbf02]J5?2m1@O6H`b>Vg2P[R8XfBG4113D/8CH
%VJe8;_312XMBhF94IT@bAH>27^^jR^3FD47j^j7^Ij4F4H4P6R6T6/7^7`=HClD6
%i<ATk>6]0@0f>`V03X;R354`CH;libT23:0U4nT`]P60>8UY0f>h?>ZlDd8:hPYb
%^L>N_HUPZJ;l8Y16o23he10T2<?25HSZkPkH[Y0d7e3hKX1>W><R3S6@]D4@^C3T
%@2kFHdHfafVF[XWn<bmnCH8X>`X^8B`N2m6lWP[Bd8]f5<ljS6QDddlf8>Rn[32>
%94>8l:K^c2>`/ZLn:NH[7BP2lk6J@Xo>]`6[7n8`0L<J0@9hW^3@:4c33RCNNQ0f
%XlgBN/Ao12bJ00[F2B8734eV:2]=7fO=3Xn8UP8S8dClOD7n68666<5052567:7<
%7D7X7Z7^O>PPY`8HGl>47jL^7J861i9h:N2M9n0402080:080>@N6@W>4k:D1O:H
%M76Dk/mLZLGHL@8i5D7k:D4j<NkJYU3X`XAPn<Mb5c;42E;8a_4jkd6o30UJaTD0
%d>njM@4o;RKT6LAT3a;/49;`GHhA8hO<BXo>8<Q<5@27<6_DaS8D;>P330AU0a4T
%Lf5:L@Dc6NaHRLaFh<MhL6dC8b>8@:mXb?6dE[590fA^6RkB14k`3Bem1F?K3;;h
%</_f8:/J9hI=:H1NHjen?Nj4LS7P870F^DkF:0MLh0C83m>98b_`c;7fc@90CT>2
%=S4J=^>@D2=86/6^6f00020:7@7B7F=87/7^?<8Bcn:8D2=0B/7ZIX/ZUl0n]J0>
%0<0B0/0Z0`nn36SBUb2R>l5`>8W9:S6Y0H@bEfa^l4KbYZDZ>ZKBlm1@CT^>78`4
%3g?D1Y@Q;R4n>a7G<bfLIJD:o@=`;_7P9Hh43Ta;8M=J<`kL89@FVj0`W>CI1i5P
%@5=f8:dll^1FI<g0mH70iO22GNXdXo30jg92kV/nGNATjZ8?5l@0CDHZ86N^2eBI
%=Y;@o?27@cA6<`lXXn<Nm`9e87;V[XX@FAAfkiA4[fJHZn9LlPLk2fMX5h>Ll1BV
%dG8lO8CgCROL?NF9@fIhL>=L5R5X5b2H2N2XnhhNXkCTD2>BcJ=/<m926YDDM69b
%06040:bM:4<Nl4WP_HLW<_:U5<IWDf7j@f3I;/3`JLP/I`=>aF7h5R5R5NaZ2]4n
%0UDm=6_EAK2S@_EXE;0lGNjDWP2UEflPCBBCCJ;BO2[N=32I555m>>n09<@16f7j
%/W5l_@5o<JLfSL2HWDX[;f8>CLFJCM1YDdkYC1;lDQ@/c4fKG:mj]<oF4Ra^5MGH
%UUA9CNYW98]V9F<j8DFNL4Tj8Hjn5^M2bL04W4CHd]7JF@]a<[76gBV73L7g0<1n
%;RBi4U:Pj@ga;h=8T><nYbCT;9D:TZX>HbD67<IF3>36303N3L3R9`0H545@5XIn
%TD>6X?HZ:?;JTXhO;`44^69`mB01DO::9bHP1[J0Z:6EFi25?2RM7e?m;0=1@GFX
%?@P/JL7`7^^P7nW>4EJ/kB101/1/1X:d4PSZmnP328eEB4U3H2RQ0fj8>`:14T0_
%KK176_F09<L@K/>a;`48MT3W3[2<hNkWB9BR86dm@JZ>2;L8>L9M8ZMP;6GdBH95
%=BGlk;KR886=LW1PLJ3Q@ZZN;`;dDTFP;98dMeHZD/DSJOB4=@D2l>@=5@^jD?CN
%<90Xj/CMA/0]MW8WEf2U2XbXA6b7Gc>T?D9H77N1MV0]=T<E8Z[Xde8iHZhF>4Hm
%G/C`=`KH=L7g>n^lGB0h0D0<7<6/6>7b7R7H000<0f6P6m4DD/I_J:cn847R7Z7/
%5b5d5hSBA49`0C?J0?:8I@0P0V0204089iC>9`/K:SKYFm2TKHABQW=Dll866CPH
%`O83BH2djj64LPP9Lf8>9H@;4_4`2_PiKJ0^lHHZ@0ZK=OF0O2@:[bZ?Q4AAETe<
%7g7Bi^MddP12`=PH6BM=0foPNi<n7g?E4P:0M]F57UP9KRlI?//01d;JK>f694RR
%L>F998Y_M6@DGO5NET<:B]9d7hHlV:A@DSFB<8;l_HDc<627HLA712XX[iHV>`<3
%H6V?A;?j7n:NBi>400Ab47GL:;SPV]NEDfKI0J>bIX7`=L;e5D7f3?Ph5@4N4D<:
%7@6J645d0>0T1J7H=M?8>@hX_3?<7/7d6j70780V0/0e>^05DL0:?V2P2L2J3^3Z
%3XnH5JR81N4^4/4b7P7R7V;m;AFQ2c=kAb8<HjaP`EFGAnhPA@WLdT1LZ>Eb4;=j
%`gR6F?A`l<8<Db2AVZd8ff3<WLib4eVi05K>e]CJjD_MIU2?A@6gW>8=5/WMA:8X
%Hj9L6IWPK:GXBoFlicPlajDbRoE1:e0IE/=3NA;iMNS0oP0YX::O6IFnb<=9Ln8@
%?F>:=SGVUWD>=J=1Rf7aXGMJ9<oaD`g8Znm/G4Lj[bgBmP8:9LmTc=<[PaP/863e
%YJHJHLLkLV6<K?EUFAC4CX?EMAT3SmIJAB7d?R7L1JgP7J6/6P<:7>1P1:0j3l4@
%527R847Y9R8PYgX^=X20262>0h0n164<4D4F76747:E:?BTHfj5@201n24D1YcP?
%7S94khRRefn9G5Lb9M=7@nHQ5c;45cVVB/LA=HF>80nh4oh91H=1bk2BG2h:GhLW
%HQ1GM4h4nh;5Gi6H:oHi1h<mY17Y58i99I=9iA9We:h:oYM77k5Hm87]2BjV9a;W
%lLIhBIm<X?>X:[j86:<::@O:DlJI<8[>WaDJ51ha6J18Xbo7;F`IGGOGiY98ZnK9
%5h7:KAJKEJkI1:Rn8lb;T5[XN[]Kk<niFnXmFGhoGno88oXg18jogkQ<7Rl@nGjo
%7`/e/^TXUD^ngZlWoV<Dmge;[K;M118[<99FH:aMD0=H0mM[00Q]UHM3]M]JYYCi
%LFmiN=__mo<9QDh=Z8>=^@1^E/0icG?ch;aWo>^9`>]enWQ/Hog]1>kP/AfGgPWe
%5WjlWTl124@TlVjf4ZPSR1mHX5@_FHfWYh7LkGB9hVRLAa7TNlK^<Lcao?0_C09J
%a9n;dO1k/<2@8PXK9]6hScR9P_J[Y8Nl@X:/Ql^Tdb24g58NaF4TFR[5i8aRj:<^
%ZPRm^a71oa2NlC/2SB23Q88OB6VR/S38i?BBTiABHKlW>6dLMA36/LbZf/X<DOlK
%X>gaoTe;h[c2FLaPk<YhC>PYTcDSdMUk=a]CQ6In>97J?B`jBB;g4SY2]?Y7CnSK
%3^hT:2:bfT[DAA:39dNU6X:YQhR7B@MDXiiccU7[YBc@;Y/O@ZF/<V9k7H]a:4`D
%8G1T7LK;MB4/df]LNd31[RanOlcWP3EM03GSG068=PCZ`LXdE:cYBfjLXfAH]4fF
%]BM75J86fVf3H2SJjmeTX=RFIK[/]7;;^^h`=?/9CbHX8NMe1N40@PTeQN5DCHC0
%j2P_S>?9e`W@AmT<@Q2VZJa[<E1K2?0k9jhCC[4<4Od6Wj?0kSd=`gSR_/JBSC=K
%A93M^7o>1]3cT@7I89VC:8Ej:gDNH:iJK>G[cI5]Fld:H:b@nL1OWAeIhdAoC2:i
%?j57/NVQXeM0e=aNa6/[B85VNJJROl^jHO:[ZcB`7jeTP74G[`^K1JH6TK/VKE/P
%/?;?:D9X?UJ?F@d]19?4Q^KZ^P;6K_<@A5ZFnfNUeQ<A@CY8[W13PYa1LLDP^Z@f
%`K0HLj=?/IM1o7NOIl7N?A04LAQ9U6PFf7ZlB;>bflZEW]2EROeP2mLf6]0OWQe>
%9e6o>a]b3_@cGKd@hTmJK7dibRFWRP9hh4NBf3I4<]3ZNOg[P<9F3_N[1^6lVNYl
%[haAj>jm9oWcDQl7PNk2KHaD97V9XURHlJo/8OC0A:cM2Wg;:H[iCf79LOQc3U7@
%N`2RSAj8mM/h8OZcR34`5E0eB@@fkQcPT>62Q>V>473M1T?46ba42NNoQ^COH;][
%8:8b4ac@>3SQDch_HUXG5b6@@E@j?AO@e0W3Ma@^8I:4NRe9Z18gOT[0o4>2@LdE
%Pm4[4TM4Bg6YJ9FWPPT8eI[79HMj7S?R/UGRTRQ58<8_5I9dG^3l?Hb5XA8kDUi7
%1RA[C:1dY@O3DVZKZ=a1AP2>V7<Bi=EiPbh3m7H?XNHj0=0R1X</Jhjec7N@PE=j
%QK4/<M>Y2hBa/04bE=PbQaQDHbWFFA9dUL@BnBK=ZCZ7i8TZ1]U@K1hh105b]QQ6
%1SdY2>@7U4BQCJ3Aj?F>d`AbHo7i9J<8GXa0lAl3c7F?T]cmQo3A6P<`?HN@m6:N
%fPZG[SbP^@V``TNKT@V1=2NT`DBE6c5n98>2L`OYd=81a>/E<kDR]WD:[H]liQ`0
%GW/`TNZVV?BeIl@ET`C01D17I@>OZXAnaWOj[HWAEF3SNXL7NR3<ilClDC5U]A=9
%`1JXdR@<]7DGQEKRC5]CL6e4NRfl:Tc`BB8LD4L@[:?B5Q;3kC=3m1ZJdDIY:1e:
%`d/UI7CCl8E@@Oe3W/1N2PhF5TM7loMQQfgYT6;P?/L`jA_SC020h3hj2h9c8/?i
%dKdc5B==3CL_Hf:c07[@]DeR@@hDkDG?^W4@6<W2EXCXDeMjhU]YM@XUe9gEBQ7n
%LP6eJP00S/=?R1E1Jl[?PFmELK3eT[T<@^JYSYBbSl7VFhNaO9T464Z9@B0cQV3=
%?;DbbB2e@6XOfAbHAhC22a5T;@6E/blf:[X?dFe^@YFkK^6Ng`e;PEo[LAjVlBad
%=YM:[D_m;Jh;NF@d2MH>5L9f[YM@a:DF[c`O3BXPT1;5[6E/7FlAG@617_<:Bm2B
%A?0Y_IM<PkA;ZgO9:YI^hakk=EAkCL_ef[4gbYFU64M2jBU^;O9XPPJ<46`_/<MQ
%Hn9TE;?<mbJQfAiSiKHMdOHj1D2K4P58<8LQgAA9H?h^2iY/6e[95DOk:`Fh]/82
%_62T6;/7RQOh]<7eN01a/XU:QFEXSR0QT4f6>@Yi5AkA<PkPLMbV<FPeLDOC5WP?
%17^dkT2h9JbT@Bd@b`:PD0P<@H@`kBUo/T?PRc1eH>AcEI2YhohD3CcQ;1;8kLj2
%3c/Rd4P<Lm4h4`kVkMWKU6gL30M`SJVIb?_OKM@BMb<S[dL3cB56P]5O7O6Q1Ef/
%Ugn:^FlFFWB/Uk6OZ66h4aYJUCUGnVnVBAjM5TlT16U;5B@KNB];/];iGmPAS>Ti
%Ka@jm9l4T2F`A1R145M]`Ai[TVO7j?POUWC2HH7D3H4h7aLS96`>]>`nQf3[7RN2
%?;YbG<b8iKh<j_YE?7[<=RC>IVeJYeEGi6f:SHK^eDL14Rb1FkiEm@40A/1;koIW
%4gN]HLVc9a8jIPcTn4>C<>jFdbRd6T2VVXD`4_c`K<LQ=MQKTKG>Vc/8>SXIB2Ro
%i8d3H84PaLYe2<lTm]d[5kWdMBhM1/i6W^e1JkPoj73Nca4GVM:=jm1RMH2<A;Rg
%PKj@:kYEOlJgFj4B8<gD@JMCIGYo5A^ZaE_jc_E7^0BG:7[MLJX8@TDRK6gfL8P@
%PQQ;2<4PM3ol8e;?2N4N@nak64`L>LK88P9P<50:hFheQdBi8h<LGX^d`QM2J54;
%6gbfUkk0@@EOTjd7d=I_c/]Om;Jaj5dEjQFLLm?AaSF3lAMcb[09b_Vc`n]eih8j
%HjKg<B^Vbbi@kG/?LHWfJGXk^KL7:N]>Z3R76lf>VMVjh0]k0DP^nHf@A^S]/KaO
%UJ`PGCJN7F7=mUUhfJm/7RK`:N<_RmhZ9ei7XHa_d0AoDd8Ci1LTIoL3n3dE>>GH
%4b^@HR_nMfh3eco<Z30`Oh=l0CZH6RO3j`Pc9@PSmkYkFcoXcJ3b=8OZ>H3d2SY0
%3JXkmaQ8?@?8?P4D3`H0HPH8OCIY7`OHO;<bbI;@LPJXIX10eP@XAhBadJ:<4hoX
%Z@3H3h4ca`jj>If;diX0W@jCnD1[NXg<20O`gP;KnCnH]8]j3hhQgH6l:@f3OP44
%:`]kN3X:GSf0OaoAkSKkfYdbYC:;QC=B[XOHakfHNhZ@dSQ9ZK<S=;4kSSS8a@V1
%=@I8GL?9@l8RPaVL0h]0]hX`337kG3FJ`4@400PY`8DlAQf8H<AkG2k9Pl9T9Q3[
%5BjcV<;;9IVH_J]Rj9gKmjO0hS[4BQKIjPZl18Oi9`Kl2P3cSl@BRbd`N[IPE`F@
%FJN`2XAHAAiXcIQ8N:cIlanXOQ48N8McQ`j8OXHhG`Gh^P3`JHJhKd7IVXSP_IH0
%88f1Gd:`42PHMT0klbDZob:R`2WDDXd<9Kj@PZh0JQf;7:EX1JgH:C6/?keb?@U[
%29C/;LBL<h``aAd[=2>`lXNjG8cJ>ZdZ?;Rd<[SC=JGKg3XJn1FQgL@cG2Uj48fZ
%]RR0>l@aFKP<A;l;V8PYfH9DTCiP5c>0JJVklZ7Q@lCDLZ<P[94PR/E;0Anj_Yh;
%@lR[Yj9[10=40TDRP`Sa;/Lk6bTRi9S@OPJ<Y1UX2[mSmP;<Y`_YnHdPPPLZL`70
%6@60989@8PNXNhN9L`e3SRYPOY49dHO0O@O8N0NH>@>@?@BhCHDDJ@]XRX@4^Sdh
%f0ID_2U94YF`ZlL3nK?`P/R<UY:hSSnA;ZL2`Pf3GXD8V4XBaL;J40a2[/<2YakR
%D;h2cZi;^CIHa0O@N`NXN9KkRS<XR`ac=Y1chTQSeX_<NH[0S8]l_`]94S>PMX1D
%fd1Kjkl;Wi?IFaI0C<gkm@2:=lU1IDBhZSoT`HP`P820?n1@>2@F3@N4@V3?f6@U
%l@mka65@ElaF9aN<AV=A^6?enAn3@ml@<hbD>BMOBUiB^>af1_^HA^IC>J@R:_V4
%c2M?^1YVO1NP:^QAmn62S9bT?jUBn1?N1>mjB=n@9l_LdV`aQ/@1UW/eV?mo?nN?
%ml_em?Uk>mo_fYCbY[EJ[eAZIF_f`cF2<>m02n0RoG`08?1@=kHF4hEk@Ijh^lHg
%7@UmI61i5mI?8dZk_o:Ho>Ig7c[5H_4BnHIPgJL2JW00WF=CG@>RIkIAVke>`KF1
%?fN?jk@;KIUoIEob>ef?RCSLcbfF;R?]o?an_9i_>k_Yn_oKFF`iV1Kb`MO_F^`N
%>bAJ4J3L`bMDBF`c<@j7ik<;7j=3k@=LoUcO^4a6W>jYCd;4V1b@:9D3QO19Y`FP
%bM<fgb@@0OcAX:f;I`_34<YW1kb^@PSo=Q2<1[6PSYWW3DD8c0B1_NPClUbX0;SZ
%>Hj7PMah_6Qk4[F^cN:FPkN_8kS^aBVC<:92c/8n8lV1Y9a/BQ5RU0m:Q/b/Pc/X
%4O3[^`PAm7`/9m5>EQBPX2@8TTB18[74SQW^Mie1B40@Sd>XlTLAa:=]8:JWE?dZ
%0l0=1<09e2YfV<9=94RRAJcC9B;5=6_K;SKWlDe;b58TQ?0gKQ>8b[]]l/B`^_;S
%`DdlT^;_D;b898K>Z93T/A4M]J`B5k0<05EM/FN]8DSDEFe=DcLEJOe>]c;:a86Q
%Zc;0gJcDNlQkWfSmCX@ke/dY5Scd@PRGDBRK<G1556/`4md6kMDSa59<1<XCmhPc
%NHlG[AE6`i1mXc0lBZ<RglFE;CE@^L]MEeoQ64hEQN68bN9gWL<P_S24P=16GQJU
%hPF2WfiZ5^PcBY]eSK]i0Q]B?M7mG:ELU6X_MSK@k0EhTn4VK3OW2A;aPkb7`NbW
%=hSimE8KFRQ]XhXRT:Aj<FimX7fO9mHNN3ai0RmbBC9PS]H1;00e[kmW=LJ6hK/Z
%4e9]63Ahk4NP0081dcO/^:Z]K4W`MSQW6K9YV:KQ^W2Ii[6dN1n7LM1gW>KAY7:K
%YZWHJa^W:hVecHg=Ul_E=DK<XT[6b1_?/00_A3?dSea5AFFiE/eDIiEmFh2km^KS
%COHg5fGEmaIVb88bS<15gi`N2c7QiELSG6Y@XW1WiI]nJNWW`KKb5WfhF2WdZN2l
%^NUS^D]K:n_bin>NOik97JVBMOg?eOGmWLj2NilV>GYS1:3`BSD=8bV/K1Y7Tb9b
%4;?F;:Uljk<CN?D<BAihS`bR4jG8@UBL47MRhPX3:2bCPJ2kPdkYKI=FM7YDXXM4
%PkhB1YQ<1n50eXE=SDXI@SZBEg?B84WPA`1XK60Q/0HnP/H9@MOJ[lO0nQk]Y=j?
%]JPn6A5l04?X/IHAl3e:VW/WRKbe]h7X=X>8JP/5l08:TF@]bW3b72>PK`9P?0e0
%T0/5@^aPS<@lb0OIebaabHfN8^jZWLTR8j:V?RPP0Zi;h::@A1VH469_3nA4RHO[
%TET@844SfRSJIL@DILU@ZBGD0H8@I7I3[HMDNU=Se1jYQSR?XN[DBaTh8l//OY>8
%h737V?LZHmRLBd;2`2AD^IMBk9X?b9PoQlU^7n>lMXl0kQf3TBL30A0SQ;5<:TEb
%eGa:S>6mQ7jU4^72QlAM0DTb2@=D>:NLDU`Z0SW<:FM10i>Y:IRQN1jGUY43Sh:T
%1DmA=cgDDP:Mj?8O3:Wm3T`01j1@V3Bm54TgYN6c;_<5;If5B?HP6fh0JZeC5D;2
%?MG`o1j737DF0M0Wa<R92X5T;Z7QoSd7h?/NP:@CPlW4<69[^Vf9M?6`MJk[V5c[
%?lCX<U?@1doZ13TJ]@e546<A?^Q=BJU6NBBRH65CeiPI@:>A:@oZQSE2aEV507a5
%EM7CElba`Y_TOVlRd/Hm1kSh7Lg:VPn2N5WU7BXZLYQlTSS^N=Z0nak=3F=D^_eO
%i4/77X?>^aTc5Sa5H:/F8?0MQ1CV24?hP@n3R7;9:EQVRY;7C2d:PaR96ZE8^id>
%MX`7fU29JLCEZD>@O]0Idc288@8[Hf]hbRjQ^PX]`5VgA:ai43Ek1b5c^ahG31;L
%Ed@1C00a^E2m4Bn9hf0<Njd]HmAkUA7jnLOPFP]QK[BZ1CEO6AW;7mH@MhgP?PK0
%N:`FH]akBY7N=LIhbVg0D7?F]n2VUVY4MMCMmR9R3G37QLD4YP01H5^D35dc<ImY
%9^QPg1c;bU1k`T1;2SWG>QO``173@S<>H0WG?XmA<<6@P8;BXN`jB1DK8jIE2:G:
%D_N>@Onm/ecM5::VM^?63lMHk@dC2Te5iJ9NHf/i;XcQVS@3H6`=05P;P=0X1D1h
%A`RQ@4684A`_QP2m7H>m/ChbI4g?/=2NMX`iPic<il1X7Le1ncH>?=e[59HQDFjL
%adnco8DMiLnMV60_fh1@<c@4724U43;XFX1P<dBA]U?bY6?2IDY<c@aU1VR`eiGh
%NB^Y^cdSe7NgQ2Hm1f3Q097l<XK0h1N326D?XJ`cPN0P0l60?0UE[KGCAKKUKlGl
%QnB9A^H@7Jo`:08`0H]RH;8oX_AfbIMVDdFldKIP11KA0[]<@^eAhkGZ:@E3V8b5
%8]?0Z2F@oDCVJ7n?DOXSQ0R:3HDH;PE`/Qc3h8LMQUIE5CXKF;LU=:LK:gi_dQ1d
%6DWQFniH]`mYFSfa^I<LXi1`2c5T;P>`MPo0h1d3L1`405PQ121m@6JP>lJ122WT
%B^`ELPfV1G?`CNE27iH<7U`jnH:cWKRC4^8/j6=PL@aG]2>J8SM@@`D7@NCRFj8X
%ff0oaBM9X3@8`4PQAE6<<Q20dWmo>fYZ@8N@m1h]Y7f?4NHl6dUR[8bajRcg_2TY
%04<8@?Aha8UFn@NPH@W1?4@9DDKE3K]eUDcdZU<VC^JK;XeKi39kRKT000_`21DN
%;j>@>eWEO8@o/nCL27U@eNG]ic`Oj9UbK8G2@LWMMD]7HaAi/<@FPcR43`8Xc@n`
%]=94V9lEZ>?=UVg]@`lTZO0NAmiXiH[@d^<M7]:<k/1B9;7LbUfH6UVQ_I>l=kj0
%hOY3RnY/hJGeo/O@6l>ckQSlE[B<XTWcAWYeXQB@^@S/gQ^O[1Gnd;_kkFBA0]o?
%`hG_k4jj<A8P_P_N^l7bhBGdXHP:dZXHN^JR7h>@?10DDL2HBHj84/7bIh7F7H0^
%040:6@6X707BRRklFVm6?BYVEHM`8jdFo:842e1@^><0]:0NTRZZfbok1RH@THcd
%lB]ngni^8dQH[:DJXd;86j6F5f5B0F0N1@7TEl;87f1<0^0P6B6/6h7J84n8;^In
%9P>8=/Ua1U2d^P;^;LI49P?nUJ9`>0R@7^A`U^DlL//f<d=j>0dHMfT8IDPG1hgf
%8^?I3P<jlll6QJcd<`@49^A<o/2lclZ^c<1bM2M4I/18f^mX8`^2Vg2fMZXNWh[^
%7h5:5>54dZdZP:?D<RC0:D7/JHf406706n752`OP6X5f5l0l0D0NY@7n]j7n7^I>
%H4?72@:LDi12[jl2Mg1<[67hA=4Df2<01e6<ca3e4S6D=T/n<`lZ0PE[2R@TVjID
%oa3W3ZQ0?O151l7d6j423L2f3X3f4ZNf7n645Z5d0d0H0>7N[LXfL^7a5XFdSZBD
%OC6G7^UbPDGh<RSR;^7^g`>`aDRA4dkj>:BlSRR@BlF_7`;`BC4NlL?Rof8H:@4h
%lB<0Sl^>6K8e1XRHFlo77`^TZZa/00f54fdXVX8J7i0V7H2d2b2hRh4P4NCd>^6Z
%6P6T0l0F0H0R040>5h5l6D?n7U0@I4e]5V:JGj>Dee6`Udd06HWZ0Dl>=>3LW0CJ
%]VA8f<h14Q8I7`G8Qc1_3NQlJ`F]3`9[2j<B7f781^1:0/585D5`732R;h0D3230
%3:Gj;26h6f6/3J3H3N0@0B167I2R?27hElh5:g<@OF;6AfR4nK7XSZRX7h7`>@7X
%ab7l[L7[5TF[7Y:G<B8>o4jX86lJ84Pd5fX0T04==BlO:/9b=:N97`dbKRC2FTKL
%00N^UU<^O4GhR<;@Ak7lh@JZ908J<TNZV[:<^^7l:LLZ>@96LZknMV[n<`4Y>V<0
%d>;h5W>`o=1:?<@k<m<B<@]H8k:NEj`h4H`0[3:n9^fh9X=[3@Y>7>5:4^4D060>
%0<2b3<3L1l2<2`5P5Z6<blKX7R7<>:121D2>712Rn6[]7O:[>m@LHD=fO:7V7J=/
%Hl7n3X3V3N3^382f382/2V3D3/48mXR@=f96I6O47VTk<k@N8:NO7O;11N84`0oV
%0]8^D4Jn0dclK2PFT<8ZdG8o1RMk</WHD77X[h;;9>=dF/>g4VL]0@YW0RFF:F<B
%;>FFLZmdHhMS92`L9d^f2fl>`d0RoF6hjP7]1j^Ja]1cAJgk:no<86i88j3[CVI`
%3NdFWg5n8f;^[L;4>_7R;F7X7P7X72El7^0/0j1b747@L`7jn66Z6<2L1b1X4N58
%5j718FYDk=CIDfB;>7A>R27i7n;02N2/2h4<464B<d7V2j2T2H4R545Dm:>b7VA`
%_2kNYSDh8fWFVl9d2;El=B08f3AZK2]B4d^>5OFA8KCG7^;3@DNX;/>_BnAd8nDn
%8O<[9>;8N^<TEF>2U4YX=]5b<Z7S629`[Nb4E8[Nd[3DH6`J@47AGNG@1>l?6<1d
%<Xj>oBIHh2d5Ebmh<`WFPR84Zn7C6N7MH;AU>j@^>gE5@Rjf7n7H5N5/5H0<0J1>
%7U>JVV7c2R7J765d5<5:262f3TZXEJ[de[GiI><ln2;07Y5T7F5h5h5N0T0Z18Bn
%Bd7T140f0P6>6b6`7IBL[V7f7ZUXk0j`US7]I@WE>iJBSN8n4OJM68T0ANDJn`Zf
%bB3HEj8k?2?K<@/hNmFg4T;4onYZUKB><Rh<I6FhI1=WJ2;90hL^U_9?G<;8n:[V
%V/S]GH`NG861KfZ1F0Qc:UCNij9_B3J@`KG`>0N8QP8n2_LH4KLL8G;9L8F`:JUJ
%R3>DP:7f:l6@4ZW^4X4j5D6R6`71IF>`;DBn7D747F363T46k`[hk=<?L;MTB=7X
%9R7j783/3J2f3j404RXJ5f5^5X0V0V0>7JJQ5`g6:V>@ElLW;_MV@UJc8RIF7l6;
%NZ0GN_4@0:9:3Ro<^H7hQ87OLH2^ZN1PZW1P[37_IDL`7W2>Dbjn<BXXYB?n>4NZ
%:8n7MN<[7f>6>_33Fc<T7b7R8l:MOY11><O1:D`JBBG90Nl>Z05YPO=GHAASNNfC
%PDMfa07j`07;Pg1Q6]AH8EG0kj>^RHO9A>YX>@E8>`7V3l3N3>2X2P2J4>4H4P6n
%7@dh:U=IPYQe1d<e5X>`9h7R721j1>0b5D5H5/70gV000>0B2n3:33@]3N545[24
%5h64V09`m5;9QfWF]hi41Bl>1gS5AO=JA89^QXZR5ESEL7=36F;=KHDMIZd[2^h9
%K4?2NX7b:R7_<d>nUG2Xg;0S>Db490dd>6NlgbSV>=KZKEK``MH1SR@>2EN^0F<0
%i>nX74^0ce6CQf`L/oCMNP?J/n/n8d;75T]jU^STH4^j;0NnR67S;?Pb7`7BEljR
%RJa`mgTiUcKa<V>67J5F4X4D04020<2l3@3R262D2U?j5b>/8;<^5X;P00080V70
%mXS^PC:eDhQIAl7b:<30l>`X0TLkNk;8fiKf60W<163_WGO?SL:DNZ?DkNaL7n5?
%;JDf=h>AOYOT;FhBJSQ8O0aHm7K4IS<T/`O3P:[i<fCiPo7c;8`B`0AS>/0027XX
%c`Z[TgUdUhWg8iH??F:YJD<L;6g6?oRaCjJPWJ>2>IT@g:7n7P967X;690:FAoXI
%XcI?BLBhRXg47T7L7Fk:160l1L7@79U>>j7b605n5d4b4d4l3D3R4B7QT4?6Ve6E
%6^=hMf<aPSNl86jL<1F0<0W45>GbFUX`86iP7FJeGXK33R>Nf>FmP]VbZDX[VM0F
%SnKPB0L/[ILV=j_hIiBgPA[bChgk6XN695:Jf3XT3c/EGfimY]/LIO7XP=[bT90F
%S`d[K]KaY[/OGh[_Y?UH85;>7Z5V5H5N0R0@0f7k847d5j5h5^3>3@346:6@6H3Z
%3/4QBBR6O8>7QC:g189PWgVf8:N?6O=>00Yj39X/lnljD>ldcH3l9>0h5_^U]lNY
%[9=MZ_[RZECbWP[4<1[;/fiUL>ZZ9_JL4Nl>Qb5e_CGm>iXm_1_M_O_PEn>h[PBd
%6^6V6N4b4X4/5@525P6b6T72?5Z@5d5:5<500T0V0^4`4`5L7PEl7RV29hH;^bgm
%Pl<PFU^Blf>W4<Sl<0i1S8jTj?3lQTm1a8865ka@ZR41aFDK5o^2adMjjX:8Sm_R
%=VG8<@2=abl?N60VnhK`@ULUa[b5b7b88VlNJ2R<>aA>>^>AYR>obJ2X2Z2^7R]k
%Be5VUK/dfC_5VMGc:d:9CV3Zl?F0Z^B@8o5o3^DYC@iW6087O025cOGYH4[3`/lP
%<APmFUNUb;L28ETN7?cl0ad0l?XX27PSced=d?dAVLDea09N=eX27iC>Db8RA<>X
%;2V2[JdQFHjXehID@h8kIN5i8`M4<04Se:8ebg4YbjinDXWG:n3ieNAR65eU;4B@
%`O8LFT^M81dB8AZfika?a@jF0>fPfS_Kegf=f?/LXNknUFIm<<<ZXZaZbl[HEI3K
%<ll5NRLVnT73AZl>2[fme@QH<X/oP`X=94N:Mg=;A[=B4=dibbZF_l8:]ifAWJWi
%H>j?gFl>Sl6AggU7gWgmgoJ@E8[g0SBJFH]V7eC>aN[^:Z>934n8B3/590:E=7g[
%]0<:2IhaXT0Yhf`0j?^nWI:ag:8X8ZVlcL77GYTS[?f:XC[6[5aR<cgkcdl5a6SS
%;9AOcN258/;hAScl7?h1ioj1Gi>7@ZC0M>8IWbSZa^YR[[7NDnDI:fWF@h@4?mLL
%4Jl>Jh9B5lG9PSiYaO8QNJFjA9Tl<HiZ7fhR3/D069kD`NcR9JZZD^5=fACaY08?
%Aj85Pf7;hf0YA^022Ckmj3l1l3f]88AjkcI90ofO[bXY]1lHM_6GkKeb6OlTf3`j
%;i/D3bWgd:XBQgd00`ZjmIbh<cPaeXPhT;_TN9aYl49Y^XiL63JPEb49mSJGS;mE
%m[m//0R:KAh:F50n/;[d?37OAQ>Q2eiF7nCl7Di1Zn;iGXiUi4K=4OiR86N270J>
%1]TSH:eX8`dGg8jT<O^gSR87^ma=m_:Yjn87k?F0SmF1W>PhG9nom_oQoROFk3=T
%92m7Bh87n2nCgLfB80oX4oh8nX=17nIXD08I3@Q3fo4Gk4hY27c5hA6He6hi7Hm7
%hk5Hdo997SK9`i:FG:h<nX4oXA;H@miY97i<iY89e>iK;hg=P3@Ig@j9AJ=AjABJ
%EBY]6i4oa_DHJ1:X7j/jJa>7_CiUBjmGk1HK5Hk9IK=IkABH280oh50h91H=1hA2
%HE2hI3HM3hQ4HU4h8oH8oX567o6X8nX4n8g6I58H4mY;98]98Y:iI;HHnIQ0dU<`
%1=@7=`9>EM>gi?H<mJ11Wk@iM;WWAh7?GhnjI4U[C`QDDKDh6oZ]0geFH7@iC6j_
%1JHnj;27]IK3EWlFkDn;IHkMKkQLKU0kI88;<7bhkd6;i=Kl02EPJ5A;WQL=QlAR
%LERlISLMSlQTHSGI97;4ohmEH5:HiMY16]1T]5GXi0fUY`WZKo=C7[H=BX=HJ[Gm
%72[AFLc1:EB[@i]l=^0C^4kN9J87@7[2Ji/m;5=Q0]ac:aF][eN]5=U1JiaXcEUU
%gkl0_40O8R_=1^ieoEjoIkOMkoQlLKXH5Uh]m7oUmc:97V>Pb[n_T^:l86Nl31Q1
%2KP6W821=1d37^ik<>XOkU^ji[J]a2B4`8/Rb]`=4@Q34IZA;2D9@k2[2<<XiiX<
%NDH@56C9:i3J2`T]0jAdl@1;l1<OV98;GYm6LRb=8lTBC9DU/dUC<[4o2DWfS1n]
%0S2[Xa:Kl`0UDV9H_0eC20daam7iXC>[LE`;0b1^c5C:<Q2b:Z6^Z4_C=<h7nDTm
%PS?Y<CnPJl>RQ4g9G@L9]bg3dd?;e6XU2CLD?@jd:D6m;;m1PBddLm>D;Ae?e1D=
%AE7D;l<_:40/g:T[:lT<ZbfnT<E8QAKeZ_cb02_a:efjKL[:TdKYk>lVX9Dj;Y7F
%:]eEE<k;@fTfZJn]XX>/<96eJl41P9U]dlo:VA/USdZi>Bd5=LeIg@Q=6>Q2S1Wj
%L5h:R23EP0;=k>gImdgeOMnGkObgYBnmV8@o5UH;9UbFLSTi75QX;hONPXHU?2RX
%dnin8bTam7TT:UeK8V<@[=//i3T:;cc@efXA2AjIJ=VGQ1V9[IWG]VeTkBQg0m65
%EaOnO8RYAGj5NRo9VBE0YRQ4iIeWnVjMYnXJS94iGFdRTYj8>/PG[Jo0i[e>7>m>
%V8M:jkEm2^>7lRbDh`OIl/g;/YBhRZGCUV/?F0OjUCfDSDPVC_0Ca^b1AB[Tj[_Y
%:3d>_e^jUO_3]8=_9GX0o:VGbkSZ3YDEk7ag?Lod7@m4UcN=Y5Z343e=j0;eQUMM
%ZinF6RRDkO_B@WfSak6nKa/WXMYh7o5co<^^fC:BRanEO;L^Z;J/R895>kWndiY1
%Gj`_naZ]X7g`IolQG_I:EW_AjN]6FWX6Odc60bo19mafOPPg8;ak_bO]nolOcZ2d
%CM=bU38P0GieP1DN1oP<m8PJ_e`We@Z?HO8malSdH`?P58:@?Q7Jb?mf[Kf@^eI<
%aI]KbV@/g8NoEJ@ne85IDG2XZci`]@_Dd2DK4<gW<VG6R]aY1EOUW:/FX;Kggm:P
%R0@@KTAH1Zg?92l;C/8Pa=RM4n:2o6Z5I:hRd3/EdOP9;l3b;QN5^`:9LAPOS]BD
%/K5D:HC@YQARJ:V8dEPZQNSm<^A`ScJR=<UBJfX]c2R>;PMU3TOhVi1=n5?8EMbg
%D=??DVKAkDDEA`l7l:fBDAcEYo4`@I22kY7BKTi9fCaTDg5L2]:=NRlQdbWHY2L]
%im2;3c7D>48X?@I3f7V>`NQ@0D0[1d>`M[Jc=UR:6AZ3JCBR@T8Jd]iijAHC;APa
%`cJJRBXO@X<bJSkPB9Q3D?2KA2G>T2M>@FI/We7B=CN6VLaOP4CYWD=6MR;dHT2V
%k>:NDlijCc;2m4PB^a:a802n/FTodD^bJ@kDUZFBbRJ4T8dJXcQS=jX8<HI8cA9R
%F4jkJRdMSl/H7k1mPI;W2U35]B49m8g[0[6CBLPb:E^S^YI3h5U;e[SJQ<XQjBRY
%6<ZWZO1L2n2>:o1UCmNP;JQ5hS0VnW=AjTE9W/Da4Xe7:P7@DGi48J9<^4LC:6J1
%;F0Wg9<?a];g6<AhWQF<SJ[amDJXhlb[CW2NS0[L1V^0gZi2S[X`l2hUZl>bCT`T
%OdnP:Eo9f:i@kYF5`g>H^HDeBTRe5CLNVYX2[88lE`5bbR@gSF:/aIVcBC3dUXR7
%@=?1BPGfS;lPZ2X:JRV?=2?XX8naf427J8L@HP791c1L387HQQ42B7f?N/QV1lSk
%7ZGHnd:5_8E</Db_MFG<W984KhL`5[Y2h^X@J^@gU/QD^e:LM:9gWc87h<jlDE`>
%Q__<K]iln4gUhZO?6cJAQ?gaZN_A`0WK_FGYY?1imk[ggm_mOlURgJN?cLB6C0aO
%Wee?ZJKEF9magQT2j4/A8QA0_97n4@90Da?RQ5Jb8Oe`CX>aJBOXO3KbR?:8jEUb
%1BY00^aL8_63fhKab:H6O6d<AQHiCMEE_DbB[C=HT52dH;eh3P>EEUG50/0992_T
%eG23;80:QV=Q>Ej[;9[]mT_;FFl^4;K5Mm5J:IUR`D`CT_`W<dDc<L?ii8o1l3e6
%H<DGX507P59:D<O<E`B^k7Fg>3AFBa3l7d?iE6Q2ACgLCBUa9b21QNdL5SB42Bb[
%^CTMlFCOX31ob>bPPXT=?0Ee0;7DAHB`ZA@XGk;ZBi4Sl]?>RM89mHJ<QdFELEK;
%lJYea[VcJL]B;C;`NTKN`EiBD01MX:VEcJWg7f8D?PMa=RB4F?dO@kaPS35j0/1h
%61j<J7_78NU_Xa4FKNfiK`n8a<3;[N1>ElA?j`1>nNWMQYWkB:b>SN`Aml701/=o
%OQ1ZR^G6F=GPA0h0380o`L?72B4UQ2U`gGBAhJSGhT0cRRm6GQ/Nf^2;bdleL?hm
%anCJKXQUQZ;_P8jm=g3ZiDFSSYRB=3eSUWP:P@@M3B5l;DMXjA^P0080098E``39
%6T=m;Hd1P311S;T183@73I7H>PNRbUHHP_eEi60R>/8Y:ESTH@4^_K16fc]IclRf
%bZQ>NHA@6neISG07W]b35N_`7H4G^RUPKSTkaOcT1lRl2JkmU5NPX_149Z;S?_OQ
%b0?n1@>2@F3@N4@V5@^6@f7@n8A69A>:AF;AN1_f=?j>@Ilan37jA02BBD2bMSbV
%<aZ1_ZGAR:_j1?V1?an?QA8i2Q6B7Tj6Y7YQ9P04Q5V=E`?mk_ef=U]_mm_a18I2
%Z]O[ed_]mE21E]o_f3ZJa0:bB]n^Nd1Ve;ZfCInFJ4aZ`@^>?ji<:l22m7:n?2oF
%iHH6BZ?2GFj`=2HT>h]Nhf?cBIb2HI?:IG;IO<A>GEj2?_?5o@BFBQ;B=OC@>g@=
%kj^3G;<joHK7IK?JKGKKOLKWMK_N@W3i5ljV1;cR07SF@10?U8;VJkN`bI?nk?Qo
%_ah_mi^En?UiFmo_B`?Vi_^1?OZ_QjW4iVic?9hMB1C9n_JX_ZXcJ1X?mBE/Og=Q
%k012`4hB_YH[ZGX4ib26Y1Rg;Zcck^lOif`X:4;1c33C6^hQN0=3`@a0^3hXhaYN
%]82A0aC23WaI5/G<XN/HX6N<J1E6bB^D0HHag1k?=K0cY8k5lQb98/SB?94TbE9K
%:/NQ<:7J3TY>@TXOB/^:=@8ikW?8OAh>TNR17fNil7`kamYTOch?8BQ9TNJa/6Vl
%SZZjO3b;Vj:JY/8/n0G?aGd0=E12I@TEY[=3D?a<DOCdOQEdN0@006M9cW@UZG>R
%nj1c:O1<Dl2]@4>A140EDX80L1he3@=:j`DPIeeP8MI1IFQae]9UL8bR3XccG:i@
%EEZ=6UHH4f:dBBD4=B3<=8DPekG=XFSJEYfYJ][=kIUW`:OXYFj0U_Y:2ma79LT5
%;M@dS_7<D4X7GT4c@D9?U4KI]Vc6Qg_^j:i7lOR`GLOIlWd0`20:T/;2L4PBQ:Mj
%oH2OSXWXNYlW/Nilge8AnY/OAc7>M8T2>9AXVFJ@/RX;3YI@kn7/Pj;7/NHIR6<2
%`=0b0`3P>0JB0OHYT6<Hl2@8^ZBPgXQPJ<^Ed@QEe5cVPT]8;YMY[]P1l8h[anW`
%NbJCB[kiIBVF7dAOb_[NhBiaIM3=X<B6fBXTTLUI^;O^[AAobMJnlKc_Fmki_^n4
%G`5_P8T[S02E?3d^OFigKI][TSakT1QbAGLYYmWH0]jI58DAAPJ1H6><05_P44HB
%19dXB0X2X;Y80PPR48f;gdSC87j:XY2`K1ZVfOAjW^A134>EaFUU>fk9VP@kSb>`
%L1`6`;0Z32B0415RP2/VLdTTP:0T2MH7FQ=>@l0aKo;L@;T1m=4hOa^VFGI^T<ma
%MZDc>kaYLjSiC@NAk7VlQMVbYMP0ElPR_FXVh@8?:1AZSF452[0m]`006`C6k1Ea
%PoUd=nPe1^3T7H?@O8RPXcJ6P7@U9:0R50JhE46KD@R3;NHF`5FI0`lbJBgQ9Q`B
%H0[fCA03Fnil1`P10R3I@aU^QfakSfC4=HJ8da;2>4fE`P@n1f3b7@74?0P1jUP>
%lOIf`FPZ0T1B2<1h3P8P9060X2`3`9@l02BB=h1D?0RSX>Z>aSfiXi86>R?P@8o1
%1T0>V@BVdb_c7nI]bb_dP;EMVeQ>bS44UPD<deODDTiVY;/AUmY^HGT:DhU1Q@9B
%B^21o:D_`l6PbKQ1:^ET[IGB_BD?>F@:IJ;7003BG0mYM>9KVFi1dZUYX:Dh^PeK
%5C97B;N=DJHeUBP:U]2P0`5@;0F4l9lCk5cZZ8GJN<[@mDj?77o=hc`kSb3d7V@:
%KcM2<UK7bUdOYFao7P5`:/F0D`VQ=0L1@200P5P6U/BELiWRg1AX8R8OhNJ40JXD
%<FQQ0i>T9;M0MnQ6TbX5FFeU0[5QoWd?U99ARLf0>:V>]Xg/<J38:6GBU71bRBd8
%3c@JF5<JIDcYYCDS210bDiYF0=Vh1aYdoYQ94O/QW;;GT<@JH[:0U192I<dTZOP4
%/77L>hMQ6C_;^7bV@OQZao3j?<?ljQgYcS65b<X<XHPWQU3H5P6@A@Z3P>^Xb31i
%1l4d9Y5dPAm2_Sk?0?PCXYaA0R1<2E`A9Hj0RJR/1IYK1M0D/LOZ8Q`5>6KKV]U_
%LVBi9UK^EmRJo2XTe?R?`c`nAl3jRhJemSG4G5bQS9e6Qeb1>?4RSVF`][KFKY]K
%VgE^kNDb53Kn7D>cU2R^8@aOJcIN]eFY@6BQ79OV686=dKPh@6P<0Nm<Th1FhRZG
%N`11=9RI=D>TonN4BRgS85l=H281@;eP7<8dA`O0D0m2P>e4LhAgS/:fVJ0RLicb
%79V?M>lgQm7NO:;Mlh3<5;50C;:ojfhA887n>72R00NZb26>o3BF6c_[Z:]6C=V:
%mWNJAR5/K:HSA6JQA8g>7b2:L7YS5mhoPSHeL:SVJH5Ub3T]kSg7f?lP;D6eT?1@
%34o0;9:5S9D5kV5bTC8Z3LQVU4K8h3<6@=gYPH0^1XJ6GKAg>^L^a/1mX2DFWN?T
%NPkSY3f7TQ@3`6`G3F6N=m^`kA=RC4@8DC8[abhW:n?M/=@k@5LTLaVoPoDiYT?P
%@@BnSG2`C0K@K9hoC7Qgd/GX40bM=HaC2da0V;<@;l>TF0OEHBK[m@TB`/0kiS:j
%7i;Xj9gY<95/ZAaM2iRKH>17[^FdY@Od?b3/7HF`mR6``]144fbJYiZDJ@JC^]i5
%[FTDfNeV4R1]a5H0@0H2090A0YM8Ki_m4GNJj_`OVI4dTPP`EnlYGajSK6^=@1H3
%P>jU84>lM@6`5P96:=DMEmRU3gVl?hNdVAiSfa>WTZ8oS85@TQ;hVcL`[lC<8:<Q
%RW235^5Sa/2?7E?2H/fg?D2d;A[[:d:@C`W09PK0j<@I@bSZSm345`;PaQWSB7P?
%//1;:/YW@??3?a_;LK=A7B@PX_nTH<PR7KYVaNW=k820P3oPD3PT5Pd7Q49QD;QT
%=Qd?R4ARDCRTERd>O/IOTKQQhS`0T4Q0TSIlUPKjU4GUD[UT7SKlQ<_O4cT860X:
%M[/MkoOd4OKkO;nOd`OkmPCmXM6W[lNkgWSkX[jWSfOkhN2`EjZ99A;;lWXf40S3
%851bhHCGLKdXkjL3GJ0B2@LJ3FLE1OkgO[iV3kW]lO=@XdlQE2`Sn0>7U[Na@faQ
%?aceb4_S>1WU2bLWU=7bLIPN4c]2U5BPF4WkkUl3O>YPNWQ6QP[mOSkYfaOklOAO
%<iYF:gFneOZJBRDFboHCa[e5XffXShXD4Oe:U_AR^/Oj5jdQ0OIT:ekT3bN4boBl
%GSlWUlgWm7YmG[mW]mg_QfUPfYO<3GOgT85oF70:4ob1_TPBVW^cch@<QSB/VVIl
%86=L7960Qc7:MAmWdOYjWXYb2<33RS]/Z2NWnOBH<hOL67jYao7/K9]6X0020:4h
%EQTEA:U21H00>D1CUbN[EZXNQgRb;Hd7DZT=7U2jH=4Z2X=[4AlBLPkG84T<0X/U
%k@SO;HCBjH/_/nXJ>85:SJYO<JO9nQ;j8Nd/bYS<JU:<X2V7^Ba=4f;@_2ni0nS`
%?A_7<M3jZ>PBOa2OD@Z>dd3YH`T5c2`PVDVVX30<3]<71CB7^YA]?DoD5@e5DMBE
%;DbEW]E;_8c<YbeL3MH?d0Z@R3F/0CDPCZB_Dkd<9=SG/hPYgf6`CW]6i1nYo@RT
%:6cEPZ>W]S7hn[I:VY1k7HO1iD8Om27VOig7PY2CWXLi[VZ>8kT:LTO7TPD6@I4D
%A:U9bR9jd<2X8Ukn?50K9UAP0;H4Cf2EBZSA^Jn=LGVdB5EnPl1X=;;<f@WT;WWM
%c0YjDYBU6@a348I9T6FE1CUDOR<d@_CH>MI]LcAGR7HSH1nWCV`?i`T;n1mWSj?3
%=<YISXFQj9X^SJ?Y5?hNPHUJJT:@d`3YcjW<ZG_1InT_8Un7/9</5WTN:eDDZZI`
%m3jP>MReX<4i2WZ;Pil7ZObVX71QoAlX]2a4NQB4/BYIUdI2MWnN2RZM3BX:8V1o
%BM/J1h<d[22gbM88_Pf98fKO=1OcP/LmVJ2<PNZGW=dYGM>IgDWYeMlio=KE8:dV
%5]FSUYA8bS@VPIQTRF98T3F=`i7/O:T=Xf4XbO3L:kC[:2M1fDY<8H7YY20G[?h?
%o/mY<kDMQi__o1l?aO7lSf@CIi6oBoSn92Fgg8C<[=jalZ8CNP[ZL[Hk1O/bJnC8
%XM]IPS;[67nQDO8m2NUoA4heaJQ4@[C7n?DN@I`^QL7<]T]D4D15E:6E12cNEY?n
%C8aAO;mRE_b=PVQ0HHhF0UQL=661Q1C`cH41H3<=e9Q<Lh2l0l?HMSJR0a=QYYE>
%T;JF@8O8mbZ4Y8bULL@g1]06<>>m3;3B>A=D<Mh_ZDVD?R>n`UUYcfDU24?6Do9n
%R@S7SDm/NLKGjA_SQ76>DLgVa57n<J?02hm<j<>7F?bnHS[MNljj>Q3hD?MFhP]>
%S;R2TcH?6=U2bB_::9jb`cdHQn;a7d?@O8lRR>`<XF/G@/QH0:0:0M@@lWA[MEbg
%UAJdGm>>856eKi1AiBg9J_TQhXiN@e2A;l5L`A/c3M0Bm0H[IT0:VE30J:]fPT2M
%4cmAkIF4=SA2AY^Q1A0Qk3f=dK0f3V><<jXE9aXX1VD=<DAlC3d[^PH<4>N2/R@P
%?WX>bNdQIlCiWe?^OQj39S`X02NPBUP34Q1_@LjSX9WCBS1?eEIU7X46Oc08_TTY
%9=j7j?=eRQY9baEc92;<1BmSgA<faAATalSjP0gX_J5ZE:<NC08Z@nRm6HHJ_R<4
%9R9DXT6AV@9X@@e1WP4<PdQ23SQZ@B4G5Bi0V5S0iMnjJ4?W8CZ7`?PN0X1@2L<P
%H`bFlZ9@Z/HYID7R;C7j`e]Sm39af8HZhLX5jh7I06O`85MH_bbXMGV_ENjn?TIn
%6:`3Cb@0=/9DPL9m4[V4S]Fb_T^R2YGLR_IoBhiGASA3INSm9UXCGYm9D[b83J`O
%KJKA4D3iFb^G_0UIR7Ja6JXZ//`PYAC2V/aAjTb7Gm46Efc@FM_HKPICLBPjSEid
%<;63LL35bGESdZP@M:i8JgF40J:njTiam3h7^a`D8eec[9UQ9FB/0W5U5_3IQ0<X
%F/[i/DVR8S<212m_PB8TI8F?R6XOGfo5nKmGk>UDIn;lR3Fc5=H9YhY<3GlSSGPQ
%5U<54=>>Ibg1BjE=iCXLMa@nf3Sf>NGHOh00304W:aZ958Jc5<DA;0OmbkM<;=;@
%L6h_<H<o=2eJQ[=46X>45SU<9lg_4Q1ESl5^@D[/o8fXVYae3=fBaXHG9606GbCb
%HVR@nCjW9RWEU=<fD;eiGFOK]3Jck73o47V<k1fG[02^><77J0Y/`5HGV7112KJi
%c]]W@j;EDdIEcSW_13?WiaQ87<<K<NTL4PET5kA3MBIi`ciPVg93;JdnMFWE]YZX
%[U6]I;2LYJbOP00608_2bF4FW:9FMMkRZ>BbQ<JFjD]egA8=COlbTk3BTo4e[N5P
%HfOd:VZQ0T:VQ`>?EEXdRMS256U@F3gIElP2:`0g?HMUmiZT9bm/BcFelkIfUcSG
%;<9F:KFg1?Uo:IF7j^1U^NPULPAK[UY^6Qe]B6fHFBE9Hc:CE6Z8b;/kP62h0490
%5/;8FQaTj@eILV2UP21m3l7h?HP11Qj3j86Ea]RRZ47d7cR?2a2203n8:Z`O<N7d
%7b7CTP4NC1miAamehnI^1k43bmk8OnGlB84=;V`:NL6C3ec/A7?NMQj41d4Mg@`4
%M53CdLPO7nPlLNcbP?ZTH`M>iSc7YgD55MBjV7oZ/eElmHjWe/bYQB1mNjYbSZgH
%nDLa3cf/o`Q<_E6Nf@?J03>jK<2KgMGC2mSK^W7]S>_ObEiKGbI;?oO?3A_Ye]?9
%o;GZ_F[T<cb2IGAN7SU_3B4/GRY=LBkLE<_=o005R:TD`f1US31<283`H`j1k7J[
%VJho`GLhiP7KQHOc[3n7dDkDblbV22468L?W;_PQnc68>@90`kO90Cl/S`N>fYW8
%fUN<XQnFm>iD@8D7f@ZoKk@7gWo<nFeI2PB5O??nUlOn;Uhd_aN?oXc7nXWok?fQ
%loBk=@glLaocoYnonfKQm_i?f_jYW_o@0;j^HR639TbT[T5QL`6R@YU052@WdQ6^
%hUW7<9e=g=/_0=]2::8_525?9_:@A7`;853X`2G`6QL/22@Q9@FSZ>m`AYn[<1kT
%<6e<84;Z00:9j1L;NRRT61lQe1C1@Q;P:PEPK1c_G:@UTRlQjU25^?L3JQk2T1l4
%B6f<A=_:d5W>L0DRBQW]82Q<QUWV3>W?RZ9R2SkQM_6P12://93<W28@fR<@g`g3
%=R4Y5@C32/I8B8`@@R28o0jR@_UP4Zi1Ta2Z9=5`C[g@H]]/6[R>@/R?XA5a97_W
%@:eR=VYQcP?A=<bP1ZQZN5^@:a9]g_<@K3H2VQRWYP7YU1kYL1nT61mQf0o0kPfP
%[Pg0mQdU39:QiRX;/2N1m1jUT_M5gRYUkWKRH9<US]N22;V^?P^aW4baU<_2GQha
%ZA=0?<dR36^RD>C08PYa_487l2IWnRO^h6J=Jab?2acAcab/_UTaeadafacQmaf:
%7/_?1R=`?Af^@S@]U0N/2:10CUQQg`c88S8AA3a]6>`RGWA7laa]Jb3b86RAi943
%j0WB;8cP2]W1eB=R31fb?@B`1b8YlSH=iVe3WQA1@1?PJPIPI1o=kRe5bPB0?P;Q
%@1IQO_FSJT@TW=A4C5276Qm2Z1o9=4ASj`>9W<_9J4^PC9N1A`Gal=^:7R@_[RkR
%VSZ>F`841R@/e]S_n]Z[7b^_n/E`1b_6PBa44B`B@YIXg@?a3Ql:S<`Q^BhP:BiZ
%22@a_0Y/`b2:m?;43b4WX;00a>W:gA/X`BmBAC3T3a;9e>NQ4@ER@;h1N]5@ZA5@
%HC4?:Ti6;1l1k1jQGQFQF04P3P31a1^Q^U^QkPnPj0fP60402QfRX71SSX2QoR/Q
%E2Q>:9F3=2XTb:>=<C<@m66al[^1[R@_TPk3j5lT[b=Qe0RcV@8:L9I321YcY;WR
%@7A6L0?QMC/W8S;Ah:7/Zaj5WC_c^c`ZWC`5TCa;d23Zka`Uh^`bb7FUW/UQICiX
%n00/cQ8Cl=[Bn43B4b71Ocoa0_UQ5d1]GCSbXC;AAA898cd_SR;V7QVd85:P3<c_
%Vd4@>/Sc:<lc^3:3Z8C8kC5=Y66@;R5TD@JC<c=QfQeQe0S0R0QP0R@DGP00H0G0
%HQ`1_Qa9`X721C=Ql038NU4]A:HS0X^bQ4b=D:dR;^QQg370WXMPdDWV21??RP[d
%Z0:d[17D/:072R;R@Phd_0]D`D;3gPhDb3n5I3n?81V:K@4<^b`W`@=284f;<:Y[
%<2TRFYT1FSn>j06:20NDo7CQG:gA7<Wb]c3Da:mZVcKA5<Ze6E6alR1PbE8cj]cP
%I:ke7E;e<E<e=E=e>E>e?E?/ZS@T[XCEB6:39QdED263@TbQ_eFdA]HA@8S3DX/>
%:XUBC2lXU1aDK1e1dQf5E8`2OQn8<[:000100==VfcI82Y:TDZBCM[b>`e?b732@
%DQ<E[E8Pb>B0j<31BCQ?4b5D=<[3@T86XQeec:KE@EdeeEeefEfegE=T1PHEiCjP
%eEjR363:S<E<K>^Egene>;ES;F0e>S_3C2T`JBPZ?@h]096YZ1oQ=f7bj[1>RP4:
%i09f;:jPP?RQAF=QUF>QaF?e3/mWWRQ<28NP3cjc7FD`EZiFD[Y=VFEFHFHfIFIf
%JFJfKFKfL=38d;1FCA>FJ7fDH7eck<cW[B<Cj/c`e2@f9fJF9S3P0FWFDRAfT2@=
%o00P79CP8P3]o??dHVWfRP1UIP0F`P2]oC@eRZ2]?7ZR@01??eSFLa>@8FDfQF^f
%P6WT8=OFMF`TG[ifefRc7FNfgg0g1G1g2G2g2SnG000FU[15I9iC7EkUDfYg3G9g
%:FIDHg;R@:iP104P20301g<dHC7FifHflFEF9f8VWYj07fD;11DgGF@/hRG/_AU2
%E6^@n38AZ1hd@gH:RXVadDBT==hRQ>5PoA[;VT5a]66cRbUD@242Gd]0JgXW9P]R
%34Z:c[[Z<2SWE]G[:851kSABGDMQlQl84210Y7?529eBM;CdRRZTW76SY;VT`VOa
%f<][4@l45e[1<2@b2GJGN2ET[gLYRTdGkTY39V3B6caVSDh=hZ?8TTCZF<D<6S1Z
%WUDf7Q=P8H</25IDmgE0Mh?cl18BV1THBB?1fccGoYl5o5WgTD3eXedY4946OgKE
%oHJhKHKefVO`nde_k/<5D]40_0MHQEc1ehHZXQnE/Do0NHC2IF6W]S51_:h0;^I/
%iC^BMgO6d;:cK6dT@`Z563:GT<AUiETggUXT25^eT5aee<Ua7hFAa<ohf25a<2h0
%9=P=Q63X`hLHmHmhnHKYWBcHNi0682V[4hnhnF03Wf1E<[=<<H8BLTA@ZT?RTc5H
%hf5QoQJI<3nG5P00QI>QHi?hk@;HNhJC:hDY2aU;e:W2FT5Xk4[d6iC?2H`HgXDY
%<RIi>PQ0XiLaU3ZHRCV0RUJPPgi<Z8`8e1S[OQ?iT>[Em<g5UUU<RZ<2D6k2Y1lb
%PZ<RS1gW5/i`U/9dQ55eWZH;93aeA65iMa8/5Wi3j0RIe>fY0iBiC29UlelChic5
%mBWh9eH7`h6?;`[DS>9Qo1_Q]1^I8DTB]`;QRJ3d91:j5IU[V`/GMig[m41ch@ji
%Qeeba7cWL@mi3J=j>EoC]U5IHR1eD1dBU0ijC7A?h1mVK1dei0H470eba<`i?QHd
%[0:jIR1fAj@4hZ<5UEVIZAi]j2Y1nQhTC1hd]Qg41@W5LTV3A66]C4D;E3OCNbCE
%daX<fZ7_X@<IciJ237DQW>Ud>eC<`J>jbJbjc55IGd5IDU5AUE;JchLf1I4E<h7W
%mQjaQ6lQd1aQb_?QIQG1H2P@/^`ceR=T1c0=LW8EPR=V7f5:KJ?j8:m8k@5Dg2;C
%Wa@Z6IkiC8C1[K=P>K>Q6K?XC<]bhQ^8JQ5KC9fj[UW1>KE[TP<1UkGhSBbceG/e
%X5akK3HRZJQRN1kQeRSD]X54WQKQG1GY<YEZHYa@XEU[Lcmj2H6Z:9e2GZi8D<`Z
%S8Q4`]SB4k7R8/V]IW_4h<^5V55IQ7_im7H[K@KST83Ql0Z0WPXQ[8H0GPFPG:01
%k=5][]7S:Y<c=V;9;4?2290T[]SBbK]L2L2`kHW211OL5C[dXbfR3L51OL66224a
%U>IP=L;eFQ_U6RU4@DPQi]j3AVDDHV;9[SV]j/7[`:><]Dk3J8^lGK`lCIn[L;:1
%oSn777XKZH5L3LMS1kJg/[FWT]BSATVTDQmQIQH1K121112SWQk1Y1Z1XPZP^0eB
%g:<8aT@;bSj]C76;CKk[:lNL`L`RFVOQElb]WJKj]R1lbQElci?gZ]_dMUDPblie
%:DUE_Sf;c8?Zl3nK9@1[?L^LOH]2RTBM2EXKcAG2YLQK03j481j38a5>[HDLaLaL
%DlIbC;CUjVGRWQkQiQh0j0gPh[[T=2ISHQ0Q61?1X1/1fYa4c<CRl/<CMaG2RZHM
%<dT30bMm9mLmMHZ/[17mOL;P=J_C2<XQnMO17mPMQ7HgKX99KbkPSmWdU5BUX/A8
%1;;:i21[3C/QMHkloWoKK8D98Y8dPDPD5S>?GRV7R1lL@21R@QW2BkA]GJ2b_bdm
%Ml`M:lD/jjYTiQkJQ3=89AL<DVgT@Vl1hUUS=2RGh2TMIN5mJGf2O@UMjn8mMS9^
%F/OPEHX<m<f=@Qnn:/On<IEN=21hCH?PMP`NCIUgo3gSHh9KlGc0Y0Y63=WCoQO_
%1W63Tm:a/WmDSW7:;TAl_QkM739R@PAPB0BB1@/Lkn9MLmkkU[L]=l^SA2=QEQCQ
%<PNPKPCQU1Q1NQ3Q3160@PEPP1abL5kS8:B8881MHTCn6WTVaggVmNUNhLMjIPLn
%jD]C_2Q7lninjZ0NkbQL41okF`1B]ig3c822N[/:E;A23e/EjPe:5R<RVVl4>97;
%b=jlDngO:S?He?k/g6;8fQhXNP2QKQLQK24kYn@NhmM4>Dh2nTbJjDQVGQkQgQa0
%9@8Pc0]P[QC1@1DG50>QfRW:J5X4WAP:HcIL]nei`Z@mL6HR0X0oh50h91H=1hA2
%HE2hI3HM3hQ4HU4hY5H]5ha6He6hi0TO7gY8H6oI92Gg9hnSi2m979HA9gg0e;<i
%JoGm=h==gm7HVnWbo7o>j30Z51F5A`oBGEBgaCH@oI>nI9<H7@Z]@go@:cA:i1J4
%o:1H:2oCRLCN0;@o7lngeKKM<8CH7i97k?;]MkaNKeNkiOHIEjaEi/ojXog`mW^o
%k[RWdefHa0EJ5<V4Vhfhh@H51>hWOGI]E7[HH5DlI@GgFZYFX;E:YRkm[mQ/MU/m
%Y]M]]khm]e0jJn7__hI^W]_:K_lC1Mk>X7L=7;]a1:^o/G>iQKQEeeCfNHoiGd;[
%d/E@:5RnWF:eijkd>JnI2e6Td@T4PP1@:0Ig[Y[M:[>Yacolol0@30B_:jX1n`<[
%BQ:RPAm:bNJ/WXDa=4d4ChWnOAj4^Ai6Sh@Y:9Hl:^7TZAl84NamY`kl6/8e3dX8
%eSA`76DIaY6/KA_0Bi8<kJ1adPDOANTj3B0V/R8:O<T?lOTD:6l4VY^@dXP9:Jd0
%00D[bZ0<]BZ0Bd02]4^P00JdC60DaP9;h2;A=@0CI=@0c3<80Bn002[A>di[@DAA
%51:[kahQ2M?e752D;@dI>R[T3aI4:]Z6aLBWo1io7/60@Q<GQEUN`ah2D88N4>B1
%=VTKaf?0Maf7J90WRVAi<4jO3_Z[5KCX4ZRR/DaC5YSG53emGmPF3HEQf8RcZ9n`
%9oVcIH9fJ0Sj9/jCWFB[:eBBTZ]AFm45=5Ab[?jXQnTJAI51l7PM]7:H1?_H]fgM
%MjkDCAjPEZZ4OdDPE8WXNih7@4h=0nOIe7POihWF4@<PX<0d3TN:jWbO5N7j?i34
%HJ9/W3FmIe/ZQlaL^ZGEiN6Ai9T^CI?U27/?ScZ7eF@QIPB>IClQ1m7`O9o;WGC2
%9RTQ>4ZC080B21[6PK1EU@E`70J2Ag7NNJ]7YVl4X591lW2Ki`0`2`:VjKI]=nN/
%lgIU>bk=H[0:jnl4G_NInW^]IjDY1im[[Ud;a:O9kdRhM`WXMigRB9XZ7U1[D^W5
%ImHk5cV[6[6clQb?9LWbRo9fOVG9lOQcW<M9LUdGEXP7:KafVWNmERYbBi_2inTH
%@I40>003T^B9<6XJI/:o]Yl;WWB1VBHiT6TJ1XX=:Zi_ab_UnI030:_9TV:Q8CbK
%/N[37SWQoiaSaoWPNjf7/NI/VVJ90MQB;F;DX?4lGajFlMG_VoWnWjo]U3bgV`dT
%=>OP^1M2jg]B9@BK/fIHSm0aMFM506D<4H`5`80G7^?54Y>bQ=g7dM@dL5VZY9E`
%?6401`408OjoN4d9bl`LFC1T`a8d38[>VB`Oa;5j_K84?LTXoQl2B4D8LI0b1W5D
%7]0LXSkFZ^<OR[:54BhVA=RLKPWK=Vj]D<0?T]YP2h;7@JBB7B9G58G7l:DCPX@<
%PB0^?4MPl689<DM3QAKfam?[LL?N8JbD`?bRO7V9ii3e;D@^_TiAEhY42N^?lhKY
%al3nNk1TOXga/3@0b101HaQSS;:Tje]DAXK:>SjfV?DWi@BQU4@/Z478eZ?9^lUV
%k>42aLIdH/]ZS8hS/72><?HLPkPJ0V1PHh`QS2l5f;j:aHS2B0?jJN5D5SbSe7]8
%VDLci?_bAP^52l[8>=e@^hZ=kQHF4a7/>d`T<U_C:R:_UmaZRZ]ZVQ>^MTkHCAl:
%6F``IF7nU2R]2aA@n8]UeKf5l:PEP9P80D?`N8ma<2?4X0`0X2Qd>MMg<F?lm2e4
%nDX?E1[;J9AhWMA]bIh:?CZ=8[ZE<=g3:fY<H=S`oD7SjL:a5I1>3V:AHS4NCTjH
%oDLYaCVWBkW;]gT4BL`2dIk99Y/T8/DEY<@H<8?JRhofmaaY<XiVlK5Z4k=lbj5E
%>j];]TlS6HYh9hCc9Pg17kUbMSf;0cdV;jjDT/7j?HZ1JRM]kW@?ia:1V=84OOE^
%_UOJo>ANO>ZVm=Z^T:EkAZ_mREQWh/;?2Z]PTHU[==9d[ai;2f:/aIVcEVk>FM/m
%Ind5XKAFS]9JF_Y0@0003@4000<000010GD0004100<000010A<0004200<00003
%003B9P4300<0000100D0004600<000010080004A00@0000:003B;04E00<00001
%00<0004F00@0000100007@4G00@0000:003BE04J00D00001003BO04K00D00001
%003BQ04L00<000010040004X00<00001008000000000200800P000080004CP00
%3lD002LV001?Q@00Le800926002V6`00]/L00<^K0004AP002gL001MQ000XG`00
%8ld001dd000EU@004:`001CD0005j00:o80002L@00[lP0009a001`2^07X01`01
%00400`0300@0000=00`0405e0GD1M@5e02P0O@25455eJF=[E6U]IJXPHFiT8640
%02P0R@1]5eA9ATHP:4aJEbTPI6ESKfe`LVEcLfmb02P0U@1M7f5bIB1^IFETIF@P
%M6lPLfEU87AXJG<PL6USM7EbIBh0003o\\>\"], \"Graphics\",
%  ImageSize->{373, 275},
%  ImageMargins->{{0, 0}, {0, 0}},
%  ImageRegion->{{0, 1}, {0, 1}}]
%%EndMathematicaCell
1 setgray
4 279 moveto
377 279 lineto
377 4 lineto
4 4 lineto
closepath
fill
gsave
4 279 translate
373 -275 scale
1 string
373 275 8 [373 0 0 275 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } false 3 colorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFEFBFFFEFB
FFFFFFFFFEFFFFFEFFFFFFFFFFFEFDFFFFFDFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFFFEFFFFFEFF
FAFBFBFEFFFFFEFFFFFDFEFEFEFFFFF9F9F9FFFFFFFFFEFFFFFBFBFFFCFC
FFF9FAFFFAFDFFFAFDFFFAFFFBF6FAFFFEFFF7F8FAFCFFFFFBFFFFFCFFFF
F8F9FBFEFFFFFFFEFFFFFEFFFFFEFFF8F7FAFDFEFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFEFDFFFDFFFFFDFFFFFDFEFFFFFB
FBFBF7FEFFFFFCFEFFFCFEFFF6FCFCFBFFFDFBFFFCFEFFF9FFFDF4FFFDF6
FDFBFCFEFEFFF7F8FCFFFFFFFFFEFAFFFFFAFCFFFDFBFFFFFEFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFEFFFBFAFD
FEFFFFFEFFFFFBFCFCFEFFFFF9FAFAFEFFFFFFFEFFFDF8FAFFFDFDFFF7F8
5F545613080AFCF1F7988F940C050AE8E6E9FEFFFFFCFFFFFBFFFFFAFFFF
FEFFFFFBFCFEFAF9FEF6F5FAFFFEFFFBFAFFFEFFFFFBFCFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFDFDFB
FFFFFDFDFEFEFCFFFFF7FAFFFBFFFFFBFFFFFBFFFDFEFFF9FFFDF3FFFAF2
FAF8FBF9FCFFFEFEFFFBFBFBFFFFF8FFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFEFFFEFFF9F8FBFFFEFF
FDFEFEFCFDFDF8F9F9FEFFFFFEFFFFFCFDFDFEFCFDFFFDFFFFFAFAFFFBFC
FFFAFCECE1E37B72771A1318C7C2C6BCBBBEF9FAFCFCFFFFFBFFFFF8FEFE
FEFFFFFBFCFEFFFEFFFFFEFFFEFDFFFFFEFFF5F6F8FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFBFFFFFBFFFFFFFEFDFF
FAF9FEFFFEFFFEFFFBFDFFFAFAFBFDFCFFFFF2FAFAFEFFFBFFF6EDFFFBF4
FFFEFFFCFFFFFEFEFFFEFDFFFFFEFAFFFFF8FBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFAF8FBFDFCFFFFFEFF
FEFFFFFEFFFFF9FAFAFEFFFFFEFFFFFBFBFBFFFEFFFBF9FAFFFDFDFEF8F8
FFFAFBFFFAFEA59CA1191217F1ECF0F9F8FBFEFFFFFCFFFFF7FDFDFCFFFF
F9FAFCFEFFFFFEFDFFF7F6F9FFFEFFFFFEFF000002FEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFFFEFFFFFFFAFFFFF8FEFEFEFFFEFF
FFFEFFFAF8FBFFFFF5FFFFF6FFFEFFF9F8FEF9FFFFFAFEFDDFD8D019100B
C6C7CBF9FDFFFAFDFFFFFEFFFFFEFAFFFFFAFBFFFFF9FFFFFCFFFFFFFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFDFCFF
F8F9F9FBFCFC5C5D5DF7F8F8FFFFFFFEFEFEFAF8F9FFFEFFFFFCFCFFFDFD
FFFCFDFFFCFFCAC1C6171017F7F1F8FFFEFFFEFFFFFAFDFFFAFEFFFBFFFF
FDFEFFFEFFFFF9F9F9FFFEFFFFFFFFF1F1F1070808FBFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFEFFFFFEFFFFFEFFFAFEFFF8FFFFFFFDFCFF
FDFAFFFFFDFFFFFEF4FFFEF4FFFBFCFFFDFFF9FFFFF7FDFDFFFEF8928A87
C8C8CEFBFFFFF6F9FFFEFFFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFEFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCFAFDFAF9FCE7E6E9
B9BABAFDFEFE030404FEFFFFFDFDFDFFFFFFFFFEFFF9F7F8FDF8F8FFFDFD
FFF8F9FFFAFD8C8388070007979198D4D3D8FEFFFFFCFFFFFCFFFFF8FCFD
FCFDFFFFFFFFC9C7C8D2D0D1FFFFFFFFFFFF000000FCFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFEFFFBFEFFFDFBFBFB
FFFDFFFFFDFDFFFAF5FFF8F1FFFBFBFFF9FEF9FFFFF0F7FBFAF6F3D9D3D1
808388F8FFFFFBFFFFFBFCFEFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F6F9FFFEFFFBFAFDFFFEFF
424242919191000000FEFFFFFFFFFFFFFFFFFAF8F9FEFCFDFFFDFDFFFBFB
FFFDFD9C9598100910D6D0D8ABA8AE0E0D12EEEFF3FCFFFFF4F8F9FCFFFF
FEFFFFF9F9F9E1DFE0181615DDDBDAF7F7F5000100FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFDFCFFFDFCFFFFFCFFFFFEFFFDFCFDF7
FEFBF4FEF6F3FFFBFDFFFAFDFFFAF8FFF9F7F8FFFFF6FFFFFFFEFDF4EFEF
494D54F2FAFFFBFFFFFCFDFFFFFEFAFFFFFAFBFFFFF9FFFFFEFFFFFFFFFF
FFFDFDFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF9FCFFFEFFFFFEFF
D9D9D9131313040505FDFEFEFDFDFDFFFFFFFFFEFFFFFEFFFFFCFCFEF9F9
FFFDFDFFFCFFFFFAFFFFFCFFFFFCFFFEFFFFFBFCFFFCFFFFFCFFFFFEFFFF
FEFEFEFFFFFFFFFEFD8D8B8A3E3C3BFFFFFD040402FEFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFBFFFFFCFFFFFEFFFDFFFFF8
FFFFF4F7F0E8271A1FFBEAF0FFF1EB221914606872F1FDFFF9F8FBFFFEFD
7F868CD1D9E1FBFFFFFEFFFFFFFEFAFFFFFBFBFFFFF9FFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFEFDFFFFFEFF
FEFEFE868686040404000000020202000000010101000000020000010000
020000030000030002030004010004000004000004000004000102000002
000000010000050000050000010000A2A2A0000000FEFFFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFEFFFDFCFFFBFCFFFDFCFFFFFCFFFFFEFFFDFFFFF8
FFFFF3FFFEF6302126BCABAFFFF8F04A413C87909BD2DEECFEFDFFEEECED
484F538F989DF8FDFFFEFFFFFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFD
FFFDFDFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
F8F8F8F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFF8F8F8F7F7F7
FFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFEFDFFFFFEFF
FBFBFBFAFAFA2A2A2AA9A9A9FBFBFBFFFFFFF4F4F4FFFFFFFFFEFDFFFEFD
FFFDFCFFFEFFFFFDFFFFFDFFFFFEFFFEFFFFFCFFFFFCFFFFFCFFFFFEFFFF
FFFFFFFFFEFFFFFDFDF9F4F4D4D2D1121210050501FEFFFDFFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFCFFFDFCFFFDFCFFFFFEFFFFFBFBF9FFFFFA
FFFCF3FFFCF4A69A9A221212FFFAF4978F8D7C8594F4FFFFFDFCFFFFFEFF
F2F9FDF8FFFFF6FBFEFEFFFDFFFEFAFFFFFBFCFFFFFBFFFFFEFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FF4F4F4FFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFBFBFB8F8F8FF4F4F4FFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFA5A5A5FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAF9FCFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFFC2C2C21F1F1FEAEAEAF8F8F8FFFFFFFFFFFFFFFFFDFBFBF9
FDFDFBFFFFFFFFFEFFFFFEFFFFFEFFFEFFFFFCFFFFFCFFFFFEFFFFFEFFFF
FFFFFFFFFEFFFFFCFCFFFCFCFFFEFD71716F000000FCFEFBFAFAFAFAFAFA
FBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFFFF8F6F7
FFFDFFFFFDFAD7CCC40A0000A69893E3DCE10C1427E2EFFFFFFEFFFFFDFE
FBFFFFF5FCFFFCFFFFFDFDFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFFFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB1B1B1393939F0F0F0FFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFB1B1B1393939F0F0F0FFFFFFFDFDFDFEFEFE
F8F8F8FFFFFFFFFFFF181818838383FBFBFBFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFFFEFFF8F7FAFBFAFD
FFFFFFFFFFFFFFFFFF6464646A6A6AFFFFFFFBFBFBFDFDFDF7F7F5FFFFFD
FFFFFDF8F8F6FFFDFEFEFDFFFDFEFFFDFEFFFBFFFFFBFFFFFDFEFEFEFEFE
FFFDFEFFFEFFFFFBFBFFFBFBFFFEFDF3F3F1070705B7B9B6FFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFBFFFFFAF9F7F8FFFDFF
FFFCFFFFFCFCF7EFE2120A00665B57A6A0A800081DEDF7FFFAF9FFFFFDFE
FBFFFFF5FDFFFCFFFFFFFFFBFFFDFAFFFEFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD7B7B7B2A2A2ADEDEDE
FEFEFEFEFEFEFFFFFFF7F7F7FDFDFD7B7B7B2A2A2ADEDEDEFEFEFEFEFEFE
FFFFFFF7F7F7FFFFFFEDEDED3B3B3B606060F4F4F4FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFBFEFFFEFFFFFEFFFFFEFF
FFFFFFFFFFFF525252F6F6F61B1B1BBFBFBFFEFEFEFFFFFFFCFEFBFDFFFC
FEFFFDFEFFFDFFFFFFFFFFFFFEFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FDFBFCFFFAFCFFFDFFFFFDFFF6F4F5FDFDFD000000232424EFEFEFFEFEFE
FFFFFFFAFAFAFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFFFBFFFFFAFFFEFFFFFCFF
FFFAFFFFFCFCABA7993D3727CAC2BD87868C212B40E3EDFFFFFEFFFAF5F5
F7FBFCF9FFFFFEFFFDFFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC8F8F8F1A1A1A
CECECEFFFFFFFFFFFFFEFEFEFEFEFEFCFCFC8F8F8F1A1A1ACECECEFFFFFF
FFFFFFFEFEFEFFFFFFF5F5F5F2F2F2535353474747EEEEEEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFFFEFFFFFEFF
FDFDFDFEFEFE030303FFFFFFE1E1E1BABABAFFFFFFF6F6F6FEFFFDFCFEFB
FEFFFDFEFFFDFDFDFDFDFDFDFCFDFDFCFDFDFAFEFDFAFEFDFCFDFDFDFDFD
FFFEFFFFFDFFFCF7F9FDF8FAFFFEFFFFFFFF000000CECFCFDCDCDCF2F2F2
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFDFFFDFDFFFDFFFBF6FA
FFFDFFFFFDFDF5F2E9FFFFF4FFFDF6FEFFFFF5FFFFF1F9FFFFFDFFFFFDFD
FCFFFFFBFFFFFEFFFDFEFDF8FFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFBFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB
1B1B1BB1B1B1FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFABABAB1B1B1BB1B1B1
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6656565323232EEEEEEFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFBFAFDFFFEFF
FFFFFFFFFFFF010101FAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFEFFFDFCFEFB
FEFFFDFEFFFDFFFFFDFFFFFDFEFFFDFCFFFDFCFFFDFCFFFDFEFFFFFFFFFF
FFFEFFFDF8FAFFFCFFFFFDFFFBF9FAF9F9F9040404F4F5F5FCFCFCFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFBFFFFFCFFFFFCFC
FFFEFBF7F3F0746F71FAF8F7FFFFF8F8FCFB818C9ED0D8EDFEFBFFFFFCFC
FEFFFFFAFEFDF9FBF6FFFFFAFFFDF8FFFDFBFCFFFFFBFFFFFCFFFFFEFFFF
FFFFFDFFFFFBFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
BEBEBE1F1F1F9E9E9EFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFBEBEBE1F1F1F
9E9E9EFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF8181811A1A1ADFDFDF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFBFFFEFDFBFFFFF3FAFF
FEFFFFFEFCFD010000FFFEFDFEFFFFFDFEFEFFFEFDFFFDFCFEFFFDFEFFFD
FEFFFFFBFCFCFEFEFEFEFEFCFDFFFCFBFFFCFDFFFCFDFFFCFDFEFEFEFEFE
FFFEFFFFFAFCFFFDFFFFFDFFFFFDFEFFFFFF010101FEFFFFFFFFFFFEFEFE
FBFBFBFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFDFEFFFDFFFFFDFFFFFDFFFEFDFFFEFFFFFCFFFFFCFFFFFDFFFFFEFB
FFFBF7FFFEFBB3B0B6848285FEFDF6D2D4D1555C6AF8FDFFFFFDFFFFFDFD
FDFEFEFBFFFEFEFFFDFFFEF9FFFDFAFFFEFBFEFFFFFCFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF4A4A4A0000000000001D1D1DE7E7E7FAFAFAFFFFFF
FCFCFCFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF9F9F9FFFFFF
FEFEFEFAFAFAFFFFFFF8F8F8F2F1F4FFFEFFFFFFFFF8F8F8FFFFFDFCFCFA
FBFBF9FFFFFFFFFEFFFEFDFFFFFDFEFFFEFFFFFDFDFFFEFBFFFDF6FFFFF8
F5FEF7F7FFFFFFF8FFFEF5FFFFFDFFFFFDFFFFFAF4A49695B3BAC8EFFFFF
F0FFFDF7FFF7FFFFFBFFFCFFFFFCFFFEFBFFFFFEFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFCFCFCDBDBDB2F2F2F585858F7F7F7
FFFFFFFFFFFFF5F5F5FCFCFCE6E6E6AEAEAECECECEF4F4F4FEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFCFCFCFFFEFDFFFCFCFFFDFDFFFFFFFAFAFAD0CCC94B4948
6B6E72F6F9FDFEFCFBFFFDFCF8FBFFFCFFFFFFFFFFFDFBFAFFFFFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFBFBFBFFFFFFFEFEFE
C0C0C00000000202020101017F7F7FFFFFFFFCFCFCFCFCFCFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FDFDFDFAFAFAFFFFFFE5E5E51B1B1B050505000000414141FFFFFFFBFBFB
FFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFEFEFEFFFFEFFFEFDFFFFFEFFFDFDFDFBFBF9FFFFFD
FEFEFCFFFFFDFDFDFDFFFFFFFFFDFEFFFEFDFFFCF9FFFBF7FFFEF6FDFEF6
ECF8F2F9FFFFFFF9FFFFF3FFEEF0FDFEFFFFFFFAF4E7D7D5717785E4F5FF
F2FFFFF8FFF8FFFFFAFFFAFAFFFBFFFFFCFFFFFEFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7FDFDFDA8A8A81616169E9E9EF6F6F6FFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF
FCFCFCFAFAFAFFFFFFFDFDFDFFFEFDF5F3F2FFFDFFFFFEFFA5A5A3868684
C9C8CBA8A7AAFCFDFDFEFFFFFAF9FCFDFCFFFFFFFFFEFEFCFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFDFDFDE9E9E9
1F1F1F0000000101013E3E3EF9F9F9FDFDFDFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFF9F9F9FFFFFFBBBBBB000000050505010101848484FFFFFF
FBFBFBFFFFFFF7F7F7FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFDFDFD
F8F8F8FFFFFF6B6B6B040404E6E5EAFBFAFDF5F4F7FFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFCFAFBFFFEFFFFFAFCFFFDFDFFFBF8FFFDF7FFFEF6D9DAD4
000405272B32AA95A10B0007A0A7B9F5FFFFFFFCF6FFF4EF595B68EAF6FF
F7FFFFF2FDF5FCFFFAFFFFFBFFFBFFFFFCFFFAF8FBFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFAFAFA6F6F6F262626C5C5C5FFFFFFFEFEFEFCFCFC
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFDFFFEFDFFFBF9FCF7F7969A9B5A5E5F
FFFDFD7D787ADEE6E8F9FFFFFFFDFFFFFBFBFEFFFFFAFEFFFFFFFFFDFBFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFEFEFEFEFEFE4C4C4C
0000000606061D1D1DE0E0E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3D3D3D020202000000262626
EEEEEEFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFDFDFD
FAFAFAFFFFFFFFFFFFACACAC040308121114DDDCDFFEFEFEFFFFFDFBFBF9
FFFFFDFEFEFCFCFAFBFFFEFFFEF9F9FFFEFBFFFDFAFFFEF6FFFDF5DBD7D4
0B0E1DFAF8FFFFEFEA1B0B09C5D5EAEDFFFFF7F7F5FFFEF6FEFDFFF3F6FD
FFFEFFFFFEFFFFFFFBFCFEF9FFFFFFFBFBFBFFFFFFFCFCFCFCFCFCFEFEFE
FFFFFF575757A3A3A3FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
FCFCFCB1B1B1111111989898F9F9F9FFFFFFFEFEFEFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBF9FFFFFBFFFBFAA49E9C131B1DC4CACA
FFFCFD625C5CC6CFD2F0FBFDFFFDFDFFF9F7FCFFFFFBFFFFFAFAFAFFFEFD
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF090909020202
000000767676FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDADADA0C0C0C0B0B0B000000
585858FFFFFFFEFEFEFCFCFCFBFBFBFDFDFDFCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFEFEFE33323700000218171AD0D0D0FBFBF9FEFEFC
FEFEFCFFFFFDFFFEFFFCFAFBFFFDFFFFFDFDFFFDFAF9F4EEFFFEF6F2EDED
1E1B2ED6CFDFFFF9ED9B93888599AFE5FDFFFEFFFFFFFDF7FCFEFBFDFEFF
FFFCFFFFFBFFFDF8F8FDFCF8FCFFFDFBFFFFF7F8F8FFFFFFFFFFFF979797
0101010D0D0DFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDF9F9F9
777777202020C9C9C9F4F4F4FFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFEFDFFFAF8FFFCFCF8FCFDFCFFFF
FFFDFDFFFDFFEFF7F9F9FFFFFFFDFFFCF6F6FEFFFFFCFFFFFCFCFCFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFBFBFBFFFFFFFDFDFDFFFFFFFCFCFCF3F3F3232323000000000000
3F3F3FFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA1A1A1000000050505
030303A2A2A2FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFEFEFE
FCFCFCFEFEFEFEFEFEFFFFFFDDDCE10D0C0F000002050505ACACAAFFFFFD
FBFBF9FFFFFDFAFAFAFFFFFFFFFEFFFBF9F8FFFEFBFFFEFAFFFEF6FFFCFF
C8BED6110517FFF8E68D8E7C283D50EDFFFFFEFEFFF5EFECFAFFF8FCFFFD
FFFBFFFFF3FFFFFAFFFFF9F7FBFFFDF5FFFAFCFFFFB7B7B71717170C0C0C
090909F3F3F3FFFFFFFDFDFDFDFDFDFFFFFFFAFAFAFFFFFFE1E1E13D3D3D
434343EFEFEFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFFFEFDFFFDFFFDFBFCFFFFFDFDFDFB
FEFDFFFEFDFFFEFFFFFEFFFFFDFCFFFDFCFFFFFFFFFFFFFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8F4F4F4FFFFFFFFFFFFFEFEFE464646010101030303161616
E4E4E4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF646464000000
030303070707D3D3D3FFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7FFFEFF4A494C0A0A0A0000000B0B0950504E
EEEEECFFFFFFFDFCFFFFFEFFFFFEFFF9F7F8FCF7F7FEFAF7FFFFF8FFFCFF
FFF3FFC6B9CA65624F656C58324554E0F1FFFBFBFFFFFEFBFBFFF8F9FFF9
FFFCFFFFFAFFFFF6FBFFFDFBF4FDF89DA7A2222625040404000000222222
FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFBABABA141414838383
FFFFFFF9F9F9F8F8F8FAFAFAFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFFFDFDFDF8F8F9F9F9FFFFFFFDF9F6FEFCFB
FCFFFFFCFFFFFEFCFBFBF9F8FAFDFFFCFFFFFFFFFFFFFDFCFEFEFEFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFF
FBFBFBFFFFFFFFFFFFF1F1F1FFFFFF919191030303000000000000B6B6B6
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3292929
000000000000343434F6F6F6FFFFFFFAFAFAFEFEFEFFFFFFFCFCFCFCFCFC
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FBFBFB
FFFFFFF7F7F7F9F9F9FFFFFFFEFCFFD5D3D60A0A0A000000000000080806
1516169E9F9FFEFFFFFDFEFFFCFBFEFFFFFFFFFEFDFFFFFBFBFAF5FFFCFF
FFF9FFFFF5FFFBFBEEFBFFF4F3FFFFF5FFFFFCFCFFFFFFFDFAFFF9FBFFFA
FDFAFFFEF4FDB8ABB0534D4D0E1410020B06000000000000000000FCFCFC
FBFBFBFCFCFC515151FFFFFFFDFDFDFFFFFF7979791A1A1AC5C5C5FFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFDFDF8F8FFFDFDFFFFFFFFFFFFFEF8F6FFFDFD
F9FEFFF6FBFEFFFDFDFFFBFBFBFFFFFBFFFFFBF9FAFEF9F9FFFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFDFFFFFFCBCBCB000000030303000000797979FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAD7D7D7
0E0E0E0000000808086B6B6BFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFF7F7F7FFFEFFFEFCFF494949000000050503000000
0000000304040B0C0E808183FFFEFFFDFCFFFCFCFCF9F7F6FFFFFBD6D1D3
968E9BFFFBFFFFFFF8ECF2E8717880F5FDFFFCFFFFFAFBFD555A54242923
0F0E1109030A160F12030000000100000100050606222222EAEAEAF9F9F9
FEFEFEFFFFFF030303FFFFFFE8E8E8404040414141E9E9E9FFFFFFF8F8F8
FEFEFEFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFDFDFDF8F8FBFBFBFFFFFFFFFDFDFFFBFB
FBFFFFFBFFFFFFFEFFFFFDFFFBFFFFFBFFFFFCFCFCFFFEFDFFFFFFFDFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8EDEDED2525250000000404043F3F3FF0F0F0FCFCFC
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
8B8B8B040404000000010101A9A9A9FFFFFFFAFAFAFEFEFEFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF919191020202303030AEAEAE
FCFCFCFFFFFFFFFFFFFEFEFEFBF9FCFFFEFFA4A2A30D0B0C010100040402
232424232424141517000004414246FEFFFFFDFEFEFFFFFDFDFDF9FFFFFD
555258D8D5DBFAF5F7888687AEADB2F8FBFFF9FFFFF9FFFF777976383836
161518000002080909010202030000030000141213EBEBEBFFFFFFFFFFFF
FFFFFFF8F8F8060606B7B7B7171717808080FFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFBFBFBFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFBFBFFFDFDFFFFFBFAFAF8FFFEFFFDFBFE
F2F6F3FBFFFEFDFCFFFCFBFFFAFEFDFCFFFDFFFFFFFFFEFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF2F2F2FFFFFF
F7F7F7FFFFFFFFFFFF5555550202020000000D0D0DDDDDDDFFFFFFFEFEFE
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FDFDFD525252040404000000171717E4E4E4FDFDFDFFFFFFFCFCFCFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFBFFFFFDFFFFFFFEFFFFFEFFFFFDFBFEA19FA2DBDBD9F1F1EF
FBFCFCFEFFFFFDFDFDFEFCFDFFFEFFFFFEFFFBF9FA06040500000050504E
242525EFF0F0F9FAFCFEFFFFF4F5F9F6F7F9FEFFFFFDFEFEFFFFFDFCFCFA
E6E7E948474AD1CBD2595458FFFEFFFEFFFFF4FCFEF9FFFFFEFFFFF9F9F9
F9F9F9C3C4C6161A190607070300000F0909C8C6C7FCFCFCFFFFFFFCFCFC
FFFFFFFEFEFE0000001B1B1BC0C0C0FDFDFDFBFBFBFFFFFFFBFBFBFDFDFD
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFBF9F8FEFEFAFFFFFDF8F6F9FFFEFF
FEFFFDFEFFFDFFFEFFFFFEFFFCFEFBFEFFFDFFFEFFFDFCFFFCFCFCFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
FFFFFFFFFFFF909090020202000000030303ACACACFEFEFEFFFFFFFCFCFC
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFEDEDED1C1C1C0202020000003E3E3EFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFB
FFFAF0FFFEF4FFFFFBF7F8F8FCFFFFFBFEFFFEF8FFFFFBFF94938FD6D8D3
FBFFFFFCFFFFFAF8FBFFFDFFFFFEFFFFFFFFFCFCFC4545450B0B0BAFAFAF
6A6A6A4C4C4CFBFBFBFFFFFFFCFBFEFFFFFFFCFCFCFFFFFFFBFBFBFFFFFF
FCFCFCABABAB020003E9E7E8FFFFFFFAFAFAFEFFFFFBFCFCFFFFFFF8F8F8
9898981515158788880A0A0A100E0F6A6869FEFEFEFDFDFDFFFFFFFFFFFF
EBEBEB4343432C2C2CE3E3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFEFEFE
FDFDFDD2D2D20909090000000000006A6A6AFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF9F9F9
FCFCFCFFFFFFBCBCBC010101020202030303828282FDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFDF8
FFFCF1FFF3E5FCF9F2FCFFFFF4FDFFF9FDFFFFFBFFFFF7FFFCF8F571736E
E6F2F0F8FFFFFFFEFFFDF6FBFCFAFBFCFCFCFFFFFF838383000000D8D8D8
FAFAFA3D3D3D858585FCFCFCFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFDFDFD
FFFFFFFFFFFFD4D4D4FCFCFCFEFEFEFBFBFBFCFCFCFFFFFFEDEDED505050
393939D7D7D7BCBCBC060606212121FFFFFFFDFDFDFFFFFFFEFEFEBDBDBD
121212818181FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFF
F1F1F12A2A2A000000030303313131FEFEFEFBFBFBFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFF7E7E7E000000000000050505C7C7C7FFFFFFFDFDFD
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF9FFFFFCFCF8
A28E8511000079746A8F9893000911CCD5E0FFF7FDECD9DBFFFBFC828685
ABBFBDE9FBFAFFFBFFFFFAFFFFFDFFFFFFFFFFFFFFA6A6A6020202FFFFFF
FDFDFDE7E7E7191919BABABAFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDC2C2C2202020727272
F0F0F0FCFCFCB0B0B0000000A3A3A3FEFEFEFEFEFEFFFFFF8484841D1D1D
BDBDBDF9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFB
5F5F5F000000000000121212D7D7D7FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF8F8F8FFFFFF
FFFFFFFBFBFBF6F6F6FFFFFF474747000000000000272727EAEAEAFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF5FDFBFDFDF9
54413AD2BEB5EDE9DD000400495760C9D2DFFFFBFFD0C0C131282B090D0E
D9ECE8F4FFFFFFFDFFFFFBFFFEF9FBFFFFFFFCFCFCF2F2F2888888F9F9F9
FFFFFFFCFCFCC2C2C2121212DBDBDBFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFF8F8F8FFFFFFFBFBFBFFFFFFFBFBFB8A8A8A1B1B1BB0B0B0FCFCFC
FFFFFFFFFFFF797979040404FFFFFFFAFAFAECECEC454545373737E4E4E4
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F99A9A9A
0A0A0A000000000000A2A2A2FFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFBFBFB
FFFFFFF9F9F9FEFEFEFFFFFFDBDBDB101010050505000000545454FFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFEFB
857C779B928BFDFAEFC1C3BD0B0F18F4F6FFFAF7FDFBF4F7FFFEFFFCFDFF
F9FFFBF9FFFBFBF8FEFFFCFFFFFEFFFFFFFFFFFFFFF8F8F8FDFDFDFFFFFF
FCFCFCFDFDFDFFFFFF9F9F9F272727F4F4F4FCFCFCFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFDFDFDFAFAFAE8E8E8474747363636DFDFDFFFFFFFFFFFFF
F6F6F6FFFFFFCBCBCBD5D5D5FFFFFFC8C8C81F1F1F787878FFFFFFFFFFFF
FFFFFFFBFBFB525252FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCD7D7D70C0C0C
0000000000006C6C6CFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FBFBFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFB0B0B00000000404040000009C9C9C
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFDFCF8F5
CCC5BD140F05FFFFF6FDFDF91D1D25DFDEEBFFFEFFFFFEFFFFFFFFF9FAFA
FBFFFCFAFEFBFFFEFFFEFBFFFFFEFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFF5F5F5FFFFFF5E5E5E585858FFFFFFF6F6F6FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFB2B2B21313137F7F7FFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFF909090151515B1B1B1FBFBFBFBFBFBFAFAFA
FAFAFAFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFCFCFC292929000000
080808272727F5F5F5FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FDFDFDFEFEFEF8F8F8FFFFFFF9F9F9FFFFFF646464000000060606070707
D4D4D4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFD
FFFEEF645D4B898581FCFDFF4448539FA1ADFFFDFFFEF9FBFFFFFAFCFEF9
F9FFFFFBFFFFFAF8F9FFFDFDFFFDFEFFFFFFFFFFFFFAFAFAF8F8F8FFFFFF
FCFCFCFBFBFBFFFFFFFFFFFFFFFFFF2E2E2E8B8B8BFFFFFFFBFBFBFDFDFD
FDFDFDFBFBFB676767252525C2C2C2FBFBFBFFFFFFF7F7F7FFFFFFFCFCFC
FFFFFFFEFEFEF2F2F25050502F2F2FE0E0E0FFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFF010101FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF575757010101040404
0A0A0AD8D8D8FDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEF8F8F8
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFCFCFC2F2F2F000000030303
292929F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF5F5
FFFBECFFFFED8783806D6D732E323B868892FBF7FFFFFCFFFFFFFAF9FBF5
F8FFFFFBFFFFFDFBFCFFFBFBFFFDFEFFFFFFFBFBFBFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFE6E6E6161616B8B8B8FFFFFFFFFFFF
DEDEDE303030545454E9E9E9FCFCFCFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FCFCFCCECECE1D1D1D6F6F6FFCFCFCFCFCFCFFFFFFF9F9F9FFFFFFFFFFFF
FDFDFDF9F9F9070707FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F070707000000000000
9D9D9DFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBD4D4D4070707030303
000000686868F7F7F7FFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFD
FFFEF6FFFCF2FFFEFBFDFCFFFCFFFFFCFFFFFFFCFFFFFCFFFFFEFDFEFFFA
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCC0C0C0191919DEDEDEA3A3A3
171717969696FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFEFEFE
959595141414AEAEAEFAFAFAFFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEA6A6A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFBFBFBFFFFFFFEFEFEFFFFFFD4D4D40A0A0A0202020101015C5C5C
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFFFFFF959595000000
010101060606B4B4B4F9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFBF6F6
9A928DD5CEC6FFFCF9FFFFFFC6C9CD93969DFFFCFFFFFCFFFFFEFDFEFFFB
FCFFFDFCFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDB6B6B64F4F4F2B2B2B
C9C9C9FFFFFFFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFFFFFFEEEEEE5B5B5B
2C2C2CDADADAFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFF6F6F63232320000000000002D2D2DF9F9F9
F6F6F6FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFD565656
000000000000101010E9E9E9FFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFF
F3EAE1453D32F6F3ECF4F5F5282B3AECEDFDFFFDFFFFFDFBFFFDFDFEFFFF
F9FFFFF9FFFFFFFEFFFFFDFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFB0B0B0F2F2F2
FFFFFFFDFDFDFFFFFFFFFFFFF6F6F6FAFAFAFFFFFFCCCCCC2424246A6A6A
F0F0F0FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFDFDFD696969000000080808080808D1D1D1FFFFFF
FFFFFFF2F2F2FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFDFDFDF3F3F3
1D1D1D0909090000003C3C3CF9F9F9FBFBFBFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFCF9FFFFFDFF
FFFAF2AAA69AA6A39A8D8D8DACAABDFDFBFFFFFEFFFFFFFAFFFEFDFEFFFF
FCFFFFFCFFFFFFFEFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF9B9B9B131313A7A7A7FFFFFF
FFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFAFAFAFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFEFEFEADADAD050505000000000000989898FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFBFBFBFFFFFFFCFCFC
C8C8C80000000505050202027F7F7FFFFFFFFAFAFAFFFFFFFFFFFFF6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFBFFFDF6F9
F7F9F4FCFFF829291F474141FFF9FFFFF9FFFCFFFFF9FFFFFCFFFFFFFEFF
FFFDFDFFFDFDFEFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFAFAFA
FEFEFEFFFFFFFAFAFAFEFEFEF4F4F45A5A5A252525D8D8D8FBFBFBFCFCFC
FFFFFFFDFDFDFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FBFBFBFEFEFE5B5B5BF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFDCDCDC0505050000000101015A5A5AFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFF3F3F3FFFFFF
FFFFFF818181000000000000050505CACACAFFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFF9FFFFFCFF
FEFFFBFAFFF6DFDED9F4EDF0FFF3FFFFFAFFFBFFFFF8FFFFFCFFFFFFFFFF
FFFCFDFFFCFDFEFFFFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFAFAFAFFFFFFD2D2D22B2B2B5F5F5FFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEF4F4F4333333060606000000242424ECECECFFFFFFFFFFFFF8F8F8
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFEFEFE
FFFFFFFCFCFC4141410B0B0B0000001C1C1CE7E7E7FEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEF8FFFFFAFF
FFFFF6FFFDF2FFFEFDFFFDFFFFFCFFFBF9FFFFFDFFFEFFFFFFFFFDFFFFFB
FFFEFFFFFEFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFCFCFCA4A4A41313139D9D9DFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFDFDFDF8F8F8FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFE6D6D6D000000000000070707CBCBCBFFFFFFF5F5F5FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFDFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFEFEFEFFFFFF
FDFDFDFFFFFFE2E2E2171717000000000000505050FFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFEFCFF
FFFEF6FFFAF2FFFEFFFCFBFFFEFEFFFCFCFFFFFCFFFFFDFFFFFFFBFEFFFB
FCFFFFFCFFFFFFFFFFFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
F4F4F46C6C6C202020D6D6D6FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
AFAFAF000000000000000000929292FFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFBFFFFFDFFFEFFFFFEFF
FFFFFBFFFFFAFFFFFFFFFEFFFFFDFFFFFEFFFFFFFAFFFFFAFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFF7F7F7303030030303040404262626F7F7F7
FCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF6F6F6FAFAFA686868212121D4D4D4
FCFCFCFFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFCFCFCFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFEFEFE747474020202
000000090909C4C4C4FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFF8FFFFF8FFFEFFFFFEFFFFFEFFFFFFFFFFFFF4FFFFF4FFFEFFFFFDFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFF666666000000000000
101010DFDFDFFDFDFDFDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFF6D6D6D1C1C1CCBCBCBFAFAFAFEFEFEFFFFFFFAFAFA
FFFFFFF7F7F7FCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFEFEFEFFFFFF
FFFFFFFCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFF3737370000000404041F1F1F
E9E9E9FFFFFFF7F7F7FDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFDFDFFFAFCFFFFF8F8FEFCFCFFFFFFFFFDFDF9
FFFFFAFFFFFBFFFCFFFEFBFFFFFEFFF9F8F4FFFFF8FFFFFAFCFCFCFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFAFAFAFFFFFFFBFBFBFFFFFFF7F7F78D8D8D
000000000000090909BEBEBEFDFDFDFFFFFFF8F8F8FFFFFFFFFFFFFEFEFE
FBFBFBFEFEFEFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFBFBFB767676
1E1E1EC4C4C4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEA6A6A6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFE5E5E5141414000000010101494949FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFAF7FDFFFCFBFFF1E13D2719AAACB6E0ECFA
0007095F6561F8FFFFFBFFFFFFFDFDFDFDFDA2B5BBA9BCC2FEF9F9FFF9F8
FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFF2F2F22929290000000000003B3B3B
F4F4F4FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF9F9F98E8E8E191919AAAAAA
F9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFBF5FFFFFAFAFAF8FFFEFF
FBF8FFFFFCFFFFFDFFFBF9FCFFFEFDFFFFFBFAF9F4F8F7F2FFFFFBFFFEFD
FDFCFFFEFFFFF6FFF5F9FEF7FFFBFFFFFAFFFCFCFFFBFFFEFFFFF8FFFDFA
FFFAFFFFFBFFFFFDFBFFFFF8FCFFFAFCFFFDFEFFFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFAFAFA4A4A4A0B0B0B000000
151515E2E2E2FFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF5F5F5FFFFFF
FFFFFFFEFEFEFDFDFDFDFDFDFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF2FFFFF2FFFEFFFCFDFFFBFD
FFFDFFF7F8FAFFFEFAFFFAF7FEF1F6FFFBFDF0F8E9F5FFF6F6FFFFFBFFFF
FEFEFFFEFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFDFFFFFBFFFEF4F2FFFFEBBCBCAF121524FAF8FF
FFF8F2221B10C7D9D8ECFEFFFDFCFFFFFCFFFAFBF5F6F9F0FEFFFFF2F3F7
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFF9F9F9FFFFFFFCFCFC8F8F8F020202000000
000000B9B9B9FEFEFEFFFFFFD2D2D21F1F1F6C6C6CF5F5F5FDFDFDF8F8F8
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFAFFFFFDFAFAFAFFFEFF
FEFDFFFFFEFFFBF9FCFFFEFFFEFDF9FFFFFBFFFFFAFAFAF6FDFDFBFFFFFF
FFFEFFFCFDFFFEFFFAFAFBF5FFF9FCFFFCFFFFFBFFFFFEFFFCFFFAFEFFFB
FFFAFFFFF9FFFFFEFDFCFFFAFCFFFBFEFFFDFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFC0C0C00303030404040606066E6E6E
FFFFFFFCFCFCFFFFFFFDFDFDFFFFFFF9F9F9FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFEFEFEFEFEFEFCFCFCFFFFFFFCFCFC
5757578D8D8DFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF7FDF9F8FAF7FFFBFDFFFCFB
CDCCC8959B9B949DAAD1D8E0FFFEF4FFFCEFFFFAF8EAE2EB637283F0FFFF
FAFEFFFFFEFBFFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFDFDFDFEFEFEFDFFFFFFFFFFFFFDFFFFFD
FFFBFFFCF6FDF9F6FCFFFEFFFFFFFAE5E4E0B3B2B876767E383A370E100B
21211F1E1E1E1D1D1D2121212929292A2A2A2121211515152828284D4D4D
878787C1C1C1EBEBEBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFDFDFDF5F5F5FEFEFEFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFBFBFBFFFFFFFBFBFBFDFDFDA0A0A0151515969696FEFEFEFFFFFF
F7F7F7FFFFFFA4A4A4000000070707000000A2A2A2FFFFFFFFFFFFF6F6F6
FFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFEFFFFF2F4F1
FEFFFDFEFFFBF1F3F0FEFFFDFEFFFFFBFCFCFEFEFEFDFBFAFFFEFBFFFDFA
A49F9943423DF1F8FCFDFCFFFFF6F4614E4F8895A3F0FFFFFEFEFFFDF6F9
FFFDFFFEFFFFF8FFFFF9FFFFFFFDFDFFFDFDFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
9B9B9B000000000000080808A8A8A8F7F7F7FFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF9F9F91010106A6A6AF2F2F2
FEFEFEFFFFFFFFFFFFFFFFFFF3F3F3FDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFBF9F8FFFFF8FFFCE9FFFFF3
625A6784788AFFFAFB5A5152939FADF1FFFFF3FDFAFCFFF8F9FBF8FFFEFF
FFFBFFFFF9FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFF
FFFFFFFAFAFAFFFFFF848484737373FFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFBFBFBF9F9F9FFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFDFDFDFFFFFF
FDFDFDFFFFFFD3D3D37B7B7B292929454545FFFFFFFCFCFCFCFCFC494949
767676FEFEFEADADAD393939FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FBFBFBFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC6C6C6242424707070
F7F7F7FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFEFEFEFEFEFE
FFFFFFFDFEFFF9FFFFFBFFFFFFFEFFFFFDFDFFFEFBFFFFFDFCFFFFFCFFFF
FFFEFFFFFEFFFCFEF8FFFFF6FFFCFAFFF5F4FEFFFFFAFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
FFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFE0E0E0161616030303
000000525252FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FCFCFCFEFEFEFFFFFFFDFDFDE3E3E3161616000000030303494949FFFFFF
FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFEFFFFFFFAFFFFF8
FFFDFDFFFDFFFEFFFAFCFFF8FBFFFBF7F9F4FAEEEE1C0A06E6D6C7F9F1EC
00061BD0DEF8FAFDFFFEFCFBFEFEFCFCFDFDFEFFFFFCFFFFF1F5F6B9BABC
131313000000010000090706070504000000111013010204000000040404
0000002A2A2AFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDFCFCFCFFFFFFC9C9C95F5F5F0E0E0E5A5A5AC2C2C2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF6F6F6
FFFFFFFFFFFFFFFFFFFDFDFDF6F6F6020202626262575757171717E1E1E1
FBFBFBFEFEFEFDFDFDFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFE5F5F5F9E9E9EFAFAFAFFFFFFFFFFFFFFFFFFFBFBFBFCFCFCFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEF5F5F5A9A9A9949494FFFFFF
F8F8F8FFFFFFF2F2F2FCFCFCFDFDFDFFFFFFFEFEFEFFFFFFFEFEFE4D4D4D
F8F8F8FEFEFEFFFFFFFEFEFEFBFBFBFFFFFFF7F7F7585858151515545454
9E9E9EEAEAEAFAFAFAFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE
FEFEFEFEFEFEFAFAFACFCFCF030303000000020202808080FDFDFDFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E7E71C1C1C
000000010101424242FAFAFAFFFFFFFCFCFCF9F9F9FFFFFFFEFEFEFFFFFF
F8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFDFBFAFFFDFAFFFEFBFAF6F3FFFEFB
ECE8E5010000AAA9AFFEFEFFFDFDFFFEFEFFFEFFFFF9FAFEFEFFFFFCFDFF
FEFEFE959595585858FAFAFAFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFB
FFFFFFFFFFFFFBFBFBFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEE8E8E8
8D8D8D2121212E2E2E949494F3F3F3FEFEFEFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFED3D3D3
191919FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FBFBFB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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF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FEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFFFFFDFFFFFBFFFFFDFFFEFFF8F9FD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FBFFF7FEFFFBFFFDFFFFFAFFFFFEFDFEFDF6F8F5EC9E9D999D9DA5ABADB9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FBFFF8FEFFFBFFFCFFFFFCFFFFFDF6FFFDF4FDF9F5E4E2E315131EC8C7D4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F9FDFCF8F9F9FFFDFFFFFDFAFFFFF1FFFFF3F9F9FFFFFCFF756D78ADA5AE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FEFEFFFFFEFFFFFDFDFFFBF3FFFFECDCDCD0000011211F358B7B855E5254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FEFCFFFEFBFFFFFDFBFFFCF1FDF8E2B3B3A9070D25F5F4FF3520231F0D07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FEFAFFFFFCFFFFFDFBFFFEF4FFFFECCCCDC5090E2BFEFBFFFEE9E40E0000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FFFCFFFFFCFFFEF9FBFFFEFAFFFFF3F0F0EC1A1B35CEC8E0FFFAEF9A8A7A
7A828AF1FFFFFBFFFFF7F6FCFFFEFFF7F6F9FFFFFFFEFEFEB2B2B24C4C4C
FDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFCFCFCFFFFFFFEFEFE
FFFFFDFFFFFDFBFBFBFFFFFFE0E0E08E8E8E6C6C6C969696F1F1F1F8F8F8
FFFFFDFFFFFDFBFBF9FFFFFDFFFFFBFAF5EDFFF3E41B1008818A97F2FFFF
1F2030BDB9C3FFFDFFFFFEFDFFFFFBFFFFFDF4FCFAFBFFFFFFFFFBE3DFDC
5B5B5B000002020202000000000000020202010101000000020202000000
0505059B9B9BF5F5F5FFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFF9F9F9
FFFFFFFDFDFDF9F9F9FFFFFFE9E9E98C8C8C646464989898D9D9D9FFFFFF
FFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FDFDFDB8B8B8060606010101000000929292FBFBFB
FEFEFEFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFED2D2D2040404080808
000000616161FEFEFEF6F6F6FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFF9F9F9FBFBFBFEFEFEFFFFFFB6B6B6
373737F5F5F5FAFAFAFFFFFFFEFEFEFBFBFBFFFFFFFCFCFCE6E6E66C6C6C
181818474747B1B1B1F3F3F3FFFFFFFFFFFFFDFDFDFEFEFEFEFEFE2D2D2D
BCBCBCFFFFFFFFFFFFFFFBFBFFFBFAFEF6F4F8FCFBFCFFFDFFFEF3FFFBF5
585862AAADBCFCFEFFFEFFFFFFFFFBFBFCF6F4FDF5FBFFFBF9F4F8FFF8FD
FCFAFBFFFFFFFDFDFDB3B3B33A3A3AF4F4F4FFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFDFDFDFEFEFEC1C1C15454540A0A0A6E6E6ED2D2D2E3E3E31C1C1C
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFAFCFFFCFFFFFEFFF9F9F9FEFFFAFDFEFEB2AEC41C1324FFF6EAB8AF9E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FFFBFBFFFCFDFDFCFFFCFFFFFAFFFEFEFFFFFEF6FFC6B8C35E544A6E695F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FFFCFBFFFCFCFFFEFFFBFFFFF6FCFCFAFBFDFFFAFFFDEEF3FFFDFAFAFAF6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FFFCFDFFFBFBFBFCFEFBFFFFFBFFFFFAFBFBFFFBFDFFFAFDFFFCFFFBFEFF
F8FFFFF8FEFEFFFCFFFFFDFFFCFFFFFBFFFFFEFFFFFDFDFD3D3D3DC2C2C2
FEFEFEFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEF3F3F3FFFFFFFFFFFFFDFDFDFFFFFFFCFCFC
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFDFCFCFAF9F9F7FFFFFDFFFFFBFCFBF6FBF8ED8C898248474D706E7B
BFBACAFFFAFFFFFCFFFFFDFFFDFEF6FCFFF6F3FFFBF0FAF7FFFFF6FFFEF6
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFF9F9F9D7D7D70B0B0B000000666666
FDFDFDF6F6F6FCFCFCC1C1C16262622A2A2A1C1C1C777777C6C6C6F5F5F5
FCFCFCFFFFFFFCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFCCCCCC6F6F6F6F6F6F
BEBEBEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9
FCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFA3A3A3020202000000
0000009F9F9FFFFFFFFCFCFCFAFAFAFBFBFBFFFFFFFFFFFFFFFFFFF3F3F3
FFFFFFFFFFFFF2F2F2FFFFFFFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFFFFFF
FDFDFDF7F7F7FFFFFFFFFFFFDDDDDD0808080000000000005D5D5DFDFDFD
FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FBFBFBFDFDFDFFFFFFFAFAFA
FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF626262808080FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDFFFFFFA4A4A40000004C4C4C5E5E5E5F5F5F5D5D5D
0A0A0A0F0F0FC5C5C5FFFFFFFFFEFFFCFAFDFFFBFBFFFFF8D6D6C994938C
FDFBFFFCFEFFF1F6F9696D6AFFFBFD8B8489FBF8FEF1F0F5FFFEFDFDFCF8
FCFCFAF7F7F7181818DADADAFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFFFFFF6363637B7B7B606060
989898FFFFFFEFEFEF909090272727313131949494F0F0F0FFFFFFFFFFFF
F6F6F6FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFDFDFFFEFDFDFDFDFCFDFFFCFFFFFFFFFFFFFCFAFFF7F6FFFDFFFCFFFF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FBFDF8FEFFFDFFFFFFFBF9FCFCFBFFFFFFFFFFFFF8FFFEFAFFFCFFFEFCFF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F9FFFAFCFFFBFFFEFFFFFCFFFFFCFFFFFEFFF8FFF3FCFFF6FFFAFFFCF5FC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F5FFF4F4FEF3FFFDFFFFFAFFFFF9FFFFFDFFF0FFF1F4FFEEFFFDF8FFFBFD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F7FFF4F7FEF4FFFDFFFFF8FFFFF4FFFFFDFFF5FFF8F7FFF3FFFBF3FFF8F7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FCFFFBFEFFFDFFFEFFFFFEFFFFFCFFFFFEFFFCFFFDFCFFFBFFFFFBFFFDFD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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFEFEFE969696686868FFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFD818181707070FEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFFFFFFEBEBEBC1C1C1
727272727272BABABAFFFFFFFFFFFFF6F6F6FFFFFFFDFDFDFFFFFFFCFCFC
F5F5F5FFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFF9F9F9FCFCFC
FFFFFFFFFFFFFCFCFCFFFFFFFAFAFAE1E1E19696964D4D4D101010D0D0D0
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFBFBFBF8F8F8FAFAFAC8C8C8
7B7B7B7575757D7D7D070707000000060606858585FFFFFFFFFFFFFBFBFB
FAFAFAFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFF9F9F9FCFCFCFEFEFEAEAEAE
070707000000000000949494F5F5F5FBFBFBFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFAF9FCFCF7F7
FFFEF4FAF3E91F1619E0D9DCFFFEF7FEFFF9FEFEFFFCFEFFF8FDFFFBFFFF
EFF4F8FCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5858588F8F8FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFDFDFDB1B1B10C0C0C000000C4C4C4F5F5F5FFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDF9F9F97C7C7CFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFD5D5D56F6F6F1111111C1C1C0C0C0C
B2B2B0FFFFFDFBFBF9FEFEFCFFFFFFFDFDFDFCFBFEFFFEFFFEFDFFFFFEFF
FFFEFFFDFCFFFCFCFCFDFDFD212121C4C5C5FCFFFFFEFFFFFFFDFDFFFDFD
FFFEFFFEFFFFFBFFFDFCFFFBFFFDFDFFFCFFFFFEFFFEFFFFFBFFFFFCFFFF
FFFEFFFFFDFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FDFDFDFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFDFDFD8C8C8C727272FFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF505050FFFFFF383838BABABAFFFFFFF9F9F9FFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEF9F9F9FBFBFBFFFFFFFFFFFF
FEFEFEFDFDFDCCCCCC7A7A7A696969B6B6B6FAFAFAFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFDFDFD2C2C2CBABABA
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
FFFFFFFBFBFBDADADA3A3A3A000000000000060606BEBEBEFFFFFFFFFFFF
F8F8F8FFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFBFBFBE8E8E8121212
0000000202025A5A5AFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF6F7F9FEFFFFFCFBFEFFFDFD
FFFBF3FFFEF65A5452989292FFFEFAFFFFFBDFDFE5F8FBFFFBFFFFFBFFFF
F8FBFFF8FBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFDFDFDC0C0C02D2D2DFFFFFFFFFFFFFFFFFFF8F8F8
FAFAFAFDFDFDFFFFFF4C4C4C050505717171FFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFF7F7F7FFFFFFEAEAEA343434787878FFFFFFFDFDFDFFFFFFFFFFFF
F3F3F3FCFCFCFAFAFAFFFFFFF7F7F7A7A7A73E3E3E1919194E4E4E696969
FBFBF9FFFFFDFAFAF8FFFFFDFFFFFFFFFFFFFBFAFDFFFEFFFEFDFFFDFCFF
FFFEFFFFFEFFFFFFFF9D9D9D3F3F3FFEFFFFF9FFFFFCFFFFFFFBFAFFFBFB
FFFEFFFBFFFFF8FFFFFBFFFFFFFDFDFFFBFDFFFDFDFEFFFFF7FFFFF8FFFF
FFFDFFFFFCFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFAFAFA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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4F4F4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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFB8B8B8
757575FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFEFEFEC8C8C87575752121212425277A7A7A
C8C7C3FFFFFBFFFFFFFEFDFFFFFEFFFFFEFFFFFFFFFFFFFDFEFFFFFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFDFDFDFFFFFF131313E1E1E1FFFFFFFFFFFFFCFCFCFBFBFB
FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FDFDFDFFFFFFF7F7F7BABABA6C6C6C727272C1C1C1FBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
B5B5B53F3F3F2C2C2CACACACFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFEFEFE
FAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFBFBFBFFFFFFC0C0C0777777797979C3C3C3F8F8F8FFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFDFFFFFEFFFFFEFFFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFBFAFDFFFFFFFEFEFAFEFEFC
FFFEFFFFFEFFF6F7EDFFFFF8E8E8F00F0F19000103000000000004000002
0503020C0B07000000000000FFFFFFF0F0F0616161E4E4E4FFFFFFFEFEFE
FEFEFEFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFCFCFCD4D4D4111111
0A0A0A0C0C0C3D3D3DFDFDFDFEFEFEFDFDFDFCFCFC6A6A6AE0E0E0FFFFFF
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFDFDFD7676766C6C6CFFFFFD
FCFCF8FCFDF7FFFFFAFFFEF7C0BFB83B3B2FFFFFF1EEEEEA120F28D4D2E8
FEFFF7FFFFF3FDFBFEFFFBFFFEFDFFFEFEFFFEFDFFFFFEFFFFFFFAFFFEF9
FEFDFFFEFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFCFBFEFEFED2D5DA767779
26231A252219747472C4C5C9FDFDFFFFFDFFFFFDFCFEFEFAF9FFFDFBFFFF
FFFCFFFFFCFFFFFDFFFEFCFFFFFFFFFCFCFCFEFFFFFEFFFFFAFAF8FFFFFD
FFFEFDFDFBFAFCFAFBFFFEFFFFFFFFFDFEFEFBFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
F8F8F8FFFFFFFBFBFBC1C1C1373737FAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBBEBEBE7A7A7A686868BCBCBC
F8F8F8FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD4D4D47E7E7E737373AEAEAE
F7F7F7FFFFFFF5F5F5FFFFFFFFFEFFFBF9FCFFFBFFFFFAFDFFFDFDF9F9F5
FEFFFAFDFFF9FFFFFDFFFFFFFCFDFFFCFDFFFEFFFFFEFEFCFFF9FCFFFCFF
FFFDFFFDFBFCFBFAFDFEFFFFFCFFFFFCFFFFFBFFFEFCFFFFFEFFFDFFFFFB
FFFEFDFFFEFDFFFEFFFFFEFFFFFEFFFFFEFFF9F9F7FFFFFDFFFEFFFBFBFF
FEFFFFFCFEFBFEFFF6FEFFF6FEFDFFD6D4DD0A0610010005040205000000
2527225C615B979996B1B1B1DADADA686868EDEDEDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
BABABACACACAFFFFFFF9F9F9FFFFFFFFFFFF939393D1D1D1FFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FEFEFEFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFDFDFDFDFDFDFFFFFF
FEFFFDFDFFFCFEFFFFFEFFFFFFFEFFFFFEFFECEBEE141414E2E0E1FFFEFD
FFFEFAFEFDF8FFFCF3FFFFF4FEFBF0605D54969590FDFDFD54525D9A98A1
FCFCFAFFFFFBFBFAFDFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFDFDFDFDF7FCFFFCFFFF
FFFDF3D3CFC37878742C2F341A19266A6873C7C5C4FCFDF7F1FBF6F6FEFC
FFFCFFFFFBFFFFFCFFFFFEFFFBF9FAFFFFFFF5F6F6FEFFFFFFFFFDFDFDFB
FEFCFBFFFEFDFFFDFFFFFEFFFCFCFCFBFCFCFBFFFFFBFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFDFDFD
FFFFFFF8F8F8FFFFFF686868828282FCFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFDFDFDFDFDFDFBFBFBFFFFFFC8C8C8
7B7B7B6C6C6CACACACEEEEEEFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAF4F4F4B7B7B7FCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFBFBFB
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFDEDEDE
8686866B6B6BA9A9A9EFEFEFFFFEFFFFFDFFFFFBFFFFFBFFFFFDFEFDFFFC
FEFFFAFEFFF8FEFEFAFBFBF9FEFFFFFEFFFFFBFCFEFFFFFFFFFCFFFFF9FC
FFFDFFFFFEFFFFFEFFFEFFFFFBFEFFF9FFFFFAFFFEFCFFFFFEFFFDFFFFFB
FFFFFBFFFEFDFFFEFFFFFEFFFEFEFFFFFEFFFFFEFBF6F5F1F5F8FDFBFFFF
F3F7F8FAFAF6FFFFF6FFFFF6FEFFFFF8F8FE75717D0B050F0E090D2E2C2B
333935EDF3EFF9FAFAC1C1C1777777FAFAFAFFFFFFF7F7F7FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFF
FCFCFCFEFEFEFFFFFFFFFFFFFEFEFE8A8A8ABEBEBEF7F7F7FEFEFEFFFFFF
FDFDFDFFFFFFF8F8F8FEFEFEFFFFFFB4B4B4F4F4F4FFFFFFFDFDFDFFFFFF
F7F7F7FDFDFDF7F7F7FFFFFFFFFFFFF6F6F6FFFFFFFCFCFCFFFFFFFFFFFF
FDFFFCF8FAF7FEFFFFFCFDFDFEFDFFF8F7FA8E8D90565558FFFDFEFDFBFA
FFFEFBFFFEFAFFFFF6FBF8EDFFFDF3FFFDF48684836F6E7116151849484B
FEFDFFFFFEFFFCFBFEFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFFFFFAFFFFFBFFFF
FFFEF6FFFEF4FFFFFDFEFFFFD5D7E182828A3432311818145F6765C0C6C6
FFFDFFFFF8FBFFFCFFFFFDFEFFFEFFFFFFFFFEFFFFF9FAFAFEFFFFFBFBFB
FFFEFFFBF9FAF8F6F7FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFAFAFA1F1F1FD7D7D7FDFDFDFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFD4D4D48282826F6F6F9B9B9BF3F3F3FFFFFFFFFFFFF8F8F8
FFFFFF8080806A6A6AFFFFFFFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAF9F9F9
FFFFFFFFFFFFE1E1E18B8B8B6B6B6B9C9A9BF1EBEBFFFCFEFCFFFFFBFFFF
FBFDF8FEFFF8FEFFFAFEFFFAFCFCFAFFFEFFFDFDFFFEFEFFFBF9FAFFFEFD
FFFAFAFEFCFBFFFFFFFEFFFFFCFFFFFCFFFFFCFFFFF9FDFCFEFFFDFFFFFD
FFFEFDFFFEFDFFFFFFFFFEFFFEFFFFFFFEFFFFFBF8FFFBF9F8FFFFF4FFFF
F9FFFFFFFFFBFFFEF6FFFBF5FAFBFBFBFFFFF6F6FF1B17210C0107898383
8389850D1611757676A3A3A3FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFAFAFA686868C9C9C9FFFFFFFCFCFCFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFBFBFBFFFFFF6666660F0F0F6F6F6FDCDCDCFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFBFBFB
FEFFFDFEFFFDFCFDFDFDFEFEFFFEFFF8F7FA0F0E11DAD9DCFFFEFFFFFEFD
FFFEFBF9F5F1FFFFF8FFFFF6F9F6EBFFFFF8FEFCFBFFFEFFEAE9EC070609
ECEBEEFAF9FCFFFEFFFEFDFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFAFFFFFFFBFFFFFBFFFF
FEF8F5FEF9F3FBFBF9FBFCFFFBFEFFFEFFFFF3F1F0E2E0DF8B8F902C2F33
171514666060BBB6B8FAF8F9FFFDFEFEFEFEF9FAFAFEFFFFF8F9F9FEFFFF
FFFDFEFFFEFFFFFEFFFDFBFCFBFBFBFEFFFFFEFFFFF9FDFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
F9F9F9FFFFFFCACACA2B2B2BFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFCFCFCFAFAFAFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF2F2F2E3E3E38B8B8B6363638F8F8FE9E9E9
FFFFFF222222C7C7C7FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFBFBFB
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFE8E6E5A3A29E6D6D6D8C939BDBE2EA
FCFEFBFFFFF8FBFFF7FBFEF5FFFBF7FFFDFFF8F8FFFCFEFFFCFFFFF9FBF6
FFFEFDFFFEFDFDFDFDFCFCFCFCFDFFFCFFFFFEFFFFFEFFFFFFFFFFFFFFFD
FFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFFFEFFFFFCF8FFFDFAF2FBFDF4FFFF
F9FFFFEEEEEC4B423D372E29171717D8DDE1FAFCFFA6A4AD0D04097E777A
FAFEFB525854131414959595F7F7F7FFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
FFFFFFFBFBFBEBEBEB595959EFEFEFFAFAFAFDFDFDFFFFFFFEFEFEFCFCFC
FFFFFFF8F8F8FBFBFBFFFFFFFEFEFEFFFFFFE3E3E37F7F7F0F0F0F414141
B7B7B7FBFBFBFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FBFDFAFEFFFD454646E1E2E2FDFCFF959497565558FCFBFEFDFBFCFFFEFF
FFFDFDFFFEFBFFFEFAFFFFF8FFFFF6F7F6EFFBF9F8FFFEFFECEBEE222124
B7B6B9FFFEFFFDFCFFFDFCFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFBFCFEFDFFFCFFFFFEFFFF
FFFEFBFFFDFBFFFFFFFEFFFFFCFFFFF9FAFAFFFFFBFFFAFAFEFEFFFEFFFF
E3E3E18F8E8A403B3B121011555354B9B9B9FCFDFDFDFEFEFEFFFFFBFCFC
FEFCFDFEFCFDFFFEFFFFFEFFFFFFFFFEFFFFFDFEFEFBFFFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFF777777787878FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFDFDFDF9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5C5C5999999
505050181818D5D5D5FFFFFFFFFFFFFFFFFFFAFAFAFAFAFAFFFFFFFFFFFF
FBFBFBFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB9E9E9E
4A4A4A1515154444448D8D8DF9F7F6FFFFFBF5F5F1FCFFFFEEF7FFA1A9B4
74737684837ECFD6CEFCFFF8FFFEF6FFF9F7FEFEFFF9FFFFF2FAFAFBFFFB
F9F9F5FBFAF6FDFDFBFFFFFDFFFFFFFBFCFCFDFCFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFEFDFFFBF5FFFCF7F5FDFFF5FFFF
F8FFFFFEFFFDFFF9F49C938EF1ECEEE8E7EDFCFFFFF6F9FF0000024B4B4B
5F5F5FE4E5E5D6D6D62E2E2E636363F8F8F8FFFFFFF6F6F6FFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFDBDBDB636363FFFFFFF9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
F8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFF7F7F7FFFFFFABABAB
3131311B1B1B808080F1F1F1FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFCFCFC
FEFFFDFEFFFD40423FBEBFBFF3F2F51C1B1EC7C6C9FFFEFFFFFEFFFFFEFF
FEFCFDFFFEFDFEFAF7FEFAF6FFFEFAFFFFFAFFFEFDF9F9F9E3E3E3A6A6A6
B2B2B2FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFF9FCFFFBFCFF
FFFBFDFFFDFDFFFEFFFEFFFFFBFFFDFCFFFBF9F5F2FFFDFFFFFDFFFFFEFF
F5F7F2FFFFFAFAF8F7EAE5E79C9A9B3737370F10105A5B5BAAABABF7F8F8
FFFFFFFFFEFFFDFBFCFBF9FAFCFCFCFDFEFEFEFFFFFCFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFF222222CFCFCFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FAFAFAFEFEFE
FFFFFFFFFFFFFEFEFEFCFCFCFEFEFEFFFFFFF9F9F9FCFCFC111111EAEAEA
7777776E6E6EAFAFAF6565657A7A7AC8C8C8FFFFFFFFFFFFFFFFFFFBFBFB
FAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA040404030303
000000010101000000121210353332F8F8F4FEFFFAF9FFFFEFF8FFF8FFFF
FDFBFEFFFEFDB2B8B473756F7E7468CFC4BEFFFDFFF9FFFFF6FFFFF9FFFD
FEFFFDFFFFFBFFFFFDFFFFFDFFFFFFFFFFFFFFFDFFFDFCFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFBFFFAF2FFFDF6FBFFFFF7FFFF
F3FEFFFAFFFCFEF9F3F9F0EB7C7376FFF9FFFCFFFFF8FCFF595F5F0D1110
F0EEEFFFFEFFFFFEFFF3F3F3595959303030CACACAFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
ABABAB828282FFFFFFFCFCFCFFFFFFF9F9F9FBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFD3D3D36767670C0C0C5E5E5EC7C7C7FFFFFFFFFFFFFBFBFBFFFFFF
F9FBF8FEFFFD626461939592AAAAAA454447FDFCFFFFFEFFFFFDFFFFFEFF
FFFEFFFDFBFCFFFBFBFFFEFBFFFCF9F9F8F4FFFFFDFFFFFFF9F9F9FDFDFD
FFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFEFFFCFFFFFEFFFF
FFFDFFFFFDFFFEFCFFFBFCFCF9FFF9FCFFFAFFFEFBFDF6F9FFFBFFFEFBFF
FCFFFDFBFFF9FFFEFDFFFBFBFFFEFFFAFAFAE7E8E8979B9A4243450C0D0F
525154A5A4A7F3F1F2FFFEFFFDFDFDFDFEFEFEFFFDF8FCF9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
F7F7F7D6D6D6242424FDFDFDFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF3C3C3CC2C2C2
1C1C1CD7D7D7FDFDFDFFFFFFF4F4F4BABABA7070706E6E6EBCBCBCFDFDFD
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD606060050505000000
03030300000001010101000004000024231FFCFFFBF9FFFFF7FFFFF9FFFF
FFFCFFFBF6F8F8FBFFFFFFFBFFFCEFCDBCB07775786B727ABBC4C7F5FDFF
F1F5F4FDFDFBFFFFFDFDFDFBFBF9FAFFFEFFFFFDFFFFFEFFFFFDFFFFFEFF
FFFEFFFEFFFFFEFFFFFEFFFDFEFFFDFFFFFAFFFCF2FFFDF4EDEEF0EFF8FB
F6FFFFF9FFFFFFFEFAFFFBF9F6E9EE726A73F7FAFFB7C0C5707A79F9FFFD
FFFDFFFDF6FBF9F7F8FCFCFCFFFFFF8080800B0B0BFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6909090
AAAAAAFFFFFFFEFEFEFAFAFAFFFFFFFFFFFFF7F7F7BDBDBDDCDCDCF7F7F7
FCFCFCFFFFFFFBFBFBFFFFFFF5F5F5FFFFFFFCFCFCFDFDFDF6F6F6FFFFFF
FDFDFDFCFCFCF9F9F9F1F1F18E8E8E202020333333959595F6F6F6FFFFFF
FEFFFDFEFFFD7A7C797A7C79292929BEBEBEFBFAFDFDFCFFFEFDFFFDFCFF
FEFCFFFFFEFFFFFDFEFEFCFBF7F5F4FFFEFDFBFBFBFFFFFFFFFFFFFDFDFD
F5F5F5FCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFDFFFEFFFF
FFFDFFFFFCFFFFFEFFFEFFFFFBFFFAFAFFF8FFFDFAFFFCFDFFF7FFFFFCFF
FBFFFFF9FFFDFBF9F8FFFDFDFFFEFFFFFFFFFDFEFEFBFFFEFEFFFFEBECEE
9D9C9F48474A141213464445AAAAAAEEEEEEFEFFFDFCFEFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFF8282826D6D6DFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFEFEFEFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFCFCFC
FEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFBFBFB5454547E7E7E
323232FEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFEFEFEFAFAFAC4C4C4707070
6D6D6DB4B4B4FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCBCBCB040404060606000000
000000000000020202030102070101120E0BB8BDB7F6FEFCF8FFFFFAFFFF
F9F3FAFFFCFFFEFEFFF8F6F9FFF5E7BBA99A76757191969AB7BEC4787F85
767C7CB4B8B7F1F2F2FFFFFFFFFDFFFFFCFEFFFCFFFEF9FDFFFDFFFFFEFF
FEFFFFFEFFFFFEFFFFFEFFFDFEFFFBFFFFF8FFF9EE8D8077030706566065
7B8688F2F8F8FDF7F4EBDFDEFFF8FD30283180848BA3ACAFF4FEFDFBFFFF
FFFCFFFFFCFFFFFEFFFEFEFEE2E2E22727275B5B5BFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE696969CACACA
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFD2D2D21B1B1BABABAB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDB9B9B95050500E0E0E727272
DADCD9FBFDFA9C9E9B3F413E383838FAFAFAFFFEFFFFFEFFFFFEFFFFFEFF
FAF8FBFFFEFFFDFBFCFFFEFFFFFEFFFCFAFBFEFEFEFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFDFFFFFDFFFFFEFFFEFFFDFBFFFBFBFFFAFFFEFBFFFBFDFFF9FEFFFCFF
F8FFFFF7FFFF8E8E8E040000333132AEAEAEFEFFFFFAFEFDFCFFFFFEFFFF
FFFEFFFFFEFFEEECEDA9A7A8434343111111484A479EA09DEDEDEDFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF6F6F6
FFFFFF3B3B3BBCBCBCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF747474383838
8C8C8CFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFF
FDFDFDC8C8C87D7D7D666666ABABABFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFF
FDFDFDFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFA1A1A10F0F0F000000010101
0303030000000606060200010400000D0707999B98FBFFFDFCFFFDF7F8F8
FFFDFFFFF9FFFBF8FFFFFBFF917D701100009A978E676B6C080812D2D4E0
F6FAFFD9DEE18488896A6A6AB0ABADF5EFEFFEF7FAFFFDFFFCF9FFFFFEFF
FEFFFFF4F8F9FEFFFFFEFFFDFDFDF9FFFEF6FFF2E7190B00D1D9D7F2FFFF
C2CFD3CCCFD3FFF7F7A29293160D12222126C4CBCFF8FFFFE6EAEB030303
D4D1D7FFFEFFFDFCFFE5E5E51919198F8F8FFFFFFFFDFDFDFFFFFFFCFCFC
FDFDFDFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFE5E5E55C5C5CEEEEEEF9F9F9
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFD4D4D4111111
B2B2B2FFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFDFDFDFEFEFEFFFFFFF7F7F7
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFDBDBDB787878
15171445474482828011110FD5D5D5FAFAFAFFFEFFFDFCFFFFFEFFFFFEFF
FDFCFFFFFEFFFEFDFFFFFEFFFCFBFEFFFEFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFF
FFFEFFFFFDFFFFFEFFFEFFFDF8FFFCF8FFF8FFFBF8FFFBFAFFF6F7FFFBFD
F7FFFFEEFDFFFCFCFCABA5A5E2DDDFEAEAEAF9FAFAFCFFFFFCFFFFF7FBFC
FBFCFEFFFEFFFEFCFFFEFCFDFFFFFFF2F2F0A4A6A3525451101010454545
9C9C9CEAEAEAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFF
E6E6E60C0C0CFCFCFCFCFCFCFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFC909090040404
7B7B7BE1E1E1FFFFFFFAFAFAFBFBFBFFFFFFFEFEFEF9F9F9FDFDFDFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFD2D2D28686866262629F9F9FF4F4F4F3F3F3
FFFFFFFAFAFAFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF8686860E0E0E050505000000
0000000404040000000100000903030A0404828282FEFFFBFCFCF2FFFFF8
F8F5FBECE8F6FFFBFFFFF7FFC3AFA2E7D6C2F9F9EDFCFFFD96909A44404E
F9FFFFF8FFFFFAFFFFFEFFFFE5E0E2938D8D7B75759D989AF2F0F3F5F6FA
FCFFFFFCFFFFFEFFFFFEFFFDFFFFFBFFFBF3FCE6D92C1B11D7DFDDF1FFFF
F7FFFFFEFEFFFFF4F7F7E7E85D565BE2E5E9F8FFFFF6FEFFA5A4A7010000
DEDDE0FDFCFFDEDDE01414149C9C9CFDFDFDFDFDFDFAFAFAFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBCFCFCF6F6F6FFDFDFDF8F8F8FEFEFE
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFD2D2D2
0F0F0FBBBBBBFEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFF5F5F5FFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFF8F8F8FBFBFBFFFFFFFDFDFD
F5F7F4A4A6A330302E11110F818181EAEAEAFFFEFFFFFEFFFDFCFFFFFEFF
FFFEFFFCFBFEFEFDFFFFFEFFFFFEFFFBFAFDFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFF
FFFEFFFFFEFFFFFEFFFEFFFFF9FFFFFBFFFFFFFEFBFFFBF6FFF5EFFFFBFA
F1FEFFF2FFFFFAFBFDFFFBF9948F8FD7D7D7FEFFFFFCFFFFF5F8FCFCFFFF
FEFFFFFFFEFFFFFEFFFEFCFDFCFCFCFDFDFBFEFFFDFEFFFDF6F6F6A9A9A9
5858580E0E0E353535999999E6E6E6F8F8F8FDFDFDFFFFFFFFFFFFFDFDFD
8C8C8C686868FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB868686060606
6464641717172C2C2C7F7F7FCFCFCFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
F1F1F1FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFDFDFDE0E0E09595956C6C6C
8B8B8BEFEFEFFFFFFFFBFBFBFEFEFEFCFCFCFFFFFFFFFFFFFCFCFCF8F8F8
FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFBEBEBE111111000000040404
060606000000040404020001040000140F11BAB8B9FFFFFAFFFBEC989186
00000400000D0E0518D5C7D2FFFAF1AB9E8D00030000010020141D070008
E4EAF6F5FFFFF8FFFFF7FAFFFFFEFFFFFDFDFFFDFDEAE5E59A989B757678
929599DCE2E2FAFEFFF9FBF8FFFFFBFFFEF6FFFAED605247969A9BF3FFFF
F1F9FFEBEBF3D9CED26D6163FDF8FAFEFFFFF9FFFFF3F9F93939390A0809
CBCACDD2D1D41B1A1D9E9E9EFFFFFFFFFFFFFDFDFDFFFFFFF5F5F5FFFFFF
FEFEFEF7F7F7FFFFFFFBFBFBA3A3A3929292FFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF
CACACA090909B6B6B6FFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFF9F9F9000000616161131313555555C6C6C6FFFFFFF4F4F4
FFFEFFFFFEFFFEFDFFF6F5F8FFFEFFFFFEFFFDFDFDFEFEFEFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFEFDFEFFFFF9FFFFFBFFFFFFFEFBFFF4ECFFF4E8FFF9F2
F1FEFFEBFEFFFEFFFFFFFDFBFDF8F86E6E6CF6F7F9FBFFFFFCFFFFFCFFFF
FBFCFFFCFDFFFFFEFFFFFEFFFFFFFFFFFFFDFDFDF9FBFDF8FCFCFCFFFFFF
FEFEFEFDFDFDBABABA5555551212123E3E3E929292E6E6E6F6F6F6FFFFFF
3E3E3EAAAAAAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF404040181818
FDFDFDFFFFFFC9C9C97070702525251D1D1D6D6D6DB5B5B5FFFFFFFDFDFD
FFFFFFFDFDFDF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFBFBFBFDFDFD
EFEFEF9090905B5B5B8C8C8CDCDCDCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF0B0B0B030303000000
0101010000000000000505050503041B191AFCFAFBFCF7F1FFF5E4190F01
9A9FA3F0F6FF877F8A1A0B10F4E5DE0E0500A8AEAAF8FCFB7F6F700E0004
C3CAD8F1FFFFF7FFFFFBFFFFFFFEFFFCF7F7FFFDFBFFFEFBFDFBFCFEFFFF
EBEEF2A6ABAE6D71728D8F8CD7D7D3FEF7EFFFFCEDECDED3030205D6DDE5
D7DBE60A0A12888184FFF9FAFFFDFFF8F7FAFAFEFFD8DCDD080A070B0B0B
A4A3A6121114A4A3A6FFFFFFFAFAFAFFFFFFFAFAFAF9F9F9FFFFFFFCFCFC
FFFFFFFFFFFFF4F4F4828282BEBEBEF9F9F9FAFAFAFDFDFDFFFFFFFFFFFF
FEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFBFBFB
FFFFFFC6C6C6212121BBBBBBF9F9F9FDFDFDFFFFFFFFFFFFF9F9F9FFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBF7F7F7
FFFFFFFFFFFFFFFFFF212121DFDFDFE9E9E99292922626262D2D2DA3A3A3
FAFAFAFDFCFFFFFEFFFFFEFFFEFDFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFD
FEFFFBFFFFFBFFFFFBFFFFFFF7FFFFF9FFFFFFFCFAFFFBEFFFF4E1301F15
323F50DDF1FFFEFEFFE2DCDAFFFDFD7A7A78B1B2B4FCFFFFFBFFFFF4F7FB
FAFBFFFEFFFFFFFEFFFCFAFBFEFCFDFFFFFDFFFFFBFDFDF9FFFFFFF8F8F8
FFFFFFFAFAFAFEFEFEFFFFFFFAFAFAB9B9B96363631111113737377E7E7E
111111FFFFFFF9F9F9FFFFFFFCFCFCFBFBFBFAFAFAFAFAFAFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEEEEE151515050505
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFD2D2D28383833D3D3D020202595959
AFAFAFEFEFEFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFEFEFEFA8A8A86161617A7A7AD2D2D2FBFBFBFDFDFD
FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFAFAFAE1E1E1010101040404
0000000606060A0A0A000000020305F6F6F6FFFEFFFFFDF6EED9C6130500
E7F1F8F4FFFFFFFCFC978984CBC2BD0C0C0CECF6FFF3F8FCFFF8F233211D
939AAAF0FFFFEEFBFFF9FFFFFCFBFEFFFEFBFFFCF9FFFEFAFFFFFDFBFCFC
FAFEFFFBFFFFFCFFFFF2F3F3BAB8B77E7971897D6DDFD2C7E3DCE164626F
3F3E4C4A4C56FFFEFFFFFDFCFFFEFFFFFEFFFDFCFF4A4B4B000100000100
121114A09EA1F5F4F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF2F2F26A6A6ACBCBCBFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFCFCFCFDFDFD
FFFFFFFAFAFABDBDBD101010C9C9C9FFFFFFFDFDFDFFFFFFFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF3A3A3AB7B7B7FFFFFFFEFFFDF9FBF8BBBDBA454744
10120F6D6E6ED7D8D8FEFFFFFDFEFEFCFDFDFFFFFFFFFFFDFBFBF9FFFFFD
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFB
FEFFFAFFFFFAFFFFFAFFFFFFF8FFFFF7FDFFFFFBF9FFF6E7FFF9DF685648
6D7C91CFE4FFF8FAFFC9C3C12E292911110FECEDEFF8FCFDF8FDFFFBFFFF
FEFFFFFEFFFFFFFEFFFFFEFFFFFDFEF8F6F5FAFAF6FFFFFBF9F9F9FFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFBFBFBC0C0C03F3F3F
0000002929298A8A8ADDDDDDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9F4F4F4F111111
E8E8E8FFFFFFFFFFFFF6F6F6FFFFFFF8F8F8FFFFFFFFFFFFE7E7E7999999
4646460A0A0A4646468C8C8CEAEAEAFFFFFFFAFAFAFFFFFFFCFCFCFFFFFF
FBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFF7F7F7B4B4B46E6E6E757575
BCBCBCFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFE0E0E0474747
0101010A0A0A030303393A3AEAEEEFF6FAF9FFFEFDFFF7EFFFF4E1241405
A9BAC1F0FFFFFFFFF3FFFDEDF7F3F0161A25B8C4D8FBFEFFFFFAECA99588
4D5665EDFFFFEEFDFFF8FFFFFFFEFFFFFEFBFDF7F4FFFFF8FEFEFAFCFFFF
FBFFFFF7FCFFF9FDFEFBFCFCFAF8F7FEF9F1FCF3E2574D41766D723E3746
D8D5E48B8B95D3D2D5FFFFFFFBFBFBFDFDFDCCCCCC020200040400070705
0000020A090C000000000000000000FFFFFFFCFCFCFFFFFFF7F7F7FFFFFF
E6E6E65E5E5EEEEEEEFFFFFFFDFDFDFFFFFF5D5D5DF5F5F5FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F3F3F3FFFFFFFFFFFFC0C0C00F0F0FC3C3C3FDFDFDB1B1B17A7A7AFEFEFE
FFFFFFFEFEFEFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFF1F1F1FFFFFF7F7F7FADADADFBFBFBFEFFFDFEFFFDFBFDFAFEFFFD
DEE0DD7A7C79191A1A454646B3B4B4FDFEFEF7F7F5FFFFFDFAFAF8FFFFFD
FFFFFDFBFBF9FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFDFFFFFBFFFFFB
FEFFF8FFFFF8FFFFF8FFFEFFF8FFFFF9FEFFFFFDFBFFF8E9FFFADAB7A694
56647EE4FAFFFCFEFFFFFBF9FCF7F7FBFBF9FCFDFFFCFFFFFBFFFFF3F8FB
FDFEFFFDFEFFFCFBFEFCFCFCFFFEFFFFFEFDFFFFFBFDFDF9FFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFBFBFB474747
AEAEAEBFBFBF6D6D6D1111112F2F2F787878CFCFCFFEFEFEFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4E4E4E9E9E9E373737
CBCBCBFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
FEFEFEF9F9F9ABABAB6262621111113030308B8B8BD0D0D0FDFDFDFEFEFE
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF6F6F6FEFEFEFFFFFFF9F9F9
C0C0C06D6D6D656565BDBDBDFFFFFFFBFBFBFCFCFCFFFFFFFEFEFEF9F9F9
FFFFFFD8D8D8FFFFFFFCFDFDF9FFFFFBFFFFFFFFFBFFFBF3FFF8E679695A
3F565CEAFFFFFFFFE7CEC7AB7F80805C64774E5E7FF5FAFFFFF8E2B49E87
0A1322E1F8FFF1FFFFF2FBFFF7F8FCFFFEFBFFFEF8FFFFF8FDFDF9FAFEFB
FBFFFFFBFFFFFCFFFFFEFFFFFFFEFDFFFDF8FFFDEFA4978C363135F2EFFE
CFCADC605C6AFEF8FFFEFEFEFBFFFFF9FFFF212222030100060000040000
030404080E0E171818757575A3A3A3FBFBFBFFFFFFFFFFFFFFFFFFC5C5C5
767676FDFDFDFBFBFB9A9A9A242424E7E7E71F1F1FDDDDDDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFF5F5F5BBBBBB161616D5D5D5BDBDBD3E3E3EFFFFFF
F4F4F4FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFF
FEFDFFFFFEFFFFFFFFFCFCFCFCFCFCFEFEFEFEFFFDF8FAF7FEFFFDFEFFFD
F8FAF7FEFFFDF7F9F69EA09D3739361B1D1ADEDEDCFFFFFDFDFDFBFDFDFB
FFFFFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFDFFFFFDFFFFFB
FEFFFAFFFFF8FFFFFAFFFFFFF7FDFFFBFEFFFFFEFBFFFDEDFFF6DCECDECF
061123EAF9FFFCFFFFFEF9F9FFFEFDFFFFFFFEFFFFFAFEFFFCFFFFFCFFFF
FEFFFFFDFEFFFEFDFFFFFFFFFFFEFFFCFAF9FCFCFAFFFFFDFFFFFFFAFAFA
FFFFFDFFFFFDFCFCFCFFFEFFFCFBFEFFFEFFFFFFFDFEFEFCF4F4F20E0E0E
F5F4F7FFFEFFFCFCFCFFFFFFC4C4C4737373232323252525797979D6D6D6
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE9E9E9121212F3F3F3AAAAAA
D4D4D4FFFFFFF9F9F9FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFBFBFBFCFCFC
FFFFFFFCFCFCFEFDFFFFFEFFF8F8F8C1C1C16B6B692020202524276D6C6F
C0C0C0F5F5F3FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFDFFFCFCFCFFFFFF
FCFCFCFFFFFFFFFFFFC2C2C2787878676767B1B1B1F3F3F3FFFFFFFDFDFD
FBFBFBFFFFFFFFFFFFFDFEFEFBFFFFF7FDFBFFFEFDFFFBF5FFF9EBE7DAD1
00050B617979D2D4BC49442C565757D6DEF000011C707384CFBCA92B1A06
000510DAECFFF4FFFFF6FCFFFEFFFFFFFFFBFFFEFAFEFDF8FFFFFBFAFCF9
FBFFFFFBFFFFFAFEFFFCFDFDFFFEFFFFF9F6D1C7BD70675E4B494CD3D3DD
2C2836ECE5F2FFFCFFFDFDFDFBFFFF69716F0608050402010900000D0503
4A4B4BC9CFCDFCFFFFF8FAF7FFFFFFFFFFFFFCFAFBFEFCFDA6A4A5969696
FFFFFFF7F8F8FEFFFDFEFFFD8E8E8E242424424041B8B6B7FFFFFFFEFEFE
FDFDFDFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFE
FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBACACAC171717BABABA1A1A1AFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFDFDFDFFFFFF
FFFEFFFBFAFDFFFFFFFDFDFDFFFFFFFFFFFFFAFCF9FDFFFCFDFFFCFBFDFA
FEFFFDFBFDFAFEFFFDFEFFFDFBFDFACFD1CECACAC8FDFDFBFFFFFDFCFCFA
FFFFFDFDFDFBFFFFFDFEFEFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFDFFFFFDFFFFFDFFFFFFFDFEFFFCFDFFFFFFFBFFFEF6FFF8EDFFFEF6
1E2125CCD0D7FDFEFFFDFDFDFFFFFFFEFFFFFDFDFDFCFDFDFEFFFFFEFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFDFCFFFFFFFF
FFFFFBFDFDF9FCFBFEFFFEFFF9F8FEFFFEFFFFFFFBFFFFFAA0A19B4E4E4C
FDFEFFFEFFFFFEFFFFFFFFFDFFFFFDFFFEFDFDFBFCCDCBCC737275232225
1F202278797BD0D1D3F7F8FAFFFFFFFEFEFEFFFDFCFFFDFCFFFEFDFEFCFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFDFDFD9494945A5A5AFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFBFBFFFEFEFFF7F5F6FFFEFDFCFEF9FEFFFDCFCED3818085
30322F151712595957B3B1B0F6F4F5FFFEFFFFFEFFFAF9FEFFFEFFFFFFFF
FEFEFEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFF4848488080806565656B6B6B
EFEFEFFFFFFFFAFAFAFFFFFFFEFFFFFBFCFCFEFEFEFFFEFBFBF3EEFFFEFB
DDE2E5505858030400302F28D2D2D2FCFFFFDBDFE85D5D630800008F8A84
7D8084CAD1D9FBFFFFFEFFFFFFFEFFFDFDFBFFFEFDFEFEFCFDFDFBFFFFFF
FDFEFEFEFFFFFCFDFDFFFFFFFFFFFFB8B6B58C8885FFFCF9ECECEC000004
B2B1B6FFFDFFFBF9FCFFFFFFCBCCCC090A0A0000000707074F4A4ADDDBDA
FEFEFEFCFFFFFBFFFBFCFFFBFFFFFDFFFEFFFFFCFF7A7378BBB6B8FFFEFF
FEFFFFFBFFFFFBFFFAF6FDF5FDFEFE7A797C1B16188B8688FFFEFDFDFBFA
FFFEFFFFFEFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFF7F6F9FFFEFFF9F9F9FFFFFFA4A4A4111111090909FAFAFA
FFFFFFFEFEFEFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFCFCF8FFFFFBFFFFFBFBFAF6
83827D8B8B87FFFFFDFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF9F9F9
FFFFFAFFFFFAFBFAFDF5F4FA787681D8D7DCFCFCF8FFFFF6595A54A1A19F
FBFBFFFEFEFFF8F9F9FFFFFBFDFBFAFFFEFDFFFEFFF9F7F8FFFEFFFFFEFF
C5C6C8797A7C1D1E20262729707070CDCDCDFAF8F7FFFEFDFFFEFBFFFEFD
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFEFEFE
FAFAFAFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF393939B2B2B2FFFFFFFFFFFF
FDFDFDFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFCFFFFFAFAFFFFFCFFFFFCFAFFFFF8F5FAF3FEFFFFFEFEFF
FEFFFFE0E1E193958F48474208020050494C949399F0F0F6FBFAFDFDFDFD
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9272727D6D6D67D7D7D626262
929292636363909090E3E3E3FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF5F5F5
FFFFFFFFFFFFFDFDFDFCFCFCCDCDCD909090FEFEFEFFFFFFF7F7F7DFDFDF
F6F6F6FBFBFBFFFFFFE4E4E4030303000000131313BBBBBBFFFFFFFFFFFF
FFFFFFF8FAF7FCFFFBFCFFFBFBFBF9F5F3F4625D5FE3DEE0FFFEFFFCFBFE
FEFFFFFCFFFFFAFFF9FCFFF8FEFFFDFAFAFA3B3638201B1DF7F5F6FFFDFC
FFFEFFFFFEFFFAFAFAFEFEFEFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFAF9FCFFFFFFF9F9F9FFFFFF7B7B7B000000BEBEBE
FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFF7F7F7FFFFFFFFFFFFF2F2F2FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFAFAF8FDFDF9FFFFFBFCFBF7FFFFFB
DBDAD623231FF8F8F6FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FCFDF7FFFFFBFFFEFFFFFEFF3C3A45151419FFFFFBEDEEE411120CEBEBE9
FCFBFFF7F6FCFFFFFFFDFDFBFFFEFDFFFAFAFDFBFCFFFDFEFFFEFFFFFEFF
FEFFFFFEFFFFFEFFFFCFD0D27D7E7E2526261F1F1D6B6B69BFBDBCFEFCFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF7F7F7FAFAFAFFFFFFFDFDFDFCFCFC
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFDBDBDB131313FDFDFDFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFFFFFBFFFFF7F7FDFFFBFFFFFBFDFBFBEEFCFFF4F9FDFEF5F7FF
7C7A8D494855F3F9EDFDFFEFFAF1EAAA9FA15F5F67070B143E3F43898989
DDDDDDF9F9F9FFFFFFFFFFFFF7F7F7FFFFFF434343B7B7B7252525C2C2C2
FFFFFFFFFFFFDFDFDFA1A1A16A6A6A808080D5D5D5FFFFFFF9F9F9FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFFFFFFFE3E3E36E6E6EFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
E1E1E1FFFFFFF8F8F80E0E0E0505055A5A5AF3F3F3FFFFFFF8F8F8FAFAFA
FFFFFFFDFDFDFBF9F8FFFDFCDEDEDC626461EDEFECFBFFFEF4F5F7FEFFFF
FFFEFFFBF9FAFFFFFAFCFBF4FFFFFBDCDCDA0E0F0F202121444444FBF9FA
FFFDFEFFFEFFFFFFFFFFFFFFF6F6F6FFFFFFF9F9F9FFFFFFFAFAFAFFFFFF
FEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF979797151515232323171717
E4E4E4FFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF8F8F6FFFFFBFFFFFBFCFBF7FFFFFB
CCCBC7080804E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFAFFFFFBFAF9FCFFFEFF97959E0403089E9E9AADAEA6393A34FFFFFD
FFFEFFB7B6BCD3D3D3FFFFFDFAF5F5FFFDFDFFFEFFFFFEFFF4F3F6FFFEFF
FEFFFFFBFCFEFBFCFEFEFFFFFEFFFFFCFDFDD8D8D8888886323230141412
6C6C6CBBBBBBFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FAFAFAFEFEFEE8E8E86A6A6AFFFFFF858585616161FFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFCFEFFFEFFFFFCFFFFFDFDFDFFF2FEFFF6FCFFFFF8F7FF
F2EDFF656370F9FFFAFBFFF4FFFCF9FFFBFFF8F8FEF5F8FFB4B5B7676767
1919192A2A2A737373C8C8C8FFFFFFF9F9F9616161818181242424FFFFFF
FAFAFAFFFFFFFBFBFBFCFCFCFFFFFFE2E2E2ABABAB696969808080D7D7D7
FAFAFAFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFBFBFBFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFAFAFAFEFEFEAEAEAEC8C8C8FDFDFDFFFFFFFFFFFFDDDDDD131313
0F0F0F1919191616160303039B9B9BFCFCFCFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFB9B7B87F7F7DFDFFFAF8FCF9FCFFFDFEFFFFFEFDFF
FDFAFFFFFEFFFEFDF8FDFCF5BDBCB520201C7374743B3C3E585858504E4F
FBF9FAFFFEFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC7A7A7A262626DDDDDD5A5A5A5C5C5C
232323E5E5E5FEFEFEFEFEFEFAFAFAFFFFFFFBFBFBFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFCFFFFFDFEFEFCFDFDFBFFFFFBFFFEFA
CAC9C5979793E5E5E5FBFCFCFEFFFFFBFCFCFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFF8F8F6
FEFEFAFBFBF7FFFEFFFFFEFFC0BEC700000404040063645C90918B9F9F9D
18171C000004F0EFF2FFFFFFFFFDFDFEF9F9FFFDFCFFFEFDFFFFFFF9F9F9
FEFFFFFEFFFFFEFFFFF8F9FBF6F7F9FEFFFFFEFFFFFEFFFFFAFBFBE0E0E0
8282823737371818185E5E5EC1C1C1F3F3F3FCFCFCFCFCFCF9F9F9FCFCFC
FFFFFFF9F9F9FAFAFA050505FBFBFB323232CACACAFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFFFFFDFDFFF9F9FAFAF8FCFFFDF8F9F9FCFDFFFEFEFFFFFCFF
FFF4FA665F62D6E2E0F1FFFFFEFEFFFFFCFFFFFEFFFEFEFCFEFEFEFEFEFE
FFFFFFD0D0D07676762323231A1A1A6666666868682F2F2F7D7D7DFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFF9F9F9F1F1F1ADADAD
6B6B6B6F6F6FC5C5C5FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFDFDFDFEFEFECDCDCDA8A8A8FFFFFFFCFCFCFAFAFA4C4C4C070707
000000000000000000A3A3A3FCFCFCFFFFFFFFFFFFFFFFFFFCFCFCFAFAFA
F9F9F9FFFEFF8B8C909F9EA3F7F7F5FFFFFAFFFFFBFAF8F7FFFDFFFEFBFF
FFFEFFFEFFFFF8FAF4ACAFA417180EAFB0A8EAE8E9110E14F8F7FA3D3D3D
656565FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFBFBFBFCFCFCF6F6F6575757363636ECECECFFFFFF8484847D7D7D
8C8C8C252525E9E9E9FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFEFEFCF7F7F5FFFFFBFFFFFB
FEFDF9FFFFFDF8F8F8FEFFFFFEFFFFFAFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFD
FFFFFBFFFFFDFAF9FCFFFEFFDEDDE30F0E130909050102000C0C080A0A08
070609AFAEB3FEFDFFFEFCFDFFFDFDFFFAFA8E8C8B090706353535AEAEAE
F8F9FBFEFFFFFDFEFFFEFFFFFEFFFFFEFFFFFEFFFFFBFCFCFEFFFFFBFCFC
FFFFFFFEFEFEDFDFDF9191913434341717175D5D5DB8B8B8FFFFFFFFFFFF
FFFFFFFBFBFBFFFFFF191919BEBEBE1C1C1CF8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEFBFFF6F0FFFEF6F0F8F8F7FFFFFFFEFFFAF6FFF6F6FFFAF7FD
FFFBF6AEA5A0A5ADB8F2FFFFF2F7FFFBFBFFFFFEFBFFFFF8FFFEFDFFFFFF
F9F9F9FDFDFDFFFFFFFFFFFFDCDCDC8C8C8C383838050505E0E0E0FDFDFD
FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFDFDFD
FFFFFFFCFCFCBEBEBE7171715F5F5FC1C1C1FBFBFBF8F8F8FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF606060F5F5F5FFFFFFD6D6D6080808000000
0000000606060101014A4A4AFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFF6A6B6DCACDD4FCFFFFFDFDFBFFFCF5FFFDFAFFFDFBFCF5FCFFFCFF
FFFEFFF5F9F87E857E151C12DBDFD0FFFFF6FFFCFF0B050CFCFAFDFDFDFD
3C3C3C626262F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFF7F7F7FBFBFBFFFFFF
FDFDFDFFFFFFF3F3F33B3B3B595959FBFBFBFBFBFBFFFFFF959595626262
FBFBFB8585852F2F2FF0F0F0FDFDFDF4F4F4FFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFDFFFFFDFDFBFAFFFEFD
FFFEFDF6F6F4FFFFFFFEFFFFFEFFFFFCFDFDFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
F8F8F6FFFFFDFDFCFFF9F8FDDCDBE00706090000000202000B0A06010000
A6A4A7FFFEFFFFFDFFFFFEFFFFFDFDFFFDFDFDFBFAA3A1A0D8D8D8E5E5E5
FFFFFFFCFCFCF9FAFCFEFFFFFCFDFFF6F7F9FCFFFFFCFFFFFAFEFFFEFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFE6E6E69090903A3A3A0606065F5F5F
A9A9A9FEFEFEFBFBFB3939395C5C5C757575FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF8FFFAE8E0D8CB00030E2A394CBEB6C3070004AFB2B9FCFFFF
FFFDECF1E6E06B6D84ECF6FFF5FFFFF9FFFFFFFCF5FFFCF4FFFEFAFFFFFF
FFFFFFF9F9F9FEFEFEFFFFFFF9F9F9FFFFFF8B8B8B101010FAFAFAFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFBFBFB
FEFEFEFFFFFFF7F7F7FFFFFFFFFFFFC1C1C17171716B6B6BB0B0B0F5F5F5
FFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFFBFBFBFAFAFAF0F0F0707070FFFFFFECECEC040404000000
050505000000020202686868FFFFFFFAFAFAFFFFFFF5F5F5FFFFFFF1F1F1
555555E4E5E9F3F7FFFBFFFFFCFCF8FFFEF6FFFBF6FFFCFBFFFBFFFFFCFF
FCFDFF494F4D353F3AEBF4ECF4FBEBFDFDF1FFFCFF271D26D2D0D3FEFFFF
F8F9F9BCBDBDDCDCDCFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8
FFFFFFD7D7D7262626727272FCFCFCFFFFFFFEFEFEFFFFFFBFBFBF3F3F3F
FFFFFFFEFEFE7777772E2E2EF5F5F5FEFEFEFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFEFD
FDFBFAFFFFFDFEFEFEFCFDFDFEFFFFFEFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFBFBF9FFFFFD
FEFEFCF7F7F7FCFBFEFFFEFFDAD9DE100F12010100010100070602514F4E
FFFEFFFDFBFEFFFEFFFFFDFFFFFEFFFFFEFDFFFEFDFDFBFA919191E0E0E0
F9F9F9FFFFFFFEFFFFF5F6F8FEFFFFFEFFFFFBFFFFFCFFFFF9FDFEFCFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFEBEBEB979797
4343430D0D0D5151513A3A3A141414D1D1D1FFFFFFFDFDFDFEFEFEFEFEFE
FFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEF6FFFAE29F9989485468EFF8FF2616201A0A0BACB3BBF0FBFD
FFFFF1BBB2AB0B091FECEFFFF7FFFFF8FFFFFCFBF4FFFFF6FFFFFBFEFEFE
FEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF4D4D4D0E0E0EFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFDFDFDCECECE7E7E7E
6464649F9F9FECECECFFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAFDFDFDFFFFFFFFFFFFFCFCFCC1C1C18D8D8D9999991F1F1F060606
010101010101000000E9E9E9FFFFFFFFFFFFFFFFFFFFFFFFD5D5D5656565
F7F7F7FDFEFFFCFEFFF8FBFFFFFFFBFFFDF4FFFEF6FFF7F4FFFCFFE9E3EB
3132325A5E5DF2F8F8F8FEFAFEFFF3FFFFF3FFFBFE463E47BBBABDF9FAFA
FEFFFFFCFDFDFDFDFDFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFF
C4C4C41414149D9D9DFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCE5E5E5414141
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFD
FCFCFCFEFDFFFFFEFFFAF9FEE0DFE20A0A0A0503040402013F3E3AFDFCF8
FFFEFDF3F1F2F4EFF3FEFCFFFFFEFFFFFFFFFEFEFEFFFFFFFDFDFD6A6A6A
F4F4F4FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFE4E4E4A3A3A31B1B1B0101014B4B4B9C9C9CEAEAEAFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FDFDFDFFFFF8FFFFE9C9C6BB090F27F8F8FFF6DFD9120000D0DCE8F0FFFF
FCFFFFFFFEFBFFFBFFFFFAFFFEFDFFFCFEFFFCFFFBFCFFF8FEFFFDFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFBFBFBF6F6F60C0C0C050505F7F7F7F9F9F9
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9DDDDDD8D8D8D5E5E5E969696E6E6E6FFFFFFFEFEFEFBFBFBFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFEFEFEDFDFDF1A1A1A949494FAFAFA919191
1919194F4F4FE3E3E3FFFFFFFFFFFFFEFEFEFFFFFFB4B4B4828282FFFFFF
F9F9F9FFFEFFFFFBFFFFFCFFFCFAF9FFFFF8FEFFF5FDFEF8D2D1D41F1E23
807E7DFFFEFDFEFBFFFFFEFF8585780A0C00303030AAAAB0FBFFFFFCFFFF
FAFEFFFCFFFFFAFBFDFEFFFFFCFCFCFDFDFDFFFEFFFDFBFCFCFCFAADADAB
121210BABAB8FEFFFDFAFCF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFBFDFDFB
FFFEFFFFFEFFFFFEFFFDFCFFC0C0C00F0F0F0100000B090AE8E6E5FFFFFB
9998945A5857A09B9F5B585EE5E4E7FDFCFFF9F8FBDFDFDFFDFDFD7D7D7D
B6B6B6FFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FEFEFEFFFFFFFEFEFE3C3C3C343434A9A9A95757570C0C0C3D3D3D909090
E7E7E7FAFAFAFFFFFFFBFBFBFEFEFEFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFEFFF9FFFFF1F0F1E9101026E2DAEDFFF7E77B6A58838F9DEEFFFF
F9FFFFFFFFFFFFFDFAFFFCFCFFFAFFFFFCFFFBFFFFF9FFFAFEFFFDFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFBFBFB292929DCDCDCFFFFFF
FBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFBFBFBFFFFFFE5E5E59393936A6A6A828282E3E3E3FAFAFA
FAFAFAFFFFFFFFFFFFFBFBFBECECEC191919909090797979E4E4E4FFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFFFFFFF9F9F9919191A7A7A7FDFDFDFFFFFF
FFFFFFFFFDFFFFFBFFFFFCFFFFFEFDFCFDF5FBFEF5B7B9B3161717A5A5A5
FFFFF8FFFEFBFFFBFFFEF8FFFFFFF4A1A395DCDEDBE8EBEFFBFFFFFAFFFF
F7FBFCFCFFFFFEFFFFF9FAFCFFFFFFFFFFFFFFFEFFFFFEFF898987191917
D1D1CFFFFFFDF7F9F6FEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFCFCF8FCFCFA
FFFEFFFBFAFFFFFEFFFFFEFFA9A7A60604030604077B797CFFFBFBFFFEFB
8B87848B8686FFFDFFDEDBE2090A0EFBFCFFFAFBFFBFC0C22F3032161719
EAEAEAFDFDFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFCFFFFFCFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF0E0E0E383838FBFBFBFFFFFFF9F9F9B4B4B4676767
0808082F2F2F878787DCDCDCFFFFFFFDFDFDFAFAFAFCFCFCFFFFFFFCFCFC
FAFAFAFFFFFDF5F7F2FFFFFDB7B3BD332A2DFFFDE8978E7D363E50E9F7FF
FBFEFFFFFEFFFDFFF2FFFFF4FFF9FFFFF9FFFBFFFFF8FFFBFCFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E3E3EB2B2B2FFFFFF
FDFDFDFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFF7F7F7EEEEEEA5A5A5656565
7E7E7ED9D9D9FBFBFBFFFFFF949494ACACACF9F9F9FFFFFF585858EEEEEE
FDFDFDFBFBFBFFFFFFFFFFFFF4F4F46E6E6ECECECEFFFFFFFEFEFEFFFFFF
FCFCFCFEFDFFFFFCFFF8F5FCFDFBFAFFFFF898979014130ECECCCBFFFEFA
FFFFF4F7F6F1FFFBFFFEF9FFFFFEF7FBFBEE8F8F8DD9DADCFBFFFFF7FFFF
FBFFFFFCFFFFFAFBFDFEFFFFFFFFFFF8F8F8F5F3F4666465343231EBE9E8
FFFFFDFFFFFDFBFDFAFCFEFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFEFEFAFFFFFB
FFFEFFFCFBFFFFFEFFFEFEFE949291020000110F12FFFEFFFBF6F8FFFBF8
DDD9D5120E0BF3EDF4FFFDFF79797F898C91FCFFFFFBFCFFF3F4F8F2F3F5
FFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
FFFFFFFEFEFEADADAD343434272727FFFFFFFCFCFCFFFFFFFAFAFAF6F6F6
FFFFFFC1C1C16A6A6A1919192A2A2A7C7C7CD0D0D0FAFAFAFFFFFFFFFFFF
FEFEFEFFFFFFFEFFFFFEFEFEFDF8FABCB4B166604E61615400000BE7EDFF
FFFCFFFFFEFFFBFFF3FCFFF3FFFBFFFFFAFFFCFFFFF9FFFFFEFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFDFDFD
EDEDEDA8A8A8717171707070B1B1B1FCFCFCFFFFFFF7F7F7FFFFFF494949
E7E7E7FFFFFFF8F8F8D5D5D5575757E8E8E8FDFDFDFFFFFFFFFFFFFDFDFD
FCFCFCFDFCFFFEFEFFFEFFFFFFFEFD6864602D2724E6E0DDFDF9F6F8F7F0
FFFFEFFFFFF8FDFBFFFBF9FFFDFDFBFFFFF4FFFBF86E6C6FEDF3F3F9FFFF
FBFFFFEFF5F5FEFFFFFEFFFFFCFCFCF3F3F3484647535152EBE9E8FEFCFB
FFFFFDFFFFFDFDFFFCFEFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFDFFFFFAFEFFFB
FCFBFFFFFDFFFDFCFFF8F8F854534F0100009C9A9DF8F5FBFFFDFFFFFEFB
FFFDF71F1917E2DBE2FFFCFFA6A9B0454950F9FDFFFCFFFFF9FCFFFEFFFF
FEFEFEFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE
FAFAFAFCFCFC6363638F8F8F000000FDFDFDFFFFFFFFFFFFFFFFFFFDFDFD
F3F3F3FFFFFFF8F8F8FEFEFECACACA7373732B2B2B262626616161C5C5C5
FFFFFFFBFBFBFEFCFDF9F7F8FFFDFFFFFDFCF5FAF3FAFFF9555754AEACAF
FFFAFFFFFCFFF8FFFDF8FFF8FFFFF8FFFDFBFFFEFFFEFFFFFEFDFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCF6F6F6FFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFC1C1C1F8F8F8FDFDFDABABAB7C7C7C6F6F6FBCBCBCF0F0F0FEFEFE
6B6B6B7575755F5F5F333333FCFCFCFFFFFFFBFBFBD8D8D8525252F8F8F8
FFFFFFFEFFFFF6FBFEEBEFF04343434F4949FFF5F4FFFAF9928984030100
7C8067A5ADA0000019DEDFFDFEFFFFD8D5CCFFFCFA857E81B2B6B7F9FFFF
F4FAFAFBFFFFFEFFFFFEFFFFE0E0E0312F306C6A6BFAF8F9FFFEFDFFFEFD
F9F9F7F8F8F6FEFFFBF9FBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFF9FAFCF7
FDFCFFFFFDFFF7F6FBFFFFFF0F0E0A040300FCF9FFFFFDFFFFFBFDFFFEFB
F9F4EE746E6B1F181FF4F0FA878993515860FBFFFFFBFFFFFBFEFFF6FAFB
FFFEFFFAFAFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F90E0E0EEAEAEA151515E6E6E6FFFFFFF6F6F6FFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF2F2F2D4D4D48F8F8F292929
181818616161B3B1B2FFFDFFFEF9F9FBFBFBF9FFFFF9FFFD64635C544E4B
FFFBFEFFFDFFF8FFFFF8FFFDFFFFF6FFFEF8FFFDFFFFFDFFFEFDFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFF4F4F4
F8F8F8FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF6F6F6
777777878787FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C58C8C8C707070
7474746A6A6A808080FDFDFDFFFFFFF8F8F8FEFEFEECECEC101010FFFFFF
FFFFFFF8F9F9E2E6E5222625716F70FCF5F8FFF6F8FFFCFA575048C0BEAD
DDE1C4000300555674C5C5E9F7F7FDC5C4BD342C2A0E070AEBEFF0F0F9FB
F9FFFFFBFFFFF7FBFCD0D1D31A18198E8C8DFFFEFFFBF9FAFFFEFDFFFEFD
FFFFFDFFFFFDFEFFFBFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFFFFFAFEFFFB
FFFEFFFFFDFFFFFEFFFBFBFB0100006F6E6AFFFCFFFDF7FFFFFCFEFFFEFB
FFFBF3D1CBC8040004605C6600020BBFC7CFF0F7FFF9FDFFFCFFFFFCFFFF
FFFEFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
F9F9F9AAAAAA434343F8F8F8FFFFFFFAFAFAFBFBFBFFFFFFFBFBFBFCFCFC
FFFFFFFAFAFAFFFFFFF7F7F7FDFDFDFBFBFBFFFFFFFFFFFFF9F9F9FFFFFF
DFDFDF9292923F3C420B090C5F5D5CA7A9A4EBF1EFEDF3F1B3B1B0A39F9C
FFFEF7FFFFF8FCFFFFFCFFFFFFFFFAFFFEF9FFFDFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFFFFFF
FCFCFCFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEF5F5F5FCFCFC5B5B5B
414141EDEDEDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFDFDFDFFFFFF0E0E0EF2F2F2
FCFCFCC7C7C7151513929290FFFEFFFFFEFFFAF5F7FFFEFB6464588F907C
FFFFE49A9A8D0B0527FEF7FFFBF7FFFFFFFAFFFEFBFAFAF8FBFFFFF8FFFF
F4FCFEF6FBFEB7BBBC141517ADABACFFFEFFFEFCFDFFFEFFFFFEFDFFFEFD
FFFFFBF6F6F2FDFFFAFDFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFFFDFEFFFBFCFEFB
FFFEFFFCFAFFFFFEFFBFBFBF010000F8F7F3FFFCFFFFFCFFFFFDFFFFFEFB
FFFCF6F3EDEA231C21F2EEF8FCFEFFF5FCFFFBFFFFFBFFFFFCFFFFFEFFFF
FFFFFFFDFDFDFFFEFDFFFEFDFFFEFDFFFEFDFFFFFDFFFFFDFFFFFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA4A4A4CECECEFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FBFBFBFFFEFFFFFEFFE5E4E797979550524D0206034B4F4EA2A0A1EEECEB
FFFFF5FFFFF6FFFFFDFFFFFFFFFFFBFFFEFAFFFEFDFFFEFFFFFFFFFEFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFEFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFB2B2B2505050
F4F4F4FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFFFFFF
FEFEFEFEFEFEFEFEFEFCFCFCFFFFFFFFFFFF797979989898212121D3D3D3
A6A6A6131313B8B6B5FFFEFDFEFCFDFEFEFEFFFFFFFCFCF8BDBEB43D3E2C
FFFFE5FDFAEF130A27DDD5F8FFFCFFFDFDFBFDFDFBFEFFFFFAFFFFF4FCFC
FBFFFF9A9DA1101113C8C8C8FFFEFDFFFEFDFFFEFFFAF9FCFFFEFFFEFCFB
F4F4F2FFFFFDFEFFFFFDFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFF
FFFEFFFFFEFFFFFEFFFFFFFFFFFEFDFFFEFDFFFDFFFFFDFFFFFDFFFFFCFC
FFFDFDF0EAEA20191CC0BAC1FCFAFFFDFDFFFEFEFFFBFBFFFDFEFFFFFEFF
FEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFEFDFFFFFFFFFFFFFDEAEBEBABABAB525051100E0D
41403C94938FE5E3E2FFFEFDFFFEFDFFFDFCFFFEFDFFFFFFF9FDFEFCFFFF
FFFEFFFBFAFDFCFFFFFCFFFFF9F9F7FFFEFDFFFCFCFFFEFDFEFFFDFDFFFC
FEFCFDFFFEFFFEFFFFFEFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFDFDFDFEFEFE
FCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFCFCFCFFFFFFDADADAFFFFFF
F9F9F9FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBF6F6F63E3E3E1C1C1C979797
1E1E1ED3D3D3FEFFFFFEFFFDFAFBFBFEFEFCFFFFFDFBFAF6FEFDF6605D54
959287FFFDF9524E589B97A5FEFDFFFEFFFFFEFFFFF8FBFFF8FCFBFCFFFF
71727626272BDFDFDDFDFCF7FFFEF8FEFAF6FFFEFFFAFBFFFDFBFEFFFEFF
AEAEACB3B4B4FCFFFFFCFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFF8F3F5FFFDFFFAF5F7
FFFBFEDDD6D9A69FA2C4BFC3FFFCFFFDFBFFFBF9FFFFFEFFF9F8FDFEFEFE
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFFEFFFFFEFEFEFEFEFEFFFFFFFFFFFFFEFCFBFBF9F8
B2B0AF5C5A591917162E2C2B858382DFDDDCFFFEFDFEFEFEF9FDFEFCFFFF
FFFDFFFFFEFFFCFFFFF3F9F7FFFFFDFFFBFBFFFDFDFFFFFDFCFFFDFCFFFD
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFE5E5E5FAFAFAFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFEFEFEFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEE3E3E30F0F0F4C4C4C
EDEDEDFDFEFEF8F9F9F6FAF9FEFFFDFEFFFDFBFAF6FEFDF9FFFEFAFFFEFA
8F8B88726E6B171516525154FBFAFFFCFCFFFBFEFFFCFFFFF3F7F6525451
3F3E43ECEAEDFFFFFBF8F5EEFFFEF4FFFEF7FBFEFFFCFEFFE8E6E9A09B9B
8985822D2D2DD6DAE5F4FAFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFBF9FAFFFDFFFFFDFF
989194D9D2D5FFFBFEFFFCFFCDC9D392909BFFFDFFFEFDFFFEFDFFFDFDFD
FFFFFFFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFDFC
FDFBFAFFFEFDF7F5F4C8C6C56969691515152828287B7B7BC9CDCCFEFFFF
FBF9FAFFFEFFF3F7F6FBFFFFFCFCFCFBF9FAFFFEFFFDFDFDFAFEFDFAFEFD
FFFCFEFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFCFCFCFBFBFBF9F9F9
FBFBFBFFFFFFFBFBFBFFFFFFCECECE747474FFFFFFFEFEFEFFFFFFFDFDFD
FCFCFCFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFE6D6D6D0A0A0A
C7C7C7FEFFFFFEFFFFFCFFFFFEFFFDFCFEFBFFFFFBFDFCF8FFFEFBFFFCF9
FFFDFAFCF8F5F9F7F8010003E9E8EDFEFEFFFCFFFFE6E9EE363C3C5A5E5D
F4F2F5FBF6F8FFFEFBFFFFF6FFFCEEFFFFF8F4FAFFF8FBFFFFFDFF4F4840
DBD4CC666463D7DDE9F8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFAF8F9FFFEFFFAF5F7FDF8FA
F2EBEE3B3437FFF8FBFDF8FC2B2731E7E5EEFFFEFFFFFEFFF6F5FAFFFEFF
FDFDFDFCFCFAFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFFFFFEFDFFFDFC
FFFEFDFFFEFDFEFCFBFCFCFCFFFFFFFFFFFFC9C9C97475752324241F1F1F
726D6FC2BDBFF9FDFCFBFFFFFFFFFFFFFEFFF9F7FAFEFEFEFBFFFFFCFFFF
FFFDFFFFFCFFFFFFFFFDFEFEFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFF
FDFDFDFFFFFFFBFBFBBBBBBB151515CDCDCDFFFFFFFCFCFCFAFAFAFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFA9A9A93C3C3C
1F1F1FE8E9E9F8F9F9F5F9F8FEFFFDF2F4F1FFFFFBFFFFFBFDF9F6FFFEFB
FFFEFBFFFDFDF3F1F2202020B6B5BAF6F7FBE0E3E81E2126767C7CF6FAF9
FFFEFFFFFDFFFFFBF8FEF9F1FFFFEDFFFEF7F1FEFFF2FCFFFFFDFDFAEBE3
83796D8A8683BDC4D2F7FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFAF8F9FFFDFFFFFDFF
FFFDFFA7A2A49A9597979296ACA9B0FFFDFFFBFAFFF4F3F8FDFCFFFFFEFF
FDFDFDFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
F6F6F6FFFFFFFFFFFFFBFCFEFEFFFFFEFFFFF9FAFCFEFFFFFFFFFDCDCBCA
888282342F31171B1A5E6464B5B6B8F5F4F7FFFEFFFDFEFFF5FBFBFCFFFF
FFFDFFFDF6F9FBF9F8FFFFFDFDFDFDFEFEFEFEFEFEFDFDFDFEFEFEFFFFFF
FFFFFFFBFBFBFDFDFDFFFFFFFFFFFFF7F7F7FEFEFEFFFFFFFCFCFCFBFBFB
FFFFFFFDFDFDE6E6E60F0F0FC8C8C8FFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFCFCFCFFFFFFF3F3F3858585FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFC5C5C5303030
7B7B7B363737FCFDFDFCFFFFFCFEFBFEFFFDFDFBFAF8F6F5FFFEFBFFFBF8
FBF6F6FFFBFBE1DFE09D9D9DBCBBC0CACBCF0C0F149DA0A5FBFFFFFCFFFF
F8F7FAFFFEFFFEFEFAFFFEF4FFF6E7A19893000A1DC3DCF0F8EFF0FFF9EF
FFF7EC221C195D6675F2FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFCFDFDF8FAFFFDFF
F7F2F4FFFDFF2D282A444245FEFBFFFFFEFFFFFEFFFFFEFFFFFEFFFEFDFF
FFFFFFFCFCFCFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFFFFFF
FFFFFFFCFCFCFEFFFFFEFFFFFBFCFEFEFFFFFEFFFFFDFDFDFFFEFDFFFEFB
FFFAFBFFFBFBD6DAD98C9292424347111015555459A9AAAEF0F5F8FCFFFF
FFFAFCFFFCFFFFFEFDFBFBF9FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FFFFFFFEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFEFEFEFFFFFF
F6F6F6FFFFFFAAAAAAD7D7D7FFFFFFF9F9F9FEFEFEFFFFFFFEFEFEFFFFFF
FBFBFBFBFBFBFFFFFFB3B3B3464646FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFEFEFEE6E6E61A1A1A
FEFEFE535353626363FCFFFFF8FAF7FCFCFAFAFAF8FFFEFDFFFEFBFFFCF9
FFFDFDFFFEFDFFFEFFFFFFFFA9A8AB0E0F13B9B9BFFCFFFFFCFFFFFCFFFF
FDFCFFFFFEFFFCFBF7FFFEF6FFFBEDBAB1AC3C51649DB3C8FFFCFDFFF1E6
FFF7EBFFFCF9636C79EDFAFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFEFCFDFCFAFBFFFEFF
FFFEFFFFFEFFE8E3E5E9E7EAFEFBFFFAF9FFFEFDFFFFFEFFFCFBFEF9F8FB
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFBFAFEFCFBFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFBFCFE
F9FAFCFEFFFFFEFFFFF9FAFCFCFDFFFDFEFFFBFCFEFFFFFFFEFAF7FFFDFA
FFFCFBFFFDFDFCFFFFF6FCFCEFF2F6EBEBF197979D4245490D1517424848
ABA6A8EDE6E9FFFCFCFFFEFDFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFBFBFBFFFFFFF8F8F8
FFFFFFF8F8F8F6F6F6FFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFBFBFBFFFFFF
FAFAFAFFFFFFFFFFFF5A5A5A919191FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFF303030
F3F3F3F4F4F42E2F2F8A8B8BFFFFFFFFFFFFBDBDBBC0C0BEF7F5F4FFFEFD
F7F5F4FFFEFDFFFDFE7F7F7F242326D2D3D5FCFDFFFCFFFFFBFFFFF7FBFA
FCFAFDFFFCFFFFFDFDFCF7F1FFFFF1E9EAE2080D1EEFF1FFFFFDFFFFFDF4
FFFDF2F9F8F4F5FBFFF8FFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFEFFFEFFFFFEFFFFFDFE
FEFCFDF9F7F8FFFDFFFCFAFDFFFEFFFFFEFFFFFEFFFAF9FCFFFEFFFFFEFF
FDFDFDFDFDFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFCFCFCFCFCFCFEFFFFFEFFFF
FEFFFFFCFDFFFCFDFFFEFFFFFEFFFFFEFFFFFDFEFFFEFEFEFFFEFBFFFBF8
B6ACAB0E0808DFE3E2FBFFFFFCFFFFFBFBFFFEFEFFFBFEFFE5EDEFA8AEAE
4B464A140D10454040999796EDEDEDF8F8F8FFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFEFEFEFBFBFBFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFF4F4F4969696
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFDFDFD101010E8E8E8FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFF
F9F9F9FFFFFFDBDCDC1A1B1BB9B9B9FCFCFCA2A2A05A5A58FFFEFDFFFEFD
FFFEFDF5F3F2676767353535DFDEE1FFFEFFFEFFFFFDFEFFF9FDFAFCFFFD
FFFEFFFFF9FFFFFCFCFFFEFAFBFCF2FFFFFA27232DCAC6D4FCFAFDFEFDF9
FDFEF8FEFFFDF4F8FFFBFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FEFFFFFDFEFFFAFBFDFEFFFFFBFBFBFEFEFEFAFAFAFFFFFFFEFDF9FFFEFB
FFF6F7635D5DF0F4F3FBFFFFFBFEFFFEFEFFFEFEFFFCFFFFF6FEFFF6FCFC
FFFDFFF7F0F3AEA9A95D5B5A131313383838898989DADADAFFFFFFFFFFFF
FBFBFBFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFEFEFEF4545458E8E8E
FCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFFC3C3C32E2E2EFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFFC2C3C3151515DBDBDBBCBCBC444444FCFAF9FFFEFD
F7F5F64341424C4C4CF8F8F8F1F0F3FFFEFFFEFFFFFEFFFFFFFFFBFFFFFD
FCFFFFFCFFFFFEFFFFFFFFFDFFFDFDFFFDFB94908D767475FFFEFFF8F8FE
FCFFFFFBFFFFFCFFFFFDFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEF9F9F9
F9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFF
FBFCFEFDFEFFFDFEFFFFFFFFFFFFFFFFFEFDFFFEFDFCFAF9FFFFFDFFFEFD
FFFDFD9B9698B7BBBCFBFFFFF9FCFFFEFFFFF9F9FFFCFFFFF9FFFFFBFFFF
FFFDFFFFFCFFFFFEFDFFFFFDF4F4F4BDBDBD6969691212123131317B7B7B
D2D2D2FFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FBFBFB353535686868FFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFF8F8F8
FBFBFBFFFFFF717171858585FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9FAFAFDFEFE9B9B9B292929D9D9D9191919FFFEFDE0DEDD
2A2829706E6FFCFCFCFEFEFEFFFEFFFEFDFFF8F9FBFEFEFCFFFFFAFFFFFB
FCFFFFFBFFFFFCFFFFFEFFFFFFFDFFFFFDFDE4D7CE190E08F1F1F9F8FFFF
F5FFFFF6FDFFFFFFFFFFFEFDFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF7F7F7FFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFFFFF7F7F7FCFAF9FFFEFBFFFBF8F5F4F0FCFDFDF8F9F9
FFFAFCDEDCDF6B7171F5FDFDFEFFFFFAF9FCFFFEFFFDFEFFF8FEFEFCFFFF
FFFBFDFDF6F9F9F7F8FCFCFCFFFFFFFBFBFBFCFCFCFFFFFFC6C6C6727272
2020201F1F1F757575CACACAF8F8F8FFFFFFBDBDBD7C7C7CFFFFFFFAFAFA
FFFFFFF6F6F6FBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFF181818DADADAFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF646464414141090909DCDCDC1C1C1C
8F8F8FFFFFFFF9F9F9FFFFFFF8F8F8FFFFFFFFFFFFFDFDFBFFFFFAFFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF5FFFFFCFFFFFFEBE13A1D17DEE0EAE9FCFF
F0FFFFF3FFFFFFFBF8FFFCF9FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFF000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFEFDFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FCFDFFF7F7F7FFFFFFFFFEFDFCF8F5FFFDFA9A949114100DCCD0D1FAFFFF
FFFEFFFCFBFF545A5AF3FBFBFEFFFFFFFDFEFCFAFBFEFEFEFCFFFFFCFFFF
FFFDFFFFFDFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF6F6F6FAFAFAFFFFFF
F9F9F9D1D1D17878782A2A2A1B1B1B6D6D6DA0A0A0FFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFF8F8F8FBFBFBFBFBFBFFFFFFFDFDFDFFFFFF8F8F8F
666666D4D4D41C1C1CFDFDFDFEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFAFAFAFBFBFBFFFFFF444444080808585858ADADAD
FEFEFEFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFDFFFFF8FFFFFB
FEFEFFFEFEFFFFFEFFFEFFFFF4FFFFFCFFFFFFF1E733140F9FA1ABEEFFFF
F0FFFFF4FFFFFCF8F5FFFDF8FFFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFFFFFF
F8F8F8000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFFFFFAF8F7FFFCF9FFFDFAFFFCF7B5ACA5494541B1B6B9F7FFFF
F7FAFFD2D2D8171F21C6CCCCFBFBFBFFFDFDFFFDFDFFFEFDFCFFFDF8FCFB
FDF8FAFFFCFEFEFFFFFAFEFFFCFDFDFBFBFBFFFFFFFEFEFEFBFBFBF8F8F8
FFFFFFFEFEFEFFFFFFCDCDCDDADADA8C8C8C3737370B0B0B616161B1B1B1
EEEEEEFFFFFFFBFBFBFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEF6F6F6B4B4B4
5353538585856F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF1F1F10B0B0B666666FDFDFD
FFFFFFFFFFFFF8F8F8FCFCFCFCFCFCFEFEFEFFFFFDF8F8F4FFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFEFFFFFCFFFFFFFEFFEBD7CEB7A39EABADB7F1FDFF
F4FFFFF8FFFFFFFFFBFDF7F4FFFEFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFA070707FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFFFCF9FDF5F0FFFDF6F7ECE4110B08EDF4F8F6FFFF
FBFFFFFBFEFFF7FFFFF4FAF8FEFEFCFFFEFBFFFDFBFFFDFAFCFEFBFEFFFD
FFFDFFFFFEFFFCFFFFFAFEFFFCFDFDFFFFFFF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDA7A7A7535353FBFBFBFFFFFFFBFBFBE3E3E39E9E9E3E3E3E
0F0F0F5858589F9F9FEAEAEAFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFCBCBCB
2F2F2F2F2F2FC1C1C1F9F9F9FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FCFCFCFEFEFEFEFEFEFCFCFC4F4F4F060606CACACA
FAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFDFFFFFBFFFFFAFFFFFB
FEFEFFFCFFFFFEFFFFFFFEFFFFFEFFFFFCFFFFFBF6FFFBFAFEFEFFF8FFFF
F2FBFEF9FFFFFCFCFAFFFFFBFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEF8F8F8FFFFFF
FFFFFF000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFDFFFEFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FFFFFFFDFBFAFFFBF8FFFDFAFFFDF6FFFBF3FFFAF22C2623BDC7CCF4FFFF
F4FAFFFBFFFFF2FBFDF9FFFFFFFEFDFFFDFBFFFDFBFFFEFAFEFFFBFEFFFD
FFFBFDFAF8F9FBFFFFFBFFFFFCFDFDFFFFFFFFFFFFEFEFEFFFFFFFFEFEFE
FCFCFC8E8E8E191919EBEBEBFFFFFFF6F6F6FFFFFFFFFFFFFDFDFDFFFFFF
E9E9E9A0A0A05454540404044C4C4C919191E1E1E1FFFFFFFEFEFEF1F1F1
070707111111FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFF0F0F0FFFEFF84838658595B17181A
E8E9E9FDFEFEF6F6F6FFFFFFFFFFFDFFFFFDFBF9F8FCFCF8FFFFFAFFFFFD
FEFFFFFFFEFFFFFEFFFFFEFFFFFFFFFFFEFFFFFBFDFFF9FDFCFBFFFBFFFF
F4FAFAF8FEFAFEFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFEFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FCFCFC050505FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFF
FEFEFEFFFEFDFFFEFBFEF9F3FFFEF6FFF9F0FFFDF394908C747D82F3FFFF
F9FFFFF9FDFFF9FFFFFBFFFFFFFEFDFFFEFBFFFDFBFFFEFBFEFEFAFDFFFC
FFFEFFFFFEFFFCFFFFF9FDFEFEFFFFF5F5F5FFFFFFFFFFFFFBFBFBFDFDFD
E2E2E2272727E5E5E5FBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFF3F3F3AAAAAA5E5E5E0D0D0D3C3C3C8D8D8DE4E4E4
0E0E0E515151FEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFF7F5F6FFFFFFFFFFFFFAF9FC99989B5C5D5FB3B4B6
717272FCFDFDFFFFFFFFFFFFFDFDFBFFFFFDFFFEFDFFFFFDFFFFFBFEFFFD
FFFEFFFFFEFFFFFEFFFFFEFFFFFFFDFFFEFFFFFCFFFFFAFFFFFEFFF9FDFE
FCFFFDFCFFFDFAFBFBFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFBF8FFFFF8FFFDF5FFFEF4FFF9EEDDD9D50F0F17F8FAFF
FBFAFFFEFEFFFDFDFFFEFFFFFAFAFAFFFEFDFFFDFCFFFEFDFFFFFDFFFFFD
FFFFFFD2D2D2A7A8AAFEFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB
CFCFCFEEEEEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFF1F1F1B9B9B96464643B3B3B
0D0D0D8B8B8BFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFBEBEBE444444FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFFFF
FEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFDFFFEFBFFFEFAFCF9F0FFFDF2FFFEF4FAF6F2221F26DDDBE8
FFFDFFFFFDFFFDFCFFFFFEFFFFFEFFFEFEFEFFFFFDFFFFFDF7F7F5FCFCFA
FFFFFFECECEC141316F9F8FBFFFFFFFFFFFFFBFBFBF7F7F7FCFCFCFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFDFDFDF7F7F7
010101A1A1A1FFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFBFBFBD5D5D5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFDFEFFFEFDFFFEFBFFFEFAFFFCF5FFFFF6FFFFF4F3EFEB1F1C239F9DAA
FEFCFFFFFDFFFDFCFFFEFDFFFFFEFFFFFFFFFFFFFDFCFCFAFFFFFDFFFFFD
FFFFFFFBFBFB2E2D30C0BFC2FAFAFAF9F9F9EFEFEF5F5F5FFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFEFEFEFFFFFFFBFBFBF9F9F9FFFFFFFFFFFFFFFFFFA5A5A5
2121218A8A8AFCFCFCFFFFFFF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFFFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFEFCFDFDF8F8FFFEFBFFFEFAFFFFF8FDFAF1E5E4DFA29FA6C2C0CB
FCFAFFFDFCFFFFFEFFFEFDFFFEFEFEFDFDFDFAFAF8FAFAF8FFFFFDFAFAF8
FAFAFAFFFFFF7C7B7E79787BFFFFFFD8D8D82828289E9E9EFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFBFBFB606060
555555696969FFFFFFF9F9F9FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFDFEFFFEFDFFFDFAFFFCF8FFFEFAFAF9F5FFFDFFFDFCFF
FFFEFFFFFEFFFFFEFFFDFDFDFEFEFEFFFFFDFFFFFDFFFFFDFFFFFDFFFFFD
FFFFFFFBFAFDC3C2C5343336EDEDED1C1C1C999999FEFEFEFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC131313
959595525252FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFEFFFFFEFFFFFEFF
FDFBFEFFFEFFFFFEFFFFFEFFFFFDFDFFFBF8FFFEFBFFFEFDF7F6F9FFFEFF
FCFBFFFFFEFFFFFFFFFEFEFEFEFEFCFFFFFDFFFFFDF5F5F3FFFFFDFFFFFF
FCFBFEFFFEFFFFFEFF0B0A0D858585BABABAFFFFFFFFFFFFFFFFFFFAFAFA
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFBFBFBFAFAFAFEFEFEC5C5C54A4A4A
E5E5E5717171F4F4F4FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FDFCFFFFFEFFFCFAFDFFFEFFFFFEFFFEFCFBFFFDFCFDFBFCFFFFFFFFFEFF
FAF9FCFFFFFFFFFFFFFFFFFDFFFFFDFBFBF9FEFEFCFFFFFDFFFFFFFCFCFC
F7F6F9FFFEFFFFFEFF535255191919A2A2A2FBFBFBFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF666666888888
FEFEFEFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFEFFFDFEFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFEFCFFFFFEFFFFFEFFFDFBFCFFFDFEFFFEFFFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFCFCFCFAFCFCFAFFFFFDFFFFFDFFFFFDFEFEFEFFFFFF
FFFEFF9D9C9FFEFDFF98979A4C4C4C181818A7A7A7FFFFFFFFFFFFFBFBFB
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFEFEFEFBFBFBFDFDFDFDFDFDF9F9F90F0F0FE7E7E7
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFEFEFCFFFFFDFFFFFFF5F5F5
727174535255FFFEFFDFDEE1171717D6D6D6171717999999FFFFFFFEFEFE
FAFAFAFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFAFAFAFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFADADAD414141FFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFFFDFEFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDFFFFFDF9F9F7FEFEFE606060
3C3B3EEFEEF1FEFDFFFFFEFF252525C7C7C7E5E5E51D1D1D979797FBFBFB
FFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFCFCFC989898BDBDBDFFFFFF
F9F9F9FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFDCDCDC4C4C4C
F9F9F9FFFFFFFFFFFFFCFCFCA2A2A2B0B0B0FCFCFCE0E0E0242424676767
F6F6F6FFFFFFFCFCFCFDFDFDFFFFFFF7F7F7F8F8F8FCFCFCFFFFFFFFFFFF
FCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFD
FFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFEFEFEFCFCFC
FFFFFFF8F8F8FAFAFAFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFEBEBEB646464
1F1F1FD0D0D0FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFF8F8F8FCFCFCFEFEFE
FFFFFFFDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFEFDFFFFFEFFFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFFBFBFBFCFCFCFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF
A3A3A3181818949494F8F8F8FFFFFFFCFCFCFCFCFCFBFBFBFFFFFFFFFFFF
FCFCFCFDFDFDFDFDFDFFFFFFFFFFFFF8F8F8FEFEFEFFFFFFFAFAFAFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFEFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFF7F6F9FFFFFFF9F9F9
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FAFAFAFFFFFFFCFCFCFDFDFD
FEFEFED8D8D83131315C5C5CDCDCDCFFFFFFFFFFFFFFFFFFF7F7F7FDFDFD
FDFDFDFFFFFFA2A2A2CECECEFFFFFFEFEFEF696969F8F8F8FFFFFFFFFFFF
F8F8F8FFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFFFEFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFFFAFAFAFFFFFFFAFAFAFCFCFCFFFFFF
FDFDFDFFFFFFFEFEFE7474741313136C6C6CEAEAEAFDFDFDFFFFFFFCFCFC
FFFFFFFCFCFCBEBEBE2B2B2BFDFDFD898989666666FFFFFFFFFFFFFBFBFB
FDFDFDFFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFFFFFFFEFFFDFEFFFDFEFFFDFFFEFFFFFDFFFFFEFFFFFFFF
FFFFFFFEFFFDFEFFFDFFFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFDFEFFFD
FEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFDFCFFFEFDFFFFFEFFFCFCFC
FDFCFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFF9F8FBFFFFFFFCFCF8FDFEF8
FFFFFBF9F9F9FCFDFFFEFFFFE8E6E9716F72121315808181F5F5F5FEFEFC
FAFAFAFFFFFFFBFBFB292929C1C1C1323232BFBFBFFEFEFEFEFEFEFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFCFFFBFBFFF8FCFFFBFFFCFFFFFBFFFCF9FFFFFFFF
F8FAF7F9FEF8FCFFF8FEFFFAFFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFDFF
FFFEFFFFFEFFFFFFFDFFFFFBFEFFFBFEFFFDFEFFFFF9FAFCFBFCFEFEFFFF
FBFCFFFEFFFFFCFBFEFEFEFEFEFCFDFFFEFFFBFBFFFEFFFFFEFEF1FDFEEC
FFFFF6FEFFFDF9FDFFFCFEFFFFFCFFFFF9FFD8DDE15159591A1A188D8C88
E5E5E3FFFFFFFFFFFF9696963D3D3D202020F9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFFFDFFFEFFFFFBFFFBF9FFF8FBFFFBFFFCFFFFFBFFFFFCFFFFFFFF
FEFFFDFCFFFBFBFFF7F4F6F0FFFCFFFFFBFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFEFFFFFEFFFFFEFFFFFEFFFF
F7F8FCFFFEFFFFFEFFFFFEFFFFFDFDF9F7F8FBFEFFFCFFFFF9F9EDEBECDA
0B0C02414542293038F1F3FFFEF8FFFFFCFFFBFFFFF9FFFFCDCDCD605E5D
0F0F0F4A4A4AA4A4A4EFEFEF101010CFCFCFFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFEFFFEFFFFFCFFFFFBFFFDFCFFFDFFFEFFFFFDFFFFFEFDF9F9F7
F7F8F8FCFFFFFCFFFDFEFFFDFFFEFFFFFBFDFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFDFCFFFFFEFF
FDFCFFFFFEFFFFFEFDFCFBF7F1EDE99C9A999B9EA5A5A8AFFFFEFFFFFFFA
DFE4DD9FA5A1E8EAF4FCFCFFFCFBFEFFFFFDF9FDFCFCFFFFFFFEFFFDFCFF
FAF9FC9D9D9D4C4C4C0F0F0F383838717171FFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFEFFFFFCFFFFFCFFFFFEFFFFFFFEFFFFFDFFFFFEFDFFFEFD
FEFFFFFEFFFFF8FCF9FEFFFDFFFEFFFFFEFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFBFAFDFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFDE3E1E2101115D5D5DBFFFDFFFDFCFF
F7FBF8DADEDD8E8E96F9F9FFFEFFFFFBFDFAF7F8FAFEFFFFF8F9FDFFFEFF
FFFEFFFDFDFDFFFFFFE2E2E2919191141414EEEEEEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFDFFFFFEFFFEFFFBFCFFFAFCFFFBFEFFFDFFFEFFFFFDFFFCF6FDFFFEFF
FDFFFAF8FDF6FEFFFAFEFFFBFDFBFEFFFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFCF8F5FFFFF8FFFDFDFBF7FFFEFAFF706C69A09F9BFDFDFFFCFFFF
FFFEFFFFFFFFC4C7CC95989DFDFEFEFEFFFFFBFBFFFEFEFFFEFFFDFEFFFB
F5F5F3FFFFFFFFFFFFEEEEEEF6F6F6515151969696FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFEFFFFFEFFFFFFF8FFFFF6FFFFF8FFFFFBFEFFFFFEFEFFFFFDFFFFFEFF
FFFFFAFFFFF4FFFFF6FFFFFBF8F9FDFEFEFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFEFDFFFFFEFFFFFEFFFDFBFC
FFFDFAFFFEFAFFFDF5DAD5D500000E2621318D858266615BF5FCFFF9FFFF
EBE6E8FBF6F6E7ECF03B4248F7F8FCF7F6FBFDFBFFFEFEFFFDFFF9FBFEF5
FFFFFDFEFEFEFBFBFB151515E6E6E6C0C0C0272727FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFCFFFFFFFFF6FFFDF3FFFBF6FFFCFAFBFFFFF7FFFFF9FFFFF8F8FE
FFFFF8FFFDF2FEF3EBFFFDFBFBFFFFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFAFEFEF9FB
FFFDFBFFFEF8FFF8EEBBB7B4090818FFFBFF2A1B1E18100EE2EEF8F5FFFF
FFFDFA685E5C00010989929FFFFDFFFFFCFFFEFEFFFAFEFFFEFFFAFFFFF8
FFFFFDFBFBFBB5B5B5393939FDFDFDF8F8F83B3B3BB1B1B1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
F9FFFFFBFFFFFFFEF8FFFCF4FFF9F6FFFBFAF9FFFFF5FFFFF5FCFFFEFFFF
FDFAF390877E1C0E0B352D2BA3ABADF7FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFEFBFFFFFCFFFFFDFF
FFFDFAFFFDF5FFFEF3CDC9C5100F1FFAF5FFFAEAEB070000C7D7E4EEFEFF
FFF7F9FFFBFAEDF7FEF2FFFFFBF8FEFFFCFFF7F8FCF8FCFDFEFFFBFEFFF9
FFFFFDFEFEFE5656569C9C9CFFFFFFFFFFFFCCCCCCA5A5A5FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFAFCF9FEFDF9FFFDFAFFF9FAFFFCFBF9FDFCF9FFFFFFFEFFFFFDFF
FFFEFDF9F8F4AEA5A6DCD5D8E5EBEBF9FFFFFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFDFFFFFBFFFFFDFF
FFFDFAFFFEF6FFF9EEF8F4F011101ED6D2E0FFFBF49289847B8A9FEEFCFF
FFF8FFFFF9FFF7FFFFF4FFFDFFFFF8FFFDFAFEFEFFFCFEFFFEFFFFFFFFFB
FDFDFBFAFAFA5B5B5BF4F4F4FEFEFEFCFCFCFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFBFAFFFEFDFEFFFDFFFEFDFFF9F8FFF8F6FEFFFFFCFDFDFFFCFDFFFAFB
FAFBFBFCFFFFF7F5F68F8D8EE1E5E6F6FAFBFEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFD
FFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFDFFFFFCFFFFFBFFFFFCFE
FFFDFBFFFEF8FFFDF3FFFBF7B4B4BE16121CFFF4ECB6AEAC212B42F5FEFF
FFF7FFFFFBFFF8FFFFF7FFFAFFFFF4FFFFF8FEFEFFFCFFFFFEFFFFFFFFFD
FFFFFFFEFEFEFFFFFFF9F9F9FFFFFFFDFDFDF5F5F5FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFBFEFFFDFFFAFEFDFCFEF9FFFEF8FFFDFAFEFDFFFFFCFFFEEFF4FFFBFD
F9FDFEF6FFFFFEFFFDF8F8F66E6F73F0F1F5FFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFEFFFFFEFFFEFDFFFFFDFFFFFDFE
FFFEFBFFFEFAFFFEF6FFFEFAFFFEFFB1AEB4685F60696269373C50E8EDFF
FFFBFFFDF8F8FBFFFFF9FFFFFEFFF8FFFFF8FFFFFDFEFFFFFEFFFFFEFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FFFDFFFBF9FCFCFDFDFFFFFBFFFAEF524944BFBFC9FAF7FFA3939B100406
E6E9EDF6FEFEDFE0DAFFFFFB7A7D82B6B9C0FEFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFEFFFFFEFFFFFEFFFFFEFF
FFFCFCFFFEFBFFFFF8FFFEFAFFFEFFFFFEFFFEF9FDFFFDFFFEFDFFFAFCFF
FFFFFDFFFFFBFCFFFFFCFFFFFEFFFBFEFFFAFEFFFDFEFFFFFEFFFFFEFFFF
FFFFFFFDFDFDF8F8F8FEFEFEFBFBFBFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
FEFFFFFEFFFFFFFEFFFFFDF8FFF7E9B3A49D474A59F8FEFFA9A2A94C4143
BEBDC2FBFAFDCAC1BA36312B00060EE4EDF8FCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFDFFFFFDFFFFFBFEFFFDFEFFFFFEFFFFFEFFFFFFFEFFFFFEFF
FFFEFFFFFDFCFFFEFAFFFFFBFFFDFFFBF9FCFEFFFFFEFFFFF2F0F1FFFFFF
FCFFFBFAFEFBFEFFFFFEFFFFFEFFFDFEFFFDFEFFFFFEFFFFFEFFFFFFFFFD
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF
F7F6FBFFFEFFFFFEFFFDF7F4FFFBEDEBDCD5000012D4D8EFE6DDE0170D0C
FCFAFFF9F9FFFFFDF5F8F3EDF2F9FFF8FFFFFCFFFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFFFDFFFFFBFFFFFBFEFFFBFEFFFDFDFEFEFEFFFFFFFEFFFFFEFF
FFFEFFFFFEFFFFFEFDFFFFFBFFFEFAFEFDF9F6FAFBF9FDFEFFFFFBFFFFFA
FCFFFBFAFFFCFCFFFFFEFFFFFFFFFBFFFFFBFCFFFFFCFFFFFFFFFFFFFFFF
FAFAFAFFFFFFF1F1F1FFFFFFFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
FFFBFDFBF4F7FBFFFFFBFFFFFFFFF1FFF8F11B162A1B1129FFF2F42D1B19
CFD5E0F4FFFFFBFFFBFFFFFAFDFBFFFEFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFAFEFFFAFEFFFBFDFEFEFDFEFFFEFFFFFEFFFF
FEFFFFFFFEFFFFFEFFFFFFFAFFFEEFFFFFF4F8FBFFF8FAFFFFFEFFF9F8F4
FEFEFCFCFFFFF9FFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FFFEFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFD
FFFBFBFFFAFBFBFFFFF9FFFFFAFAEDFFFEF6776F824A3C51A28D8A2D1E19
B5BDC8F1FFFFF8FFFFF9FBF6FFFCFFFFFCFFFFFEFFFEFEFEFFFFFFFFFFFF
FEFEFE010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFDFFFFFDFF
FFFEFFFFFEFDFFFFFBFFFFFBFEFFFBFEFFFBFEFFFDFEFFFFFEFFFFFEFFFF
FEFFFFFEFFFFFFFEFFFFFFFBFFFFF1FBFBEEFEFEFFFEFEFFFBF9FAFFFFFB
FFFFFDFAFBFBFBFFFFFCFFFDFFFFF6FFFFF4FBFFFAF9FFFFFFFDFFFFFCFF
FCFBFFFEFEFEFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFD
FFFDFAFFFBFBFFFEFFFDFCFFFFFEF2D3CEC45E5A68958E9DC5BDB8040100
C3C9D5F8FFFFF5FBF9FBFDF8FFFEFFFBFAFFFDFCFFFFFFFFFFFFFFFBFBFB
FFFFFF000000FCFCFCFFFFFFFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFEFF
FFFFFFFFFFFFFFFFFDFFFFFDFFFFFDFFFFFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFDFFFFFAFFFFFBFFFEFFFFFEFFFFFFFFFFFFFD
FFFFFFFFFFFFFEFFFFFEFFFFFFFFFBFFFFFBFEFFFDFEFFFFFFFEFFFFFEFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FBFAF6FFFEFDFEFDFFFFFEFFFFFCF1FCF7EFFFFDFFF5F5FFFFFFFAFFFFFB
FBFEFFF1F7FFFEFFFFFFFFFBF7F8F8FEFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFF000000FFFFFFF9F9F9F7F7F7FFFFFFFFFFFFF9F9F9FBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FFFFFBFFFFFDF7F8FAFDFBFCFFFDF6FFFDF8FDFDFFFCFEFFFFFEFBFEFCFB
F9FFFFF5FDFFFEFFFFF8F7F3FFFFFFFEFFFFFDFDFDFFFFFFFEFEFEFFFFFF
F3F3F3000000FFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFCFBFFFFFDFEFFFFFFFEFDFFFCF7A09895C5C5CBF9FCFFFEF9FBCFCDCE
888F97F8FFFFFDFEFFFFFEFDFFFFFFFCFDFFFFFFFFF9F9F9FFFFFFFBFBFB
FFFFFF020202FCFCFCFDFDFDF6F6F6FFFFFFF6F6F6FFFFFFFCFCFCFCFCFC
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFEFDFFFAF8F0EAE8343336FEFFFFFFFDFF28272C
EEF2F9F6FDFFFBFCFFF8F8F8FFFFFFFDFDFDFFFFFFC8C8C8FFFFFFF9F9F9
FDFDFD000000FFFFFFFCFCFCF9F9F9DCDCDCFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEF9F9FFFDFDFFFDFDFFFDFDACA7A9979598939498A4A7AC
FCFFFFFBFEFFFCFFFFFCFFFFFDFDFDFFFFFFF9F9F9000000484848FEFEFE
FEFEFE050505FFFFFFF0F0F0101010696969FCFCFCFFFFFFFDFDFDFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFFFFFFFFFDFBFCF6F4F6F7F7FDFDFDFFFCFB2E25263E4549F6FFFF
FFFEFFFEFBFFF9FEFFFBFFFFFFFFFFFBF9F8FFFFFF959595040404545454
FEFEFE000000D7D7D7141414000000E9E9E9FAFAFAFFFFFFFBFBFBFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FBFFFFFFFFFFFFF7F5FFFDFBFCFFFFFEFFFFFFF6F5F2E8E7E3ECF1F7FFFF
FFFEFFFFFBFFFBFFFFF5FDFFFBFBF9FFFEFBFFFEFDFCFCFC121212000000
3434340606060D0D0D060606707070FDFDFDFFFFFFFBFBFBFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFDFBFCFFFFFEFFFFFFFBFAFFFCFBF8FFFFF7FFFF
FFFEFFFFFDFFFBFFFFF9FFFFFFFEFDFFFEFBFBF9F8FFFFFF9B9B9B080808
121212000000030303030303F0F0F0F9F9F9FFFFFFFFFFFFFDFDFDFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
FCFFFFFEFFFFFFFDFBFFFEFBFEFFFFFFFEFFFFFCFAFFFDFBF9FFFFF8FFFF
FFFFFFFFFEFDFCFFFFFBFFFFFFFEFDFFFEFBFFFEFDF9F9F9EFEFEF030303
0000000000000606063A3A3AFAFAFAFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFFFFFBFFFFFBFFFDFFFFFEFFFFFEFAFFFFFBFEFEFFFCFEFF
FEFFFFFEFFFDFEFFFFFFFEFFFFFEFDFFFFFBFFFFFDFCFCFCFFFFFF434343
000000000000090909A3A3A3FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFDFFFFFDFFFCFFFFFDFFFFFFFAFEFFFBFFFCFFFFFDFF
FCFFFFFBFFFFFFFEFFFFFEFFFFFFFBFFFFFBFAFAF8FFFFFFF5F5F5A0A0A0
0E0E0E010101080808F3F3F3FFFFFFFEFEFEFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFCFFFDFFFFFDFFFCFFFFFCFFFEFFFBFCFFFDFFFCFFFFFCFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFFFBFFFFFBFFFFFDFFFFFFFFFFFFD5D5D5
0A0A0A030303191919FFFFFFFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFCFFFFFCFFFEFFFDFCFFFFFFFCFFFFFDFF
FBFFFFF9FFFFFFFEFFFFFDFFFFFEFBFFFFFBFFFFFDFBFBFBFFFFFFF7F7F7
0A0A0A000000585858FDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFCFFFFFCFFFFFFFFFFFFFDFFFFFDFFFFFFFFFEFFFFFFFDFFFFFEFF
FCFFFFFCFFFFFFFEFFFFFDFFFFFEFBFFFFFBFEFEFCFFFFFFF8F8F8FFFFFF
3232320000009E9E9EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFFFFFEFFFFFEFFFFFFFFFFFFFEFFFFFEFFFFFFFFFFFFFFFFFEFFFFFEFF
FEFFFFFEFFFFFFFFFFFFFEFFFFFEFDFFFEFDFDFDFDFFFFFFFFFFFFFAFAFA
616161010101BDBDBDFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFCFCFC
8D8D8D020202DADADAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
A6A6A6000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6F9F9F9
D0D0D0000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6
FFFFFFFDFDFDFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFF
F7F7F7FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEF9F9F9
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
grestore
%%Trailer
%%EOF
\
\>"], "Graphics",
 Evaluatable->False,
 ImageSize->{373, 274.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"q1", "[", "t_", "]"}], "=", 
   RowBox[{"q1final", "[", "t", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"q2", "[", "t_", "]"}], "=", 
    RowBox[{"q2final", "[", "t", "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"q3", "[", "t_", "]"}], "=", 
    RowBox[{"q3final", "[", "t", "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"q4", "[", "t_", "]"}], "=", 
    RowBox[{"q4final", "[", "t", "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"x", "[", "t_", "]"}], "=", 
   RowBox[{"xfinal", "[", "t", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"y", "[", "t_", "]"}], "=", 
    RowBox[{"yfinal", "[", "t", "]"}]}], ";"}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"tg", "=."}]}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"thick", "=", 
    FractionBox[
     RowBox[{"l1", "+", "l2"}], "10"]}], ";"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xa0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"a", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ya0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{"l3", " ", 
        RowBox[{"a", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xb0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yb0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xc0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yc0", "=", 
    RowBox[{"transform", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H", " ", 
         RowBox[{"n", "[", "2", "]"}]}], "-", 
        RowBox[{"l1", " ", 
         RowBox[{"b", "[", "1", "]"}]}]}], ")"}], ".", 
      RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xd0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yd0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xbl0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ybl0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xbl1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ybl1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"xbu0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", 
  RowBox[{"ybu0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "+", 
       RowBox[{"l2", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", 
  RowBox[{"xbu1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"ybu1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", 
  RowBox[{"xcl0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"ycl0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"xcl1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ycl1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", 
  RowBox[{"xcu0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"ycu0", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", 
  RowBox[{"xcu1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"ycu1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "thick", " ", 
        RowBox[{"c", "[", "1", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"xd1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"yd1", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"xd2", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"yd2", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", 
  RowBox[{"xd3", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"yd3", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"xd4", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "1", "]"}]}], "]"}]}], ";", " ", 
  RowBox[{"yd4", "=", 
   RowBox[{"transform", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"H", " ", 
        RowBox[{"n", "[", "2", "]"}]}], "-", 
       RowBox[{"l1", " ", 
        RowBox[{"b", "[", "1", "]"}]}], "-", 
       RowBox[{"l4", " ", 
        RowBox[{"c", "[", "2", "]"}]}], "-", 
       RowBox[{"d3", " ", 
        RowBox[{"d", "[", "2", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxL", " ", 
        RowBox[{"d", "[", "1", "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "boxH", " ", 
        RowBox[{"d", "[", "2", "]"}]}]}], ")"}], ".", 
     RowBox[{"n", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"xH", "=", 
    RowBox[{"x", "[", "t", "]"}]}], ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"yH", "=", 
    RowBox[{"y", "[", "t", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"tg", "=", "0"}], ",", 
    RowBox[{"tg", "\[LessEqual]", "tf"}], ",", 
    RowBox[{"tg", "+=", 
     FractionBox["tf", "100"]}], ",", 
    RowBox[{"Print", "[", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xb0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
              RowBox[{"yb0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
            FractionBox["thick", "2"]}], "]"}], ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xc0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
              RowBox[{"yc0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
            FractionBox["thick", "2"]}], "]"}], ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xd0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
              RowBox[{"yd0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
            FractionBox["thick", "2"]}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xbl0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ybl0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xbl1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ybl1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xbu0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ybu0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xbu1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ybu1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xcl0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ycl0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xcl1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ycl1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xcu0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ycu0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xcu1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ycu1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd2", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd2", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd3", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd3", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xb0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yb0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xa0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"ya0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd2", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd2", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd3", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd3", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd1", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd4", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xd0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
               RowBox[{"yd0", "/.", "\[InvisibleSpace]", 
                RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}]}], "}"}], "]"}], 
          ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xa0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
              RowBox[{"ya0", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", 
            RowBox[{"1.125`", " ", "rH"}]}], "]"}], ",", 
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"xH", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}], ",", 
              RowBox[{"yH", "/.", "\[InvisibleSpace]", 
               RowBox[{"t", "\[Rule]", "tg"}]}]}], "}"}], ",", "rH"}], "]"}], 
          ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "H"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"H", ",", "0"}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "H"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "H"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}],
         "]"}], ",", 
       RowBox[{"Axes", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"H", "+", "l1", "+", "l2", "+", "l3", "+", 
               RowBox[{"2", " ", "rH"}]}], ")"}]}], ",", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{"H", "+", "l1", "+", "l2", "+", "l3", "+", 
               RowBox[{"2", " ", "rH"}]}], ")"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"0", ",", 
            RowBox[{"1.5`", " ", 
             RowBox[{"(", 
              RowBox[{"H", "+", "l1", "+", "l2", "+", "l3", "+", 
               RowBox[{"2", " ", "rH"}]}], ")"}]}]}], "}"}]}], "}"}]}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"ImageSize", "\[Rule]", "600"}]}], "]"}], "]"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.512440219921205*^9, 3.512440507309638*^9}, {
  3.512441586661553*^9, 3.512441595588304*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660444431189781, 4.622123903134608}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302222155948904`, 14.263938048432697`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302222155948904`, 11.713938048432698`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178353723924876, 4.047590570795374}, {4.312312922859795, 
    13.689404716093463`}}], 
   LineBox[{{-8.142535138454685, 5.196657235473842}, {3.348131508329986, 
    14.838471380771932`}}], 
   LineBox[{{4.58022221559489, 14.263938048432697`}, {4.58022221559489, 
    11.713938048432698`}}], 
   LineBox[{{3.0802222155948904`, 14.263938048432697`}, {3.0802222155948904`, 
    11.713938048432698`}}], 
   LineBox[{{5.33022221559489, 11.213938048432698`}, {5.33022221559489, 
    9.213938048432698}}], 
   LineBox[{{2.3302222155948904`, 9.213938048432698}, {2.3302222155948904`, 
    11.213938048432698`}}], 
   LineBox[{{-7.660444431189781, 4.622123903134608}, {6.7620412951753615`, 
    0.5000000000000018}}], 
   LineBox[{{5.33022221559489, 11.213938048432698`}, {2.3302222155948904`, 
    11.213938048432698`}}], 
   LineBox[{{5.33022221559489, 9.213938048432698}, {2.3302222155948904`, 
    9.213938048432698}}], 
   LineBox[{{5.33022221559489, 11.213938048432698`}, {3.8302222155948904`, 
    11.713938048432698`}}], 
   LineBox[{{2.3302222155948904`, 11.213938048432698`}, {3.8302222155948904`, 
    11.713938048432698`}}], 
   CircleBox[{6.7620412951753615`, 0.5000000000000018}, 0.5625], 
   CircleBox[{6.7620412951753615`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730082754*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660444497140059, 4.622123981731089}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302222485700295`, 14.263938009134456`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830222216103317, 11.713938009134456`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.17835379576989, 4.047590644445584}, {4.312312949940198, 
    13.689404671848951`}}], 
   LineBox[{{-8.142535198510227, 5.196657319016594}, {3.348131547199861, 
    14.838471346419961`}}], 
   LineBox[{{4.5802222485700295`, 14.263937999585423`}, {4.5802222161033175`, 
    11.713937999585424`}}], 
   LineBox[{{3.0802222485700295`, 14.26393801868349}, {3.080222216103317, 
    11.71393801868349}}], 
   LineBox[{{5.330222215776471, 11.213938008153917`}, {5.330222214469088, 
    9.213938008153917}}], 
   LineBox[{{2.330222214469088, 9.213938010114994}, {2.3302222157764714`, 
    11.213938010114994`}}], 
   LineBox[{{-7.660444497140059, 4.622123981731089}, {6.762041206761236, 
    0.49999999999997335`}}], 
   LineBox[{{5.330222215776471, 11.213938008153917`}, {2.3302222157764714`, 
    11.213938010114994`}}], 
   LineBox[{{5.330222214469088, 9.213938008153917}, {2.330222214469088, 
    9.213938010114994}}], 
   LineBox[{{5.330222215776471, 11.213938008153917`}, {3.830222216103317, 
    11.713938009134456`}}], 
   LineBox[{{2.3302222157764714`, 11.213938010114994`}, {3.830222216103317, 
    11.713938009134456`}}], 
   CircleBox[{6.762041206761236, 0.49999999999997335`}, 0.5625], 
   CircleBox[{6.762041206761241, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730094021*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660445135298662, 4.622124742258991}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830222567649331, 14.263937628870506`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302222210230306`, 11.71393762887053}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178354490968086, 4.047591357111592}, {4.312313211979907, 
    13.689404243723107`}}], 
   LineBox[{{-8.142535779629238, 5.19665812740639}, {3.348131923318755, 
    14.838471014017905`}}], 
   LineBox[{{4.580222567649324, 14.263937526921595`}, {4.580222221023024, 
    11.713937526921619`}}], 
   LineBox[{{3.080222567649338, 14.263937730819418`}, {3.080222221023037, 
    11.713937730819442`}}], 
   LineBox[{{5.330222217533512, 11.213937618401976`}, {5.33022220357544, 
    9.213937618401976}}], 
   LineBox[{{2.33022220357544, 9.213937639339084}, {2.3302222175335126`, 
    11.213937639339084`}}], 
   LineBox[{{-7.660445135298662, 4.622124742258991}, {6.76204035123437, 
    0.4999999999999609}}], 
   LineBox[{{5.330222217533512, 11.213937618401976`}, {2.3302222175335126`, 
    11.213937639339084`}}], 
   LineBox[{{5.33022220357544, 9.213937618401976}, {2.33022220357544, 
    9.213937639339084}}], 
   LineBox[{{5.330222217533512, 11.213937618401976`}, {3.8302222210230306`, 
    11.71393762887053}}], 
   LineBox[{{2.3302222175335126`, 11.213937639339084`}, {3.8302222210230306`, 
    11.71393762887053}}], 
   CircleBox[{6.76204035123437, 0.4999999999999609}, 0.5625], 
   CircleBox[{6.762040351234377, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730105728*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660447431030077, 4.622127478206752}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302237155150385`, 14.263936260896624`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830222238721196, 11.713936260897052`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178356991895583, 4.047593920879497}, {4.312314154649532, 
    13.68940270356937}}], 
   LineBox[{{-8.14253787016457, 5.1966610355340075`}, {3.348133276380545, 
    14.83846981822388}}], 
   LineBox[{{4.580223715514913, 14.263935826545495`}, {4.5802222387210705`, 
    11.713935826545923`}}], 
   LineBox[{{3.080223715515164, 14.263936695247754`}, {3.080222238721322, 
    11.713936695248183`}}], 
   LineBox[{{5.330222223854293, 11.213936216296345`}, {5.330222164386682, 
    9.213936216296345}}], 
   LineBox[{{2.330222164386683, 9.21393630549776}, {2.3302222238542942`, 
    11.21393630549776}}], 
   LineBox[{{-7.660447431030077, 4.622127478206752}, {6.762037273534965, 
    0.49999999999996625`}}], 
   LineBox[{{5.330222223854293, 11.213936216296345`}, {2.3302222238542942`, 
    11.21393630549776}}], 
   LineBox[{{5.330222164386682, 9.213936216296345}, {2.330222164386683, 
    9.21393630549776}}], 
   LineBox[{{5.330222223854293, 11.213936216296345`}, {3.830222238721196, 
    11.713936260897052`}}], 
   LineBox[{{2.3302222238542942`, 11.21393630549776}, {3.830222238721196, 
    11.713936260897052`}}], 
   CircleBox[{6.762037273534965, 0.49999999999996625`}, 0.5625], 
   CircleBox[{6.762037273534969, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730116231*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660452946935394, 4.622134051818691}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830226473467697, 14.263932974090656`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830222281243154, 11.713932974094103`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178363000821796, 4.047600080798537}, {4.312316419581295, 
    13.689399003070502`}}], 
   LineBox[{{-8.142542893048992, 5.196668022838844}, {3.348136527354099, 
    14.83846694511081}}], 
   LineBox[{{4.580226473466683, 14.263931741083438`}, {4.580222281242141, 
    11.713931741086883`}}], 
   LineBox[{{3.080226473468711, 14.263934207097874`}, {3.080222281244168, 
    11.713934207101321`}}], 
   LineBox[{{5.330222239040744, 11.213932847486888`}, {5.330222070231121, 
    9.213932847486895}}], 
   LineBox[{{2.330222070231132, 9.213933100701329}, {2.330222239040754, 
    11.213933100701322`}}], 
   LineBox[{{-7.660452946935394, 4.622134051818691}, {6.762029878807074, 
    0.49999999999995914`}}], 
   LineBox[{{5.330222239040744, 11.213932847486888`}, {2.330222239040754, 
    11.213933100701322`}}], 
   LineBox[{{5.330222070231121, 9.213932847486895}, {2.330222070231132, 
    9.213933100701329}}], 
   LineBox[{{5.330222239040744, 11.213932847486888`}, {3.830222281243154, 
    11.713932974094103`}}], 
   LineBox[{{2.330222239040754, 11.213933100701322`}, {3.830222281243154, 
    11.713932974094103`}}], 
   CircleBox[{6.762029878807074, 0.49999999999995914`}, 0.5625], 
   CircleBox[{6.762029878807077, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437301268263`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660465569014102, 4.622149094296801}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830232784507051, 14.2639254528516}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302223785409533`, 11.713925452872832`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178376751086362, 4.047614176620743}, {4.312321602434791, 
    13.689390535175542`}}], 
   LineBox[{{-8.142554386941843, 5.196684011972859}, {3.348143966579311, 
    14.838460370527658`}}], 
   LineBox[{{4.580232784500806, 14.263922392273336`}, {4.5802223785347085`, 
    11.713922392294569`}}], 
   LineBox[{{3.0802327845132957`, 14.263928513429864`}, {3.080222378547198, 
    11.713928513451098`}}], 
   LineBox[{{5.330222273790323, 11.21392513862105}, {5.330221854787934, 
    9.213925138621095}}], 
   LineBox[{{2.3302218547879994`, 9.213925767124678}, {2.3302222737903886`, 
    11.213925767124636`}}], 
   LineBox[{{-7.660465569014102, 4.622149094296801}, {6.762012957382982, 
    0.49999999999962874`}}], 
   LineBox[{{5.330222273790323, 11.21392513862105}, {2.3302222737903886`, 
    11.213925767124636`}}], 
   LineBox[{{5.330221854787934, 9.213925138621095}, {2.3302218547879994`, 
    9.213925767124678}}], 
   LineBox[{{5.330222273790323, 11.21392513862105}, {3.8302223785409533`, 
    11.713925452872832`}}], 
   LineBox[{{2.3302222737903886`, 11.213925767124636`}, {3.8302223785409533`, 
    11.713925452872832`}}], 
   CircleBox[{6.762012957382982, 0.49999999999962874`}, 0.5625], 
   CircleBox[{6.762012957383142, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730137437*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660490374826383, 4.62217865702598}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302451874131913`, 14.263910671487011`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302225697348207`, 11.713910671587318`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178403774103331, 4.047641878914002}, {4.312331788136243, 
    13.689373893375032`}}], 
   LineBox[{{-8.142576975549435, 5.196715435137959}, {3.3481585866901398`, 
    14.83844744959899}}], 
   LineBox[{{4.58024518738369, 14.263904019228667`}, {4.5802225697053185`, 
    11.713904019328973`}}], 
   LineBox[{{3.080245187442693, 14.263917323745355`}, {3.0802225697643224`, 
    11.713917323845662`}}], 
   LineBox[{{5.330222342074807, 11.213909988607794`}, {5.330221431435374, 
    9.213909988608002}}], 
   LineBox[{{2.330221431435685, 9.213911354567152}, {2.3302223420751176`, 
    11.213911354566944`}}], 
   LineBox[{{-7.660490374826383, 4.62217865702598}, {6.761979702090439, 
    0.5000000000001972}}], 
   LineBox[{{5.330222342074807, 11.213909988607794`}, {2.3302223420751176`, 
    11.213911354566944`}}], 
   LineBox[{{5.330221431435374, 9.213909988608002}, {2.330221431435685, 
    9.213911354567152}}], 
   LineBox[{{5.330222342074807, 11.213909988607794`}, {3.8302225697348207`, 
    11.713910671587318`}}], 
   LineBox[{{2.3302223420751176`, 11.213911354566944`}, {3.8302225697348207`, 
    11.713910671587318`}}], 
   CircleBox[{6.761979702090439, 0.5000000000001972}, 0.5625], 
   CircleBox[{6.761979702090331, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730148077*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.66052462633953, 4.622219477203224}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830262313169765, 14.26389026139839}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830222833683925, 11.713890261704003`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178441087129772, 4.047680130227759}, {4.312345852379523, 
    13.689350914422924`}}], 
   LineBox[{{-8.142608165549289, 5.196758824178689}, {3.348178773960007, 
    14.838429608373854`}}], 
   LineBox[{{4.580262313079879, 14.263878649784907`}, {4.580222833594039, 
    11.713878650090521`}}], 
   LineBox[{{3.0802623132596514`, 14.263901873011871`}, {3.080222833773812, 
    11.713901873317486`}}], 
   LineBox[{{5.330222436345406, 11.213889069690026`}, {5.330220846993226, 
    9.213889069690659}}], 
   LineBox[{{2.330220846994173, 9.21389145371893}, {2.3302224363463537`, 
    11.213891453718297`}}], 
   LineBox[{{-7.66052462633953, 4.622219477203224}, {6.761933783438121, 
    0.4999999999999636}}], 
   LineBox[{{5.330222436345406, 11.213889069690026`}, {2.3302224363463537`, 
    11.213891453718297`}}], 
   LineBox[{{5.330220846993226, 9.213889069690659}, {2.330220846994173, 
    9.21389145371893}}], 
   LineBox[{{5.330222436345406, 11.213889069690026`}, {3.830222833683925, 
    11.713890261704003`}}], 
   LineBox[{{2.3302224363463537`, 11.213891453718297`}, {3.830222833683925, 
    11.713890261704003`}}], 
   CircleBox[{6.761933783438121, 0.4999999999999636}, 0.5625], 
   CircleBox[{6.761933783438126, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730158687*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660576014508864, 4.6222807212875665`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830288007254432, 14.263859639356218`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302232295850662`, 11.713859640178992`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178497068605432, 4.0477375201994015`}, {4.312366953157865, 
    13.689316438268053`}}], 
   LineBox[{{-8.142654960412298, 5.1968239223757315`}, {3.3482090613509996`, 
    14.838402840444383`}}], 
   LineBox[{{4.58028800701244, 14.263840587100521`}, {4.580223229343074, 
    11.713840587923297`}}], 
   LineBox[{{3.0802880074964243`, 14.263878691611914`}, {3.0802232298270584`, 
    11.713878692434687`}}], 
   LineBox[{{5.33022257774617, 11.213857684666554`}, {5.330219970395685, 
    9.213857684668252}}], 
   LineBox[{{2.3302199703982343`, 9.213861595693981}, {2.3302225777487195`, 
    11.213861595692281`}}], 
   LineBox[{{-7.660576014508864, 4.6222807212875665`}, {6.761864890376151, 
    0.49999999999995115`}}], 
   LineBox[{{5.33022257774617, 11.213857684666554`}, {2.3302225777487195`, 
    11.213861595692281`}}], 
   LineBox[{{5.330219970395685, 9.213857684668252}, {2.3302199703982343`, 
    9.213861595693981}}], 
   LineBox[{{5.33022257774617, 11.213857684666554`}, {3.8302232295850662`, 
    11.713859640178992`}}], 
   LineBox[{{2.3302225777487195`, 11.213861595692281`}, {3.8302232295850662`, 
    11.713859640178992`}}], 
   CircleBox[{6.761864890376151, 0.49999999999995115`}, 0.5625], 
   CircleBox[{6.761864890376161, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730192514*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660647484536826, 4.622365900452982}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830323742268413, 14.263817049773511`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830223779986463, 11.713817051732816`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178574927070799, 4.04781733911272}, {4.31239629973444, 
    13.68926848843325}}], 
   LineBox[{{-8.142720042002852, 5.196914461793243}, {3.3482511848023866`, 
    14.838365611113773`}}], 
   LineBox[{{4.580323741692147, 14.26378764910235}, {4.580223779410197, 
    11.713787651061654`}}], 
   LineBox[{{3.080323742844679, 14.263846450444673`}, {3.0802237805627293`, 
    11.713846452403978`}}], 
   LineBox[{{5.330222774333644, 11.213814034784473`}, {5.330218751734506, 
    9.213814034788518}}], 
   LineBox[{{2.3302187517405737`, 9.213820068687227}, {2.3302227743397124`, 
    11.213820068683182`}}], 
   LineBox[{{-7.660647484536826, 4.622365900452982}, {6.761769073821393, 
    0.5000000000027693}}], 
   LineBox[{{5.330222774333644, 11.213814034784473`}, {2.3302227743397124`, 
    11.213820068683182`}}], 
   LineBox[{{5.330218751734506, 9.213814034788518}, {2.3302187517405737`, 
    9.213820068687227}}], 
   LineBox[{{5.330222774333644, 11.213814034784473`}, {3.830223779986463, 
    11.713817051732816`}}], 
   LineBox[{{2.3302227743397124`, 11.213820068683182`}, {3.830223779986463, 
    11.713817051732816`}}], 
   CircleBox[{6.761769073821393, 0.5000000000027693}, 0.5625], 
   CircleBox[{6.761769073820074, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437302033854`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660770393995273, 4.622512390483704}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8303851969976366`, 14.26374380475815}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830224725957858, 11.713743809807356`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178708823281551, 4.04795461093406}, {4.312446767711359, 
    13.689186025208503`}}], 
   LineBox[{{-8.142831964708995, 5.197070170033349}, {3.3483236262839142`, 
    14.838301584307793`}}], 
   LineBox[{{4.580385195512576, 14.26369660739351}, {4.580224724472798, 
    11.713696612442716`}}], 
   LineBox[{{3.0803851984826975`, 14.26379100212279}, {3.080224727442919, 
    11.713791007171997`}}], 
   LineBox[{{5.330223112230925, 11.213738968652597`}, {5.330216657354439, 
    9.213738968663012}}], 
   LineBox[{{2.3302166573700642`, 9.21374865097774}, {2.330223112246549, 
    11.213748650967323`}}], 
   LineBox[{{-7.660770393995273, 4.622512390483704}, {6.761604292241151, 
    0.4999999999860334}}], 
   LineBox[{{5.330223112230925, 11.213738968652597`}, {2.330223112246549, 
    11.213748650967323`}}], 
   LineBox[{{5.330216657354439, 9.213738968663012}, {2.3302166573700642`, 
    9.21374865097774}}], 
   LineBox[{{5.330223112230925, 11.213738968652597`}, {3.830224725957858, 
    11.713743809807356`}}], 
   LineBox[{{2.330223112246549, 11.213748650967323`}, {3.830224725957858, 
    11.713743809807356`}}], 
   CircleBox[{6.761604292241151, 0.4999999999860334}, 0.5625], 
   CircleBox[{6.761604292247756, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437302142763`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.660919072224381, 4.622689600709428}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8304595361121905`, 14.263655199645287`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830225869272813, 11.713655210351206`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.178870792277588, 4.048120670292599}, {4.312507816058983, 
    13.689086269228458`}}], 
   LineBox[{{-8.142967352171175, 5.197258531126257}, {3.348411256165398, 
    14.838224130062116`}}], 
   LineBox[{{4.58045953296339, 14.263586474104294`}, {4.580225866124013, 
    11.713586484810214`}}], 
   LineBox[{{3.0804595392609904`, 14.26372392518628}, {3.0802258724216127`, 
    11.713723935892201`}}], 
   LineBox[{{5.330223520633761, 11.213648164489209`}, {5.330214126143745, 
    9.213648164511273}}], 
   LineBox[{{2.3302141261768403`, 9.213662256246298}, {2.3302235206668565`, 
    11.213662256224234`}}], 
   LineBox[{{-7.660919072224381, 4.622689600709428}, {6.761404958812847, 
    0.5000000000038316}}], 
   LineBox[{{5.330223520633761, 11.213648164489209`}, {2.3302235206668565`, 
    11.213662256224234`}}], 
   LineBox[{{5.330214126143745, 9.213648164511273}, {2.3302141261768403`, 
    9.213662256246298}}], 
   LineBox[{{5.330223520633761, 11.213648164489209`}, {3.830225869272813, 
    11.713655210351206`}}], 
   LineBox[{{2.3302235206668565`, 11.213662256224234`}, {3.830225869272813, 
    11.713655210351206`}}], 
   CircleBox[{6.761404958812847, 0.5000000000038316}, 0.5625], 
   CircleBox[{6.76140495881104, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730224964*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.661099333221686, 4.622904465739579}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830549666610843, 14.263547767130213`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302272540264912`, 11.71354778751254}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.179067168152154, 4.048322015747953}, {4.312581831680374, 
    13.688965317138585`}}], 
   LineBox[{{-8.143131498291218, 5.197486915731204}, {3.3485175015413113`, 
    14.838130217121837`}}], 
   LineBox[{{4.5805496606160405`, 14.263452939899521`}, {4.580227248031689, 
    11.713452960281849`}}], 
   LineBox[{{3.0805496726056454`, 14.263642594360904`}, {3.0802272600212937`, 
    11.713642614743232`}}], 
   LineBox[{{5.330224015330166, 11.213538071528452`}, {5.330211060670731, 
    9.213538071570408}}], 
   LineBox[{{2.3302110607336632`, 9.213557503559562}, {2.3302240153930986`, 
    11.213557503517606`}}], 
   LineBox[{{-7.661099333221686, 4.622904465739579}, {6.761163275897029, 
    0.4999999999998863}}], 
   LineBox[{{5.330224015330166, 11.213538071528452`}, {2.3302240153930986`, 
    11.213557503517606`}}], 
   LineBox[{{5.330211060670731, 9.213538071570408}, {2.3302110607336632`, 
    9.213557503559562}}], 
   LineBox[{{5.330224015330166, 11.213538071528452`}, {3.8302272540264912`, 
    11.71354778751254}}], 
   LineBox[{{2.3302240153930986`, 11.213557503517606`}, {3.8302272540264912`, 
    11.71354778751254}}], 
   CircleBox[{6.761163275897029, 0.4999999999998863}, 0.5625], 
   CircleBox[{6.761163275897075, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373023563*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.661328271580244, 4.623177370186316}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830664135790122, 14.263411314906843`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302290104489645`, 11.71341135203117}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.1793165743442175`, 4.048577749817798}, {4.312675833026148, 
    13.688811694538325`}}], 
   LineBox[{{-8.14333996881627, 5.197776990554835}, {3.3486524385540957`, 
    14.838010935275362`}}], 
   LineBox[{{4.580664124871203, 14.263283336865326`}, {4.5802289995300445`, 
    11.713283373989652`}}], 
   LineBox[{{3.0806641467090414`, 14.26353929294836}, {3.0802290213678836`, 
    11.713539330072686`}}], 
   LineBox[{{5.330224642866462, 11.213398249474414`}, {5.3302071727653555`, 
    9.213398249550716}}], 
   LineBox[{{2.330207172879807, 9.213424454702375}, {2.3302246429809137`, 
    11.213424454626075`}}], 
   LineBox[{{-7.661328271580244, 4.623177370186316}, {6.760856319319355, 
    0.49999999999980016`}}], 
   LineBox[{{5.330224642866462, 11.213398249474414`}, {2.3302246429809137`, 
    11.213424454626075`}}], 
   LineBox[{{5.3302071727653555`, 9.213398249550716}, {2.330207172879807, 
    9.213424454702375}}], 
   LineBox[{{5.330224642866462, 11.213398249474414`}, {3.8302290104489645`, 
    11.71341135203117}}], 
   LineBox[{{2.3302246429809137`, 11.213424454626075`}, {3.8302290104489645`, 
    11.71341135203117}}], 
   CircleBox[{6.760856319319355, 0.49999999999980016`}, 0.5625], 
   CircleBox[{6.760856319319445, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730246387*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.66161588274163, 4.623520243140793}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830807941370815, 14.263239878429605`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302312134216026`, 11.713239943648258`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.17962990097719, 4.04889905193517}, {4.3127939231352554`, 
    13.688618687223983`}}], 
   LineBox[{{-8.14360186450607, 5.198141434346415}, {3.3488219596063744`, 
    14.837861069635228`}}], 
   LineBox[{{4.580807922188859, 14.263070252562189`}, {4.580231194239646, 
    11.713070317780844`}}], 
   LineBox[{{3.080807960552772, 14.263409504297021`}, {3.0802312326035595`, 
    11.713409569515674`}}], 
   LineBox[{{5.330225430057222, 11.21322259388958}, {5.3302022970010565`, 
    9.213222594023364}}], 
   LineBox[{{2.3302022972017333`, 9.213257293607613}, {2.3302254302578995`, 
    11.213257293473829`}}], 
   LineBox[{{-7.66161588274163, 4.623520243140793}, {6.760470679341163, 
    0.49999999997587086`}}], 
   LineBox[{{5.330225430057222, 11.21322259388958}, {2.3302254302578995`, 
    11.213257293473829`}}], 
   LineBox[{{5.3302022970010565`, 9.213222594023364}, {2.3302022972017333`, 
    9.213257293607613}}], 
   LineBox[{{5.330225430057222, 11.21322259388958}, {3.8302312134216026`, 
    11.713239943648258`}}], 
   LineBox[{{2.3302254302578995`, 11.213257293473829`}, {3.8302312134216026`, 
    11.713239943648258`}}], 
   CircleBox[{6.760470679341163, 0.49999999997587086`}, 0.5625], 
   CircleBox[{6.760470679352578, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730279807*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.662059750437069, 4.624049457027215}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8310298752185346`, 14.262975271486393`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302346053693057`, 11.712975395497011`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.18011345971411, 4.049394975744435}, {4.312976165941493, 
    13.688320790203614`}}], 
   LineBox[{{-8.144006041160027, 5.198703938309994}, {3.3490835844955757`, 
    14.837629752769173`}}], 
   LineBox[{{4.581029838744824, 14.26274136858956}, {4.5802345688955945`, 
    11.712741492600179`}}], 
   LineBox[{{3.0810299116922457`, 14.263209174383226`}, {3.080234641843017, 
    11.713209298393844`}}], 
   LineBox[{{5.330226642300293, 11.212951506924046`}, {5.330194790785128, 
    9.212951507177674}}], 
   LineBox[{{2.3301947911655727`, 9.212999284450422}, {2.330226642680737, 
    11.212999284196792`}}], 
   LineBox[{{-7.662059750437069, 4.624049457027215}, {6.759875489891772, 
    0.5000000000297513}}], 
   LineBox[{{5.330226642300293, 11.212951506924046`}, {2.330226642680737, 
    11.212999284196792`}}], 
   LineBox[{{5.330194790785128, 9.212951507177674}, {2.3301947911655727`, 
    9.212999284450422}}], 
   LineBox[{{5.330226642300293, 11.212951506924046`}, {3.8302346053693057`, 
    11.712975395497011`}}], 
   LineBox[{{2.330226642680737, 11.212999284196792`}, {3.8302346053693057`, 
    11.712975395497011`}}], 
   CircleBox[{6.759875489891772, 0.5000000000297513}, 0.5625], 
   CircleBox[{6.759875489877691, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437302907352`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.662495837089987, 4.6245694660529875`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8312479185449937`, 14.262715266973508`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830237928584075, 11.712715466989149`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.180588547043961, 4.049882278271239}, {4.31315520859102, 
    13.68802807919176}}], 
   LineBox[{{-8.144403127136012, 5.199256653834736}, {3.3493406284989677`, 
    14.837402454755257`}}], 
   LineBox[{{4.581247859716864, 14.26241821110265}, {4.580237869755946, 
    11.71241841111829}}], 
   LineBox[{{3.081247977373123, 14.263012322844366`}, {3.080237987412204, 
    11.713012522860007`}}], 
   LineBox[{{5.33022783027262, 11.212685173074481`}, {5.330187438250437, 
    9.212685173482361}}], 
   LineBox[{{2.3301874388622563`, 9.212745761515635}, {2.3302278308844384`, 
    11.212745761107755`}}], 
   LineBox[{{-7.662495837089987, 4.6245694660529875`}, {6.759290693007345, 
    0.4999999999992166}}], 
   LineBox[{{5.33022783027262, 11.212685173074481`}, {2.3302278308844384`, 
    11.212745761107755`}}], 
   LineBox[{{5.330187438250437, 9.212685173482361}, {2.3301874388622563`, 
    9.212745761515635}}], 
   LineBox[{{5.33022783027262, 11.212685173074481`}, {3.830237928584075, 
    11.712715466989149`}}], 
   LineBox[{{2.3302278308844384`, 11.212745761107755`}, {3.830237928584075, 
    11.712715466989149`}}], 
   CircleBox[{6.759290693007345, 0.4999999999992166}, 0.5625], 
   CircleBox[{6.759290693007713, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730301421*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.66301934058523, 4.625193809474352}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.831509670292615, 14.262403095262826`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830241905785794, 11.712403410405365`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.181158876295806, 4.05046735893046}, {4.313370134582039, 
    13.687676644718934`}}], 
   LineBox[{{-8.144879804874654, 5.199920260018244}, {3.3496492060031913`, 
    14.837129545806718`}}], 
   LineBox[{{4.581509577603633, 14.262030223349056`}, {4.580241813096812, 
    11.712030538491593`}}], 
   LineBox[{{3.0815097629815966`, 14.262775967176596`}, {3.0802419984747758`, 
    11.712776282319135`}}], 
   LineBox[{{5.330229252366869, 11.212365451749557`}, {5.3301786406123295`, 
    9.212365452389944}}], 
   LineBox[{{2.3301786415729104`, 9.212441370021754}, {2.3302292533274493`, 
    11.212441369381366`}}], 
   LineBox[{{-7.66301934058523, 4.625193809474352}, {6.7585886153351336`, 
    0.49999999999891287`}}], 
   LineBox[{{5.330229252366869, 11.212365451749557`}, {2.3302292533274493`, 
    11.212441369381366`}}], 
   LineBox[{{5.3301786406123295`, 9.212365452389944}, {2.3301786415729104`, 
    9.212441370021754}}], 
   LineBox[{{5.330229252366869, 11.212365451749557`}, {3.830241905785794, 
    11.712403410405365`}}], 
   LineBox[{{2.3302292533274493`, 11.212441369381366`}, {3.830241905785794, 
    11.712403410405365`}}], 
   CircleBox[{6.7585886153351336`, 0.49999999999891287`}, 0.5625], 
   CircleBox[{6.7585886153356425`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730312059*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.663628457810856, 4.625920388053119}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.831814228905428, 14.26203980597344}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830246516667953, 11.712040287879695`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.1818224869148395`, 4.0511482537173045`}, {4.313620199801444, 
    13.687267671637628`}}], 
   LineBox[{{-8.145434428706873, 5.200692522388934}, {3.350008258009412, 
    14.836811940309257`}}], 
   LineBox[{{4.581814087168294, 14.261578714138889`}, {4.5802463749308195`, 
    11.711579196045143`}}], 
   LineBox[{{3.0818143706425616`, 14.262500897807993`}, {3.0802466584050863`, 
    11.712501379714245`}}], 
   LineBox[{{5.330230901474016, 11.211993444735997`}, {5.330168443624002, 
    9.211993445711244}}], 
   LineBox[{{2.330168445086871, 9.212087132486262}, {2.3302309029368846`, 
    11.212087131511016`}}], 
   LineBox[{{-7.663628457810856, 4.625920388053119}, {6.757771645944588, 
    0.5000000001393543}}], 
   LineBox[{{5.330230901474016, 11.211993444735997`}, {2.3302309029368846`, 
    11.212087131511016`}}], 
   LineBox[{{5.330168443624002, 9.211993445711244}, {2.330168445086871, 
    9.212087132486262}}], 
   LineBox[{{5.330230901474016, 11.211993444735997`}, {3.830246516667953, 
    11.712040287879695`}}], 
   LineBox[{{2.3302309029368846`, 11.212087131511016`}, {3.830246516667953, 
    11.712040287879695`}}], 
   CircleBox[{6.757771645944588, 0.5000000001393543}, 0.5625], 
   CircleBox[{6.757771645878635, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730322686*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.664441638555612, 4.626890599625836}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.832220819277806, 14.261554700187084`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302526445009124`, 11.71155545973856}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.18270843352755, 4.052057476734164}, {4.313954024305868, 
    13.686721577295412`}}], 
   LineBox[{{-8.146174843583674, 5.2017237225175075`}, {3.3504876142497437`, 
    14.836387823078756`}}], 
   LineBox[{{4.5822205958803135`, 14.260975825252704`}, {4.5802524211034195`, 
    11.710976584804179`}}], 
   LineBox[{{3.082221042675299, 14.262133575121464`}, {3.0802528678984054`, 
    11.71213433467294}}], 
   LineBox[{{5.3302330943287775`, 11.211496813043802`}, {5.330154898226213, 
    9.21149681457246}}], 
   LineBox[{{2.330154900519199, 9.211614108726307}, {2.330233096621764, 
    11.211614107197649`}}], 
   LineBox[{{-7.664441638555612, 4.626890599625836}, {6.7566808549119735`, 
    0.49999999913698545`}}], 
   LineBox[{{5.3302330943287775`, 11.211496813043802`}, {2.330233096621764, 
    11.211614107197649`}}], 
   LineBox[{{5.330154898226213, 9.21149681457246}, {2.330154900519199, 
    9.211614108726307}}], 
   LineBox[{{5.3302330943287775`, 11.211496813043802`}, {3.8302526445009124`, 
    11.71155545973856}}], 
   LineBox[{{2.330233096621764, 11.211614107197649`}, {3.8302526445009124`, 
    11.71155545973856}}], 
   CircleBox[{6.7566808549119735`, 0.49999999913698545`}, 0.5625], 
   CircleBox[{6.756680855320325, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437303334208`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.665438767357512, 4.628080621504772}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.832719383678756, 14.260959689247615`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302601141429133`, 11.710960875131548`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.183794813970369, 4.053172713952959}, {4.314363337065898, 
    13.686051781695802`}}], 
   LineBox[{{-8.147082720744654, 5.202988529056585}, {3.3510754302916137`, 
    14.835867596799428`}}], 
   LineBox[{{4.582719034889364, 14.26023637467825}, {4.580259765353522, 
    11.710237560562183`}}], 
   LineBox[{{3.082719732468148, 14.26168300381698}, {3.0802604629323054`, 
    11.711684189700915`}}], 
   LineBox[{{5.3302357678180705`, 11.210887842083588`}, {5.330138389630583, 
    9.210887844454216}}], 
   LineBox[{{2.330138393186525, 9.211033911735448}, {2.3302357713740123`, 
    11.21103390936482}}], 
   LineBox[{{-7.665438767357512, 4.628080621504772}, {6.755343124930168, 
    0.5000000003119389}}], 
   LineBox[{{5.3302357678180705`, 11.210887842083588`}, {2.3302357713740123`, 
    11.21103390936482}}], 
   LineBox[{{5.330138389630583, 9.210887844454216}, {2.330138393186525, 
    9.211033911735448}}], 
   LineBox[{{5.3302357678180705`, 11.210887842083588`}, {3.8302601141429133`, 
    11.710960875131548`}}], 
   LineBox[{{2.3302357713740123`, 11.21103390936482}, {3.8302601141429133`, 
    11.710960875131548`}}], 
   CircleBox[{6.755343124930168, 0.5000000003119389}, 0.5625], 
   CircleBox[{6.755343124782515, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730363756*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.666424759995062, 4.629257722090486}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.833212379997531, 14.260371138954758`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302674532292946`, 11.710372839463888`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.184869089151848, 4.054275865090856}, {4.314768050840744, 
    13.685389281955128`}}], 
   LineBox[{{-8.147980430838276, 5.204239579090116}, {3.3516567091543172`, 
    14.835352995954388`}}], 
   LineBox[{{4.583211879847787, 14.259504984022923`}, {4.58026695307955, 
    11.709506684532053`}}], 
   LineBox[{{3.0832128801472747`, 14.261237293886593`}, {3.080267953379039, 
    11.711238994395723`}}], 
   LineBox[{{5.330238396441818, 11.210285677542954`}, {5.330122179421705, 
    9.210285680919553}}], 
   LineBox[{{2.3301221844866045`, 9.21046000644972}, {2.3302384015067164`, 
    11.210460003073122`}}], 
   LineBox[{{-7.666424759995062, 4.629257722090486}, {6.754020124422468, 
    0.4999999999960725}}], 
   LineBox[{{5.330238396441818, 11.210285677542954`}, {2.3302384015067164`, 
    11.210460003073122`}}], 
   LineBox[{{5.330122179421705, 9.210285680919553}, {2.3301221844866045`, 
    9.21046000644972}}], 
   LineBox[{{5.330238396441818, 11.210285677542954`}, {3.8302674532292946`, 
    11.710372839463888`}}], 
   LineBox[{{2.3302384015067164`, 11.210460003073122`}, {3.8302674532292946`, 
    11.710372839463888`}}], 
   CircleBox[{6.754020124422468, 0.4999999999960725}, 0.5625], 
   CircleBox[{6.754020124424287, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730374763*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.667568254158942, 4.630623311581258}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.833784127079471, 14.259688344209373`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302759053924262`, 11.709690757469222`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.186115002527536, 4.055555692519337}, {4.315237378710877, 
    13.684620725147452`}}], 
   LineBox[{{-8.149021505790348, 5.205690930643178}, {3.3523308754480654`, 
    14.834755963271293`}}], 
   LineBox[{{4.5837834172971625`, 14.258656514301418`}, {4.580275195610118, 
    11.708658927561267`}}], 
   LineBox[{{3.0837848368617795`, 14.260720174117328`}, {3.0802766151747347`, 
    11.710722587377177`}}], 
   LineBox[{{5.330241425331349, 11.209587329172276`}, {5.330103519350582, 
    9.209587333926791}}], 
   LineBox[{{2.330103526482355, 9.20979419289794}, {2.3302414324631213`, 
    11.209794188143425`}}], 
   LineBox[{{-7.667568254158942, 4.630623311581258}, {6.752485527217164, 
    0.4999999999949054}}], 
   LineBox[{{5.330241425331349, 11.209587329172276`}, {2.3302414324631213`, 
    11.209794188143425`}}], 
   LineBox[{{5.330103519350582, 9.209587333926791}, {2.330103526482355, 
    9.20979419289794}}], 
   LineBox[{{5.330241425331349, 11.209587329172276`}, {3.8302759053924262`, 
    11.709690757469222`}}], 
   LineBox[{{2.3302414324631213`, 11.209794188143425`}, {3.8302759053924262`, 
    11.709690757469222`}}], 
   CircleBox[{6.752485527217164, 0.4999999999949054}, 0.5625], 
   CircleBox[{6.752485527219541, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730385417*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.668848235945843, 4.632152484358146}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8344241179729215`, 14.258923757820927`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8302852907929634`, 11.708927116625183`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.187509672272704, 4.056988866662207}, {4.315762681646061, 
    13.683760140124988`}}], 
   LineBox[{{-8.150186799618982, 5.207316102054085}, {3.353085554299782, 
    14.834087375516866`}}], 
   LineBox[{{4.584423130089316, 14.257706455709174`}, {4.580284302909359, 
    11.70770981451343}}], 
   LineBox[{{3.084425105856526, 14.26014105993268}, {3.080286278676568, 
    11.710144418736936`}}], 
   LineBox[{{5.330244790627576, 11.208805632527671`}, {5.330082809644407, 
    9.208805639087132}}], 
   LineBox[{{2.3300828194835965`, 9.209048610561885}, {2.330244800466766, 
    11.209048604002426`}}], 
   LineBox[{{-7.668848235945843, 4.632152484358146}, {6.750767426461632, 
    0.5000000006696546}}], 
   LineBox[{{5.330244790627576, 11.208805632527671`}, {2.330244800466766, 
    11.209048604002426`}}], 
   LineBox[{{5.330082809644407, 9.208805639087132}, {2.3300828194835965`, 
    9.209048610561885}}], 
   LineBox[{{5.330244790627576, 11.208805632527671`}, {3.8302852907929634`, 
    11.708927116625183`}}], 
   LineBox[{{2.330244800466766, 11.209048604002426`}, {3.8302852907929634`, 
    11.708927116625183`}}], 
   CircleBox[{6.750767426461632, 0.5000000006696546}, 0.5625], 
   CircleBox[{6.750767426144697, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730396043*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.67065749404974, 4.634315031972146}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.83532874702487, 14.257842484013928`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830298421840752, 11.707847445621}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.189481121447651, 4.059015719918416}, {4.316505119626959, 
    13.682543171960198`}}], 
   LineBox[{{-8.15183386665183, 5.2096143440258755`}, {3.354152374422781, 
    14.833141796067657`}}], 
   LineBox[{{4.585327287728672, 14.256362976606834`}, {4.580296962544554, 
    11.706367938213909`}}], 
   LineBox[{{3.085330206321068, 14.259321991421022`}, {3.08029988113695, 
    11.709326953028095`}}], 
   LineBox[{{5.3302495042190845`, 11.207700716678314`}, {5.330053862439195, 
    9.207700726247241}}], 
   LineBox[{{2.3300538767925847`, 9.207994188917077}, {2.3302495185724745`, 
    11.20799417934815}}], 
   LineBox[{{-7.67065749404974, 4.634315031972146}, {6.748338282312307, 
    0.4999999978638998}}], 
   LineBox[{{5.3302495042190845`, 11.207700716678314`}, {2.3302495185724745`, 
    11.20799417934815}}], 
   LineBox[{{5.330053862439195, 9.207700726247241}, {2.3300538767925847`, 
    9.207994188917077}}], 
   LineBox[{{5.3302495042190845`, 11.207700716678314`}, {3.830298421840752, 
    11.707847445621}}], 
   LineBox[{{2.3302495185724745`, 11.20799417934815}, {3.830298421840752, 
    11.707847445621}}], 
   CircleBox[{6.748338282312307, 0.4999999978638998}, 0.5625], 
   CircleBox[{6.748338283323205, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730406756*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.672440470270311, 4.636447378390174}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8362202351351553`, 14.256776310804915`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8303112047231087`, 11.706783157214186`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.1914240236495734`, 4.0610143431199}, {4.317236681755892, 
    13.68134327553464}}], 
   LineBox[{{-8.153456916891047, 5.211880413660448}, {3.355203788514418, 
    14.832209346075189`}}], 
   LineBox[{{4.586218221485369, 14.255038360683724`}, {4.580309191073323, 
    11.705045207092997`}}], 
   LineBox[{{3.0862222487849413`, 14.258514260926106`}, {3.0803132183728943`, 
    11.708521107335375`}}], 
   LineBox[{{5.330254095693228, 11.206611862727785`}, {5.330025698697593, 
    9.206611875769083}}], 
   LineBox[{{2.330025718259539, 9.206954471262533}, {2.330254115255173, 
    11.206954458221237`}}], 
   LineBox[{{-7.672440470270311, 4.636447378390174}, {6.745943734931783, 
    0.5000000003641034}}], 
   LineBox[{{5.330254095693228, 11.206611862727785`}, {2.330254115255173, 
    11.206954458221237`}}], 
   LineBox[{{5.330025698697593, 9.206611875769083}, {2.330025718259539, 
    9.206954471262533}}], 
   LineBox[{{5.330254095693228, 11.206611862727785`}, {3.8303112047231087`, 
    11.706783157214186`}}], 
   LineBox[{{2.330254115255173, 11.206954458221237`}, {3.8303112047231087`, 
    11.706783157214186`}}], 
   CircleBox[{6.745943734931783, 0.5000000003641034}, 0.5625], 
   CircleBox[{6.745943734759417, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730430449*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.674335893258708, 4.638715526710653}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.837167946629354, 14.255642236644675`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8303246242000304`, 11.70565141922236}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.193489557762007, 4.06314033471625}, {4.318014282126055, 
    13.680067044650272`}}], 
   LineBox[{{-8.15518222875541, 5.2142907187050564`}, {3.356321611132653, 
    14.831217428639079`}}], 
   LineBox[{{4.587165245871211, 14.253629494753698`}, {4.580321923441888, 
    11.703638677331384`}}], 
   LineBox[{{3.087170647387497, 14.257654978535653`}, {3.080327324958173, 
    11.707664161113339`}}], 
   LineBox[{{5.330258921871662, 11.205454355388206`}, {5.329996164339331, 
    9.205454372648587}}], 
   LineBox[{{2.3299961902299016`, 9.205848508947083}, {2.330258947762233, 
    11.205848491686703`}}], 
   LineBox[{{-7.674335893258708, 4.638715526710653}, {6.743397416414097, 
    0.49999999998606004`}}], 
   LineBox[{{5.330258921871662, 11.205454355388206`}, {2.330258947762233, 
    11.205848491686703`}}], 
   LineBox[{{5.329996164339331, 9.205454372648587}, {2.3299961902299016`, 
    9.205848508947083}}], 
   LineBox[{{5.330258921871662, 11.205454355388206`}, {3.8303246242000304`, 
    11.70565141922236}}], 
   LineBox[{{2.330258947762233, 11.205848491686703`}, {3.8303246242000304`, 
    11.70565141922236}}], 
   CircleBox[{6.743397416414097, 0.49999999998606004`}, 0.5625], 
   CircleBox[{6.743397416420648, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437304413853`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.676455844642593, 4.641253970919697}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8382279223212965`, 14.254373014540153`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830339424953567, 11.704385216214586`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.1957998924615705`, 4.065519782571503}, {4.318883874502319, 
    13.678638826191957`}}], 
   LineBox[{{-8.157111796823616, 5.216988159267892}, {3.357571970140274, 
    14.830107202888346`}}], 
   LineBox[{{4.588224333593523, 14.252052868255527`}, {4.580335836225792, 
    11.70206506992996}}], 
   LineBox[{{3.0882315110490706`, 14.25669316082478}, {3.080343013681341, 
    11.706705362499212`}}], 
   LineBox[{{5.33026425085531, 11.204159750405793`}, {5.329963622245458, 
    9.204159773000185}}], 
   LineBox[{{2.3299636561370436`, 9.204610715914963}, {2.330264284746897, 
    11.204610693320573`}}], 
   LineBox[{{-7.676455844642593, 4.641253970919697}, {6.740548544245307, 
    0.5000000001051816}}], 
   LineBox[{{5.33026425085531, 11.204159750405793`}, {2.330264284746897, 
    11.204610693320573`}}], 
   LineBox[{{5.329963622245458, 9.204159773000185}, {2.3299636561370436`, 
    9.204610715914963}}], 
   LineBox[{{5.33026425085531, 11.204159750405793`}, {3.830339424953567, 
    11.704385216214586`}}], 
   LineBox[{{2.330264284746897, 11.204610693320573`}, {3.830339424953567, 
    11.704385216214586`}}], 
   CircleBox[{6.740548544245307, 0.5000000001051816}, 0.5625], 
   CircleBox[{6.74054854419547, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730452148*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.678868921109723, 4.64414548304325}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8394344605548616`, 14.252927258478376`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8303560048533236`, 11.702943418991923`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.1984298323379665`, 4.06823031396002}, {4.319873549326618, 
    13.677012089395147`}}], 
   LineBox[{{-8.15930800988148, 5.220060652126479}, {3.3589953717831054`, 
    14.828842427561606`}}], 
   LineBox[{{4.589429707462642, 14.250257124448511`}, {4.580351251761104, 
    11.700273284962059`}}], 
   LineBox[{{3.089439213647081, 14.25559739250824}, {3.080360757945543, 
    11.705613553021788`}}], 
   LineBox[{{5.330270229530098, 11.202686166558466`}, {5.329927216480659, 
    9.202686195972955}}], 
   LineBox[{{2.3299272606023917`, 9.203200715547112}, {2.3302702736518306`, 
    11.203200686132625`}}], 
   LineBox[{{-7.678868921109723, 4.64414548304325}, {6.737304572275006, 
    0.4999999971038944}}], 
   LineBox[{{5.330270229530098, 11.202686166558466`}, {2.3302702736518306`, 
    11.203200686132625`}}], 
   LineBox[{{5.329927216480659, 9.202686195972955}, {2.3299272606023917`, 
    9.203200715547112}}], 
   LineBox[{{5.330270229530098, 11.202686166558466`}, {3.8303560048533236`, 
    11.702943418991923`}}], 
   LineBox[{{2.3302702736518306`, 11.203200686132625`}, {3.8303560048533236`, 
    11.702943418991923`}}], 
   CircleBox[{6.737304572275006, 0.4999999971038944}, 0.5625], 
   CircleBox[{6.737304573645755, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437304807243`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.6821370858157465`, 4.648065152257926}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8410685429078733`, 14.250967423871039`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830378001838957, 11.70098983331624}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.201991972235091, 4.071904870821745}, {4.321213656488529, 
    13.674807142434858`}}], 
   LineBox[{{-8.162282199396403, 5.224225433694107}, {3.360923429327218, 
    14.82712770530722}}], 
   LineBox[{{4.591061951894579, 14.247823147086063`}, {4.580371410825663, 
    11.697845556531266`}}], 
   LineBox[{{3.091075133921168, 14.254111700656015`}, {3.0803845928522517`, 
    11.704134110101215`}}], 
   LineBox[{{5.330278172517724, 11.200690444951828`}, {5.329878974751934, 
    9.200690484791542}}], 
   LineBox[{{2.3298790345115057`, 9.201289281440225}, {2.3302782322772955`, 
    11.201289241600511`}}], 
   LineBox[{{-7.6821370858157465`, 4.648065152257926}, {6.732909064267673, 
    0.5000000019782052}}], 
   LineBox[{{5.330278172517724, 11.200690444951828`}, {2.3302782322772955`, 
    11.201289241600511`}}], 
   LineBox[{{5.329878974751934, 9.200690484791542}, {2.3298790345115057`, 
    9.201289281440225}}], 
   LineBox[{{5.330278172517724, 11.200690444951828`}, {3.830378001838957, 
    11.70098983331624}}], 
   LineBox[{{2.3302782322772955`, 11.201289241600511`}, {3.830378001838957, 
    11.70098983331624}}], 
   CircleBox[{6.732909064267673, 0.5000000019782052}, 0.5625], 
   CircleBox[{6.732909063331189, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437304918747`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.68504917156517, 4.651561188022075}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.842524585782585, 14.249219405988963`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8303971605448646`, 11.69924824427809}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.205166260666826, 4.075182500154687}, {4.322407496680929, 
    13.672840718121575`}}], 
   LineBox[{{-8.164932082463515, 5.227939875889463}, {3.362641674884241, 
    14.825598093856351`}}], 
   LineBox[{{4.592516103932843, 14.245652516213163`}, {4.580388678695122, 
    11.69568135450229}}], 
   LineBox[{{3.092533067632328, 14.252786295764764`}, {3.0804056423946076`, 
    11.702815134053889`}}], 
   LineBox[{{5.330285106328044, 11.198912207104758`}, {5.329837040033318, 
    9.19891225729561}}], 
   LineBox[{{2.329837115319596, 9.199584356737699}, {2.3302851816143217`, 
    11.199584306546848`}}], 
   LineBox[{{-7.68504917156517, 4.651561188022075}, {6.7289905016782114`, 
    0.4999999999669269}}], 
   LineBox[{{5.330285106328044, 11.198912207104758`}, {2.3302851816143217`, 
    11.199584306546848`}}], 
   LineBox[{{5.329837040033318, 9.19891225729561}, {2.329837115319596, 
    9.199584356737699}}], 
   LineBox[{{5.330285106328044, 11.198912207104758`}, {3.8303971605448646`, 
    11.69924824427809}}], 
   LineBox[{{2.3302851816143217`, 11.199584306546848`}, {3.8303971605448646`, 
    11.69924824427809}}], 
   CircleBox[{6.7289905016782114`, 0.4999999999669269}, 0.5625], 
   CircleBox[{6.72899050169384, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730502591*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.688280276549717, 4.655444003746891}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8441401382748586`, 14.247277998126556`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8304179275958106`, 11.697314919779327`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.208688576830734, 4.078822983005662}, {4.323731837993842, 
    13.670656977385327`}}], 
   LineBox[{{-8.1678719762687, 5.2320650244881195`}, {3.3645484385558753`, 
    14.823899018867785`}}], 
   LineBox[{{4.59412927896522, 14.243242053809189`}, {4.580407068286172, 
    11.69327897546196}}], 
   LineBox[{{3.0941509975844967`, 14.251313942443923`}, {3.0804287869054487`, 
    11.701350864096693`}}], 
   LineBox[{{5.330292636800769, 11.196939204254141`}, {5.32979166185253, 
    9.196939266998118}}], 
   LineBox[{{2.3297917559684933`, 9.197690729420476}, {2.3302927309167325`, 
    11.1976906666765}}], 
   LineBox[{{-7.688280276549717, 4.655444003746891}, {6.7246404937658095`, 
    0.4999999999601439}}], 
   LineBox[{{5.330292636800769, 11.196939204254141`}, {2.3302927309167325`, 
    11.1976906666765}}], 
   LineBox[{{5.32979166185253, 9.196939266998118}, {2.3297917559684933`, 
    9.197690729420476}}], 
   LineBox[{{5.330292636800769, 11.196939204254141`}, {3.8304179275958106`, 
    11.697314919779327`}}], 
   LineBox[{{2.3302927309167325`, 11.1976906666765}, {3.8304179275958106`, 
    11.697314919779327`}}], 
   CircleBox[{6.7246404937658095`, 0.4999999999601439}, 0.5625], 
   CircleBox[{6.724640493784658, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730513247*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.69176635466735, 4.659637698439365}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.845883177333675, 14.245181150780319`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8304397527283207`, 11.695227915790221`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.2124891820503025`, 4.082755221839314}, {4.325160349950723, 
    13.668298674180267`}}], 
   LineBox[{{-8.171043527284398, 5.236520175039416}, {3.366606004716627, 
    14.82206362738037}}], 
   LineBox[{{4.595869422918998, 14.240638967072861`}, {4.580425998313643, 
    11.690685732082764`}}], 
   LineBox[{{3.0958969317483525`, 14.249723334487776`}, {3.080453507142998, 
    11.699770099497679`}}], 
   LineBox[{{5.330300567748657, 11.194810554414207`}, {5.329744060105575, 
    9.194810631839399}}], 
   LineBox[{{2.329744176243362, 9.195645393304021}, {2.3303006838864433`, 
    11.19564531587883}}], 
   LineBox[{{-7.69176635466735, 4.659637698439365}, {6.719944656060998, 
    0.5000000046911026}}], 
   LineBox[{{5.330300567748657, 11.194810554414207`}, {2.3303006838864433`, 
    11.19564531587883}}], 
   LineBox[{{5.329744060105575, 9.194810631839399}, {2.329744176243362, 
    9.195645393304021}}], 
   LineBox[{{5.330300567748657, 11.194810554414207`}, {3.8304397527283207`, 
    11.695227915790221`}}], 
   LineBox[{{2.3303006838864433`, 11.19564531587883}, {3.8304397527283207`, 
    11.695227915790221`}}], 
   CircleBox[{6.719944656060998, 0.5000000046911026}, 0.5625], 
   CircleBox[{6.71994465384007, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437305240183`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.696159991975829, 4.664929806344288}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8480799959879146`, 14.242535096827858`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8304664081268562`, 11.692595928627437`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.2172797274516505`, 4.087717806946101}, {4.326960260512093, 
    13.66532309742967}}], 
   LineBox[{{-8.175040256500008, 5.242141805742476}, {3.3691997314637363`, 
    14.819747096226045`}}], 
   LineBox[{{4.598062104282157, 14.2373546298099}, {4.580448516421098, 
    11.687415461609477`}}], 
   LineBox[{{3.098097887693673, 14.247715563845816`}, {3.0804842998326145`, 
    11.697776395645395`}}], 
   LineBox[{{5.33031029293675, 11.192127826548628`}, {5.3296861243661375`, 
    9.192127923945232}}], 
   LineBox[{{2.329686270461043, 9.193064176801151}, {2.3303104390316554`, 
    11.193064079404547`}}], 
   LineBox[{{-7.696159991975829, 4.664929806344288}, {6.7140225020149025`, 
    0.4999999762171159}}], 
   LineBox[{{5.33031029293675, 11.192127826548628`}, {2.3303104390316554`, 
    11.193064079404547`}}], 
   LineBox[{{5.3296861243661375`, 9.192127923945232}, {2.329686270461043, 
    9.193064176801151}}], 
   LineBox[{{5.33031029293675, 11.192127826548628`}, {3.8304664081268562`, 
    11.692595928627437`}}], 
   LineBox[{{2.3303104390316554`, 11.193064079404547`}, {3.8304664081268562`, 
    11.692595928627437`}}], 
   CircleBox[{6.7140225020149025`, 0.4999999762171159}, 0.5625], 
   CircleBox[{6.714022513275866, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730547594*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.701055302950222, 4.670834911925992}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.850527651475111, 14.239582544037006`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830494959608293, 11.68966123324003}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.222617921344671, 4.093255764204725}, {4.328965033080662, 
    13.66200339631574}}], 
   LineBox[{{-8.179492684555772, 5.248414059647258}, {3.37209026986956, 
    14.817161691758272`}}], 
   LineBox[{{4.600504507591869, 14.233690575840884`}, {4.58047181572505, 
    11.683769265043907`}}], 
   LineBox[{{3.100550795358353, 14.245474512233129`}, {3.080518103491535, 
    11.695553201436152`}}], 
   LineBox[{{5.330320726893331, 11.189138838348603`}, {5.3296241599376355`, 
    9.189138959649988}}], 
   LineBox[{{2.3296243418897116`, 9.190183810083532}, {2.3303209088454073`, 
    11.190183688782147`}}], 
   LineBox[{{-7.701055302950222, 4.670834911925992}, {6.707419154694513, 
    0.5000000070898771}}], 
   LineBox[{{5.330320726893331, 11.189138838348603`}, {2.3303209088454073`, 
    11.190183688782147`}}], 
   LineBox[{{5.3296241599376355`, 9.189138959649988}, {2.3296243418897116`, 
    9.190183810083532}}], 
   LineBox[{{5.330320726893331, 11.189138838348603`}, {3.830494959608293, 
    11.68966123324003}}], 
   LineBox[{{2.3303209088454073`, 11.190183688782147`}, {3.830494959608293, 
    11.68966123324003}}], 
   CircleBox[{6.707419154694513, 0.5000000070898771}, 0.5625], 
   CircleBox[{6.707419151336817, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730558717*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.705654917677787, 4.676391737040303}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8528274588388935`, 14.23680413147985}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8305207023081, 11.686901700285066`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.2276342979558095`, 4.098467618214469}, {4.330848078560871, 
    13.658880012654016`}}], 
   LineBox[{{-8.183675537399765, 5.254315855866137}, {3.3748068391169164`, 
    14.814728250305684`}}], 
   LineBox[{{4.602798762131478, 14.2302433207355}, {4.580492005600684, 
    11.680340889540714`}}], 
   LineBox[{{3.1028561555463097`, 14.2433649422242}, {3.080549399015516, 
    11.693462511029416`}}], 
   LineBox[{{5.330330182803703, 11.18633050433437}, {5.329568539861109, 
    9.186330649359368}}], 
   LineBox[{{2.329568757398606, 9.18747311377326}, {2.3303304003412, 
    11.187472968748262`}}], 
   LineBox[{{-7.705654917677787, 4.676391737040303}, {6.701209836948141, 
    0.4999999999163638}}], 
   LineBox[{{5.330330182803703, 11.18633050433437}, {2.3303304003412, 
    11.187472968748262`}}], 
   LineBox[{{5.329568539861109, 9.186330649359368}, {2.329568757398606, 
    9.18747311377326}}], 
   LineBox[{{5.330330182803703, 11.18633050433437}, {3.8305207023081, 
    11.686901700285066`}}], 
   LineBox[{{2.3303304003412, 11.187472968748262`}, {3.8305207023081, 
    11.686901700285066`}}], 
   CircleBox[{6.701209836948141, 0.4999999999163638}, 0.5625], 
   CircleBox[{6.701209836987584, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437305697613`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.71070914670435, 4.682507208097533}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.855354573352175, 14.233746395951234`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8305477619852364`, 11.683867061137565`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.233147187311665, 4.104204022094708}, {4.33291653274486, 
    13.655443209948409`}}], 
   LineBox[{{-8.188271106097035, 5.260810394100359}, {3.37779261395949, 
    14.81204958195406}}], 
   LineBox[{{4.60531908359149, 14.226450274960959`}, {4.580512272224551, 
    11.676570940147288`}}], 
   LineBox[{{3.10539006311286, 14.24104251694151}, {3.0805832517459217`, 
    11.691163182127841`}}], 
   LineBox[{{5.330340162559487, 11.183244693299564`}, {5.329510281383586, 
    9.183244865475263}}], 
   LineBox[{{2.329510539647134, 9.184489687239115}, {2.3303404208230356`, 
    11.184489515063415`}}], 
   LineBox[{{-7.71070914670435, 4.682507208097533}, {6.6943813928719464`, 
    0.49999999990176747`}}], 
   LineBox[{{5.330340162559487, 11.183244693299564`}, {2.3303404208230356`, 
    11.184489515063415`}}], 
   LineBox[{{5.329510281383586, 9.183244865475263}, {2.329510539647134, 
    9.184489687239115}}], 
   LineBox[{{5.330340162559487, 11.183244693299564`}, {3.8305477619852364`, 
    11.683867061137565`}}], 
   LineBox[{{2.3303404208230356`, 11.184489515063415`}, {3.8305477619852364`, 
    11.683867061137565`}}], 
   CircleBox[{6.6943813928719464`, 0.49999999990176747`}, 0.5625], 
   CircleBox[{6.69438139291825, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730597273*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.7160992598332845`, 4.6890399928626945`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8580496299166422`, 14.230480003568655`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830575197562396, 11.680628016576701`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.239027259297987, 4.110332548375197}, {4.33512163045194, 
    13.651772559081156`}}], 
   LineBox[{{-8.193171260368583, 5.267747437350192}, {3.380977629381344, 
    14.80918744805615}}], 
   LineBox[{{4.608006096678982, 14.222399288170347`}, {4.580531664324735, 
    11.672547301178394`}}], 
   LineBox[{{3.108093163154303, 14.238560718966962`}, {3.0806187308000568`, 
    11.688708731975009`}}], 
   LineBox[{{5.3303503284549265`, 11.179953914234375`}, {5.329451458001147, 
    9.179954116226408}}], 
   LineBox[{{2.3294517609891967`, 9.181302421907077}, {2.330350631442976, 
    11.181302219915045`}}], 
   LineBox[{{-7.7160992598332845`, 4.6890399928626945`}, {6.687092887169489, 
    0.5000000101795941}}], 
   LineBox[{{5.3303503284549265`, 11.179953914234375`}, {2.330350631442976, 
    11.181302219915045`}}], 
   LineBox[{{5.329451458001147, 9.179954116226408}, {2.3294517609891967`, 
    9.181302421907077}}], 
   LineBox[{{5.3303503284549265`, 11.179953914234375`}, {3.830575197562396, 
    11.680628016576701`}}], 
   LineBox[{{2.330350631442976, 11.181302219915045`}, {3.830575197562396, 
    11.680628016576701`}}], 
   CircleBox[{6.687092887169489, 0.5000000101795941}, 0.5625], 
   CircleBox[{6.687092882347982, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730608369*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.7233921437967, 4.697896899991357}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.86169607189835, 14.226051550004323`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830609984776512, 11.676241036419547`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.246984411296052, 4.1186424892066045`}, {4.338103804398998, 
    13.64679713921957}}], 
   LineBox[{{-8.199799876297348, 5.27715131077611}, {3.385288339397702, 
    14.805305960789076`}}], 
   LineBox[{{4.611640340599754, 14.216908583203782`}, {4.580554253477916, 
    11.667098069619007`}}], 
   LineBox[{{3.1117518031969458`, 14.235194516804864`}, {3.0806657160751074`, 
    11.685384003220088`}}], 
   LineBox[{{5.330363321550238, 11.175501654269437`}, {5.329377397679597, 
    9.175501897280922}}], 
   LineBox[{{2.329377762196823, 9.176980783086885}, {2.3303636860674644`, 
    11.1769805400754}}], 
   LineBox[{{-7.7233921437967, 4.697896899991357}, {6.677221086184775, 
    0.49999997409113917`}}], 
   LineBox[{{5.330363321550238, 11.175501654269437`}, {2.3303636860674644`, 
    11.1769805400754}}], 
   LineBox[{{5.329377397679597, 9.175501897280922}, {2.329377762196823, 
    9.176980783086885}}], 
   LineBox[{{5.330363321550238, 11.175501654269437`}, {3.830609984776512, 
    11.676241036419547`}}], 
   LineBox[{{2.3303636860674644`, 11.1769805400754}, {3.830609984776512, 
    11.676241036419547`}}], 
   CircleBox[{6.677221086184775, 0.49999997409113917`}, 0.5625], 
   CircleBox[{6.6772210984588725`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730619247*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.730080498515433, 4.706037871608046}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8650402492577167`, 14.221981064195978`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8306394906349186`, 11.672213116361082`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.254283338886037, 4.126281834219389}, {4.340837408887113, 
    13.64222502680732}}], 
   LineBox[{{-8.20587765814483, 5.285793908996704}, {3.3892430896283203`, 
    14.801737101584635`}}], 
   LineBox[{{4.614971998620922, 14.211863194012802`}, {4.5805712399981235`, 
    11.662095246177905`}}], 
   LineBox[{{3.115108499894512, 14.232098934379154`}, {3.080707741271714, 
    11.682330986544258`}}], 
   LineBox[{{5.33037441549536, 11.171418592475439`}, {5.329314956776764, 
    9.171418873088653}}], 
   LineBox[{{2.3293153776965845`, 9.173008061166545}, {2.33037483641518, 
    11.173007780553332`}}], 
   LineBox[{{-7.730080498515433, 4.706037871608046}, {6.668157082812766, 
    0.5000000030637999}}], 
   LineBox[{{5.33037441549536, 11.171418592475439`}, {2.33037483641518, 
    11.173007780553332`}}], 
   LineBox[{{5.329314956776764, 9.171418873088653}, {2.3293153776965845`, 
    9.173008061166545}}], 
   LineBox[{{5.33037441549536, 11.171418592475439`}, {3.8306394906349186`, 
    11.672213116361082`}}], 
   LineBox[{{2.33037483641518, 11.173007780553332`}, {3.8306394906349186`, 
    11.672213116361082`}}], 
   CircleBox[{6.668157082812766, 0.5000000030637999}, 0.5625], 
   CircleBox[{6.668157081360575, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730629994*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.736999232366745, 4.714477694904991}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8684996161833727`, 14.217761152547506`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8306676064261227`, 11.668041807396412`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.2618350594846195`, 4.134202752477485}, {4.3436637890654985`, 
    13.637486210119999`}}], 
   LineBox[{{-8.212163405248871, 5.294752637332497}, {3.393335443301247, 
    14.79803609497501}}], 
   LineBox[{{4.618417070639577, 14.206634090854198`}, {4.580585060882327, 
    11.656914745703103`}}], 
   LineBox[{{3.1185821617271685`, 14.228888214240815`}, {3.0807501519699185`, 
    11.679168869089722`}}], 
   LineBox[{{5.330385096899575, 11.167195075583166`}, {5.329256014913063, 
    9.167195394289724}}], 
   LineBox[{{2.3292564929729007`, 9.168889017269494}, {2.330385574959413, 
    11.168888698562936`}}], 
   LineBox[{{-7.736999232366745, 4.714477694904991}, {6.6587702072144985`, 
    0.4999999998140874}}], 
   LineBox[{{5.330385096899575, 11.167195075583166`}, {2.330385574959413, 
    11.168888698562936`}}], 
   LineBox[{{5.329256014913063, 9.167195394289724}, {2.3292564929729007`, 
    9.168889017269494}}], 
   LineBox[{{5.330385096899575, 11.167195075583166`}, {3.8306676064261227`, 
    11.668041807396412`}}], 
   LineBox[{{2.330385574959413, 11.168888698562936`}, {3.8306676064261227`, 
    11.668041807396412`}}], 
   CircleBox[{6.6587702072144985`, 0.4999999998140874}, 0.5625], 
   CircleBox[{6.65877020730197, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730659635*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.744415001513449, 4.723544729919176}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8722075007567245`, 14.213227635040413`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830694998251269, 11.663565557012085`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.269930856257387, 4.142713604805667}, {4.346691646012786, 
    13.632396509926904`}}], 
   LineBox[{{-8.21889914676951, 5.304375855032685}, {3.3977233555006627`, 
    14.794058760153922`}}], 
   LineBox[{{4.622108111941527, 14.201018075479984`}, {4.580595609436072, 
    11.651355997451656`}}], 
   LineBox[{{3.122306889571922, 14.225437194600842`}, {3.0807943870664665`, 
    11.675775116572513`}}], 
   LineBox[{{5.330395622217265, 11.162668323563942`}, {5.32919919166589, 
    9.162668681425489}}], 
   LineBox[{{2.3291997284582124`, 9.16446332725255}, {2.3303961590095863`, 
    11.164462969391002`}}], 
   LineBox[{{-7.744415001513449, 4.723544729919176}, {6.648696890987246, 
    0.5000000042231099}}], 
   LineBox[{{5.330395622217265, 11.162668323563942`}, {2.3303961590095863`, 
    11.164462969391002`}}], 
   LineBox[{{5.32919919166589, 9.162668681425489}, {2.3291997284582124`, 
    9.16446332725255}}], 
   LineBox[{{5.330395622217265, 11.162668323563942`}, {3.830694998251269, 
    11.663565557012085`}}], 
   LineBox[{{2.3303961590095863`, 11.164462969391002`}, {3.830694998251269, 
    11.663565557012085`}}], 
   CircleBox[{6.648696890987246, 0.5000000042231099}, 0.5625], 
   CircleBox[{6.64869688898548, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373067071*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.752680414584091, 4.733676196605795}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8763402072920456`, 14.208161901697103`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8307221763290906`, 11.658569974495602`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.278956129329526, 4.152225165511989}, {4.350064492546611, 
    13.626710870603297`}}], 
   LineBox[{{-8.226404699838657, 5.315127227699601}, {3.40261592203748, 
    14.78961293279091}}], 
   LineBox[{{4.626220185880722, 14.194744833766823`}, {4.580602154917767, 
    11.645152906565322`}}], 
   LineBox[{{3.126460228703369, 14.221578969627384`}, {3.080842197740414, 
    11.671987042425883`}}], 
   LineBox[{{5.330406244760411, 11.157623176029654`}, {5.329143713973801, 
    9.15762357452569}}], 
   LineBox[{{2.329144311717856, 9.159517370705606}, {2.3304068425044657`, 
    11.15951697220957}}], 
   LineBox[{{-7.752680414584091, 4.733676196605795}, {6.637454590386588, 
    0.4999999526403309}}], 
   LineBox[{{5.330406244760411, 11.157623176029654`}, {2.3304068425044657`, 
    11.15951697220957}}], 
   LineBox[{{5.329143713973801, 9.15762357452569}, {2.329144311717856, 
    9.159517370705606}}], 
   LineBox[{{5.330406244760411, 11.157623176029654`}, {3.8307221763290906`, 
    11.658569974495602`}}], 
   LineBox[{{2.3304068425044657`, 11.15951697220957}, {3.8307221763290906`, 
    11.658569974495602`}}], 
   CircleBox[{6.637454590386588, 0.4999999526403309}, 0.5625], 
   CircleBox[{6.637454612828936, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730681609*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.763225575815438, 4.746641477830643}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.881612787907719, 14.20167926108468}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830751631354641, 11.652186538452572`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.290473686652737, 4.164399559644485}, {4.354364677070421, 
    13.619437342898522`}}], 
   LineBox[{{-8.23597746497814, 5.328883396016801}, {3.4088608987450173`, 
    14.783921179270838`}}], 
   LineBox[{{4.631463588681869, 14.186720097392598`}, {4.58060243212879, 
    11.637227374760489`}}], 
   LineBox[{{3.1317619871335696`, 14.216638424776761`}, {3.0809008305804912`, 
    11.667145702144653`}}], 
   LineBox[{{5.330417990490798, 11.151186726800608`}, {5.329084760162906, 
    9.151187171176435}}], 
   LineBox[{{2.329085426726645, 9.153187016668273}, {2.3304186570545373`, 
    11.153186572292448`}}], 
   LineBox[{{-7.763225575815438, 4.746641477830643}, {6.6230886279248615`, 
    0.5000000247220715}}], 
   LineBox[{{5.330417990490798, 11.151186726800608`}, {2.3304186570545373`, 
    11.153186572292448`}}], 
   LineBox[{{5.329084760162906, 9.151187171176435}, {2.329085426726645, 
    9.153187016668273}}], 
   LineBox[{{5.330417990490798, 11.151186726800608`}, {3.830751631354641, 
    11.652186538452572`}}], 
   LineBox[{{2.3304186570545373`, 11.153186572292448`}, {3.830751631354641, 
    11.652186538452572`}}], 
   CircleBox[{6.6230886279248615`, 0.5000000247220715}, 0.5625], 
   CircleBox[{6.623088616203271, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730692315*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.772333995851792, 4.7578760138625285`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.886166997925896, 14.196061993068737`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830772373122348, 11.646663743374729`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.300424696891481, 4.174950964173643}, {4.358076296886207, 
    13.613136943379851`}}], 
   LineBox[{{-8.244243294812103, 5.340801063551414}, {3.4142576989655855`, 
    14.778987042757622`}}], 
   LineBox[{{4.635990012541781, 14.17976945636181}, {4.580595387738233, 
    11.630371206667803`}}], 
   LineBox[{{3.1363439833100113`, 14.212354529775663`}, {3.0809493585064636`, 
    11.662956280081655`}}], 
   LineBox[{{5.3304265747071184`, 11.145627541420076`}, {5.329044812995443, 
    9.14562801873649}}], 
   LineBox[{{2.329045528970064, 9.147700661304004}, {2.33042729068174, 
    11.14770018398759}}], 
   LineBox[{{-7.772333995851792, 4.7578760138625285`}, {6.6106591504913865`, 
    0.4999999996689235}}], 
   LineBox[{{5.3304265747071184`, 11.145627541420076`}, {2.33042729068174, 
    11.14770018398759}}], 
   LineBox[{{5.329044812995443, 9.14562801873649}, {2.329045528970064, 
    9.147700661304004}}], 
   LineBox[{{5.3304265747071184`, 11.145627541420076`}, {3.830772373122348, 
    11.646663743374729`}}], 
   LineBox[{{2.33042729068174, 11.14770018398759}, {3.830772373122348, 
    11.646663743374729`}}], 
   CircleBox[{6.6106591504913865`, 0.4999999996689235}, 0.5625], 
   CircleBox[{6.6106591506466925`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437307032433`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.782153532152466, 4.7700249680427165`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.891076766076233, 14.189987515978643`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8307897862932, 11.640700266556046`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.31115540475567, 4.186363453131281}, {4.36207489347303, 
    13.606326001067208`}}], 
   LineBox[{{-8.253151659549262, 5.353686482954152}, {3.4200786386794366`, 
    14.773649030890079`}}], 
   LineBox[{{4.640867133553468, 14.172256051336575`}, {4.580580153770435, 
    11.622968801913977`}}], 
   LineBox[{{3.1412863985989983`, 14.207718980620712`}, {3.0809994188159653`, 
    11.658431731198114`}}], 
   LineBox[{{5.330434140336211, 11.13963459083387}, {5.3290130710868056`, 
    9.139635095693386}}], 
   LineBox[{{2.3290138283760804`, 9.141766699567494}, {2.3304348976254863`, 
    11.141766194707978`}}], 
   LineBox[{{-7.782153532152466, 4.7700249680427165`}, {6.597237510902105, 
    0.499999999623685}}], 
   LineBox[{{5.330434140336211, 11.13963459083387}, {2.3304348976254863`, 
    11.141766194707978`}}], 
   LineBox[{{5.3290130710868056`, 9.139635095693386}, {2.3290138283760804`, 
    9.141766699567494}}], 
   LineBox[{{5.330434140336211, 11.13963459083387}, {3.8307897862932, 
    11.640700266556046`}}], 
   LineBox[{{2.3304348976254863`, 11.141766194707978`}, {3.8307897862932, 
    11.640700266556046`}}], 
   CircleBox[{6.597237510902105, 0.499999999623685}, 0.5625], 
   CircleBox[{6.5972375110785, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}], 
   LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730731625*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.792432796183699, 4.782784420736694}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8962163980918496`, 14.183607789631655`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8308024652843793`, 11.634446943903269`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.322391627738951, 4.198351961022916}, {4.366257566536597, 
    13.599175329917877`}}], 
   LineBox[{{-8.262473964628446, 5.367216880450472}, {3.4261752296471015`, 
    14.768040249345432`}}], 
   LineBox[{{4.645969588011964, 14.164368397629458`}, {4.580555655204493, 
    11.615207551901072`}}], 
   LineBox[{{3.146463208171736, 14.202847181633851`}, {3.0810492753642658`, 
    11.653686335905466`}}], 
   LineBox[{{5.330440155111627, 11.133361323225927`}, {5.3289924862297156`, 
    9.133361847162293}}], 
   LineBox[{{2.328993272134265, 9.13553335048516}, {2.3304409410161764`, 
    11.135532826548793`}}], 
   LineBox[{{-7.792432796183699, 4.782784420736694}, {6.583163121240422, 
    0.5000000438460086}}], 
   LineBox[{{5.330440155111627, 11.133361323225927`}, {2.3304409410161764`, 
    11.135532826548793`}}], 
   LineBox[{{5.3289924862297156`, 9.133361847162293}, {2.328993272134265, 
    9.13553335048516}}], 
   LineBox[{{5.330440155111627, 11.133361323225927`}, {3.8308024652843793`, 
    11.634446943903269`}}], 
   LineBox[{{2.3304409410161764`, 11.135532826548793`}, {3.8308024652843793`, 
    11.634446943903269`}}], 
   CircleBox[{6.583163121240422, 0.5000000438460086}, 0.5625], 
   CircleBox[{6.5831631004513875`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437307427263`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.8051865302067425`, 4.798675082138249}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.9025932651033712`, 14.175662458930876`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830810309986291, 11.626673010668162`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.336337161367111, 4.213286092372744}, {4.371442633943003, 
    13.590273469165371`}}], 
   LineBox[{{-8.274035899046375, 5.3840640719037545`}, {3.43374389626374, 
    14.761051448696382`}}], 
   LineBox[{{4.65229604400417, 14.154549825072912`}, {4.5805130888870895`, 
    11.605560376810196`}}], 
   LineBox[{{3.1528904862025726`, 14.19677509278884}, {3.0811075310854923`, 
    11.647785644526126`}}], 
   LineBox[{{5.330445018875291, 11.12557846879467}, {5.328985452182701, 
    9.125579001378473}}], 
   LineBox[{{2.3289862510584065`, 9.127768351417359}, {2.330445817750996, 
    11.127767818833554`}}], 
   LineBox[{{-7.8051865302067425`, 4.798675082138249}, {6.5656655964302795`, 
    0.49999980313284276`}}], 
   LineBox[{{5.330445018875291, 11.12557846879467}, {2.330445817750996, 
    11.127767818833554`}}], 
   LineBox[{{5.328985452182701, 9.125579001378473}, {2.3289862510584065`, 
    9.127768351417359}}], 
   LineBox[{{5.330445018875291, 11.12557846879467}, {3.830810309986291, 
    11.626673010668162`}}], 
   LineBox[{{2.330445817750996, 11.127767818833554`}, {3.830810309986291, 
    11.626673010668162`}}], 
   CircleBox[{6.5656655964302795`, 0.49999980313284276`}, 0.5625], 
   CircleBox[{6.565665689790274, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373075355*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.818631843667754, 4.815499531383082}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.909315921833877, 14.16725023430846}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830808833076554, 11.61845902335868}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.351044308521486, 4.229102143108001}, {4.376903456980146, 
    13.580852846033379`}}], 
   LineBox[{{-8.286219378814023, 5.401896919658164}, {3.4417283866876085`, 
    14.753647622583541`}}], 
   LineBox[{{4.6589603956426355`, 14.144159914085717`}, {4.580453306885313, 
    11.595368703135938`}}], 
   LineBox[{{3.1596714480251182`, 14.190340554531202`}, {3.0811643592677953`, 
    11.64154934358142}}], 
   LineBox[{{5.330446631838123, 11.117373728697626`}, {5.3289993977494845`, 
    9.11737425231932}}], 
   LineBox[{{2.329000183182028, 9.119545103452278}, {2.3304474172706664`, 
    11.119544579830583`}}], 
   LineBox[{{-7.818631843667754, 4.815499531383082}, {6.5471770177788144`, 
    0.5000000520199759}}], 
   LineBox[{{5.330446631838123, 11.117373728697626`}, {2.3304474172706664`, 
    11.119544579830583`}}], 
   LineBox[{{5.3289993977494845`, 9.11737425231932}, {2.329000183182028, 
    9.119545103452278}}], 
   LineBox[{{5.330446631838123, 11.117373728697626`}, {3.830808833076554, 
    11.61845902335868}}], 
   LineBox[{{2.3304474172706664`, 11.119544579830583`}, {3.830808833076554, 
    11.61845902335868}}], 
   CircleBox[{6.5471770177788144`, 0.5000000520199759}, 0.5625], 
   CircleBox[{6.547176993096129, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373076438*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.831083899149802, 4.8311476167642695`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.915541949574901, 14.159426191617866`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830798606023894, 11.610834704987694`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.364669970407123, 4.243816324328034}, {4.381955878317581, 
    13.57209489918163}}], 
   LineBox[{{-8.297497827892482, 5.4184789092005055`}, {3.4491280208322213`, 
    14.746757484054102`}}], 
   LineBox[{{4.665127680936717, 14.134501678808746`}, {4.580384337385709, 
    11.585910192178574`}}], 
   LineBox[{{3.1659562182130854`, 14.184350704426986`}, {3.081212874662078, 
    11.635759217796814`}}], 
   LineBox[{{5.330445161305067, 11.109775617420857`}, {5.329032878337333, 
    9.109776116056715}}], 
   LineBox[{{2.3290336262911184`, 9.111894540508317}, {2.330445909258853, 
    11.111894041872459`}}], 
   LineBox[{{-7.831083899149802, 4.8311476167642695`}, {6.530014955615285, 
    0.4999999993694457}}], 
   LineBox[{{5.330445161305067, 11.109775617420857`}, {2.330445909258853, 
    11.111894041872459`}}], 
   LineBox[{{5.329032878337333, 9.109776116056715}, {2.3290336262911184`, 
    9.111894540508317}}], 
   LineBox[{{5.330445161305067, 11.109775617420857`}, {3.830798606023894, 
    11.610834704987694`}}], 
   LineBox[{{2.330445909258853, 11.111894041872459`}, {3.830798606023894, 
    11.610834704987694`}}], 
   CircleBox[{6.530014955615285, 0.4999999993694457}, 0.5625], 
   CircleBox[{6.530014955909565, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730775296*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.84442745088662, 4.84798758726037}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.92221372544331, 14.151006206369816`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8307780020272757`, 11.60264604570112}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.379276519931148, 4.259655528443874}, {4.387364656398782, 
    13.56267414755332}}], 
   LineBox[{{-8.309578381842092, 5.436319646076866}, {3.457062794487838, 
    14.739338265186312`}}], 
   LineBox[{{4.6717314197576325`, 14.12411334654157}, {4.580295696341598, 
    11.575753185872873`}}], 
   LineBox[{{3.1726960311289876`, 14.177899066198062`}, {3.0812603077129532`, 
    11.629538905529365`}}], 
   LineBox[{{5.330440220876398, 11.101633840903146`}, {5.329090462658478, 
    9.101634296365008}}], 
   LineBox[{{2.3290911458512733`, 9.10365893369189}, {2.330440904069193, 
    11.103658478230026`}}], 
   LineBox[{{-7.84442745088662, 4.84798758726037}, {6.511581880918529, 
    0.49999999929240335`}}], 
   LineBox[{{5.330440220876398, 11.101633840903146`}, {2.330440904069193, 
    11.103658478230026`}}], 
   LineBox[{{5.329090462658478, 9.101634296365008}, {2.3290911458512733`, 
    9.10365893369189}}], 
   LineBox[{{5.330440220876398, 11.101633840903146`}, {3.8307780020272757`, 
    11.60264604570112}}], 
   LineBox[{{2.330440904069193, 11.103658478230026`}, {3.8307780020272757`, 
    11.60264604570112}}], 
   CircleBox[{6.511581880918529, 0.49999999929240335`}, 0.5625], 
   CircleBox[{6.511581881248346, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437307978697`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.858357509124646, 4.86564738563653}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.929178754562323, 14.142176307181735`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8307457230298385`, 11.594076831434503`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.394531063047386, 4.276270572452182}, {4.393005200639584, 
    13.552799493997387`}}], 
   LineBox[{{-8.322183955201906, 5.455024198820878}, {3.4653523084850626`, 
    14.731553120366083`}}], 
   LineBox[{{4.678619776840922, 14.113225415554535`}, {4.580186745308437, 
    11.5651259398073}}], 
   LineBox[{{3.179737732283725, 14.171127198808936`}, {3.0813047007512404`, 
    11.623027723061703`}}], 
   LineBox[{{5.33043128792378, 11.09313451294989}, {5.32917473169982, 
    9.093134907683314}}], 
   LineBox[{{2.3291753237999577`, 9.095019742019254}, {2.330431880023917, 
    11.09501934728583}}], 
   LineBox[{{-7.858357509124646, 4.86564738563653}, {6.492291375638814, 
    0.5000000583507829}}], 
   LineBox[{{5.33043128792378, 11.09313451294989}, {2.330431880023917, 
    11.09501934728583}}], 
   LineBox[{{5.32917473169982, 9.093134907683314}, {2.3291753237999577`, 
    9.095019742019254}}], 
   LineBox[{{5.33043128792378, 11.09313451294989}, {3.8307457230298385`, 
    11.594076831434503`}}], 
   LineBox[{{2.330431880023917, 11.09501934728583}, {3.8307457230298385`, 
    11.594076831434503`}}], 
   CircleBox[{6.492291375638814, 0.5000000583507829}, 0.5625], 
   CircleBox[{6.492291347955758, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437308089333`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.876858652514173, 4.88922912548173}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.9384293262570864`, 14.130385437259136`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830685687010243, 11.582662668156924`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.414800836925303, 4.298464726543168}, {4.400487141845956, 
    13.539621038320574`}}], 
   LineBox[{{-8.338916468103044, 5.479993524420292}, {3.476371510668216, 
    14.721149836197698`}}], 
   LineBox[{{4.6877595524636195`, 14.098696131598299`}, {4.5800159132167755`, 
    11.550973362496087`}}], 
   LineBox[{{3.1890991000505533`, 14.162074742919973`}, {3.0813554608037097`, 
    11.61435197381776}}], 
   LineBox[{{5.330413482417167, 11.081846794123475`}, {5.329325551739798, 
    9.081847090021787}}], 
   LineBox[{{2.329325995587265, 9.083478986037841}, {2.330413926264634, 
    11.083478690139529`}}], 
   LineBox[{{-7.876858652514173, 4.88922912548173}, {6.46659513874585, 
    0.4999998835773507}}], 
   LineBox[{{5.330413482417167, 11.081846794123475`}, {2.330413926264634, 
    11.083478690139529`}}], 
   LineBox[{{5.329325551739798, 9.081847090021787}, {2.329325995587265, 
    9.083478986037841}}], 
   LineBox[{{5.330413482417167, 11.081846794123475`}, {3.830685687010243, 
    11.582662668156924`}}], 
   LineBox[{{2.330413926264634, 11.083478690139529`}, {3.830685687010243, 
    11.582662668156924`}}], 
   CircleBox[{6.46659513874585, 0.4999998835773507}, 0.5625], 
   CircleBox[{6.466595193988823, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730819763*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.893064400170796, 4.910005344077536}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.946532200085398, 14.119997327961233`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8306166650220654`, 11.572633280807592`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.432564800976611, 4.318025514064727}, {4.407031799279583, 
    13.528017497948424`}}], 
   LineBox[{{-8.353563999364981, 5.501985174090345}, {3.486032600891213, 
    14.711977157974042`}}], 
   LineBox[{{4.6957569198364695`, 14.085904523530841`}, {4.579841384773136, 
    11.5385404763772}}], 
   LineBox[{{3.197307480334327, 14.154090132391625`}, {3.0813919452709944`, 
    11.606726085237984`}}], 
   LineBox[{{5.330391988624641, 11.071959755730834`}, {5.329493887973561, 
    9.071959957377038}}], 
   LineBox[{{2.329494190442869, 9.073307108353658}, {2.330392291093949, 
    11.073306906707453`}}], 
   LineBox[{{-7.893064400170796, 4.910005344077536}, {6.444015250704129, 
    0.5000000057056999}}], 
   LineBox[{{5.330391988624641, 11.071959755730834`}, {2.330392291093949, 
    11.073306906707453`}}], 
   LineBox[{{5.329493887973561, 9.071959957377038}, {2.329494190442869, 
    9.073307108353658}}], 
   LineBox[{{5.330391988624641, 11.071959755730834`}, {3.8306166650220654`, 
    11.572633280807592`}}], 
   LineBox[{{2.330392291093949, 11.073306906707453`}, {3.8306166650220654`, 
    11.572633280807592`}}], 
   CircleBox[{6.444015250704129, 0.5000000057056999}, 0.5625], 
   CircleBox[{6.444015247985066, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437308484*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.909722972188278, 4.931480366686968}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.954861486094139, 14.109259816656516`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830529556886595, 11.562292684677871`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.4508339996898005`, 4.338251143772848}, {4.413750458592617, 
    13.516030593742396`}}], 
   LineBox[{{-8.368611944686755, 5.5247095896010885`}, {3.4959725135956616`, 
    14.702489039570636`}}], 
   LineBox[{{4.703969466087859, 14.07269160218371}, {4.579637536880314, 
    11.525724470205063`}}], 
   LineBox[{{3.2057535061004194`, 14.145828031129323`}, {3.0814215768928754`, 
    11.598860899150678`}}], 
   LineBox[{{5.330364185078275, 11.06179684246025}, {5.329703025693802, 
    9.061796951743187}}], 
   LineBox[{{2.329703189618206, 9.062788690819897}, {2.3303643490026786`, 
    11.06278858153696}}], 
   LineBox[{{-7.909722972188278, 4.931480366686968}, {6.4207334667972225`, 
    0.4999999988709236}}], 
   LineBox[{{5.330364185078275, 11.06179684246025}, {2.3303643490026786`, 
    11.06278858153696}}], 
   LineBox[{{5.329703025693802, 9.061796951743187}, {2.329703189618206, 
    9.062788690819897}}], 
   LineBox[{{5.330364185078275, 11.06179684246025}, {3.830529556886595, 
    11.562292684677871`}}], 
   LineBox[{{2.3303643490026786`, 11.06278858153696}, {3.830529556886595, 
    11.562292684677871`}}], 
   CircleBox[{6.4207334667972225`, 0.4999999988709236}, 0.5625], 
   CircleBox[{6.42073346732006, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730859474*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.927151396634051, 4.954077532084025}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.9635756983170256`, 14.097961233957989`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830420581732467, 11.551440133529534`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.469957211540353, 4.359541177336471}, {4.420769883410724, 
    13.503424879210435`}}], 
   LineBox[{{-8.38434558172775, 5.548613886831578}, {3.506381513223327, 
    14.692497588705542`}}], 
   LineBox[{{4.712552492560689, 14.058797964374294`}, {4.57939737597613, 
    11.51227686394584}}], 
   LineBox[{{3.2145989040733625`, 14.137124503541683`}, {3.081443787488803, 
    11.590603403113228`}}], 
   LineBox[{{5.330328680874485, 11.051164515366729`}, {5.329961178735928, 
    9.051164549131185}}], 
   LineBox[{{2.3299612293826115`, 9.051715802339022}, {2.3303287315211696`, 
    11.051715768574566`}}], 
   LineBox[{{-7.927151396634051, 4.954077532084025}, {6.396297688924817, 
    0.5000000413568149}}], 
   LineBox[{{5.330328680874485, 11.051164515366729`}, {2.3303287315211696`, 
    11.051715768574566`}}], 
   LineBox[{{5.329961178735928, 9.051164549131185}, {2.3299612293826115`, 
    9.051715802339022}}], 
   LineBox[{{5.330328680874485, 11.051164515366729`}, {3.830420581732467, 
    11.551440133529534`}}], 
   LineBox[{{2.3303287315211696`, 11.051715768574566`}, {3.830420581732467, 
    11.551440133529534`}}], 
   CircleBox[{6.396297688924817, 0.5000000413568149}, 0.5625], 
   CircleBox[{6.396297669291972, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437308702927`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.946500116007047, 4.979321627173782}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.9732500580035235`, 14.08533918641311}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830277982157197, 11.53935038330965}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.4911992380450805`, 4.383334118473254}, {4.4285509359654895`, 
    13.489351677712582`}}], 
   LineBox[{{-8.401800993969013, 5.57530913587431}, {3.517949180041557, 
    14.681326695113638`}}], 
   LineBox[{{4.722070294210424, 14.043288575870072`}, {4.579098218364098, 
    11.497299772766613`}}], 
   LineBox[{{3.2244298217966234`, 14.127389796956148`}, {3.081457745950297, 
    11.581400993852686`}}], 
   LineBox[{{5.330281584600105, 11.039361190768153`}, {5.330295994527471, 
    9.039361190820063}}], 
   LineBox[{{2.330295994605338, 9.039339575929015}, {2.330281584677972, 
    11.039339575877102`}}], 
   LineBox[{{-7.946500116007047, 4.979321627173782}, {6.369074434812499, 
    0.49999966063378665`}}], 
   LineBox[{{5.330281584600105, 11.039361190768153`}, {2.330281584677972, 
    11.039339575877102`}}], 
   LineBox[{{5.330295994527471, 9.039361190820063}, {2.330295994605338, 
    9.039339575929015}}], 
   LineBox[{{5.330281584600105, 11.039361190768153`}, {3.830277982157197, 
    11.53935038330965}}], 
   LineBox[{{2.330281584677972, 11.039339575877102`}, {3.830277982157197, 
    11.53935038330965}}], 
   CircleBox[{6.369074434812499, 0.49999966063378665`}, 0.5625], 
   CircleBox[{6.369074595787115, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373088124*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.970134067028406, 5.010383873656106}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.985067033514203, 14.069808063171948`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.830072041186729, 11.52452290186813}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.517162857552614, 4.412623818628975}, {4.438038242989995, 
    13.472048008144817`}}], 
   LineBox[{{-8.423105276504199, 5.608143928683236}, {3.532095824038411, 
    14.667568118199078`}}], 
   LineBox[{{4.73368031625062, 14.02422130072269}, {4.578685323923146, 
    11.478936139418872`}}], 
   LineBox[{{3.2364537507777857`, 14.115394825621205`}, {3.081458758450312, 
    11.570109664317386`}}], 
   LineBox[{{5.330212155214606, 11.024943440436388`}, {5.330772847107665, 
    9.024943519030238}}], 
   LineBox[{{2.3307729649984426`, 9.02410248119065}, {2.3302122731053823`, 
    11.024102402596798`}}], 
   LineBox[{{-7.970134067028406, 5.010383873656106}, {6.335684282844264, 
    0.5000001493543254}}], 
   LineBox[{{5.330212155214606, 11.024943440436388`}, {2.3302122731053823`, 
    11.024102402596798`}}], 
   LineBox[{{5.330772847107665, 9.024943519030238}, {2.3307729649984426`, 
    9.02410248119065}}], 
   LineBox[{{5.330212155214606, 11.024943440436388`}, {3.830072041186729, 
    11.52452290186813}}], 
   LineBox[{{2.3302122731053823`, 11.024102402596798`}, {3.830072041186729, 
    11.52452290186813}}], 
   CircleBox[{6.335684282844264, 0.5000001493543254}, 0.5625], 
   CircleBox[{6.33568421192906, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730892282*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-7.990273085677478, 5.037052634830559}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.995136542838739, 14.056473682584722`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8298687453064932`, 11.51183489582169}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.539302033289769, 4.437782153404749}, {4.446107595226447, 
    13.457203201158912`}}], 
   LineBox[{{-8.441244138065185, 5.636323116256369}, {3.5441654904510305`, 
    14.655744164010532`}}], 
   LineBox[{{4.743559715416102, 14.007865506839943`}, {4.578291917883856, 
    11.46322672007691}}], 
   LineBox[{{3.246713370261376, 14.1050818583295}, {3.0814455727291303`, 
    11.560443071566468`}}], 
   LineBox[{{5.330142916085329, 11.012658161093519`}, {5.33124050272306, 
    9.012658462267648}}], 
   LineBox[{{2.3312409544842536`, 9.011012082311053}, {2.3301433678465227`, 
    11.011011781136924`}}], 
   LineBox[{{-7.990273085677478, 5.037052634830559}, {6.307109659879865, 
    0.4999999982569854}}], 
   LineBox[{{5.330142916085329, 11.012658161093519`}, {2.3301433678465227`, 
    11.011011781136924`}}], 
   LineBox[{{5.33124050272306, 9.012658462267648}, {2.3312409544842536`, 
    9.011012082311053}}], 
   LineBox[{{5.330142916085329, 11.012658161093519`}, {3.8298687453064932`, 
    11.51183489582169}}], 
   LineBox[{{2.3301433678465227`, 11.011011781136924`}, {3.8298687453064932`, 
    11.51183489582169}}], 
   CircleBox[{6.307109659879865, 0.4999999982569854}, 0.5625], 
   CircleBox[{6.307109660679695, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730914736*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.011633683760977, 5.065542988939889}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.005816841880488, 14.042228505530057`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8296244320242745`, 11.498322800770335`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.562799407931468, 4.464670462657816}, {4.4546511177099966`, 
    13.441355979247984`}}], 
   LineBox[{{-8.460467959590485, 5.666415515221962}, {3.55698256605098, 
    14.64310103181213}}], 
   LineBox[{{4.754024402103936, 13.990407208513522`}, {4.577831992247722, 
    11.446501503753801`}}], 
   LineBox[{{3.2576092816570403`, 14.094049802546591`}, {3.0814168718008266`, 
    11.550144097786868`}}], 
   LineBox[{{5.330058728343743, 10.99962758079294}, {5.331798182898655, 
    8.99962833721862}}], 
   LineBox[{{2.331799317537176, 8.997019155386251}, {2.330059862982263, 
    10.99701839896057}}], 
   LineBox[{{-8.011633683760977, 5.065542988939889}, {6.276676825133649, 
    0.49999999807763995`}}], 
   LineBox[{{5.330058728343743, 10.99962758079294}, {2.330059862982263, 
    10.99701839896057}}], 
   LineBox[{{5.331798182898655, 8.99962833721862}, {2.331799317537176, 
    8.997019155386251}}], 
   LineBox[{{5.330058728343743, 10.99962758079294}, {3.8296244320242745`, 
    11.498322800770335`}}], 
   LineBox[{{2.330059862982263, 10.99701839896057}, {3.8296244320242745`, 
    11.498322800770335`}}], 
   CircleBox[{6.276676825133649, 0.49999999807763995`}, 0.5625], 
   CircleBox[{6.276676826013451, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730925963*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.033596227796794, 5.095058216176325}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.016798113898397, 14.02747089191184}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.82934181775785, 11.48437039506999}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.586975594010019, 4.492538499091564}, {4.463418747685173, 
    13.42495117482708}}], 
   LineBox[{{-8.48021686158357, 5.697577933261085}, {3.5701774801116213`, 
    14.6299906089966}}], 
   LineBox[{{4.764768848263647, 13.97233668716462}, {4.5773125521231, 
    11.42923619032277}}], 
   LineBox[{{3.268827379533147, 14.082605096659059`}, {3.0813710833926002`, 
    11.539504599817208`}}], 
   LineBox[{{5.329960252534761, 10.986229538275753`}, {5.332438598292441, 
    8.986231073825767}}], 
   LineBox[{{2.3324409016174603`, 8.982513555189247}, {2.32996255585978, 
    10.982512019639232`}}], 
   LineBox[{{-8.033596227796794, 5.095058216176325}, {6.245249735918495, 
    0.5000002247586313}}], 
   LineBox[{{5.329960252534761, 10.986229538275753`}, {2.32996255585978, 
    10.982512019639232`}}], 
   LineBox[{{5.332438598292441, 8.986231073825767}, {2.3324409016174603`, 
    8.982513555189247}}], 
   LineBox[{{5.329960252534761, 10.986229538275753`}, {3.82934181775785, 
    11.48437039506999}}], 
   LineBox[{{2.32996255585978, 10.982512019639232`}, {3.82934181775785, 
    11.48437039506999}}], 
   CircleBox[{6.245249735918495, 0.5000002247586313}, 0.5625], 
   CircleBox[{6.245249629351586, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730936747*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.060712880550186, 5.13181549313201}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.030356440275093, 14.009092253433996`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8289482928571075`, 11.467058666292855`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.616849042535087, 4.527262027090747}, {4.4742202782901925`, 
    13.404538787392733`}}], 
   LineBox[{{-8.504576718565286, 5.736368959173274}, {3.5864926022599937`, 
    14.61364571947526}}], 
   LineBox[{{4.778013377669546, 13.949854563016942`}, {4.576605230251561, 
    11.4078209758758}}], 
   LineBox[{{3.28269950288064, 14.068329943851051`}, {3.081291355462654, 
    11.52629635670991}}], 
   LineBox[{{5.3298220923318365`, 10.969687740272555`}, {5.333326500897368, 
    8.969690810494761}}], 
   LineBox[{{2.333331106230675, 8.964434197646463}, {2.329826697665144, 
    10.964431127424259`}}], 
   LineBox[{{-8.060712880550186, 5.13181549313201}, {6.206251644657771, 
    0.4999990852356788}}], 
   LineBox[{{5.3298220923318365`, 10.969687740272555`}, {2.329826697665144, 
    10.964431127424259`}}], 
   LineBox[{{5.333326500897368, 8.969690810494761}, {2.333331106230675, 
    8.964434197646463}}], 
   LineBox[{{5.3298220923318365`, 10.969687740272555`}, {3.8289482928571075`, 
    11.467058666292855`}}], 
   LineBox[{{2.329826697665144, 10.964431127424259`}, {3.8289482928571075`, 
    11.467058666292855`}}], 
   CircleBox[{6.206251644657771, 0.4999990852356788}, 0.5625], 
   CircleBox[{6.206252078297852, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730965176*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.088070556104308, 5.169259002516898}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.044035278052154, 13.990370498741552`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.828499342974293, 11.449495794886575`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.647014981293075, 4.562653710809076}, {4.485090852863387, 
    13.38376520703373}}], 
   LineBox[{{-8.52912613091554, 5.7758642942247205`}, {3.602979703240921, 
    14.596975790449374`}}], 
   LineBox[{{4.791351367421265, 13.926977576659828`}, {4.575815432343403, 
    11.386102872804852`}}], 
   LineBox[{{3.296719188683043, 14.053763420823275`}, {3.081183253605182, 
    11.512888716968298`}}], 
   LineBox[{{5.329661894032348, 10.952997058432118`}, {5.334328430710221, 
    8.953002502580668}}], 
   LineBox[{{2.334336596933047, 8.94600269756386}, {2.3296700602551743`, 
    10.945997253415308`}}], 
   LineBox[{{-8.088070556104308, 5.169259002516898}, {6.166683823090455, 
    0.5000002188524348}}], 
   LineBox[{{5.329661894032348, 10.952997058432118`}, {2.3296700602551743`, 
    10.945997253415308`}}], 
   LineBox[{{5.334328430710221, 8.953002502580668}, {2.334336596933047, 
    8.94600269756386}}], 
   LineBox[{{5.329661894032348, 10.952997058432118`}, {3.828499342974293, 
    11.449495794886575`}}], 
   LineBox[{{2.3296700602551743`, 10.945997253415308`}, {3.828499342974293, 
    11.449495794886575`}}], 
   CircleBox[{6.166683823090455, 0.5000002188524348}, 0.5625], 
   CircleBox[{6.166683719270692, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437309765787`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.113318815046632, 5.204141824726648}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.056659407523316, 13.972929087636677`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8280381793889733`, 11.43319832748781}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.6748794519011305`, 4.59564291359815}, {4.495098770668818, 
    13.36443017650818}}], 
   LineBox[{{-8.551758178192134, 5.812640735855146}, {3.6182200443778147`, 
    14.581427998765175`}}], 
   LineBox[{{4.803639042861218, 13.905687549950105`}, {4.575017814726875, 
    11.365956789801238`}}], 
   LineBox[{{3.3096797721854143`, 14.040170625323249`}, {3.0810585440510714`, 
    11.500439865174382`}}], 
   LineBox[{{5.329496048414647, 10.937593376401885`}, {5.335353254721808, 
    8.937601953136706}}], 
   LineBox[{{2.335366119824039, 8.928816143675967}, {2.3295089135168796`, 
    10.928807566941146`}}], 
   LineBox[{{-8.113318815046632, 5.204141824726648}, {6.129962045270515, 
    0.49999999713224774`}}], 
   LineBox[{{5.329496048414647, 10.937593376401885`}, {2.3295089135168796`, 
    10.928807566941146`}}], 
   LineBox[{{5.335353254721808, 8.937601953136706}, {2.335366119824039, 
    8.928816143675967}}], 
   LineBox[{{5.329496048414647, 10.937593376401885`}, {3.8280381793889733`, 
    11.43319832748781}}], 
   LineBox[{{2.3295089135168796`, 10.928807566941146`}, {3.8280381793889733`, 
    11.43319832748781}}], 
   CircleBox[{6.129962045270515, 0.49999999713224774`}, 0.5625], 
   CircleBox[{6.129962046565118, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730987533*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.139919755613755, 5.24123882637882}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.069959877806878, 13.954380586810592`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.827502097872276, 11.41593337937271}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.704262667592167, 4.630744844707787}, {4.505616965828466, 
    13.34388660513956}}], 
   LineBox[{{-8.575576843635345, 5.851732808049852}, {3.634302789785289, 
    14.564874568481624`}}], 
   LineBox[{{4.816561997641549, 13.88306947506512}, {4.574104217706948, 
    11.344622267627237`}}], 
   LineBox[{{3.3233577579722064`, 14.025691698556063`}, {3.0808999780376047`, 
    11.48724449111818}}], 
   LineBox[{{5.329301225910797, 10.921363486412435`}, {5.336537005573875, 
    8.9213765755821}}], 
   LineBox[{{2.3365566393283714`, 8.910522906087483}, {2.3293208596652937`, 
    10.910509816917818`}}], 
   LineBox[{{-8.139919755613755, 5.24123882637882}, {6.091055416926798, 
    0.4999999968602724}}], 
   LineBox[{{5.329301225910797, 10.921363486412435`}, {2.3293208596652937`, 
    10.910509816917818`}}], 
   LineBox[{{5.336537005573875, 8.9213765755821}, {2.3365566393283714`, 
    8.910522906087483}}], 
   LineBox[{{5.329301225910797, 10.921363486412435`}, {3.827502097872276, 
    11.41593337937271}}], 
   LineBox[{{2.3293208596652937`, 10.910509816917818`}, {3.827502097872276, 
    11.41593337937271}}], 
   CircleBox[{6.091055416926798, 0.4999999968602724}, 0.5625], 
   CircleBox[{6.0910554183385965`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443730998405*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.167329595041577, 5.279841658502083}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.083664797520789, 13.93507917074896}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.826894402666392, 11.398039761451912`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.734567719429234, 4.667291938873965}, {4.516426673133132, 
    13.322529451120841`}}], 
   LineBox[{{-8.600091470653922, 5.892391378130202}, {3.650902921908445, 
    14.547628890377078`}}], 
   LineBox[{{4.829852859078744, 13.859558466380019`}, {4.573082464224347, 
    11.322519057082971`}}], 
   LineBox[{{3.3374767359628335`, 14.0105998751179}, {3.0807063411084363`, 
    11.473560465820851`}}], 
   LineBox[{{5.3290780252543914`, 10.904638946669047`}, {5.337870496550154, 
    8.904658273650302}}], 
   LineBox[{{2.3378994870220366`, 8.891469566706657}, {2.329107015726274, 
    10.891450239725403`}}], 
   LineBox[{{-8.167329595041577, 5.279841658502083}, {6.050726374286292, 
    0.500000191145646}}], 
   LineBox[{{5.3290780252543914`, 10.904638946669047`}, {2.329107015726274, 
    10.891450239725403`}}], 
   LineBox[{{5.337870496550154, 8.904658273650302}, {2.3378994870220366`, 
    8.891469566706657}}], 
   LineBox[{{5.3290780252543914`, 10.904638946669047`}, {3.826894402666392, 
    11.398039761451912`}}], 
   LineBox[{{2.329107015726274, 10.891450239725403`}, {3.826894402666392, 
    11.398039761451912`}}], 
   CircleBox[{6.050726374286292, 0.500000191145646}, 0.5625], 
   CircleBox[{6.050726283838968, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731009264*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.2032904448762, 5.331081756398086}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.1016452224381, 13.909459121800959`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8260095566316097`, 11.374399954890764`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.7743715766060575`, 4.715834973032371}, {4.530564090708244, 
    13.294212338435244`}}], 
   LineBox[{{-8.632209313146344, 5.9463285397638}, {3.6727263541679567`, 
    14.524705905166673`}}], 
   LineBox[{{4.847250859764628, 13.828389808328462`}, {4.571615193958137, 
    11.293330641418267`}}], 
   LineBox[{{3.3560395851115725`, 13.990528435273456`}, {3.0804039193050814`, 
    11.455469268363261`}}], 
   LineBox[{{5.328749310381871, 10.882695539109692`}, {5.339799912944689, 
    8.882726068296952}}], 
   LineBox[{{2.339845706725577, 8.866150164452723}, {2.328795104162758, 
    10.866119635265465`}}], 
   LineBox[{{-8.2032904448762, 5.331081756398086}, {5.997436531129248, 
    0.4999997499578015}}], 
   LineBox[{{5.328749310381871, 10.882695539109692`}, {2.328795104162758, 
    10.866119635265465`}}], 
   LineBox[{{5.339799912944689, 8.882726068296952}, {2.339845706725577, 
    8.866150164452723}}], 
   LineBox[{{5.328749310381871, 10.882695539109692`}, {3.8260095566316097`, 
    11.374399954890764`}}], 
   LineBox[{{2.328795104162758, 10.866119635265465`}, {3.8260095566316097`, 
    11.374399954890764`}}], 
   CircleBox[{5.997436531129248, 0.4999997499578015}, 0.5625], 
   CircleBox[{5.997436649261836, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437310324383`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.23366401165407, 5.374898508115244}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.116832005827035, 13.887550745942379`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8251820285996896`, 11.35428402275998}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.808031399762714, 4.7573737072411895`}, {4.542464617718392, 
    13.270025945068324`}}], 
   LineBox[{{-8.659296623545428, 5.992423308989299}, {3.691199393935679, 
    14.505075546816434`}}], 
   LineBox[{{4.861910453821858, 13.801771340875513`}, {4.5702604765945125`, 
    11.268504617693115`}}], 
   LineBox[{{3.3717535578322124`, 13.973330151009245`}, {3.0801035806048667`, 
    11.440063427826846`}}], 
   LineBox[{{5.328437810927463, 10.864159494810078`}, {5.341590690318689, 
    8.86420274483679}}], 
   LineBox[{{2.341655565358757, 8.84447342574995}, {2.32850268596753, 
    10.844430175723238`}}], 
   LineBox[{{-8.23366401165407, 5.374898508115244}, {5.952081104300262, 
    0.4999999958200618}}], 
   LineBox[{{5.328437810927463, 10.864159494810078`}, {2.32850268596753, 
    10.844430175723238`}}], 
   LineBox[{{5.341590690318689, 8.86420274483679}, {2.341655565358757, 
    8.84447342574995}}], 
   LineBox[{{5.328437810927463, 10.864159494810078`}, {3.8251820285996896`, 
    11.35428402275998}}], 
   LineBox[{{2.32850268596753, 10.844430175723238`}, {3.8251820285996896`, 
    11.35428402275998}}], 
   CircleBox[{5.952081104300262, 0.4999999958200618}, 0.5625], 
   CircleBox[{5.952081106151434, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731043543*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.264811990275447, 5.420356781695734}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.132405995137724, 13.864821609152134`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.824254703673846, 11.333509146896803`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.842588748902627, 4.800495882425075}, {4.554629236510544, 
    13.244960709881475`}}], 
   LineBox[{{-8.687035231648267, 6.040217680966393}, {3.7101827537649035`, 
    14.484682508422793`}}], 
   LineBox[{{4.876909660506938, 13.77418887636864}, {4.568758369043061, 
    11.24287641411331}}], 
   LineBox[{{3.387902329768509, 13.955454341935628`}, {3.0797510383046314`, 
    11.424141879680297`}}], 
   LineBox[{{5.328084718203642, 10.84514935391696}, {5.343584972439749, 
    8.845209419289269}}], 
   LineBox[{{2.343675070498211, 8.821959037935109}, {2.328174816262104, 
    10.8218989725628}}], 
   LineBox[{{-8.264811990275447, 5.420356781695734}, {5.90522996788429, 
    0.4999999954461254}}], 
   LineBox[{{5.328084718203642, 10.84514935391696}, {2.328174816262104, 
    10.8218989725628}}], 
   LineBox[{{5.343584972439749, 8.845209419289269}, {2.343675070498211, 
    8.821959037935109}}], 
   LineBox[{{5.328084718203642, 10.84514935391696}, {3.824254703673846, 
    11.333509146896803`}}], 
   LineBox[{{2.328174816262104, 10.8218989725628}, {3.824254703673846, 
    11.333509146896803`}}], 
   CircleBox[{5.90522996788429, 0.4999999954461254}, 0.5625], 
   CircleBox[{5.905229969889966, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731054504*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.296823474093921, 5.467642053780136}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.148411737046961, 13.841178973109933`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8232157707278405`, 11.311999741918562`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.878146628127431, 4.845380293223091}, {4.567088583013451, 
    13.218917212552888`}}], 
   LineBox[{{-8.71550032006041, 6.08990381433718}, {3.729734891080471, 
    14.463440733666978`}}], 
   LineBox[{{4.892287981515011, 13.745533100663133`}, {4.5670920151958905`, 
    11.216353869471764`}}], 
   LineBox[{{3.4045354925789106`, 13.936824845556734`}, {3.0793395262597905`, 
    11.407645614365363`}}], 
   LineBox[{{5.32768422747464, 10.825610327299058`}, {5.345804312629955, 
    8.825692413355098}}], 
   LineBox[{{2.3459274417140143`, 8.798512285622124}, {2.327807356558699, 
    10.798430199566086`}}], 
   LineBox[{{-8.296823474093921, 5.467642053780136}, {5.856710878153059, 
    0.500000224927672}}], 
   LineBox[{{5.32768422747464, 10.825610327299058`}, {2.327807356558699, 
    10.798430199566086`}}], 
   LineBox[{{5.345804312629955, 8.825692413355098}, {2.3459274417140143`, 
    8.798512285622124}}], 
   LineBox[{{5.32768422747464, 10.825610327299058`}, {3.8232157707278405`, 
    11.311999741918562`}}], 
   LineBox[{{2.327807356558699, 10.798430199566086`}, {3.8232157707278405`, 
    11.311999741918562`}}], 
   CircleBox[{5.856710878153059, 0.500000224927672}, 0.5625], 
   CircleBox[{5.8567107721456795`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731112754*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.332389622968474, 5.520869582742032}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.166194811484237, 13.814565208628984`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8219560654116167`, 11.287907399248706`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.9177048416741265`, 4.895940361019397}, {4.580879592778585, 
    13.18963598690635}}], 
   LineBox[{{-8.747074404262822, 6.1457988044646665`}, {3.7515100301898894`, 
    14.439494430351619`}}], 
   LineBox[{{4.909329461301966, 13.713318518607625`}, {4.565090715229346, 
    11.186660709227347`}}], 
   LineBox[{{3.423060161666508, 13.915811898650343`}, {3.078821415593888, 
    11.389154089270065`}}], 
   LineBox[{{5.327192801951285, 10.803900821843596`}, {5.348479603681021, 
    8.80401410703395}}], 
   LineBox[{{2.3486495314665516`, 8.772083904439347}, {2.327362729736816, 
    10.771970619248993`}}], 
   LineBox[{{-8.332389622968474, 5.520869582742032}, {5.802349608252207, 
    0.4999984565936071}}], 
   LineBox[{{5.327192801951285, 10.803900821843596`}, {2.327362729736816, 
    10.771970619248993`}}], 
   LineBox[{{5.348479603681021, 8.80401410703395}, {2.3486495314665516`, 
    8.772083904439347}}], 
   LineBox[{{5.327192801951285, 10.803900821843596`}, {3.8219560654116167`, 
    11.287907399248706`}}], 
   LineBox[{{2.327362729736816, 10.771970619248993`}, {3.8219560654116167`, 
    11.287907399248706`}}], 
   CircleBox[{5.802349608252207, 0.4999984565936071}, 0.5625], 
   CircleBox[{5.8023503334888105`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731123878*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.374140314235516, 5.5843093759804265`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.187070157117758, 13.782845312009787`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.820328803485601, 11.259355510259827`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-7.9642135174340485`, 4.956248852412763}, {4.596996953919226, 
    13.154784788442125`}}], 
   LineBox[{{-8.784067111036984, 6.21236989954809}, {3.7771433603162903`, 
    14.410905835577452`}}], 
   LineBox[{{4.929273039985393, 13.67498020800033}, {4.562531686353236, 
    11.15149040625037}}], 
   LineBox[{{3.444867274250123, 13.890710416019244`}, {3.078125920617966, 
    11.367220614269286`}}], 
   LineBox[{{5.326546837940608, 10.778411404689859`}, {5.351901125038649, 
    8.778572121115864}}], 
   LineBox[{{2.352142199677656, 8.740540690468801}, {2.326787912579615, 
    10.740379974042797`}}], 
   LineBox[{{-8.374140314235516, 5.5843093759804265`}, {5.73790433752494, 
    0.5000005983077846}}], 
   LineBox[{{5.326546837940608, 10.778411404689859`}, {2.326787912579615, 
    10.740379974042797`}}], 
   LineBox[{{5.351901125038649, 8.778572121115864}, {2.352142199677656, 
    8.740540690468801}}], 
   LineBox[{{5.326546837940608, 10.778411404689859`}, {3.820328803485601, 
    11.259355510259827`}}], 
   LineBox[{{2.326787912579615, 10.740379974042797`}, {3.820328803485601, 
    11.259355510259827`}}], 
   CircleBox[{5.73790433752494, 0.5000005983077846}, 0.5625], 
   CircleBox[{5.737904056240078, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731134872*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.409436136965017, 5.638772425936339}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.204718068482508, 13.755613787031832`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8188236556660415`, 11.234981822195031`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.003594068910242, 5.008064715663964}, {4.610560136537283, 
    13.124906076759457`}}], 
   LineBox[{{-8.81527820501979, 6.269480136208714}, {3.7988760004277338`, 
    14.386321497304207`}}], 
   LineBox[{{4.946080411081567, 13.642115430321107`}, {4.5601859982651005`, 
    11.121483465484305`}}], 
   LineBox[{{3.4633557258834493`, 13.869112143742557`}, {3.0774613130669826`, 
    11.348480178905756`}}], 
   LineBox[{{5.3259407723559375`, 10.756862593779843`}, {5.35504454493367, 
    8.757074362385893}}], 
   LineBox[{{2.3553621978427444`, 8.713418703519295}, {2.326258425265012, 
    10.713206934913245`}}], 
   LineBox[{{-8.409436136965017, 5.638772425936339}, {5.682867361321229, 
    0.499999993517366}}], 
   LineBox[{{5.3259407723559375`, 10.756862593779843`}, {2.326258425265012, 
    10.713206934913245`}}], 
   LineBox[{{5.35504454493367, 8.757074362385893}, {2.3553621978427444`, 
    8.713418703519295}}], 
   LineBox[{{5.3259407723559375`, 10.756862593779843`}, {3.8188236556660415`, 
    11.234981822195031`}}], 
   LineBox[{{2.326258425265012, 10.713206934913245`}, {3.8188236556660415`, 
    11.234981822195031`}}], 
   CircleBox[{5.682867361321229, 0.499999993517366}, 0.5625], 
   CircleBox[{5.68286736409478, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437311459007`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.446370499868243, 5.696606181219668}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.223185249934121, 13.726696909390167`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.817115474908582, 11.209236415596727`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.044865963459717, 5.063128393729549}, {4.624689786342646, 
    13.093219121900049`}}], 
   LineBox[{{-8.847875036276768, 6.330083968709786}, {3.8216807135255966`, 
    14.360174696880286`}}], 
   LineBox[{{4.963614806932192, 13.607264622617949`}, {4.557545031906653, 
    11.089804128824511`}}], 
   LineBox[{{3.482755692936051, 13.846129196162385`}, {3.0766859179105115`, 
    11.328668702368946`}}], 
   LineBox[{{5.325242408163046, 10.734312049836783`}, {5.358583942552897, 
    8.734589983627448}}], 
   LineBox[{{2.3590008432388956`, 8.68457768204267}, {2.325659308849044, 
    10.684299748252005`}}], 
   LineBox[{{-8.446370499868243, 5.696606181219668}, {5.624709207256631, 
    0.4999999929715555}}], 
   LineBox[{{5.325242408163046, 10.734312049836783`}, {2.325659308849044, 
    10.684299748252005`}}], 
   LineBox[{{5.358583942552897, 8.734589983627448}, {2.3590008432388956`, 
    8.68457768204267}}], 
   LineBox[{{5.325242408163046, 10.734312049836783`}, {3.817115474908582, 
    11.209236415596727`}}], 
   LineBox[{{2.325659308849044, 10.684299748252005`}, {3.817115474908582, 
    11.209236415596727`}}], 
   CircleBox[{5.624709207256631, 0.4999999929715555}, 0.5625], 
   CircleBox[{5.624709210238539, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731156801*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.483784885478006, 5.756098412613345}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.241892442739003, 13.696950793693329`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8152401615884255`, 11.182896730832109`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.086742266424006, 5.1198145462024955`}, {4.638935061793002, 
    13.06066692728248}}], 
   LineBox[{{-8.880827504532006, 6.392382279024194}, {3.8448498236850037`, 
    14.333234660104178`}}], 
   LineBox[{{4.981320108286421, 13.571464828649042`}, {4.554667827135843, 
    11.057410765787822`}}], 
   LineBox[{{3.502464777191585, 13.822436758737616`}, {3.0758124960410074`, 
    11.308382695876396`}}], 
   LineBox[{{5.324463361102811, 10.71146769688579}, {5.362437800172984, 
    8.711828243889999}}], 
   LineBox[{{2.362978620679297, 8.654866585284742}, {2.325004181609125, 
    10.654506038280532`}}], 
   LineBox[{{-8.483784885478006, 5.756098412613345}, {5.565180841557986, 
    0.5000008107257958}}], 
   LineBox[{{5.324463361102811, 10.71146769688579}, {2.325004181609125, 
    10.654506038280532`}}], 
   LineBox[{{5.362437800172984, 8.711828243889999}, {2.362978620679297, 
    8.654866585284742}}], 
   LineBox[{{5.324463361102811, 10.71146769688579}, {3.8152401615884255`, 
    11.182896730832109`}}], 
   LineBox[{{2.325004181609125, 10.654506038280532`}, {3.8152401615884255`, 
    11.182896730832109`}}], 
   CircleBox[{5.565180841557986, 0.5000008107257958}, 0.5625], 
   CircleBox[{5.565180463852364, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731167756*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.529821819554343, 5.8305996774864415`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.264910909777171, 13.65970016125678}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.81272345936888, 11.15011324112565}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.138366795365826, 5.190863041019865}, {4.656365933965688, 
    13.019963524790203`}}], 
   LineBox[{{-8.92127684374286, 6.470336313953018}, {3.8734558855886543`, 
    14.299436797723356`}}], 
   LineBox[{{5.0030247098157385`, 13.526703852313164`}, {4.550837259407447, 
    11.017116932182034`}}], 
   LineBox[{{3.5267971097386037`, 13.792696470200395`}, {3.0746096593303123`, 
    11.283109550069264`}}], 
   LineBox[{{5.323400165936446, 10.683362892187192`}, {5.367570429837323, 
    8.68385070473073}}], 
   LineBox[{{2.3683021486526297`, 8.617595308879416}, {2.3241318847517527`, 
    10.617107496335876`}}], 
   LineBox[{{-8.529821819554343, 5.8305996774864415`}, {5.491043877791027, 
    0.4999969820115737}}], 
   LineBox[{{5.323400165936446, 10.683362892187192`}, {2.3241318847517527`, 
    10.617107496335876`}}], 
   LineBox[{{5.367570429837323, 8.68385070473073}, {2.3683021486526297`, 
    8.617595308879416}}], 
   LineBox[{{5.323400165936446, 10.683362892187192`}, {3.81272345936888, 
    11.15011324112565}}], 
   LineBox[{{2.3241318847517527`, 10.617107496335876`}, {3.81272345936888, 
    11.15011324112565}}], 
   CircleBox[{5.491043877791027, 0.4999969820115737}, 0.5625], 
   CircleBox[{5.491045279595696, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437311786757`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.574367559806609, 5.9041063993378105`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.287183779903304, 13.622946800331096`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.810054853088537, 11.11798213247716}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.188425539756944, 5.2610288323523156`}, {4.6731257999529685`, 
    12.979869233345601`}}], 
   LineBox[{{-8.960309579856274, 6.547183966323305}, {3.90124175985364, 
    14.266024367316591`}}], 
   LineBox[{{5.023938093977992, 13.482614763032636`}, {4.546809167163225, 
    10.977650095178697`}}], 
   LineBox[{{3.550429465828617, 13.763278837629557`}, {3.0733005390138497`, 
    11.25831416977562}}], 
   LineBox[{{5.322247750933871, 10.656167624578009`}, {5.372947500593023, 
    8.656810344003949}}], 
   LineBox[{{2.3739115797319323`, 8.58076071951522}, {2.32321183007278, 
    10.58011800008928}}], 
   LineBox[{{-8.574367559806609, 5.9041063993378105`}, {5.418332005953344, 
    0.5000006581090828}}], 
   LineBox[{{5.322247750933871, 10.656167624578009`}, {2.32321183007278, 
    10.58011800008928}}], 
   LineBox[{{5.372947500593023, 8.656810344003949}, {2.3739115797319323`, 
    8.58076071951522}}], 
   LineBox[{{5.322247750933871, 10.656167624578009`}, {3.810054853088537, 
    11.11798213247716}}], 
   LineBox[{{2.32321183007278, 10.58011800008928}, {3.810054853088537, 
    11.11798213247716}}], 
   CircleBox[{5.418332005953344, 0.5000006581090828}, 0.5625], 
   CircleBox[{5.418331700498271, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731189526*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.615427405042919, 5.973149536530013}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.307713702521459, 13.588425231734995`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.807381588968891, 11.087991714092901`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.234663620282669, 5.326992481151795}, {4.688477487281708, 
    12.942268176356777`}}], 
   LineBox[{{-8.996191189803168, 6.619306591908231}, {3.92694991776121, 
    14.234582287113213`}}], 
   LineBox[{{5.04313532535737, 13.441268727748945`}, {4.542803211804801, 
    10.940835210106851`}}], 
   LineBox[{{3.572292079685549, 13.735581735721045`}, {3.071959966132981, 
    11.23514821807895}}], 
   LineBox[{{5.321071833657923, 10.631108968595482`}, {5.378288636936632, 
    8.631927576769677}}], 
   LineBox[{{2.3795165491979233`, 8.546102371851612}, {2.322299745919214, 
    10.545283763677418`}}], 
   LineBox[{{-8.615427405042919, 5.973149536530013}, {5.350410702393706, 
    0.49999999016541885`}}], 
   LineBox[{{5.321071833657923, 10.631108968595482`}, {2.322299745919214, 
    10.545283763677418`}}], 
   LineBox[{{5.378288636936632, 8.631927576769677}, {2.3795165491979233`, 
    8.546102371851612}}], 
   LineBox[{{5.321071833657923, 10.631108968595482`}, {3.807381588968891, 
    11.087991714092901`}}], 
   LineBox[{{2.322299745919214, 10.545283763677418`}, {3.807381588968891, 
    11.087991714092901`}}], 
   CircleBox[{5.350410702393706, 0.49999999016541885`}, 0.5625], 
   CircleBox[{5.350410706384541, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731200367*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.657986544000611, 6.04607464045432}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.3289932720003055`, 13.551962679772842`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.8043814040205226`, 11.05651033841772}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.282692142034685, 5.3967256496542735`}, {4.704287673966231, 
    12.902613688972796`}}], 
   LineBox[{{-9.033280945966537, 6.695423631254366}, {3.9536988700343794`, 
    14.201311670572888`}}], 
   LineBox[{{5.0629498429871065`, 13.397665071543495`}, {4.538337975007323, 
    10.90221273018837}}], 
   LineBox[{{3.5950367010135045`, 13.70626028800219}, {3.070424833033722, 
    11.210807946647067`}}], 
   LineBox[{{5.319725809976811, 10.60514426599204}, {5.384224285448511, 
    8.606184549874222}}], 
   LineBox[{{2.3857847112717834`, 8.509436836666673}, {2.321286235800084, 
    10.508396552784491`}}], 
   LineBox[{{-8.657986544000611, 6.04607464045432}, {5.27905245159006, 
    0.49999998937135004`}}], 
   LineBox[{{5.319725809976811, 10.60514426599204}, {2.321286235800084, 
    10.508396552784491`}}], 
   LineBox[{{5.384224285448511, 8.606184549874222}, {2.3857847112717834`, 
    8.509436836666673}}], 
   LineBox[{{5.319725809976811, 10.60514426599204}, {3.8043814040205226`, 
    11.05651033841772}}], 
   LineBox[{{2.321286235800084, 10.508396552784491`}, {3.8043814040205226`, 
    11.05651033841772}}], 
   CircleBox[{5.27905245159006, 0.49999998937135004`}, 0.5625], 
   CircleBox[{5.279052455847583, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731211337*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.70131217526318, 6.1217988648375234`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.35065608763159, 13.51410056758124}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.801073320416257, 11.024028524049179`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.331697090125994, 5.469200451692784}, {4.720271172768776, 
    12.8615021544365}}], 
   LineBox[{{-9.070927260400365, 6.7743972779822625`}, {3.981041002494404, 
    14.166698980725979`}}], 
   LineBox[{{5.083030218082196, 13.35245857722379}, {4.533447450866863, 
    10.862386533691728`}}], 
   LineBox[{{3.6182819571809834`, 13.67574255793869}, {3.0686991899656504`, 
    11.18567051440663}}], 
   LineBox[{{5.31821059726267, 10.578725836876679`}, {5.390702283394236, 
    8.580040029791984}}], 
   LineBox[{{2.3926735727671926`, 8.471302500594636}, {2.3201818866356265`, 
    10.46998830767933}}], 
   LineBox[{{-8.70131217526318, 6.1217988648375234`}, {5.205354642228222, 
    0.5000003957278789}}], 
   LineBox[{{5.31821059726267, 10.578725836876679`}, {2.3201818866356265`, 
    10.46998830767933}}], 
   LineBox[{{5.390702283394236, 8.580040029791984}, {2.3926735727671926`, 
    8.471302500594636}}], 
   LineBox[{{5.31821059726267, 10.578725836876679`}, {3.801073320416257, 
    11.024028524049179`}}], 
   LineBox[{{2.3201818866356265`, 10.46998830767933}, {3.801073320416257, 
    11.024028524049179`}}], 
   CircleBox[{5.205354642228222, 0.5000003957278789}, 0.5625], 
   CircleBox[{5.2053544610463875`, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731222233*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.757365031025167, 6.222106286031394}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.378682515512583, 13.463946856984304`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7963874264214255`, 10.981320741512963`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.395273002477522, 5.565303908704507}, {4.740774544060229, 
    12.807144479657417`}}], 
   LineBox[{{-9.119457059572811, 6.878908663358281}, {4.016590486964938, 
    14.120749234311191`}}], 
   LineBox[{{5.108866667121801, 13.292683595486904`}, {4.5265715780306435`, 
    10.810057480015564`}}], 
   LineBox[{{3.6484983639033652`, 13.635210118481703`}, {3.0662032748122074`, 
    11.152584003010363`}}], 
   LineBox[{{5.316010906928264, 10.544577707805175`}, {5.399768658681654, 
    8.546332317713855}}], 
   LineBox[{{2.4024005735446714`, 8.420695690083768}, {2.318642821791282, 
    10.41894108017509}}], 
   LineBox[{{-8.757365031025167, 6.222106286031394}, {5.1083300293270355`, 
    0.499999987357409}}], 
   LineBox[{{5.316010906928264, 10.544577707805175`}, {2.318642821791282, 
    10.41894108017509}}], 
   LineBox[{{5.399768658681654, 8.546332317713855}, {2.4024005735446714`, 
    8.420695690083768}}], 
   LineBox[{{5.316010906928264, 10.544577707805175`}, {3.7963874264214255`, 
    10.981320741512963`}}], 
   LineBox[{{2.318642821791282, 10.41894108017509}, {3.7963874264214255`, 
    10.981320741512963`}}], 
   CircleBox[{5.1083300293270355`, 0.499999987357409}, 0.5625], 
   CircleBox[{5.108330034224556, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731233086*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.803099318401808, 6.306009866119699}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.401549659200904, 13.421995066940152`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7921998464277387`, 10.945870513192236`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.447300058360785, 5.645777417239564}, {4.7573489192419265`, 
    12.761762618060017`}}], 
   LineBox[{{-9.15889857844283, 6.9662423149998345`}, {4.045750399159881, 
    14.082227515820287`}}], 
   LineBox[{{5.1298215867738195`, 13.242774533771573`}, {4.520471774000654, 
    10.76664998002366}}], 
   LineBox[{{3.6732777316279877`, 13.60121560010873}, {3.0639279188548225`, 
    11.125091046360815`}}], 
   LineBox[{{5.313993557652377, 10.516750599325325`}, {5.407767145501939, 
    8.518950180308996}}], 
   LineBox[{{2.4110665169774443`, 8.378289798534652}, {2.3172929291278823`, 
    10.376090217550983`}}], 
   LineBox[{{-8.803099318401808, 6.306009866119699}, {5.027672506626214, 
    0.499999986347615}}], 
   LineBox[{{5.313993557652377, 10.516750599325325`}, {2.3172929291278823`, 
    10.376090217550983`}}], 
   LineBox[{{5.407767145501939, 8.518950180308996}, {2.4110665169774443`, 
    8.378289798534652}}], 
   LineBox[{{5.313993557652377, 10.516750599325325`}, {3.7921998464277387`, 
    10.945870513192236`}}], 
   LineBox[{{2.3172929291278823`, 10.376090217550983`}, {3.7921998464277387`, 
    10.945870513192236`}}], 
   CircleBox[{5.027672506626214, 0.499999986347615}, 0.5625], 
   CircleBox[{5.02767251182542, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437312961607`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.849733111267382, 6.393582508050019}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.424866555633691, 13.378208745974991`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.787566532263016, 10.909130237662277`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.500501799371133, 5.729852524704966}, {4.77409786752994, 
    12.714478762629938`}}], 
   LineBox[{{-9.19896442316363, 7.057312491395073}, {4.075635243737442, 
    14.041938729320044`}}], 
   LineBox[{{5.151066116902136, 13.190767562630676`}, {4.513766093531461, 
    10.72168905431796}}], 
   LineBox[{{3.6986669943652455`, 13.565649929319306`}, {3.0613669709945706`, 
    11.096571421006594`}}], 
   LineBox[{{5.311706606742675, 10.488420084034939`}, {5.4165104521817335`, 
    8.491167933208413}}], 
   LineBox[{{2.4206322259419437`, 8.333962165049826}, {2.3158283805028854`, 
    10.331214315876352`}}], 
   LineBox[{{-8.849733111267382, 6.393582508050019}, {4.94394968365836, 
    0.4999999852571486}}], 
   LineBox[{{5.311706606742675, 10.488420084034939`}, {2.3158283805028854`, 
    10.331214315876352`}}], 
   LineBox[{{5.4165104521817335`, 8.491167933208413}, {2.4206322259419437`, 
    8.333962165049826}}], 
   LineBox[{{5.311706606742675, 10.488420084034939`}, {3.787566532263016, 
    10.909130237662277`}}], 
   LineBox[{{2.3158283805028854`, 10.331214315876352`}, {3.787566532263016, 
    10.909130237662277`}}], 
   CircleBox[{4.94394968365836, 0.4999999852571486}, 0.5625], 
   CircleBox[{4.943949689169404, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731307745*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.896793652867673, 6.484141625247944}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.448396826433837, 13.33292918737603}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.782490264867741, 10.871411677533125`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.55435427476127, 5.816882101282869}, {4.790836204540241, 
    12.665669663410954`}}], 
   LineBox[{{-9.239233030974077, 7.15140114921302}, {4.105957448327432, 
    14.000188711341105`}}], 
   LineBox[{{5.172372564622926, 13.137074316327178`}, {4.506466003056831, 
    10.675556806484273`}}], 
   LineBox[{{3.724421088244747, 13.52878405842488}, {3.0585145266786515`, 
    11.067266548581976`}}], 
   LineBox[{{5.30913646158453, 10.45988842175022}, {5.4259670333317604`, 
    8.46330368337691}}], 
   LineBox[{{2.4310899257717966`, 8.288057825756066}, {2.314259354024567, 
    10.284642564129376`}}], 
   LineBox[{{-8.896793652867673, 6.484141625247944}, {4.857844096196661, 
    0.5000008855916311}}], 
   LineBox[{{5.30913646158453, 10.45988842175022}, {2.314259354024567, 
    10.284642564129376`}}], 
   LineBox[{{5.4259670333317604`, 8.46330368337691}, {2.4310899257717966`, 
    8.288057825756066}}], 
   LineBox[{{5.30913646158453, 10.45988842175022}, {3.782490264867741, 
    10.871411677533125`}}], 
   LineBox[{{2.314259354024567, 10.284642564129376`}, {3.782490264867741, 
    10.871411677533125`}}], 
   CircleBox[{4.857844096196661, 0.5000008855916311}, 0.5625], 
   CircleBox[{4.857843702283577, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731318708*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-8.94899383546612, 6.587320386495418}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.47449691773306, 13.281339806752293`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7763497279648806`, 10.828771662659493`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.614292864453276, 5.91614584883546}, {4.809197888745903, 
    12.610165269092334`}}], 
   LineBox[{{-9.283694806478962, 7.258494924155376}, {4.139795946720216, 
    13.95251434441225}}], 
   LineBox[{{5.195840489525059, 13.076002397996946`}, {4.497693299756881, 
    10.623434253904147`}}], 
   LineBox[{{3.75315334594106, 13.486677215507639`}, {3.055006156172881, 
    11.03410907141484}}], 
   LineBox[{{5.305941665028484, 10.428336267033664`}, {5.4372559651029295`, 
    8.432651784307009}}], 
   LineBox[{{2.4437292410129463`, 8.235680334195338}, {2.3124149409385, 
    10.231364816921994`}}], 
   LineBox[{{-8.94899383546612, 6.587320386495418}, {4.760290063251274, 
    0.49999462025224073`}}], 
   LineBox[{{5.305941665028484, 10.428336267033664`}, {2.3124149409385, 
    10.231364816921994`}}], 
   LineBox[{{5.4372559651029295`, 8.432651784307009}, {2.4437292410129463`, 
    8.235680334195338}}], 
   LineBox[{{5.305941665028484, 10.428336267033664`}, {3.7763497279648806`, 
    10.828771662659493`}}], 
   LineBox[{{2.3124149409385, 10.231364816921994`}, {3.7763497279648806`, 
    10.828771662659493`}}], 
   CircleBox[{4.760290063251274, 0.49999462025224073`}, 0.5625], 
   CircleBox[{4.76029242841499, 0.5}, 0.5], LineBox[{{0, 11.05}, {11.05, 0}}],
    LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731329645*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.007657488155568, 6.706947320596386}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.503828744077784, 13.221526339701807`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7687456093882976`, 10.779774348795467`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.681928537200296, 6.031373008984719}, {4.8295576950330545`, 
    12.545952028090142`}}], 
   LineBox[{{-9.33338643911084, 7.382521632208054}, {4.178099793122513, 
    13.897100651313476`}}], 
   LineBox[{{5.221991094344355, 13.00532541773431}, {4.486907959654868, 
    10.56357342682797}}], 
   LineBox[{{3.785666393811213, 13.437727261669304`}, {3.050583259121727, 
    10.995975270762962`}}], 
   LineBox[{{5.30185300648197, 10.393016402559498`}, {5.450986429836276, 
    8.398584347552703}}], 
   LineBox[{{2.459338347326084, 8.174884212521246}, {2.3102049239717783`, 
    10.169316267528039`}}], 
   LineBox[{{-9.007657488155568, 6.706947320596386}, {4.647884551282232, 
    0.5000018875232888}}], 
   LineBox[{{5.30185300648197, 10.393016402559498`}, {2.3102049239717783`, 
    10.169316267528039`}}], 
   LineBox[{{5.450986429836276, 8.398584347552703}, {2.459338347326084, 
    8.174884212521246}}], 
   LineBox[{{5.30185300648197, 10.393016402559498`}, {3.7687456093882976`, 
    10.779774348795467`}}], 
   LineBox[{{2.3102049239717783`, 10.169316267528039`}, {3.7687456093882976`, 
    10.779774348795467`}}], 
   CircleBox[{4.647884551282232, 0.5000018875232888}, 0.5625], 
   CircleBox[{4.647883725644016, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437313406153`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.056753033315882, 6.810280139735226}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.528376516657941, 13.169859930132388`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7617515241006494`, 10.737826599606976`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.738774043796024, 6.131023662236534}, {4.846355506177799, 
    12.490603452633696`}}], 
   LineBox[{{-9.37473202283574, 7.4895366172339175`}, {4.210397527138083, 
    13.84911640763108}}], 
   LineBox[{{5.24368043740071, 12.94438199114495}, {4.477055444843418, 
    10.512348660619537`}}], 
   LineBox[{{3.8130725959151723`, 13.395337869119826`}, {3.0464476033578807`, 
    10.963304538594414`}}], 
   LineBox[{{5.2979715327671135`, 10.363623332688034`}, {5.463415615930969, 
    8.3704780155207}}], 
   LineBox[{{2.473697640179968, 8.122311890774917}, {2.308253557016113, 
    10.115457207942251`}}], 
   LineBox[{{-9.056753033315882, 6.810280139735226}, {4.55134618366381, 
    0.49999997948586383`}}], 
   LineBox[{{5.2979715327671135`, 10.363623332688034`}, {2.308253557016113, 
    10.115457207942251`}}], 
   LineBox[{{5.463415615930969, 8.3704780155207}, {2.473697640179968, 
    8.122311890774917}}], 
   LineBox[{{5.2979715327671135`, 10.363623332688034`}, {3.7617515241006494`, 
    10.737826599606976`}}], 
   LineBox[{{2.308253557016113, 10.115457207942251`}, {3.7617515241006494`, 
    10.737826599606976`}}], 
   CircleBox[{4.55134618366381, 0.49999997948586383`}, 0.5625], 
   CircleBox[{4.551346190603763, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731351552*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.107221571841565, 6.919804454824973}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.553610785920783, 13.115097772587514`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.753897675940154, 10.69374299855602}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.797456905953439, 6.236762836936856}, {4.86337545180891, 
    12.432056154699398`}}], 
   LineBox[{{-9.416986237729692, 7.60284607271309}, {4.243846120032655, 
    13.798139390475631`}}], 
   LineBox[{{5.265773954753575, 12.879888034357919`}, {4.466060844772946, 
    10.458533260326423`}}], 
   LineBox[{{3.84144761708799, 13.35030751081711}, {3.0417345071073614`, 
    10.928952736785616`}}], 
   LineBox[{{5.293475751122849, 10.333605038300862`}, {5.477141428889736, 
    8.342056163979564}}], 
   LineBox[{{2.489818117407789, 8.066557647329233}, {2.3061524396409023`, 
    10.058106521650531`}}], 
   LineBox[{{-9.107221571841565, 6.919804454824973}, {4.449552029444581, 
    0.4999999777812185}}], 
   LineBox[{{5.293475751122849, 10.333605038300862`}, {2.3061524396409023`, 
    10.058106521650531`}}], 
   LineBox[{{5.477141428889736, 8.342056163979564}, {2.489818117407789, 
    8.066557647329233}}], 
   LineBox[{{5.293475751122849, 10.333605038300862`}, {3.753897675940154, 
    10.69374299855602}}], 
   LineBox[{{2.3061524396409023`, 10.058106521650531`}, {3.753897675940154, 
    10.69374299855602}}], 
   CircleBox[{4.449552029444581, 0.4999999777812185}, 0.5625], 
   CircleBox[{4.449552036743244, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731362441*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.157383172547581, 7.032247714064193}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.5786915862737905`, 13.058876142967904`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7453513333925184`, 10.648887756496347`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.856051751102395, 6.345443976123123}, {4.880023007718976, 
    12.372072405026834`}}], 
   LineBox[{{-9.458714593992767, 7.719051452005262}, {4.277360164828605, 
    13.745679880908973`}}], 
   LineBox[{{5.287511699941895, 12.813776068591059`}, {4.454171447060623, 
    10.403787682119502`}}], 
   LineBox[{{3.8698714726056855`, 13.303976217344749`}, {3.036531219724413, 
    10.893987830873192`}}], 
   LineBox[{{5.288422408742777, 10.30402306358419}, {5.491813207388293, 
    8.314391895999016}}], 
   LineBox[{{2.5073664560105327`, 8.009305698030744}, {2.303975657365017, 
    9.998936865615917}}], 
   LineBox[{{-9.157383172547581, 7.032247714064193}, {4.345571000847519, 
    0.5000024192829393}}], 
   LineBox[{{5.288422408742777, 10.30402306358419}, {2.303975657365017, 
    9.998936865615917}}], 
   LineBox[{{5.491813207388293, 8.314391895999016}, {2.5073664560105327`, 
    8.009305698030744}}], 
   LineBox[{{5.288422408742777, 10.30402306358419}, {3.7453513333925184`, 
    10.648887756496347`}}], 
   LineBox[{{2.303975657365017, 9.998936865615917}, {3.7453513333925184`, 
    10.648887756496347`}}], 
   CircleBox[{4.345571000847519, 0.5000024192829393}, 0.5625], 
   CircleBox[{4.345569986864427, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731373495*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.21848081944346, 7.1744856623213185`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.60924040972173, 12.987757168839343`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.733816542720984, 10.592734610890158`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.92781724411756, 6.483099600863058}, {4.899903985047631, 
    12.296371107381082`}}], 
   LineBox[{{-9.509144394769361, 7.865871723779579}, {4.318576834395829, 
    13.679143230297603`}}], 
   LineBox[{{5.313658809118549, 12.730279560897946`}, {4.438234942117804, 
    10.335257002948762`}}], 
   LineBox[{{3.904822010324911, 13.24523477678074}, {3.0293981433241646`, 
    10.850212218831553`}}], 
   LineBox[{{5.281344903971995, 10.268456996609181`}, {5.511223111335226, 
    8.281711917395578}}], 
   LineBox[{{2.53110549251482, 7.93689460635073}, {2.3012272851515894`, 
    9.923639685564334}}], 
   LineBox[{{-9.21848081944346, 7.1744856623213185`}, {4.214729148867821, 
    0.499991677960975}}], 
   LineBox[{{5.281344903971995, 10.268456996609181`}, {2.3012272851515894`, 
    9.923639685564334}}], 
   LineBox[{{5.511223111335226, 8.281711917395578}, {2.53110549251482, 
    7.93689460635073}}], 
   LineBox[{{5.281344903971995, 10.268456996609181`}, {3.733816542720984, 
    10.592734610890158`}}], 
   LineBox[{{2.3012272851515894`, 9.923639685564334}, {3.733816542720984, 
    10.592734610890158`}}], 
   CircleBox[{4.214729148867821, 0.499991677960975}, 0.5625], 
   CircleBox[{4.214732580031045, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731384396*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.274810005495837, 7.31129710167359}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.637405002747919, 12.919351449163207`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7219310138825774`, 10.539349899644598`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-8.994407288121357, 6.615686351261402}, {4.9178077201224, 
    12.223740698751019`}}], 
   LineBox[{{-9.555212722870317, 8.006907852085778}, {4.357002285373437, 
    13.614962199575395`}}], 
   LineBox[{{5.337405458488686, 12.650094393614577`}, {4.421931469623345, 
    10.270092844095968`}}], 
   LineBox[{{3.937404547007151, 13.188608504711837`}, {3.02193055814181, 
    10.808606955193227`}}], 
   LineBox[{{5.273743197511617, 10.23623449795661}, {5.53072958893765, 
    8.252813716926568}}], 
   LineBox[{{2.5555984173925843`, 7.867334129787521}, {2.298612025966553, 
    9.850754910817564}}], 
   LineBox[{{-9.274810005495837, 7.31129710167359}, {4.089555092301847, 
    0.5000016644775886}}], 
   LineBox[{{5.273743197511617, 10.23623449795661}, {2.298612025966553, 
    9.850754910817564}}], 
   LineBox[{{5.53072958893765, 8.252813716926568}, {2.5555984173925843`, 
    7.867334129787521}}], 
   LineBox[{{5.273743197511617, 10.23623449795661}, {3.7219310138825774`, 
    10.539349899644598`}}], 
   LineBox[{{2.298612025966553, 9.850754910817564}, {3.7219310138825774`, 
    10.539349899644598`}}], 
   CircleBox[{4.089555092301847, 0.5000016644775886}, 0.5625], 
   CircleBox[{4.089554413142508, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437313951807`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.326337510163182, 7.441755461928442}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.663168755081591, 12.85412226903578}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.7098397880934626`, 10.489029484238248`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.055719169807814, 6.742280148666203}, {4.933787095436958, 
    12.154646955773542`}}], 
   LineBox[{{-9.59695585051855, 8.141230775190682}, {4.392550414726224, 
    13.55359758229802}}], 
   LineBox[{{5.358784280022041, 12.573731396392214`}, {4.405455313033913, 
    10.208638611594681`}}], 
   LineBox[{{3.96755323014114, 13.134513141679347`}, {3.014224263153012, 
    10.769420356881817`}}], 
   LineBox[{{5.265700227149817, 10.2074299562213}, {5.550124969152021, 
    8.227757618146896}}], 
   LineBox[{{2.580616462040415, 7.801120505143589}, {2.2961917200382107`, 
    9.780792843217993}}], 
   LineBox[{{-9.326337510163182, 7.441755461928442}, {3.970730988727791, 
    0.4999999681213172}}], 
   LineBox[{{5.265700227149817, 10.2074299562213}, {2.2961917200382107`, 
    9.780792843217993}}], 
   LineBox[{{5.550124969152021, 8.227757618146896}, {2.580616462040415, 
    7.801120505143589}}], 
   LineBox[{{5.265700227149817, 10.2074299562213}, {3.7098397880934626`, 
    10.489029484238248`}}], 
   LineBox[{{2.2961917200382107`, 9.780792843217993}, {3.7098397880934626`, 
    10.489029484238248`}}], 
   CircleBox[{3.970730988727791, 0.4999999681213172}, 0.5625], 
   CircleBox[{3.970730997664172, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731406095*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.378476378474433, 7.579527291794809}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.689238189237217, 12.785236354102597`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.69622567955316, 10.436529016946482`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.118190925359043, 6.876141563409227}, {4.949523642352606, 
    12.081850625717015`}}], 
   LineBox[{{-9.638761831589823, 8.282913020180391}, {4.428952736121827, 
    13.48862208248818}}], 
   LineBox[{{5.380034464871368, 12.493173851254346`}, {4.387021955187311, 
    10.14446651409823}}], 
   LineBox[{{3.998441913603065, 13.077298856950849`}, {3.0054294039190084`, 
    10.728591519794733`}}], 
   LineBox[{{5.256274019771345, 10.179139863751393`}, {5.571426372024513, 
    8.204126194211534}}], 
   LineBox[{{2.608905867714726, 7.731397665831784}, {2.2937535154615585`, 
    9.70641133537164}}], 
   LineBox[{{-9.378476378474433, 7.579527291794809}, {3.8457548970684403`, 
    0.4999999649915807}}], 
   LineBox[{{5.256274019771345, 10.179139863751393`}, {2.2937535154615585`, 
    9.70641133537164}}], 
   LineBox[{{5.571426372024513, 8.204126194211534}, {2.608905867714726, 
    7.731397665831784}}], 
   LineBox[{{5.256274019771345, 10.179139863751393`}, {3.69622567955316, 
    10.436529016946482`}}], 
   LineBox[{{2.2937535154615585`, 9.70641133537164}, {3.69622567955316, 
    10.436529016946482`}}], 
   CircleBox[{3.8457548970684403`, 0.4999999649915807}, 0.5625], 
   CircleBox[{3.845754906436002, 0.5}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731417006*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.430510105497639, 7.723518502966401}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.7152550527488195`, 12.7132407485168}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.6810103649318715`, 10.382395853264775`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.18102399322012, 7.0162302450540786`}, {4.964741165026339, 
    12.005952490604479`}}], 
   LineBox[{{-9.679996217775159, 8.430806760878724}, {4.4657689404713, 
    13.420529006429124`}}], 
   LineBox[{{5.400797668999415, 12.40905113445299}, {4.366552981182467, 
    10.078206239200966`}}], 
   LineBox[{{4.029712436498224, 13.017430362580608`}, {2.9954677486812757`, 
    10.686585467328584`}}], 
   LineBox[{{5.245282174030118, 10.15206194941973}, {5.594590213055362, 
    8.182802216963816}}], 
   LineBox[{{2.6407006143714913`, 7.658840158425949}, {2.291392575346247, 
    9.628099890881863}}], 
   LineBox[{{-9.430510105497639, 7.723518502966401}, {3.7156224664524906`, 
    0.5000014647978164}}], 
   LineBox[{{5.245282174030118, 10.15206194941973}, {2.291392575346247, 
    9.628099890881863}}], 
   LineBox[{{5.594590213055362, 8.182802216963816}, {2.6407006143714913`, 
    7.658840158425949}}], 
   LineBox[{{5.245282174030118, 10.15206194941973}, {3.6810103649318715`, 
    10.382395853264775`}}], 
   LineBox[{{2.291392575346247, 9.628099890881863}, {3.6810103649318715`, 
    10.382395853264775`}}], 
   CircleBox[{3.7156224664524906`, 0.5000014647978164}, 0.5625], 
   CircleBox[{3.7156223105686275`, 0.5000010635240791}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731428029*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.495788193095072, 7.914715867441}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.747894096547536, 12.617642066279501`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.659114612628353, 10.31176712704349}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.260641883153147, 7.202531752958869}, {4.983040406489461, 
    11.90545795179737}}], 
   LineBox[{{-9.730934503036996, 8.626899981923131}, {4.512747786605611, 
    13.329826180761632`}}], 
   LineBox[{{5.426092608087539, 12.29741280630327}, {4.3373131241683565`, 
    9.99153786706726}}], 
   LineBox[{{4.0696955850075325`, 12.937871326255731`}, {2.98091610108835, 
    10.63199638701972}}], 
   LineBox[{{5.228629092630271, 10.120392371486993`}, {5.626785177963242, 
    8.160425093262091}}], 
   LineBox[{{2.6868342606258913`, 7.563190965262637}, {2.2886781752929206`, 
    9.523158243487536}}], 
   LineBox[{{-9.495788193095072, 7.914715867441}, {3.543552805273082, 
    0.5001635324530422}}], 
   LineBox[{{5.228629092630271, 10.120392371486993`}, {2.2886781752929206`, 
    9.523158243487536}}], 
   LineBox[{{5.626785177963242, 8.160425093262091}, {2.6868342606258913`, 
    7.563190965262637}}], 
   LineBox[{{5.228629092630271, 10.120392371486993`}, {3.659114612628353, 
    10.31176712704349}}], 
   LineBox[{{2.2886781752929206`, 9.523158243487536}, {3.659114612628353, 
    10.31176712704349}}], 
   CircleBox[{3.543552805273082, 0.5001635324530422}, 0.5625], 
   CircleBox[{3.5435524700610865`, 0.5001626442887186}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.51244373143884*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.547347488363966, 8.075414997612228}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.773673744181983, 12.537292501193887`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.6390600757715754`, 10.253621810517082`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.324253613184883, 7.35936393598493}, {4.996767619361067, 
    11.82124143956659}}], 
   LineBox[{{-9.77044136354305, 8.791466059239525}, {4.5505798690029, 
    13.253343562821184`}}], 
   LineBox[{{5.445341594381044, 12.203582598720239`}, {4.310727925970636, 
    9.919911908043431}}], 
   LineBox[{{4.1020058939829225`, 12.871002403667536`}, {2.9673922255725147`, 
    10.587331712990732`}}], 
   LineBox[{{5.212520399089712, 10.097985661298505`}, {5.655141149354676, 
    8.147578813629313}}], 
   LineBox[{{2.729530877850885, 7.4836476882318665`}, {2.286910127585921, 
    9.43405453590106}}], 
   LineBox[{{-9.547347488363966, 8.075414997612228}, {3.39965597967346, 
    0.5007796137388336}}], 
   LineBox[{{5.212520399089712, 10.097985661298505`}, {2.286910127585921, 
    9.43405453590106}}], 
   LineBox[{{5.655141149354676, 8.147578813629313}, {2.729530877850885, 
    7.4836476882318665`}}], 
   LineBox[{{5.212520399089712, 10.097985661298505`}, {3.6390600757715754`, 
    10.253621810517082`}}], 
   LineBox[{{2.286910127585921, 9.43405453590106}, {3.6390600757715754`, 
    10.253621810517082`}}], 
   CircleBox[{3.39965597967346, 0.5007796137388336}, 0.5625], 
   CircleBox[{3.3996559906601527`, 0.5007796589121443}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731512816*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.59880769389194, 8.245915326585006}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.79940384694597, 12.452042336707498`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.6159118531593077`, 10.193315549191382`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.388501343385816, 7.526004749543111}, {5.009710197452095, 
    11.732131759665602`}}], 
   LineBox[{{-9.809114044398065, 8.965825903626902}, {4.589097496439845, 
    13.171952913749394`}}], 
   LineBox[{{5.463735255038945, 12.10395645618201}, {4.2802432612522825`, 
    9.845229668665894}}], 
   LineBox[{{4.135072438852995, 12.800128217232986`}, {2.9515804450663325`, 
    10.541401429716872`}}], 
   LineBox[{{5.192914793369541, 10.07902763833341}, {5.686570476424066, 
    8.14090894573794}}], 
   LineBox[{{2.7793924375308627`, 7.400425421156152}, {2.2857367544763374`, 
    9.33854411375162}}], 
   LineBox[{{-9.59880769389194, 8.245915326585006}, {3.2478575973406763`, 
    0.5023250162031871}}], 
   LineBox[{{5.192914793369541, 10.07902763833341}, {2.2857367544763374`, 
    9.33854411375162}}], 
   LineBox[{{5.686570476424066, 8.14090894573794}, {2.7793924375308627`, 
    7.400425421156152}}], 
   LineBox[{{5.192914793369541, 10.07902763833341}, {3.6159118531593077`, 
    10.193315549191382`}}], 
   LineBox[{{2.2857367544763374`, 9.33854411375162}, {3.6159118531593077`, 
    10.193315549191382`}}], 
   CircleBox[{3.2478575973406763`, 0.5023250162031871}, 0.5625], 
   CircleBox[{3.247857608882798, 0.5023250638297507}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731524015*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.649426517097481, 8.425391859508172}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.824713258548741, 12.362304070245916`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.589120937281665, 10.131651337159512`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.452580906560595, 7.701684870725861}, {5.021558869085628, 
    11.638597081463605`}}], 
   LineBox[{{-9.846272127634368, 9.149098848290484}, {4.627867648011853, 
    13.086011059028227`}}], 
   LineBox[{{5.480787591809447, 11.998894563990893`}, {4.2451952705423714`, 
    9.76824183090449}}], 
   LineBox[{{4.168638925288034, 12.725713576500938`}, {2.933046604020958, 
    10.495060843414535`}}], 
   LineBox[{{5.16887051319199, 10.065384622957376`}, {5.721250286513557, 
    8.143178446184132}}], 
   LineBox[{{2.83794102135369, 7.314608786201782}, {2.2855612480321232`, 
    9.236814962975027}}], 
   LineBox[{{-9.649426517097481, 8.425391859508172}, {3.0892948138511276`, 
    0.5054815789282916}}], 
   LineBox[{{5.16887051319199, 10.065384622957376`}, {2.2855612480321232`, 
    9.236814962975027}}], 
   LineBox[{{5.721250286513557, 8.143178446184132}, {2.83794102135369, 
    7.314608786201782}}], 
   LineBox[{{5.16887051319199, 10.065384622957376`}, {3.589120937281665, 
    10.131651337159512`}}], 
   LineBox[{{2.2855612480321232`, 9.236814962975027}, {3.589120937281665, 
    10.131651337159512`}}], 
   CircleBox[{3.0892948138511276`, 0.5054815789282916}, 0.5625], 
   CircleBox[{3.0892934015735785`, 0.5054779423054321}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.5124437315345297`*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.705376290720677, 8.640503983087553}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.8526881453603385`, 12.254748008456225`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.552861987695939, 10.060903902816218`}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.524664089452244, 7.912600761283503}, {5.033400346628772, 
    11.526844786652173`}}], 
   LineBox[{{-9.88608849198911, 9.368407204891604}, {4.671975944091905, 
    12.982651230260274`}}], 
   LineBox[{{5.497936411725046, 11.87244619737846}, {4.198110254060647, 
    9.678602091738455}}], 
   LineBox[{{4.207439878995631, 12.63704981953399}, {2.9076137213312307`, 
    10.443205713893983`}}], 
   LineBox[{{5.134000564282003, 10.060008564111552`}, {5.765381588470828, 
    8.16228413672641}}], 
   LineBox[{{2.9187949473931134`, 7.21521260044317}, {2.287413923204288, 
    9.112937027828313}}], 
   LineBox[{{-9.705376290720677, 8.640503983087553}, {2.9015530705466617`, 
    0.5124456614454473}}], 
   LineBox[{{5.134000564282003, 10.060008564111552`}, {2.287413923204288, 
    9.112937027828313}}], 
   LineBox[{{5.765381588470828, 8.16228413672641}, {2.9187949473931134`, 
    7.21521260044317}}], 
   LineBox[{{5.134000564282003, 10.060008564111552`}, {3.552861987695939, 
    10.060903902816218`}}], 
   LineBox[{{2.287413923204288, 9.112937027828313}, {3.552861987695939, 
    10.060903902816218`}}], 
   CircleBox[{2.9015530705466617`, 0.5124456614454473}, 0.5625], 
   CircleBox[{2.9015621951617536`, 0.5124673337136134}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731544915*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.76694632399299, 8.903663701970299}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.883473161996495, 12.123168149014852`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{3.4994843002601987`, 9.98142240533054}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-9.605971101640762, 8.171142727670825}, {5.044448384348723, 
    11.390647174715378`}}], 
   LineBox[{{-9.927921546345218, 9.636184676269773}, {4.722497939644267, 
    12.855689123314326`}}], 
   LineBox[{{5.513398380727176, 11.716112601445353`}, {4.1294095189908795`, 
    9.57436685776104}}], 
   LineBox[{{4.253547943265814, 12.53022369658435}, {2.8695590815295184`, 
    10.388477952900038`}}], 
   LineBox[{{5.07769772059452, 10.07755980635972}, {5.824347969963265, 
    8.222158662370207}}], 
   LineBox[{{3.041246253978995, 7.1021832883170894`}, {2.2945960046102503`, 
    8.957584432306602}}], 
   LineBox[{{-9.76694632399299, 8.903663701970299}, {2.6775631203956944`, 
    0.5290482070045215}}], 
   LineBox[{{5.07769772059452, 10.07755980635972}, {2.2945960046102503`, 
    8.957584432306602}}], 
   LineBox[{{5.824347969963265, 8.222158662370207}, {3.041246253978995, 
    7.1021832883170894`}}], 
   LineBox[{{5.07769772059452, 10.07755980635972}, {3.4994843002601987`, 
    9.98142240533054}}], 
   LineBox[{{2.2945960046102503`, 8.957584432306602}, {3.4994843002601987`, 
    9.98142240533054}}], 
   CircleBox[{2.6775631203956944`, 0.5290482070045215}, 0.5625], 
   CircleBox[{2.6775588872753757`, 0.5290399662569533}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731555307*^9}],

Cell[BoxData[
 GraphicsBox[{
   CircleBox[{-9.999911169006516, 11.092149875192382`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.999955584503258, 11.028925062403811`}, NCache[
    Rational[3, 4], 0.75]], 
   CircleBox[{4.978459339110124, 8.479015669614727}, NCache[
    Rational[3, 4], 0.75]], 
   LineBox[{{-10.003072409645945`, 10.342156537516892`}, {4.996794343863829, 
    10.278931724728322`}}], 
   LineBox[{{-9.996749928367088, 11.842143212867871`}, {5.003116825142687, 
    11.7789184000793}}], 
   LineBox[{{5.749928935323577, 11.022602637288184`}, {5.728432689930443, 
    8.4726932444991}}], 
   LineBox[{{4.249982233682939, 11.035247487519438`}, {4.228485988289805, 
    8.485338094730354}}], 
   LineBox[{{6.472017087178376, 7.960088648555607}, {6.446727761134733, 
    5.960248542450057}}], 
   LineBox[{{3.446967601976408, 5.998182531515521}, {3.472256928020051, 
    7.998022637621071}}], 
   LineBox[{{-9.999911169006516, 11.092149875192382`}, {-24.999378185412894`, 
    11.218598377504936`}}], 
   LineBox[{{6.472017087178376, 7.960088648555607}, {3.472256928020051, 
    7.998022637621071}}], 
   LineBox[{{6.446727761134733, 5.960248542450057}, {3.446967601976408, 
    5.998182531515521}}], 
   LineBox[{{6.472017087178376, 7.960088648555607}, {4.978459339110124, 
    8.479015669614727}}], 
   LineBox[{{3.472256928020051, 7.998022637621071}, {4.978459339110124, 
    8.479015669614727}}], 
   CircleBox[{-24.999378185412894`, 11.218598377504936`}, 0.5625], 
   CircleBox[{0.004215000000000004, 0.004215000000000004}, 0.5], 
   LineBox[{{0, 11.05}, {11.05, 0}}], LineBox[{{0, 11.05}, {-11.05, 0}}]},
  AspectRatio->Automatic,
  Axes->True,
  ImageSize->600,
  PlotRange->{{-42.05, 84.1}, {0, 63.074999999999996`}}]], "Print",
 CellChangeTimes->{3.51244018491819*^9, 3.512440770384869*^9, 
  3.512441425929867*^9, 3.512441723409668*^9, 3.512442198519747*^9, 
  3.512442483161292*^9, 3.512442716609419*^9, 3.5124428671111603`*^9, 
  3.512442933406946*^9, 3.512443124127716*^9, 3.512443385330233*^9, 
  3.512443570229259*^9, 3.512443731574717*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Evaluator->"Local",
WindowSize->{769, 709},
WindowMargins->{{Automatic, 794}, {Automatic, 122}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 79, 2, 67, "Section",
 Evaluatable->False],
Cell[661, 26, 213, 4, 41, "Text"],
Cell[877, 32, 184, 4, 43, "Input"],
Cell[CellGroupData[{
Cell[1086, 40, 118, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[1207, 44, 206, 5, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1438, 53, 199, 5, 27, "Input"],
Cell[1640, 60, 144, 2, 20, "Print"]
}, Open  ]],
Cell[1799, 65, 220, 5, 41, "Text",
 Evaluatable->False],
Cell[2022, 72, 730, 21, 88, "Input"],
Cell[2755, 95, 207, 5, 26, "Text",
 Evaluatable->False],
Cell[2965, 102, 14315, 495, 2113, "Input"],
Cell[17283, 599, 3222, 98, 88, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20542, 702, 82, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[20627, 706, 14701, 375, 993, "Input"],
Cell[35331, 1083, 2186, 62, 74, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37554, 1150, 107, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[37664, 1154, 34343, 832, 896, "Input"],
Cell[72010, 1988, 4923, 134, 134, "Input"],
Cell[76936, 2124, 3323, 91, 85, "Input"],
Cell[80262, 2217, 2551, 70, 156, "Input"],
Cell[82816, 2289, 1744, 51, 83, "Input"],
Cell[84563, 2342, 171, 5, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84771, 2352, 107, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[84881, 2356, 16864, 436, 427, "Input"],
Cell[101748, 2794, 4923, 134, 134, "Input"],
Cell[106674, 2930, 3323, 91, 85, "Input"],
Cell[110000, 3023, 1793, 54, 47, "Input"],
Cell[111796, 3079, 2151, 63, 65, "Input"],
Cell[113950, 3144, 2182, 64, 65, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116169, 3213, 110, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[116282, 3217, 38533, 993, 1033, "Input"],
Cell[154818, 4212, 4923, 134, 134, "Input"],
Cell[159744, 4348, 3323, 91, 85, "Input"],
Cell[163070, 4441, 8789, 248, 271, "Input"],
Cell[171862, 4691, 558, 17, 30, "Input"],
Cell[172423, 4710, 620, 20, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[173080, 4735, 85, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[173168, 4739, 7030, 198, 203, "Input"],
Cell[180201, 4939, 440460, 9502, 14872, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[620710, 14447, 84, 2, 67, "Section",
 Evaluatable->False],
Cell[620797, 14451, 313, 6, 56, "Text"],
Cell[621113, 14459, 275, 10, 26, "Text",
 Evaluatable->False],
Cell[621391, 14471, 774370, 12835, 283, 702013, 11645, "GraphicsData", \
"PostScript", "Graphics",
 Evaluatable->False],
Cell[1395764, 27308, 4156, 111, 601, "Input"],
Cell[1399923, 27421, 141, 3, 26, "Text"],
Cell[1400067, 27426, 633, 20, 118, "Input"],
Cell[1400703, 27448, 157, 5, 26, "Text",
 Evaluatable->False],
Cell[1400863, 27455, 4020, 127, 343, "Input"],
Cell[CellGroupData[{
Cell[1404908, 27586, 537, 17, 88, "Input"],
Cell[CellGroupData[{
Cell[1405470, 27607, 426, 8, 20, "Print"],
Cell[1405899, 27617, 481, 9, 20, "Print"],
Cell[1406383, 27628, 426, 8, 20, "Print"],
Cell[1406812, 27638, 457, 8, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[1407296, 27650, 222, 5, 41, "Text",
 Evaluatable->False],
Cell[1407521, 27657, 29368, 758, 2316, "Input"],
Cell[1436892, 28417, 110, 2, 26, "Text",
 Evaluatable->False],
Cell[1437005, 28421, 774370, 12835, 283, 702013, 11645, "GraphicsData", \
"PostScript", "Graphics",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[2211400, 41260, 250, 7, 27, "Input"],
Cell[2211653, 41269, 19351, 321, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2231041, 41595, 225, 6, 27, "Input"],
Cell[2231269, 41603, 18226, 303, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2249532, 41911, 225, 6, 27, "Input"],
Cell[2249760, 41919, 23753, 393, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2273550, 42317, 225, 6, 27, "Input"],
Cell[2273778, 42325, 18192, 302, 229, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2292007, 42632, 224, 6, 27, "Input"],
Cell[2292234, 42640, 19814, 329, 245, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2312085, 42974, 224, 6, 27, "Input"],
Cell[2312312, 42982, 5363, 92, 233, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2317712, 43079, 321, 9, 27, "Input"],
Cell[2318036, 43090, 4736, 82, 66, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2322809, 43177, 80, 2, 24, "Subsubsection",
 Evaluatable->False],
Cell[2322892, 43181, 358, 7, 56, "Text",
 Evaluatable->False],
Cell[2323253, 43190, 774370, 12835, 283, 702013, 11645, "GraphicsData", \
"PostScript", "Graphics",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[3097648, 56029, 28481, 799, 1565, "Input"],
Cell[CellGroupData[{
Cell[3126154, 56832, 2086, 41, 323, "Print"],
Cell[3128243, 56875, 2078, 41, 323, "Print"],
Cell[3130324, 56918, 2064, 41, 323, "Print"],
Cell[3132391, 56961, 2068, 41, 323, "Print"],
Cell[3134462, 57004, 2069, 41, 323, "Print"],
Cell[3136534, 57047, 2080, 41, 323, "Print"],
Cell[3138617, 57090, 2080, 41, 323, "Print"],
Cell[3140700, 57133, 2067, 41, 323, "Print"],
Cell[3142770, 57176, 2095, 41, 323, "Print"],
Cell[3144868, 57219, 2075, 41, 323, "Print"],
Cell[3146946, 57262, 2068, 41, 323, "Print"],
Cell[3149017, 57305, 2077, 41, 323, "Print"],
Cell[3151097, 57348, 2082, 41, 323, "Print"],
Cell[3153182, 57391, 2086, 41, 323, "Print"],
Cell[3155271, 57434, 2084, 41, 323, "Print"],
Cell[3157358, 57477, 2082, 41, 323, "Print"],
Cell[3159443, 57520, 2073, 41, 323, "Print"],
Cell[3161519, 57563, 2092, 41, 323, "Print"],
Cell[3163614, 57606, 2079, 41, 323, "Print"],
Cell[3165696, 57649, 2086, 41, 323, "Print"],
Cell[3167785, 57692, 2077, 41, 323, "Print"],
Cell[3169865, 57735, 2082, 41, 323, "Print"],
Cell[3171950, 57778, 2083, 41, 323, "Print"],
Cell[3174036, 57821, 2073, 41, 323, "Print"],
Cell[3176112, 57864, 2060, 41, 323, "Print"],
Cell[3178175, 57907, 2075, 41, 323, "Print"],
Cell[3180253, 57950, 2075, 41, 323, "Print"],
Cell[3182331, 57993, 2067, 41, 323, "Print"],
Cell[3184401, 58036, 2083, 41, 323, "Print"],
Cell[3186487, 58079, 2077, 41, 323, "Print"],
Cell[3188567, 58122, 2070, 41, 323, "Print"],
Cell[3190640, 58165, 2079, 41, 323, "Print"],
Cell[3192722, 58208, 2072, 41, 323, "Print"],
Cell[3194797, 58251, 2085, 41, 323, "Print"],
Cell[3196885, 58294, 2069, 41, 323, "Print"],
Cell[3198957, 58337, 2047, 41, 323, "Print"],
Cell[3201007, 58380, 2076, 41, 323, "Print"],
Cell[3203086, 58423, 2084, 41, 323, "Print"],
Cell[3205173, 58466, 2066, 41, 323, "Print"],
Cell[3207242, 58509, 2072, 41, 323, "Print"],
Cell[3209317, 58552, 2086, 41, 323, "Print"],
Cell[3211406, 58595, 2074, 41, 323, "Print"],
Cell[3213483, 58638, 2068, 41, 323, "Print"],
Cell[3215554, 58681, 2077, 41, 323, "Print"],
Cell[3217634, 58724, 2076, 41, 323, "Print"],
Cell[3219713, 58767, 2071, 41, 323, "Print"],
Cell[3221787, 58810, 2089, 41, 323, "Print"],
Cell[3223879, 58853, 2080, 41, 323, "Print"],
Cell[3225962, 58896, 2074, 41, 323, "Print"],
Cell[3228039, 58939, 2077, 41, 323, "Print"],
Cell[3230119, 58982, 2070, 41, 323, "Print"],
Cell[3232192, 59025, 2059, 41, 323, "Print"],
Cell[3234254, 59068, 2069, 41, 323, "Print"],
Cell[3236326, 59111, 2070, 41, 323, "Print"],
Cell[3238399, 59154, 2070, 41, 323, "Print"],
Cell[3240472, 59197, 2077, 41, 323, "Print"],
Cell[3242552, 59240, 2067, 41, 323, "Print"],
Cell[3244622, 59283, 2065, 41, 323, "Print"],
Cell[3246690, 59326, 2072, 41, 323, "Print"],
Cell[3248765, 59369, 2064, 41, 323, "Print"],
Cell[3250832, 59412, 2047, 41, 323, "Print"],
Cell[3252882, 59455, 2071, 41, 323, "Print"],
Cell[3254956, 59498, 2070, 41, 323, "Print"],
Cell[3257029, 59541, 2080, 41, 323, "Print"],
Cell[3259112, 59584, 2063, 41, 323, "Print"],
Cell[3261178, 59627, 2072, 41, 323, "Print"],
Cell[3263253, 59670, 2073, 41, 323, "Print"],
Cell[3265329, 59713, 2064, 41, 323, "Print"],
Cell[3267396, 59756, 2048, 41, 323, "Print"],
Cell[3269447, 59799, 2076, 41, 323, "Print"],
Cell[3271526, 59842, 2079, 41, 323, "Print"],
Cell[3273608, 59885, 2066, 41, 323, "Print"],
Cell[3275677, 59928, 2085, 41, 323, "Print"],
Cell[3277765, 59971, 2071, 41, 323, "Print"],
Cell[3279839, 60014, 2069, 41, 323, "Print"],
Cell[3281911, 60057, 2075, 41, 323, "Print"],
Cell[3283989, 60100, 2059, 41, 323, "Print"],
Cell[3286051, 60143, 2069, 41, 323, "Print"],
Cell[3288123, 60186, 2069, 41, 323, "Print"],
Cell[3290195, 60229, 2064, 41, 323, "Print"],
Cell[3292262, 60272, 2077, 41, 323, "Print"],
Cell[3294342, 60315, 2085, 41, 323, "Print"],
Cell[3296430, 60358, 2077, 41, 323, "Print"],
Cell[3298510, 60401, 2058, 41, 323, "Print"],
Cell[3300571, 60444, 2067, 41, 323, "Print"],
Cell[3302641, 60487, 2073, 41, 323, "Print"],
Cell[3304717, 60530, 2075, 41, 323, "Print"],
Cell[3306795, 60573, 2062, 41, 323, "Print"],
Cell[3308860, 60616, 2067, 41, 323, "Print"],
Cell[3310930, 60659, 2059, 41, 323, "Print"],
Cell[3312992, 60702, 2058, 41, 323, "Print"],
Cell[3315053, 60745, 2056, 41, 323, "Print"],
Cell[3317112, 60788, 2061, 41, 323, "Print"],
Cell[3319176, 60831, 2082, 41, 323, "Print"],
Cell[3321261, 60874, 2067, 41, 323, "Print"],
Cell[3323331, 60917, 2077, 41, 323, "Print"],
Cell[3325411, 60960, 2080, 41, 323, "Print"],
Cell[3327494, 61003, 2082, 41, 323, "Print"],
Cell[3329579, 61046, 2077, 41, 323, "Print"],
Cell[3331659, 61089, 2075, 41, 323, "Print"],
Cell[3333737, 61132, 2076, 41, 323, "Print"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
