(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    116718,       3484]
NotebookOptionsPosition[    107707,       3180]
NotebookOutlinePosition[    108063,       3196]
CellTagsIndexPosition[    108020,       3193]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Utilizing Vector Notation in Mathematica\[Dash]Example 1\
\>", "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Input the definitions for the vector operations", "Subsection"],

Cell["\<\
Input the vector definition with the command that follows.  The path will \
depend on where  the definitions reside on the local system.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Get", "[", 
  RowBox[{"StringJoin", "[", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<vectors3.m\>\""}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5184549584944*^9, 3.5184549628311996`*^9}, {
   3.519556403575*^9, 3.519556403575*^9}, 3.536265185608418*^9},
 AspectRatioFixed->True],

Cell[BoxData["\<\"These Engineering Vector algorithms are copyright Alan A. \
Barhorst\"\>"], "Print",
 CellChangeTimes->{3.5184549642352*^9, 3.5184552224872*^9, 
  3.5184560553556004`*^9, 3.519556404745*^9, 3.5195564518726*^9, 
  3.536265194490871*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the symbols used for Unit Vectors and Unit Dyads", "Subsection"],

Cell[TextData[{
 "Define Unit Vectors and Unit Dyads for however many frames we need for the \
system. For this example we will use three frames of reference, with the \
frame ",
 StyleBox["N",
  FontWeight->"Bold"],
 " being the Newtonian frame.  The header ",
 StyleBox["unitVector",
  FontWeight->"Bold"],
 " must be included.  The arguments are ",
 StyleBox["[frame, symbol, direction]",
  FontWeight->"Bold"],
 ".  So unit vector ",
 StyleBox["b[1]=unitVector[B,b,1]",
  FontWeight->"Bold"],
 " is the vector in the ",
 StyleBox["B",
  FontWeight->"Bold"],
 " frame in the ",
 StyleBox["1",
  FontWeight->"Bold"],
 " direction.  The unitDyads are double vectors used to describe inertia \
properties."
}], "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"B", ",", "b", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"c", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"C", ",", "c", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"n", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"N", ",", "n", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"bb", "[", 
   RowBox[{"a_", ",", "c_"}], "]"}], ":=", 
  RowBox[{"unitDyad", "[", 
   RowBox[{
    RowBox[{"b", "[", "a", "]"}], ",", 
    RowBox[{"b", "[", "c", "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"cc", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], ":=", 
  RowBox[{"unitDyad", "[", 
   RowBox[{
    RowBox[{"c", "[", "a", "]"}], ",", 
    RowBox[{"c", "[", "b", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5184549675112*^9, 3.5184549675112*^9}},
 AspectRatioFixed->True],

Cell["Now to see what they look like.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"b", "[", "1", "]"}], "\n", 
 RowBox[{"c", "[", "1", "]"}], "\n", 
 RowBox[{"n", "[", "1", "]"}], "\n", 
 RowBox[{"bb", "[", 
  RowBox[{"1", ",", "1"}], "]"}], "\n", 
 RowBox[{"cc", "[", 
  RowBox[{"2", ",", "1"}], "]"}]}], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["b", "^"], "1"]], "Output",
 CellChangeTimes->{3.5184549708028*^9, 3.5184552241252003`*^9, 
  3.5195564102674*^9, 3.5195564534793997`*^9, 3.536265194623425*^9}],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["c", "^"], "1"]], "Output",
 CellChangeTimes->{3.5184549708028*^9, 3.5184552241252003`*^9, 
  3.5195564102674*^9, 3.5195564534793997`*^9, 3.536265194625659*^9}],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["n", "^"], "1"]], "Output",
 CellChangeTimes->{3.5184549708028*^9, 3.5184552241252003`*^9, 
  3.5195564102674*^9, 3.5195564534793997`*^9, 3.5362651946273613`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}],
  SequenceForm[
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
  Editable->False]], "Output",
 CellChangeTimes->{3.5184549708028*^9, 3.5184552241252003`*^9, 
  3.5195564102674*^9, 3.5195564534793997`*^9, 3.5362651946292562`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["c", "^"], "2"], "\[InvisibleSpace]", 
   SubscriptBox[
    OverscriptBox["c", "^"], "1"]}],
  SequenceForm[
   $CellContext`unitVector[C, $CellContext`c, 2], 
   $CellContext`unitVector[C, $CellContext`c, 1]],
  Editable->False]], "Output",
 CellChangeTimes->{3.5184549708028*^9, 3.5184552241252003`*^9, 
  3.5195564102674*^9, 3.5195564534793997`*^9, 3.536265194631055*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operations with the vector notation.", "Subsection"],

Cell[CellGroupData[{

Cell["Normal operations", "Subsubsection"],

Cell["\<\
Now we are in a position to perform vector operation.  Consider the following \
simple operations.\
\>", "Text"],

Cell["In the same frame  right-handed systems are assumed.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], " ", "\[Cross]", " ", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["n", "^"], "3"]], "Output",
 CellChangeTimes->{
  3.5184549729712*^9, 3.5184552258568*^9, {3.5195564451646*^9, 
   3.5195564559754*^9}, 3.536265194688686*^9}]
}, Open  ]],

Cell["\<\
where the cross product can be input from the pallet \"\[Cross]\" or by \
typing [Esc]cross[Esc] or by using \"\\[ Cross ] \"  without the extra space \
and the quotation marks.\
\>", "Text"],

Cell["Continuing with the example...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  SubscriptBox[
   OverscriptBox["n", "^"], "1"]}]], "Output",
 CellChangeTimes->{3.5184549742036*^9, 3.5184552265587997`*^9, 
  3.5195564580034*^9, 3.536265194723888*^9}]
}, Open  ]],

Cell["The Dot product is also defined.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], ".", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184549750928*^9, 3.5184552277756*^9, 3.5195564585806*^9,
   3.536265194756906*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5184549762939997`*^9, 3.5195564593138*^9, 
  3.536265194790534*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184549774016*^9, 3.5195564608582*^9, 
  3.536265194824114*^9}]
}, Open  ]],

Cell["The normal i,j and k vectors are predefined.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"i", " ", "\[Cross]", "j"}]], "Input"],

Cell[BoxData[
 OverscriptBox["\<\"k\"\>", "^"]], "Output",
 CellChangeTimes->{3.5184549793515997`*^9, 3.519556461841*^9, 
  3.5362651948571033`*^9}]
}, Open  ]],

Cell["Etcetera...", "Text"],

Cell["Now notice how the Dyads work.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bb", "[", 
  RowBox[{"1", ",", "2"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"]}],
  SequenceForm[
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
  Editable->False]], "Output",
 CellChangeTimes->{3.5184549806308002`*^9, 3.5195564641342*^9, 
  3.536265194891142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"bb", "[", 
   RowBox[{"1", ",", "2"}], "]"}], " ", "\[Cross]", " ", 
  RowBox[{"b", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}],
  SequenceForm[
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
  Editable->False]], "Output",
 CellChangeTimes->{3.5184549818943996`*^9, 3.5195564646802*^9, 
  3.536265194924418*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "1", "]"}], ".", 
  RowBox[{"bb", "[", 
   RowBox[{"1", ",", "2"}], "]"}]}]], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["b", "^"], "2"]], "Output",
 CellChangeTimes->{3.5184549825652*^9, 3.519556465429*^9, 
  3.536265194957471*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "1", "]"}], ".", 
  RowBox[{
   RowBox[{"bb", "[", 
    RowBox[{"1", ",", "2"}], "]"}], " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "3", "]"}]}]}]], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["b", "^"], "1"]], "Output",
 CellChangeTimes->{3.5184549833608*^9, 3.5195564660062*^9, 
  3.5362651949911003`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "2", "]"}], ".", 
  RowBox[{"bb", "[", 
   RowBox[{"1", ",", "2"}], "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184549852796*^9, 3.5195564665678*^9, 3.5362651950243*^9}
  ]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"b", "[", "2", "]"}], " ", "\[Cross]", " ", 
  RowBox[{"bb", "[", 
   RowBox[{"1", ",", "2"}], "]"}]}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}], "\[InvisibleSpace]", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"]}],
  SequenceForm[-$CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
   $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
  Editable->False]], "Output",
 CellChangeTimes->{3.518454985888*^9, 3.5195564682525997`*^9, 
  3.536265195056999*^9}]
}, Open  ]],

Cell["Etcetera...", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operations between reference frames", "Subsubsection"],

Cell["Consider the following operations.", "Text"],

Cell["\<\
Notice how the cross product has precedence in order for the operation to be \
defined.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "2", "]"}]}], ".", 
  RowBox[{"n", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "3"], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "3"]}]], "Output",
 CellChangeTimes->{3.5184549871048*^9, 3.5195564699686003`*^9, 
  3.536265195094593*^9}]
}, Open  ]],

Cell["\<\
Now notice how the scalar triple product is utilized to permute the \"b\" \
vectors together such that their cross product is found first.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], " ", "\[Cross]", 
   RowBox[{"n", "[", "2", "]"}]}], ".", 
  RowBox[{"b", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "2"], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "2"]}]], "Output",
 CellChangeTimes->{3.5184549878224*^9, 3.5195564705769997`*^9, 
  3.536265195129751*^9}]
}, Open  ]],

Cell["\<\
In both cases above, the final Dot product is not defined as of yet.  As in \
the textbook we will reduce this at the latest possible time in the use of \
the symbols in a derivation of the equations of motion for some system.\
\>", "Text"],

Cell["A few more examples.", "Text"],

Cell["\<\
The following is irreducible at this point.  We would need to know more about \
the relative orientation of the coordinate frames.  More on this  below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "2", "]"}]}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[Cross]", 
   SubscriptBox[
    OverscriptBox["c", "^"], "2"]}], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "1"]}]], "Output",
 CellChangeTimes->{3.5184549894604*^9, 3.5195564718873997`*^9, 
  3.5362651951743298`*^9}]
}, Open  ]],

Cell["\<\
The canonical order for Mathematica is to have the Cross product first \
because Cross is before Dot alphabetically.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], ".", 
  RowBox[{
   RowBox[{"b", "[", "2", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], "\[Cross]", 
   SubscriptBox[
    OverscriptBox["c", "^"], "1"]}], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "3"]}]], "Output",
 CellChangeTimes->{3.5184549902248*^9, 3.5195564728858*^9, 
  3.536265195207493*^9}]
}, Open  ]],

Cell["\<\
Notice how the simple inline notation is used for typing so that it is \
simpler to input, but the fancy output is used.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples with more complicated expressions", "Subsubsection"],

Cell["Position vector to some point.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", "=", " ", 
  RowBox[{
   RowBox[{"p1", " ", 
    RowBox[{"n", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"p2", " ", 
    RowBox[{"n", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{"p3", " ", 
    RowBox[{"n", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{"p3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.5184549941404*^9, 3.5195564744146*^9, 
  3.536265195276865*^9}]
}, Open  ]],

Cell["Position vector to some other point.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrT", " ", "=", " ", 
  RowBox[{
   RowBox[{"t1", " ", 
    RowBox[{"n", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"t2", " ", 
    RowBox[{"n", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{"t3", " ", 
    RowBox[{"n", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{"t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.518454995248*^9, 3.5195564751478*^9, 
  3.536265195342174*^9}]
}, Open  ]],

Cell["Now some operations.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", ".", " ", "OrT"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", " ", "t1"}], "+", 
  RowBox[{"p2", " ", "t2"}], "+", 
  RowBox[{"p3", " ", "t3"}]}]], "Output",
 CellChangeTimes->{3.5184549964648*^9, 3.5195564766921997`*^9, 
  3.536265195412703*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", "\[Cross]", " ", "OrT"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "p3"}], " ", "t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p2", " ", "t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p3", " ", "t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "-", 
  RowBox[{"p1", " ", "t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "-", 
  RowBox[{"p2", " ", "t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}], "+", 
  RowBox[{"p1", " ", "t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.5184549978064003`*^9, 3.5195564784238*^9, 
  3.5362651954974127`*^9}]
}, Open  ]],

Cell["\<\
Now if we want to gather like terms we can use the following operation\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "gatherVectors"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "p3"}], " ", "t2"}], "+", 
     RowBox[{"p2", " ", "t3"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p3", " ", "t1"}], "-", 
     RowBox[{"p1", " ", "t3"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "p2"}], " ", "t1"}], "+", 
     RowBox[{"p1", " ", "t2"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.5184549996316*^9, 3.5195564798122*^9, 
  3.536265195564864*^9}]
}, Open  ]],

Cell["\<\
where Mathematica's Postfix function ability is used. The operation \
gatherVectors[x] is the same as x//gatherVectors.\
\>", "Text"],

Cell["I can also chain operations together as follows.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"OrP", " ", "\[Cross]", " ", "OrT"}], " ", ".", " ", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "p3"}], " ", "t2"}], "+", 
  RowBox[{"p2", " ", "t3"}]}]], "Output",
 CellChangeTimes->{3.5184550013632*^9, 3.5195564819026003`*^9, 
  3.536265195708453*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differention of the multiple frame vectors", "Subsubsection"],

Cell["\<\
In order to make use of differentiation in multiple reference frames we must \
know the angular velocity of the frames with respect to the frame the \
differentiation is with respect to.\
\>", "Text"],

Cell["We define the angular velocity of a frame as follows.", "Text"],

Cell[TextData[{
 "The angular velocity of frame ",
 StyleBox["B",
  FontWeight->"Bold"],
 " with respect to ",
 StyleBox["N",
  FontWeight->"Bold"],
 " is given by:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NwB", " ", "=", " ", 
  RowBox[{
   RowBox[{"omega", "[", 
    RowBox[{"N", ",", "B"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"q1", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q2", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"b", "[", "2", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q3", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"b", "[", "3", "]"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], " ", 
   RowBox[{
    SuperscriptBox["q1", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "3"], " ", 
   RowBox[{
    SuperscriptBox["q3", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184550033599997`*^9, 3.5195564844765997`*^9, 
  3.536265195776338*^9}]
}, Open  ]],

Cell[TextData[{
 "where the symbol ",
 StyleBox["omega[X,Y]",
  FontWeight->"Bold"],
 " must be defined.  The symbol on the left can be any convenient symbol and \
the expression on the right is the vector expression for the angular \
velocity, which may be generated from simple angular velocity expressions.\n\
The two equals signs in this equation equate all of the expressions to one \
another. The Vector Tools looks for the omega[] function to calculate angular \
velocity. A simple explination of why this is necessary:\n\nSymbol you want \
to use for angluar velocity (Eg: ",
 StyleBox["NwB) ",
  FontWeight->"Bold"],
 "= is equal to what the compiler needs to see (omega[refrence frame, moving \
frame]) = is equal to the function that describes the motion."
}], "Text",
 CellChangeTimes->{{3.5195565030094*^9, 3.5195566046434*^9}, {
  3.519556649587*^9, 3.5195567368066*^9}}],

Cell[TextData[{
 "Similarly we can write the angular velocity of frame ",
 StyleBox["C",
  FontWeight->"Bold"],
 " with respect to Frame ",
 StyleBox["N",
  FontWeight->"Bold"],
 " as:"
}], "Text",
 CellChangeTimes->{3.5195566249077997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NwC", " ", "=", " ", 
  RowBox[{
   RowBox[{"omega", "[", 
    RowBox[{"N", ",", "C"}], "]"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"q4", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"c", "[", "1", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q5", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"c", "[", "2", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"q6", "'"}], "[", "t", "]"}], " ", 
     RowBox[{"c", "[", "3", "]"}]}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["c", "^"], "1"], " ", 
   RowBox[{
    SuperscriptBox["q4", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["c", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q5", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["c", "^"], "3"], " ", 
   RowBox[{
    SuperscriptBox["q6", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.518455004842*^9, 3.5195564852722*^9, 
  3.536265195810307*^9}]
}, Open  ]],

Cell["Now consider differentiation of vector expressions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DvDt", "[", 
  RowBox[{"N", ",", 
   RowBox[{"b", "[", "1", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}], " ", 
   RowBox[{
    SuperscriptBox["q2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q3", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184550060587997`*^9, 3.5195567432650003`*^9, 
  3.536265195877624*^9}]
}, Open  ]],

Cell[TextData[{
 "which describes how to take the derivative with respect to time of the \
vector ",
 StyleBox["b[1]",
  FontWeight->"Bold"],
 " as seen in frame ",
 StyleBox["N",
  FontWeight->"Bold"],
 ".  Note we can also use the cross product form and write:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NwB", " ", "\[Cross]", " ", 
  RowBox[{"b", "[", "1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}], " ", 
   RowBox[{
    SuperscriptBox["q2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q3", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184550070727997`*^9, 3.5195567442478*^9, 
  3.5362651959104147`*^9}]
}, Open  ]],

Cell[TextData[{
 "which is really how ",
 StyleBox["DvDt[X,Y] ",
  FontWeight->"Bold"],
 "works except that ",
 StyleBox["DvDt",
  FontWeight->"Bold"],
 " knows which frame to use."
}], "Text"],

Cell[TextData[{
 "To see that ",
 StyleBox["b[1]",
  FontWeight->"Bold"],
 " is fixed in ",
 StyleBox["B",
  FontWeight->"Bold"],
 " we can write:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DvDt", "[", 
  RowBox[{"B", ",", 
   RowBox[{"b", "[", "1", "]"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184550090852003`*^9, 3.5195567455425997`*^9, 
  3.5362651959434223`*^9}]
}, Open  ]],

Cell["We can also differentiate arbitrary expressions.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v", " ", "=", " ", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"d", " ", 
    RowBox[{"c", "[", "3", "]"}]}], " ", "+", " ", 
   RowBox[{"e", " ", 
    RowBox[{"n", "[", "2", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}], "+", 
  RowBox[{"d", " ", 
   SubscriptBox[
    OverscriptBox["c", "^"], "3"]}], "+", 
  RowBox[{"e", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}]}]], "Output",
 CellChangeTimes->{3.51845501077*^9, 3.5195567470246*^9, 3.536265195977768*^9}
  ]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DvDt", "[", 
  RowBox[{"N", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Dt", "[", 
    RowBox[{"a", ",", "t"}], "]"}], " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}], "+", 
  RowBox[{
   RowBox[{"Dt", "[", 
    RowBox[{"d", ",", "t"}], "]"}], " ", 
   SubscriptBox[
    OverscriptBox["c", "^"], "3"]}], "+", 
  RowBox[{
   RowBox[{"Dt", "[", 
    RowBox[{"e", ",", "t"}], "]"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox[
        OverscriptBox["b", "^"], "3"]}], " ", 
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], " ", 
      RowBox[{
       SuperscriptBox["q3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox[
        OverscriptBox["c", "^"], "2"]}], " ", 
      RowBox[{
       SuperscriptBox["q4", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["c", "^"], "1"], " ", 
      RowBox[{
       SuperscriptBox["q5", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5184550114407997`*^9, 3.5195567483817997`*^9, 
  3.5362651960113363`*^9}]
}, Open  ]],

Cell["\<\
where Dt[x,t] is the first time derivative of the coefficients.  If they are \
supposed to be constants we can write:\
\>", "Text",
 CellChangeTimes->{{3.5195567579602003`*^9, 3.5195567847454*^9}}],

Cell["\<\
 ** * THIS IS A VERY IMPORTANT STEP! *** 
If you leave this out, you will see some strange results, as seen above!\
\>", "Text",
 CellChangeTimes->{{3.5195567871633997`*^9, 3.5195568133246*^9}, {
  3.5195569099042*^9, 3.5195569436001997`*^9}}],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "d", ",", "e"}], "}"}], ",", "Constant"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5195568290962*^9, 3.5195568328714*^9}, {
  3.5195568920266*^9, 3.5195568927754*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DvDt", "[", 
  RowBox[{"N", ",", "v"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox[
        OverscriptBox["b", "^"], "3"]}], " ", 
      RowBox[{
       SuperscriptBox["q2", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], " ", 
      RowBox[{
       SuperscriptBox["q3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"d", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SubscriptBox[
        OverscriptBox["c", "^"], "2"]}], " ", 
      RowBox[{
       SuperscriptBox["q4", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "+", 
     RowBox[{
      SubscriptBox[
       OverscriptBox["c", "^"], "1"], " ", 
      RowBox[{
       SuperscriptBox["q5", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.5184550137028*^9, 3.5195567532802*^9, 3.5195569523674*^9,
   3.536265196076878*^9}]
}, Open  ]],

Cell["We can distribute scalars into the expressions as follows:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "distributeScalars"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "a"}], " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "3"], " ", 
   RowBox[{
    SuperscriptBox["q2", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"a", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q3", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"d", " ", 
   SubscriptBox[
    OverscriptBox["c", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q4", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"d", " ", 
   SubscriptBox[
    OverscriptBox["c", "^"], "1"], " ", 
   RowBox[{
    SuperscriptBox["q5", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184550149508*^9, 3.5195569542706003`*^9, 
  3.5362651961113033`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A simple example", "Subsection"],

Cell[CellGroupData[{

Cell["System Extent, Choosing Coordinates, and Define the System", \
"Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 0.681193
200 dict begin
MathPictureStart
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 436 297 0 0 ]
] MathScale
% Start of Graphics
%!PS-Adobe-2.0 EPSF-2.0
%%Title: 
%%Creator: AppsoftDraw
%%CreationDate: Wed Apr  2 22:15:27 1997
%%For: alan
%%DocumentFonts: (atend)
%%Pages: 0 0
%%BoundingBox: 0 0 436 297
%%NXNextStepVersion: 3.0
%%EndComments

%%BeginProcSet: /usr/lib/NextStep/printPackage.ps 3.0
%!
% NeXT Printing Package
% Version: 3.1
% Copyright: 1988, NeXT, Inc.

/__NXdef{1 index where{pop pop pop}{def}ifelse}bind def
/__NXbdef{1 index where{pop pop pop}{bind def}ifelse}bind def
/UserObjects 10 array __NXdef
/defineuserobject{
\texch dup 1 add dup UserObjects length gt{
\t\tarray dup 0 UserObjects putinterval
\t\t/UserObjects exch def
\t}{pop}ifelse UserObjects exch 3 -1 roll put
}__NXbdef
/undefineuserobject{UserObjects exch null put}__NXbdef
/execuserobject{UserObjects exch get exec}__NXbdef
/__NXRectPath{4 2 roll moveto 1 index 0 rlineto
0 exch rlineto neg 0 rlineto closepath}__NXbdef
/__NXProcessRectArgs{
\t1 index type /arraytype eq{
\t\texch 0 4 2 index length 1 sub{
\t\t\tdup 3 add 1 exch{1 index exch get exch}for
\t\t\t5 1 roll 5 index exec
\t\t}for pop pop
\t}{exec}ifelse
}__NXbdef
/rectfill{gsave newpath {__NXRectPath fill} __NXProcessRectArgs \
grestore}__NXbdef
/rectclip{newpath {__NXRectPath} __NXProcessRectArgs clip newpath}__NXbdef
/rectstroke{
\tgsave newpath dup type /arraytype eq{dup length 6 eq}{false}ifelse{
\t\t{gsave __NXRectPath null concat stroke grestore}
\t\tdup length array cvx copy dup 2 4 -1 roll put __NXProcessRectArgs
\t}{{__NXRectPath stroke} __NXProcessRectArgs}ifelse grestore
}__NXbdef
/_NXLevel2 systemdict /languagelevel known {languagelevel 2 ge}{false}ifelse \
__NXdef
/xyshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\t3 index 3 index 2 mul 1 add get add exch
\t\t3 index\t3 index 2 mul get add exch moveto pop
\t}for pop pop
}__NXbdef
/xshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\texch 3 index 3 index get add exch moveto pop
\t}for pop pop
}__NXbdef
/yshow{
\t0 1 3 index length 1 sub{
\t\tcurrentpoint 4 index 3 index 1 getinterval show
\t\t3 index 3 index get add moveto pop
\t}for pop pop
}__NXbdef
/arct{arcto pop pop pop pop}__NXbdef
/setbbox{pop pop pop pop}__NXbdef
/ucache{}__NXbdef
/ucachestatus{mark 0 0 0 0 0}__NXbdef
/setucacheparams{cleartomark}__NXbdef
/uappend{systemdict begin cvx exec end}__NXbdef
/ueofill{gsave newpath uappend eofill grestore}__NXbdef
/ufill{gsave newpath uappend fill grestore}__NXbdef
/ustroke{
\tgsave newpath dup length 6 eq
\t{exch uappend concat}{uappend}ifelse
\tstroke grestore
}__NXbdef
/__NXustrokepathMatrix dup where {pop pop}{matrix def}ifelse
/ustrokepath{
\tnewpath dup length 6 eq{
\t\texch uappend __NXustrokepathMatrix currentmatrix exch concat
\t\tstrokepath setmatrix
\t}{uappend strokepath}ifelse
} __NXbdef
/upath{
\t[exch {/ucache cvx}if pathbbox /setbbox cvx
\t {/moveto cvx}{/lineto cvx}{/curveto cvx}{/closepath cvx}pathforall]cvx
} __NXbdef
/setstrokeadjust{pop}__NXbdef
/currentstrokeadjust{false}__NXbdef
/selectfont{exch findfont exch
dup type /arraytype eq {makefont}{scalefont}ifelse setfont}__NXbdef
/_NXCombineArrays{
\tcounttomark dup 2 add index dup length 3 -1 roll {
\t\t2 index length sub dup 4 1 roll 1 index exch 4 -1 roll putinterval exch
\t}repeat pop pop pop
}__NXbdef
/flushgraphics{}def
/setwindowtype{pop pop}def
/currentwindowtype{pop 0}def
/setalpha{pop}def
/currentalpha{1.0}def
/hidecursor{}def
/obscurecursor{}def
/revealcursor{}def
/setcursor{4 {pop}repeat}bind def
/showcursor{}def
/NextStepEncoding where not{
/NextStepEncoding StandardEncoding 256 array copy def
0 [129/Agrave/Aacute/Acircumflex/Atilde/Adieresis/Aring/Ccedilla/Egrave
/Eacute/Ecircumflex/Edieresis/Igrave/Iacute/Icircumflex/Idieresis
/Eth/Ntilde/Ograve/Oacute/Ocircumflex/Otilde/Odieresis/Ugrave/Uacute
/Ucircumflex/Udieresis/Yacute/Thorn/mu/multiply/divide/copyright
176/registered 181/brokenbar 190/logicalnot 192/onesuperior 201/twosuperior
204/threesuperior 209/plusminus/onequarter/onehalf/threequarters/agrave
/aacute/acircumflex/atilde/adieresis/aring/ccedilla/egrave/eacute
/ecircumflex/edieresis/igrave 226/iacute 228/icircumflex/idieresis/eth
/ntilde 236/ograve/oacute/ocircumflex/otilde/odieresis 242/ugrave/uacute
/ucircumflex 246/udieresis/yacute 252/thorn/ydieresis]
{dup type /nametype eq
 {NextStepEncoding 2 index 2 index put pop 1 add}{exch pop}ifelse
}forall pop
/NextStepEncoding NextStepEncoding readonly def
/_NXfstr 128 string dup 0 (_NX) putinterval def
/_NXfindfont /findfont load def
/findfont{
 % Because we can never let NextStepEncoding get into
 % SharedFontDirectory, we cannot reencode a font to NextStepEncoding
 % if we are in shared mode.  So if currentshared is true,
 % we call the normal findfont and return that
 /currentshared where {pop currentshared} {false} ifelse
 {_NXfindfont}
 {dup _NXfstr 3 125 getinterval cvs length 3 add _NXfstr 0 3 -1 roll
  getinterval cvn exch FontDirectory 2 index known 
  {pop FontDirectory exch get}
  {_NXfindfont dup /Encoding get StandardEncoding eq
   {\tdup length dict exch
\t{1 index /FID ne {2 index 3 1 roll put}{pop pop}ifelse}forall
\t dup /Encoding NextStepEncoding put definefont
\t}{exch pop} ifelse
   }ifelse
 }ifelse
}bind def
}{pop}ifelse
/_NXImageString {/__NXImageString where{pop}{/__NXImageString 4000 string \
__NXdef}ifelse __NXImageString}__NXbdef
/_NXDoImageOp{
\t3 dict begin /parr 5 array def 1 index{dup}{1}ifelse /chans exch def
\tchans 2 add 2 roll parr 0 chans getinterval astore pop
\t5 index 4 index mul 2 index{1 sub 8 idiv 1 add mul}{mul 1 sub 8 idiv 1 \
add}ifelse
\t4 index mul /totbytes exch def pop exch pop
\tgsave matrix invertmatrix concat 0.5 setgray 0 0 4 2 roll rectfill grestore
\t{0 1 chans 1 sub{parr exch get exec length totbytes exch sub /totbytes exch \
def}for totbytes 0 le{exit}if}loop end
}__NXbdef
/alphaimage{1 add _NXDoImageOp}def
_NXLevel2{ 
\t/NXCalibratedRGBColorSpace where{pop}{
\t\t/NXCalibratedRGBColorSpace
\t\t{mark /NXCalibratedRGB /ColorSpace findresource exch pop}stopped
\t\t{cleartomark /NXCalibratedRGB[/CIEBasedABC 2 dict dup begin 
\t\t/MatrixLMN[.4124 .2126 .0193 .3576 .7152 .1192 .1805 .0722 .9505]def
\t\t/WhitePoint[.9505 1 1.089] def end] /ColorSpace defineresource}if \
def}ifelse
\t/nxsetrgbcolor{NXCalibratedRGBColorSpace setcolorspace setcolor}__NXbdef
\t/nxsetgray{dup dup nxsetrgbcolor}__NXbdef
\t/_NXCalibratedImage{exch{array astore dup length true}{false}ifelse
\t\t8 -1 roll{NXCalibratedRGBColorSpace setcolorspace}if
\t\t8 dict dup 9 1 roll begin /ImageType 1 def /MultipleDataSources exch def
\t\tcurrentcolorspace 0 get /Indexed eq{pop /Decode[0 2 6 index exp 1 \
sub]def}
\t\t{2 mul dup array /Decode exch def 1 sub 0 1 3 -1 roll{Decode exch dup 2 \
mod put}for}ifelse
\t\t/DataSource exch def /ImageMatrix exch def 
\t\t/BitsPerComponent exch def /Height exch def /Width exch def end \
image}__NXbdef
} {
\t/setcmykcolor{
\t\t1.0 exch sub dup dup 6 -1 roll sub dup 0 lt{pop 0}if 5 1 roll
\t\t4 -1 roll sub dup 0 lt{pop 0}if 3 1 roll exch sub dup 0 lt{pop 0}if \
setrgbcolor}__NXbdef
\t/currentcmykcolor{currentrgbcolor 3{1.0 exch sub 3 1 roll}repeat 0}__NXbdef
\t/colorimage{2 copy 3 ne or{_NXDoImageOp}{4 index dup 8 ne exch 4 ne \
and{_NXDoImageOp}{
\t\tpop pop save 6 1 roll 12 dict begin/Proc exch def/Res 0 string def
\t\t/Alloc{2 index length mul 2 add dup 2 index load length gt{1.2 mul round \
cvi string def}{pop pop}ifelse}def
\t\t1 index 8 eq{/Unpack{.34 Alloc}def}{
\t\t\t/Wid 4 index 3 mul def exch pop 8 exch/Str1 0 string def/Lim Wid def
\t\t\t/Unpack{.67 Alloc/Str1 2 Alloc 0 exch Lim exch
\t\t\t\t{dup -4 bitshift 17 mul Str1 exch 4 index exch put 15 and 17 mul Str1 \
exch 3 index 1 add exch put
\t\t\t\t2 sub dup 0 le{0 lt Wid exch{exch 1 sub exch}if}if exch 2 add exch
\t\t\t\t}forall/Lim exch def Str1 exch 0 exch getinterval
\t\t\t}def
\t\t}ifelse
\t\t/Ops[{.3 mul add 1}{.59 mul add 2}{.11 mul add round cvi Res exch 2 index \
exch put 1 add 0.0 0}]def/Val 0.0 def/Phase 0 def
\t\t{0 Val Phase Proc/Res Unpack{exch Ops exch get exec}forall/Phase exch \
def/Val exch def Res exch 0 exch getinterval}
\t\timage end restore}ifelse}ifelse
\t}__NXbdef
\t/nxsetrgbcolor{setrgbcolor}__NXbdef /nxsetgray{setgray}__NXbdef
\t/setpattern{pop .5 setgray}__NXbdef
\t/_NXCalibratedImage{dup 1 eq {pop pop image}{colorimage}ifelse pop}__NXbdef
} ifelse
/_NXSetCMYKOrRGB where{pop}{
\tmark{systemdict /currentwindow get exec}stopped
\t{{pop pop pop setcmykcolor}}{{nxsetrgbcolor pop pop pop pop}}ifelse \
/_NXSetCMYKOrRGB exch def cleartomark
}ifelse
%%EndProcSet

_NXLevel2{/_NXsethsb where{pop}{/_NXsethsb /sethsbcolor load def}ifelse \
/sethsbcolor{_NXsethsb currentrgbcolor nxsetrgbcolor}def \
/setrgbcolor{nxsetrgbcolor}bind def /setgray{nxsetgray}bind def
}if
gsave
 /__NXbasematrix matrix currentmatrix def
grestore
%%EndProlog
%%BeginSetup
/TopDrawDict 250 dict def
TopDrawDict begin /prt_stack {
    (***Top of Stack\\012) print pstack (---Bottom of Stack\\012) print flush
} def /prt_top {
    (top item of stack) == dup == flush
} def /prtmat matrix def /prt_ctm {
    (current transformation matrix: ) print prtmat currentmatrix == flush
} def /tmmat matrix def /obmat matrix def /strmat matrix def /pgmat matrix \
def /idmat matrix def /sc1mt matrix def /sc2mt matrix def /sc3mt matrix def \
/sc4mt matrix def /sc5mt matrix def /sc6mt matrix def /sc7mt matrix def \
/inmat matrix def /ctmmt matrix def /octmmt matrix def /clpmt matrix def \
/weglet_mat matrix def /crlinw 1 def crlinw setlinewidth /crlinjn 0 def \
crlinjn setlinejoin /crlincp 0 def crlincp setlinecap /crmtrlmt \
currentmiterlimit def /crstrpat 0 def /crfilpat 0 def /crflat currentflat def \
/dftflat currentflat def /strinclr false def /crlingry 0 def /crlinred 0 def \
/crlingrn 0 def /crlinblu 0 def /crlinalph 1 def /filinclr false def \
/crfilgry 0 def /crfilred 0 def /crfilgrn 0 def /crfilblu 0 def /crfilalph 1 \
def /crfilstyl 0 def /txtdraw true def /txtinclr false def /txtwpat false def \
/txtwittrans false def /crtxtgry 0 def /crtxtred 0 def /crtxtgrn 0 def \
/crtxtblu 0 def /crtxtalph 1 def /crtxtpat 0 def /txlndraw true def \
/txlninclr false def /txlnwpat false def /txlnwittrans false def /crtxlngry 0 \
def /crtxlnred 0 def /crtxlngrn 0 def /crtxlnblu 0 def /crtxlnalph 1 def \
/crtxlnpat 0 def /hilittxt false def /strdsh [2 2] def /dshpatoff 0 def \
/usedash false def /filwpat false def /strwpat false def /filwittrans false \
def /strwittrans false def /crfrtarw false def /crendarw false def /rsave 0 \
def /esave 0 def /sslsave 0 def /lsave 0 def /clpsave 0 def /pathsave 0 def \
/tpatstr 10 string def /ptdist {
    sub dup mul 3 1 roll sub dup mul add sqrt
} bind def /dodrawctm {
    octmmt currentmatrix pop idmat obmat concatmatrix ctmmt currentmatrix \
sc1mt concatmatrix setmatrix
} bind def /undrawctm {
    obmat inmat invertmatrix ctmmt currentmatrix sc1mt concatmatrix setmatrix
} bind def /undrawmat {
    obmat aload pop 7 -1 roll astore
} bind def /unpagectm {
    octmmt setmatrix
} bind def /unpagemat {
    pgmat aload pop 7 -1 roll astore
} bind def /drtan {
    gsave 1 setalpha 0 setlinewidth 0.333333 setgray moveto lineto stroke \
grestore
} bind def /drdgrdln {
    gsave 1 setalpha 0 setlinewidth [1 2] 0 setdash setgray moveto lineto \
stroke grestore
} bind def /drgrdln {
    gsave 1 setalpha 0 setlinewidth setgray moveto lineto stroke grestore
} bind def end
TopDrawDict begin /rpath {
    newpath moveto dup 0 exch rlineto exch 0 rlineto 0 exch neg rlineto \
closepath
} bind def /rfpath {
    /rad3 exch def /hh3 exch def /ww3 exch def /yy1 exch def /xx1 exch def \
/xx2 xx1 ww3 add def /yy2 yy1 hh3 add def newpath xx1 yy1 rad3 hh3 0 gt {
        add
    } {
        sub
    } ifelse moveto xx1 yy1 xx2 yy1 rad3 arcto 4 {
        pop
    } repeat xx2 yy1 xx2 yy2 rad3 arcto 4 {
        pop
    } repeat xx2 yy2 xx1 yy2 rad3 arcto 4 {
        pop
    } repeat xx1 yy2 xx1 yy1 rad3 arcto 4 {
        pop
    } repeat closepath
} bind def /rfill {
    gsave dodrawctm crfilalph setalpha filinclr {
        crfilred crfilgrn crfilblu setrgbcolor
    } {
        crfilgry setgray
    } ifelse filwpat {
        4 2 roll rpath crfilpat findfont exch filwittrans {
            trpatfil
        } {
            oppatfil
        } ifelse
    } {
        rectfill pop
    } ifelse grestore
} bind def /rstroke {
    gsave dodrawctm crlinalph setalpha crlinw setlinewidth crlincp setlinecap \
crlinjn setlinejoin crmtrlmt setmiterlimit usedash {
        strdsh dshpatoff setdash
    } if strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse 4 2 roll rpath unpagectm concat strwpat {
        crstrpat findfont exch strwittrans {
            trpatstrk
        } {
            oppatstrk
        } ifelse
    } {
        stroke pop
    } ifelse grestore
} bind def /rffill {
    gsave dodrawctm crfilalph setalpha filinclr {
        crfilred crfilgrn crfilblu setrgbcolor
    } {
        crfilgry setgray
    } ifelse rfpath filwpat {
        crfilpat findfont exch filwittrans {
            trpatfil
        } {
            oppatfil
        } ifelse
    } {
        fill pop
    } ifelse grestore
} bind def /rfstroke {
    gsave dodrawctm crlinalph setalpha crlinw setlinewidth crlincp setlinecap \
crlinjn setlinejoin crmtrlmt setmiterlimit usedash {
        strdsh dshpatoff setdash
    } if strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse rfpath unpagectm concat strwpat {
        crstrpat findfont exch strwittrans {
            trpatstrk
        } {
            oppatstrk
        } ifelse
    } {
        stroke pop
    } ifelse grestore
} bind def /mkrpath {
    dodrawctm rpath unpagectm
} bind def end
TopDrawDict begin /p1x 0 def /p1y 0 def /p2x 0 def /p2y 0 def /ssl {
    gsave dodrawctm crfrtarw crendarw or {
        /p1y 1 index def /p1x 2 index def /p2y 1 index 4 index add def /p2x 2 \
index 5 index add def newpath moveto rlineto
    } {
        newpath moveto rlineto
    } ifelse crlinalph setalpha crlinw setlinewidth crlincp setlinecap \
usedash {
        strdsh dshpatoff setdash
    } if strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse crfrtarw {
        2 copy currentlinewidth exch p2x p2y p1x p1y arow
    } if crendarw {
        2 copy currentlinewidth exch p1x p1y p2x p2y arow
    } if unpagectm concat strwpat {
        crstrpat findfont exch strwittrans {
            trpatstrk
        } {
            oppatstrk
        } ifelse
    } {
        stroke pop
    } ifelse grestore
} bind def end
TopDrawDict begin /arwlen 6 def /arw 4 def /arow {
    gsave newpath moveto lineto unpagectm concat {
        
    } {
        
    } {
        
    } {
        
    } pathforall newpath 4 2 roll 2 copy moveto 4 2 roll exch 4 -1 roll exch \
sub 3 1 roll sub exch atan rotate dup 1 lt {
        pop 1 1 scale
    } {
        dup scale
    } ifelse -1 2 rlineto 7 -2 rlineto -7 -2 rlineto closepath crlinalph \
setalpha strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse strwpat {
        crstrpat findfont exch strwittrans {
            trpatfil
        } {
            oppatfil
        } ifelse
    } {
        fill pop
    } ifelse grestore
} bind def /arwpath {
    sc7mt currentmatrix pop gsave newpath moveto lineto unpagectm dup concat \
{
        
    } {
        
    } {
        
    } {
        
    } pathforall grestore unpagectm 5 -1 roll concat 4 2 roll 2 copy moveto 4 \
2 roll exch 4 -1 roll exch sub 3 1 roll sub exch atan rotate dup 1 lt {
        pop 1 1 scale
    } {
        dup scale
    } ifelse -1 2 rlineto 7 -2 rlineto -7 -2 rlineto closepath sc7mt \
setmatrix
} bind def end
TopDrawDict begin /estroke {
    gsave dodrawctm translate scale newpath dup dup 0 360 arc closepath \
crlinalph setalpha crlinw setlinewidth usedash {
        strdsh dshpatoff setdash
    } if strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse unpagectm concat strwpat {
        crstrpat findfont exch strwittrans {
            trpatstrk
        } {
            oppatstrk
        } ifelse
    } {
        stroke pop
    } ifelse grestore
} bind def /efill {
    gsave dodrawctm translate scale newpath dup dup 0 360 arc closepath \
unpagectm crfilalph setalpha filinclr {
        crfilred crfilgrn crfilblu setrgbcolor
    } {
        crfilgry setgray
    } ifelse filwpat {
        crfilpat findfont exch filwittrans {
            trpatfil
        } {
            oppatfil
        } ifelse
    } {
        fill pop
    } ifelse grestore
} bind def /apstroke {
    gsave dodrawctm /chord exch def /pie exch def /radius exch def /yscale \
exch def /xscale exch def /yy exch def /xx exch def /angle2 exch def /angle1 \
exch def xx yy translate xscale yscale scale newpath pie {
        radius dup moveto
    } if radius dup dup angle1 angle2 arc pie chord or {
        closepath
    } if crlinalph setalpha pie not chord not and {
        crfrtarw {
            2 copy crlinw exch gsave newpath angle1 1 add cos radius mul \
radius add angle1 1 add sin radius mul radius add moveto angle1 cos radius \
mul radius add angle1 sin radius mul radius add lineto unpagectm {
                
            } {
                
            } {
                
            } {
                
            } pathforall arow grestore
        } if crendarw {
            2 copy crlinw exch gsave newpath angle2 1 sub cos radius mul \
radius add angle2 1 sub sin radius mul radius add moveto angle2 cos radius \
mul radius add angle2 sin radius mul radius add lineto unpagectm {
                
            } {
                
            } {
                
            } {
                
            } pathforall arow grestore
        } if
    } if crlincp setlinecap crlinalph setalpha crlinw setlinewidth usedash {
        strdsh dshpatoff setdash
    } if strinclr {
        crlinred crlingrn crlinblu setrgbcolor
    } {
        crlingry setgray
    } ifelse unpagectm concat strwpat {
        crstrpat findfont exch strwittrans {
            trpatstrk
        } {
            oppatstrk
        } ifelse
    } {
        stroke pop
    } ifelse grestore
} bind def /apfill {
    gsave dodrawctm /chord exch def /pie exch def /radius exch def /yscale \
exch def /xscale exch def /yy exch def /xx exch def xx yy translate xscale \
yscale scale newpath pie {
        radius dup moveto
    } if radius dup dup 5 -2 roll arc pie chord or {
        closepath
    } if 1 xscale div 1 yscale div scale crfilalph setalpha filinclr {
        crfilred crfilgrn crfilblu setrgbcolor
    } {
        crfilgry setgray
    } ifelse filwpat {
        crfilpat findfont exch filwittrans {
            trpatfil
        } {
            oppatfil
        } ifelse
    } {
        fill pop
    } ifelse grestore
} bind def /mkepath {
    dodrawctm /chord exch def /pie exch def /radius exch def /yscale exch def \
/xscale exch def /yy exch def /xx exch def /angle2 exch def /angle1 exch def \
/closed exch def xx yy translate xscale yscale scale newpath pie {
        radius dup moveto
    } if radius dup dup angle1 angle2 arc closed pie or chord or {
        closepath
    } if unpagectm
} bind def end
TopDrawDict begin /dotx {
    gsave txtdraw {
        concat selectfont txtinclr {
            crtxtred crtxtgrn crtxtblu setrgbcolor
        } {
            crtxtgry setgray
        } ifelse crtxtalph setalpha moveto xyshow
    } {
        pop pop pop pop pop pop pop
    } ifelse grestore
} bind def /txtlin {
    gsave txlndraw {
        concat txlninclr {
            crtxlnred crtxlngrn crtxlnblu setrgbcolor
        } {
            crtxlngry setgray
        } ifelse crtxlnalph setalpha setlinewidth 0 setlinecap newpath moveto \
0 rlineto stroke
    } {
        pop pop pop pop pop
    } ifelse grestore
} bind def end
%%EndSetup
0 0 436 297 rectclip
-92 -355.216003 translate
92 355.216003 436 296.132751 rectclip
gsave
TopDrawDict begin
/invpats true def
/crlincp 0 def
/crlinjn 0 def
/crmtrlmt 10 def
/crlinw 0 def
/crlinalph 1 def
/crlinred 0 def /crlingrn 0 def /crlinblu 0 def /strinclr true def
/crfilalph 1 def
/crfilred 0 def /crfilgrn 0 def /crfilblu 0 def /filinclr true def
/filwpat false def
TopDrawDict /piddict known TopDrawDict /ipiddict known or {
    1 getpat /crfilpat exch def
} if
/filwittrans false def
/strwpat false def
TopDrawDict /piddict known TopDrawDict /ipiddict known or {
    1 getpat /crstrpat exch def
} if
/strwittrans false def
/usedash false def
/strdsh [2 2] def /dshpatoff 0 def
/crendarw false def
/crfrtarw false def
/txtdraw false def
/crtxtalph 1 def
/crtxtred 0 def /crtxtgrn 0 def /crtxtblu 0 def /txtinclr true def
/txtwpat false def
/txtwittrans false def
/txlndraw false def
/crtxlnalph 1 def
/crtxlnred 0 def /crtxlngrn 0 def /crtxlnblu 0 def /txlninclr true def
/txlnwpat false def
/txlnwittrans false def
/crlinw 1 def
0.509793 -0.616532 0.616532 0.509793 -204.750031 446.554718 sc4mt astore \
0.509793 -0.616532 0.616532 0.509793 -204.750031 446.554718 sc5mt astore 179 \
579 227 -17 8.5 0.509793 -0.616532 0.616532 0.509793 -307.950043 370.554718 \
sc6mt astore rfstroke
/esave save def 0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 \
62.095673 100.655975 sc6mt astore 2.118194 180 154 610 1 -1.351852 27 false \
false 0.8 0 0 0.8 -7.504326 100.655975 sc5mt astore apstroke esave restore
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore 109 0 125 574 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 166 592 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 175 591 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 184 591 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 194 591 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 203 591 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -9 -17 212 593 0.8 0 0 0.8 -7.504326 100.655975 sc6mt \
astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc6mt astore 5.147812 1.000001 -1 111 421 \
0.8 0 0 0.8 46.895672 211.855988 sc5mt astore efill
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc6mt astore 5.147812 1.000001 -1 111 421 0.8 0 0 0.8 46.895672 \
211.855988 sc5mt astore estroke
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore 0 -166.075287 184 540 0.8 0 0 0.8 -7.504326 \
100.655975 sc6mt astore ssl
/crendarw true def
/crfrtarw true def
/esave save def 0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 \
62.095673 100.655975 sc6mt astore 266.834137 325.971252 227 236 1.067485 1 \
81.5 false false 0.993334 0 0 0.731848 -162.631088 238.339783 sc5mt astore \
apstroke esave restore
/crfrtarw false def
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore 54.204132 -66.353333 315 398 0.8 0 0 0.8 -7.504326 \
100.655975 sc6mt astore ssl
-3.49691e-08 0.8 -0.8 -3.49691e-08 627.727661 90.287979 sc4mt astore \
-3.49691e-08 0.8 -0.8 -3.49691e-08 627.727661 90.287979 sc5mt astore \
54.204132 -66.353333 333 380 -3.49691e-08 0.8 -0.8 -3.49691e-08 550.127686 \
153.487976 sc6mt astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore 121.015747 0 191 556 0.8 0 0 0.8 -7.504326 100.655975 \
sc6mt astore ssl
-3.49691e-08 0.8 -0.8 -3.49691e-08 707.791626 315.503967 sc4mt astore \
-3.49691e-08 0.8 -0.8 -3.49691e-08 707.791626 315.503967 sc5mt astore \
121.015747 0 209 538 -3.49691e-08 0.8 -0.8 -3.49691e-08 570.19165 381.903992 \
sc6mt astore ssl
/txtdraw true def
/txlndraw true def
(b) [0 0] 229 288 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 0 0 0.8 \
113.29567 128.655975] dotx
/txtdraw true def
/txlndraw true def
(1 ) [6 0 0 0] 236 283.200012 /Times-BoldItalic [ 12 1 mul 0 0 12 0 0 ] [0.8 \
0 0 0.8 113.29567 128.655975] dotx
/txtdraw true def
/txlndraw true def
(b) [0 0] 229 288 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 0 0 0.8 \
124.495674 226.255981] dotx
/txtdraw true def
/txlndraw true def
(2 ) [6 0 0 0] 236 283.200012 /Times-BoldItalic [ 12 1 mul 0 0 12 0 0 ] [0.8 \
0 0 0.8 124.495674 226.255981] dotx
/txtdraw true def
/txlndraw true def
(^ ) [7.979996 0 0 0] 132 154.399994 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 \
] [0.8 0 0 0.8 190.89566 242.255981] dotx
/txtdraw true def
/txlndraw true def
( ) [0 0] 190 101.400002 /Helvetica [ 14 1 mul 0 0 14 0 0 ] [0.8 0 0 0.8 \
234.895676 310.255981] dotx
/txtdraw true def
/txlndraw true def
(^ ) [7.979996 0 0 0] 132 154.399994 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 \
] [0.8 0 0 0.8 202.895691 339.055969] dotx
/txtdraw true def
/txlndraw true def
(i ) [3.891998 0 0 0] 169 258 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 \
0 0 0.8 118.895676 333.455994] dotx
(j ) [3.891998 0 0 0] 122 278 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 \
0 0 0.8 51.695675 417.455994] dotx
(^ ) [7.980003 0 0 0] 75 309 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 0 \
0 0.8 89.295677 396.655975] dotx
(^ ) [7.980003 0 0 0] 75 309 /Times-BoldItalic [ 14 1 mul 0 0 14 0 0 ] [0.8 0 \
0 0.8 194.095673 296.655975] dotx
/txtdraw true def
/txlndraw true def
(q ) [9 0 0 0] 240 362 /Times-Italic [ 18 1 mul 0 0 18 0 0 ] [0.8 0 0 0.8 \
-3.504326 114.255974] dotx
(l ) [5.003998 0 0 0] 240 362 /Times-Italic [ 18 1 mul 0 0 18 0 0 ] [0.8 0 0 \
0.8 12.495695 198.255981] dotx
/crendarw false def
0.509793 -0.616532 0.616532 0.509793 -204.750031 446.554718 sc4mt astore \
0.509793 -0.616532 0.616532 0.509793 -204.750031 446.554718 sc5mt astore 179 \
579 227 -17 8.5 0.509793 -0.616532 0.616532 0.509793 -33.550034 377.7547 \
sc6mt astore rfstroke
/crendarw true def
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore -0.944946 -103.000244 286 225 0.8 0 0 0.8 234.895676 \
310.255981 sc6mt astore ssl
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc5mt astore 76.016174 -0.926849 139 306 0.8 0 0 0.8 234.895676 \
310.255981 sc6mt astore ssl
-3.49691e-08 0.8 -0.8 -3.49691e-08 707.791626 315.503967 sc4mt astore \
-3.49691e-08 0.8 -0.8 -3.49691e-08 707.791626 315.503967 sc5mt astore 0.11058 \
70.575775 227 225 0.8 0 0 0.8 234.895676 310.255981 sc6mt astore ssl
(mg ) [12.996002 0 9 0 0 0] 302 113 /Times-Italic [ 18 1 mul 0 0 18 0 0 ] \
[0.8 0 0 0.8 226.895676 317.455994] dotx
(Rx ) [10.998001 0 7.992004 0 0 0] 131 277 /Times-Italic [ 18 1 mul 0 0 18 0 \
0 ] [0.8 0 0 0.8 240.495682 315.855988] dotx
(Ry ) [10.998001 0 7.992004 0 0 0] 201 225 /Times-Italic [ 18 1 mul 0 0 18 0 \
0 ] [0.8 0 0 0.8 235.695679 316.655975] dotx
( ) [0 0] 93 261 /Times-Italic [ 18 1 mul 0 0 18 0 0 ] [0.8 0 0 0.8 \
234.895676 310.255981] dotx
(l/2 ) [5.003998 0 5.003998 0 9 0 0 0] 261 290 /Times-Italic [ 18 1 mul 0 0 \
18 0 0 ] [0.8 0 0 0.8 235.695679 301.455994] dotx
(o ) [9 0 0 0] 175 665 /Times-Italic [ 18 1 mul 0 0 18 0 0 ] [0.8 0 0 0.8 \
-17.904327 15.855972] dotx
/crendarw false def
0.8 0 0 0.8 62.095673 100.655975 sc6mt astore 5.147812 1.000001 -1 111 421 \
0.8 0 0 0.8 98.095673 150.255981 sc5mt astore efill
0.8 0 0 0.8 62.095673 100.655975 sc4mt astore 0.8 0 0 0.8 62.095673 \
100.655975 sc6mt astore 5.147812 1.000001 -1 111 421 0.8 0 0 0.8 98.095673 \
150.255981 sc5mt astore estroke
(cm ) [7.992004 0 12.996002 0 0 0] 174 462 /Times-Italic [ 18 1 mul 0 0 18 0 \
0 ] [0.8 0 0 0.8 31.695673 118.255974] dotx
end
grestore
%%Trailer
%%DocumentFonts: Times-BoldItalic
%%+ Helvetica
%%+ Times-Italic
%%BoundingBox: 0.000000 0.000000 436.000000 296.132751

%End of Graphics
MathPictureEnd
end
\
\>"], "Graphics",
 ImageSize->{432, 294.25},
 ImageMargins->{{1, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["\<\
Let's write the equations of motion for this system and solve the equations \
and animate the results.  This is a single degree of freedom system with the \
coordinate and free body diagram as shown.  We will use angular momentum to \
derive the equations of motion.\
\>", "Text",
 CellChangeTimes->{3.519556630867*^9}],

Cell["\<\
Define fixed relationships between the frames of reference.  This step is not \
mandatory but it helps reduce the results considerably.  If this step is \
skipped the transformations we will apply later will have to include these \
definitions.  Note: these are different for different base orientations of \
the frames. \
\>", "Text",
 CellChangeTimes->{{3.5195566325674*^9, 3.519556633675*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "Dot", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], ".", "k"}], ":=", "1"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", ".", "i"}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", ".", "j"}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{"k", ".", 
   RowBox[{"b", "[", "1", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{"k", ".", 
   RowBox[{"b", "[", "2", "]"}]}], ":=", "0"}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Dot", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Unprotect", "[", "Cross", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "1", "]"}]}], " ", ":=", " ", 
  RowBox[{"b", "[", "2", "]"}]}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "2", "]"}]}], " ", ":=", " ", 
  RowBox[{"-", 
   RowBox[{"b", "[", "1", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{"k", " ", "\[Cross]", " ", 
   RowBox[{"b", "[", "3", "]"}]}], " ", ":=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", "\[Cross]", " ", "i"}], " ", ":=", " ", 
  "j"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "3", "]"}], " ", "\[Cross]", " ", "j"}], " ", ":=", " ", 
  
  RowBox[{"-", "i"}]}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Dot", "]"}], ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FMR\[Dash]Angular Momentum", "Subsubsection"],

Cell["The force vector on the rod is given by:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"F1", "=", 
   RowBox[{
    RowBox[{"-", "m"}], " ", "g", " ", "j"}]}], " "}], "\n", 
 RowBox[{"F2", " ", "=", " ", 
  RowBox[{
   RowBox[{"Rx", " ", "i"}], " ", "+", 
   RowBox[{"Ry", " ", "j"}]}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "g"}], " ", "m", " ", 
  OverscriptBox["\<\"j\"\>", "^"]}]], "Output",
 CellChangeTimes->{
  3.5184550199896*^9, {3.518455185328*^9, 3.5184551864356003`*^9}, 
   3.518455234078*^9, 3.5184560660104*^9, 3.5195569687318*^9, 
   3.53626519621194*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rx", " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"Ry", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{
  3.5184550199896*^9, {3.518455185328*^9, 3.5184551864356003`*^9}, 
   3.518455234078*^9, 3.5184560660104*^9, 3.5195569687318*^9, 
   3.5362651962137327`*^9}]
}, Open  ]],

Cell[TextData[{
 "The position to the point of application of the forces is 0 and ",
 StyleBox["l",
  FontSlant->"Italic"],
 "/2 ",
 StyleBox["b[1].",
  FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Or1", " ", "=", " ", 
  RowBox[{
   RowBox[{"l", "/", "2"}], " ", 
   RowBox[{"b", "[", "1", "]"}]}]}], "\n", 
 RowBox[{"Or2", " ", "=", " ", "0"}]}], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"l", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}], "2"]], "Output",
 CellChangeTimes->{3.5184550212376003`*^9, 3.5184551877304*^9, 
  3.518455236106*^9, 3.5184560674611998`*^9, 3.5195569708845997`*^9, 
  3.536265196277052*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.5184550212376003`*^9, 3.5184551877304*^9, 
  3.518455236106*^9, 3.5184560674611998`*^9, 3.5195569708845997`*^9, 
  3.536265196278995*^9}]
}, Open  ]],

Cell["The net moment about o is given as:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mo", " ", "=", " ", 
  RowBox[{
   RowBox[{"Or1", " ", "\[Cross]", " ", "F1"}], " ", "+", " ", 
   RowBox[{"Or2", " ", "\[Cross]", " ", "F2"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[Cross]", 
   OverscriptBox["\<\"j\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.5184550227664003`*^9, 3.5184551895088*^9, 
  3.5184552374476*^9, 3.5184560688964*^9, 3.5195569726317997`*^9, 
  3.536265196349854*^9}]
}, Open  ]],

Cell[TextData[{
 "The full inertia Dyadic about point  ",
 StyleBox["o",
  FontSlant->"Italic"],
 " is given by:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Io", " ", "=", " ", 
  RowBox[{
   RowBox[{"I11", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I12", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I13", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"1", ",", "3"}], "]"}]}], "+", "  ", 
   RowBox[{"I21", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I22", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I23", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"2", ",", "3"}], "]"}]}], "+", "  ", 
   RowBox[{"I31", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "1"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I32", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "2"}], "]"}]}], " ", "+", " ", 
   RowBox[{"I33", " ", 
    RowBox[{"bb", "[", 
     RowBox[{"3", ",", "3"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.5195584495038*^9, 3.5195584524834003`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I11", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I12", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I13", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "1"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I21", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I22", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I23", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "2"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I31", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "1"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 1]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I32", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "2"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 2]],
     Editable->False], ")"}]}], "+", 
  RowBox[{"I33", " ", 
   RowBox[{"(", 
    InterpretationBox[
     RowBox[{
      SubscriptBox[
       OverscriptBox["b", "^"], "3"], "\[InvisibleSpace]", 
      SubscriptBox[
       OverscriptBox["b", "^"], "3"]}],
     SequenceForm[
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3], 
      $CellContext`unitVector[$CellContext`B, $CellContext`b, 3]],
     Editable->False], ")"}]}]}]], "Output",
 CellChangeTimes->{3.518455023484*^9, 3.518455191256*^9, 3.5184552385084*^9, 
  3.5184560707995996`*^9, 3.5195569741762*^9, 3.5195584539186*^9, 
  3.536265196446003*^9}]
}, Open  ]],

Cell["Making the I's constants.", "Text"],

Cell[BoxData[
 RowBox[{"SetAttributes", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "I11", ",", "I12", ",", "I13", ",", "I21", ",", "I22", ",", "I23", ",", 
     "I31", ",", "I32", ",", "I33"}], "}"}], ",", "Constant"}], 
  "]"}]], "Input"],

Cell[TextData[{
 "The angular velocity of frame ",
 StyleBox["B",
  FontWeight->"Bold"],
 " is:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NwB", " ", "=", " ", 
  RowBox[{
   RowBox[{"omega", "[", 
    RowBox[{"N", ",", "B"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"q", "'"}], "[", "t", "]"}], " ", 
    RowBox[{"b", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "3"], " ", 
  RowBox[{
   SuperscriptBox["q", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.5184550262139997`*^9, 3.5184551934244003`*^9, 
  3.5184552413788*^9, 3.5184560751832*^9, 3.5195569783258*^9, 
  3.5195584566018*^9, 3.5362651965627403`*^9}]
}, Open  ]],

Cell[TextData[{
 "The angular momentum is given by ",
 StyleBox["Ho = Io . NwB",
  FontWeight->"Bold"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ho", "=", 
  RowBox[{"Io", " ", ".", " ", "NwB"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"I13", " ", 
     SubscriptBox[
      OverscriptBox["b", "^"], "1"]}], "+", 
    RowBox[{"I23", " ", 
     SubscriptBox[
      OverscriptBox["b", "^"], "2"]}], "+", 
    RowBox[{"I33", " ", 
     SubscriptBox[
      OverscriptBox["b", "^"], "3"]}]}], ")"}], " ", 
  RowBox[{
   SuperscriptBox["q", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.5184550272592*^9, 3.5184551993524*^9, 3.5184552420652*^9,
   3.5184560766963997`*^9, 3.5195569800262003`*^9, 3.5195584576938*^9, 
  3.536265196628718*^9}]
}, Open  ]],

Cell[TextData[{
 "The equation of motion is given by",
 StyleBox[" Mo - DvDt[N,Ho]==0",
  FontWeight->"Bold"],
 " we will drop the",
 StyleBox[" == 0 ",
  FontWeight->"Bold"],
 "until we get to the solution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", "=", 
  RowBox[{
   RowBox[{"Mo", " ", "-", " ", 
    RowBox[{"DvDt", "[", 
     RowBox[{"N", ",", "Ho"}], "]"}]}], "//", 
   "distributeScalars"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "1"], "\[Cross]", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "+", 
  RowBox[{"I23", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["q", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"I13", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["q", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"I13", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"I23", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"I33", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "3"], " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5184550283044*^9, 3.5184552002728*^9, 3.5184552433912*^9,
   3.5184560815792*^9, 3.5195569820854*^9, 3.5195576161362*^9, 
  3.5195578867026*^9, 3.5195582322426*^9, 3.519558371535*^9, 
  3.519558459363*^9, 3.536265196797143*^9}]
}, Open  ]],

Cell[TextData[{
 "Now lets take the ",
 StyleBox["b[3]",
  FontWeight->"Bold"],
 " component."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", " ", "=", " ", 
  RowBox[{"eom", ".", 
   RowBox[{"b", "[", "3", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.5195582220713997`*^9, 3.5195582233038*^9}, {
  3.5195583276678*^9, 3.5195583288845997`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "2"], ".", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "-", 
  RowBox[{"I33", " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5184550295524*^9, 3.5184552021604*^9, 3.5184552450916*^9, 
   3.518456085682*^9, 3.5195569843162003`*^9, 3.5195576172906*^9, 
   3.5195578873733997`*^9, {3.5195582239122*^9, 3.519558233085*^9}, 
   3.5195583293058*^9, 3.519558372315*^9, 3.5195584612349997`*^9, 
   3.536265196829968*^9}]
}, Open  ]],

Cell["\<\
The last thing we need to do is transform the unresolved Dot product.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"transform", "[", "x_", "]"}], ":=", 
  RowBox[{"x", "//.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b", "[", "1", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"q", "[", "t", "]"}], "]"}]}], " ", "j"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], "i"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"b", "[", "2", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], "i"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"q", "[", "t", "]"}], "]"}], " ", "j"}]}]}]}], 
    "}"}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eom", "=", 
  RowBox[{"eom", "//", "transform"}]}]], "Input",
 CellChangeTimes->{{3.5195577244158*^9, 3.5195577348522*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "2"]}], " ", "g", " ", "l", " ", "m", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"q", "[", "t", "]"}], "]"}]}], "-", 
  RowBox[{"I33", " ", 
   RowBox[{
    SuperscriptBox["q", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.5184550321576*^9, 3.5184552055456*^9, 3.518455248118*^9, 
   3.5184561411868*^9, 3.5195569875766*^9, 3.5195576215338*^9, 
   3.5195576827326*^9, {3.5195577279414*^9, 3.5195577356633997`*^9}, 
   3.519557888793*^9, 3.5195582355966*^9, {3.5195583667146*^9, 
   3.5195583751034*^9}, 3.5195584646046*^9, 3.5362651969297857`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve and Interpret", "Subsubsection"],

Cell["Define the constants.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"l", "=", "5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"m", "=", "10"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g", "=", "9.81"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"I33", " ", "=", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"m", " ", 
       RowBox[{"(", 
        RowBox[{"l", "^", "2"}], ")"}]}], ")"}], " ", "/", " ", "3"}]}], 
   ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Appendix", " ", "C"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5195579185889997`*^9, 3.5195579222706003`*^9}}],

Cell["Initial conditions and final time.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Wo", "=", ".5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Qo", "=", 
   RowBox[{"Pi", "/", "4"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"tf", "=", "7"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5184555105880003`*^9, 3.5184555305248003`*^9}, {
  3.5184562417132*^9, 3.5184562646296*^9}, {3.5195570429877996`*^9, 
  3.5195570453122*^9}, {3.5195579338302*^9, 3.5195579347818003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"eom", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"q", "[", "0", "]"}], "\[Equal]", "Qo"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"q", "'"}], "[", "0", "]"}], "\[Equal]", "Wo"}]}], "}"}], ",", 
    RowBox[{"q", "[", "t", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5184553864588003`*^9, 3.5184554291716003`*^9}, {
  3.5184554910411997`*^9, 3.5184555074212*^9}, {3.5184555642832003`*^9, 
  3.5184555689944*^9}, {3.5184556454032*^9, 3.5184556631716003`*^9}, {
  3.518455788112*^9, 3.5184557988448*^9}, {3.5184558393268003`*^9, 
  3.5184558542092*^9}, {3.5184561901864*^9, 3.5184561951004*^9}, {
  3.5184563097292*^9, 3.5184563175604*^9}, {3.5184563541112003`*^9, 
  3.5184563733459997`*^9}, {3.519557055967*^9, 3.5195570849362*^9}, {
  3.5195573528662*^9, 3.5195574140025997`*^9}, {3.5195574807082*^9, 
  3.5195574858873997`*^9}, {3.5195575448866*^9, 3.5195575522342*^9}, {
  3.5195579613798*^9, 3.5195579615982*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"q", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{"0.`", ",", "7.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
       "]"}],
      False,
      Editable->False], "[", "t", "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5184550366504*^9, {3.5184550884736*^9, 3.5184550909852*^9}, 
   3.5184552097888002`*^9, 3.5184552527200003`*^9, {3.5184553878472*^9, 
   3.5184554295772*^9}, {3.5184554917743998`*^9, 3.5184555322564*^9}, {
   3.5184555649695997`*^9, 3.5184555701176*^9}, 3.518455752466*^9, {
   3.5184557905456*^9, 3.5184557991724*^9}, {3.5184558406216*^9, 
   3.518455854568*^9}, 3.5184561484876003`*^9, {3.5184561925264*^9, 
   3.5184561954435997`*^9}, {3.5184562433044*^9, 3.5184562660648003`*^9}, {
   3.518456310244*^9, 3.5184563179816*^9}, {3.5184563563576*^9, 
   3.5184563738608*^9}, {3.5184564068392*^9, 3.5184564203487997`*^9}, 
   3.519556994737*^9, {3.519557047153*^9, 3.5195570874322*^9}, {
   3.5195573557834*^9, 3.5195574145486*^9}, 3.5195574484630003`*^9, {
   3.5195574864334*^9, 3.5195575225474*^9}, 3.519557677725*^9, 
   3.5195577601085997`*^9, 3.519557797767*^9, 3.5195578703538*^9, {
   3.519557924907*^9, 3.5195579659505997`*^9}, 3.519558468957*^9, 
   3.536265197097375*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"q", "[", "t", "]"}], "/.", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5195570749678*^9, 3.5195570864026003`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmHk8lN8Xx2dkyT6EGSlZC0klhbZ7SIUiISVpUZTsy5eUSqvSgiyJVqnQ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 7}, {-0.8437935663646616, 0.8437933738178454}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5184550424536*^9, 3.5184550931535997`*^9, 3.518455211926*^9, 
   3.5184552547324*^9, 3.5184554166292*^9, 3.5184554942860003`*^9, {
   3.518455527592*^9, 3.5184555348772*^9}, 3.5184557538856*^9, {
   3.5184557922616*^9, 3.5184558040396*^9}, {3.518455846066*^9, 
   3.5184558572980003`*^9}, 3.5184561514048*^9, 3.518456198158*^9, {
   3.5184562443496*^9, 3.5184562667824*^9}, {3.518456311804*^9, 
   3.5184563211172*^9}, 3.5195569975762*^9, {3.5195570482918*^9, 
   3.519557088259*^9}, {3.5195573618674*^9, 3.5195573832706003`*^9}, 
   3.5195578803222*^9, 3.5195579382138*^9, 3.519558470829*^9, 
   3.5362651971329727`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsubsection"],

Cell["\<\
For this animation we will draw two circles center at each end of the bar and \
two lines tangent to the circles to represent the bar and animate according \
the time solution above.\
\>", "Text",
 CellChangeTimes->{3.5195566432846003`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"thick", "=", 
    RowBox[{"l", "/", "10"}]}], ";"}], "\n", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"circle", " ", "centers"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xc0", "[", "t_", "]"}], "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"yc0", "[", "t_", "]"}], "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xc1", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{"l", " ", 
       RowBox[{
        RowBox[{"b", "[", "1", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
     "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yc1", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"transform", "[", 
       RowBox[{"l", " ", 
        RowBox[{
         RowBox[{"b", "[", "1", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
      "First"}]}], ";"}], "\n", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"lower", " ", "line", " ", "points"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xl0", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], " ", "thick", " ", 
       RowBox[{
        RowBox[{"b", "[", "2", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
     "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"yl0", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}], " ", "thick", " ", 
       RowBox[{
        RowBox[{"b", "[", "2", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
     "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xl1", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"b", "[", "1", "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", "thick", " ", 
          RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "i"}], "]"}], "//.", 
     "sol"}], "//", "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yl1", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"transform", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l", " ", 
           RowBox[{"b", "[", "1", "]"}]}], " ", "-", " ", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "thick", " ", 
           RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "j"}], "]"}], "//.", 
      "sol"}], "//", "First"}]}], ";"}], "\n", "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"upper", " ", "line", " ", "points"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xu0", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], " ", "thick", " ", 
       RowBox[{
        RowBox[{"b", "[", "2", "]"}], ".", "i"}]}], "]"}], "//.", "sol"}], "//",
     "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"yu0", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{"1", "/", "2"}], " ", "thick", " ", 
       RowBox[{
        RowBox[{"b", "[", "2", "]"}], ".", "j"}]}], "]"}], "//.", "sol"}], "//",
     "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"xu1", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"transform", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"l", " ", 
          RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", "thick", " ", 
          RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "i"}], "]"}], "//.", 
     "sol"}], "//", "First"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"yu1", "[", "t_", "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"transform", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"l", " ", 
           RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
          RowBox[{
           RowBox[{"1", "/", "2"}], " ", "thick", " ", 
           RowBox[{"b", "[", "2", "]"}]}]}], ")"}], ".", "j"}], "]"}], "//.", 
      "sol"}], "//", "First"}]}], ";"}], "\n", "\n"}], "\n", 
 RowBox[{"Animate", "[", 
  RowBox[{
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", "\n", "\t\t\t\t\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"xc0", "[", "t", "]"}], ",", 
            RowBox[{"yc0", "[", "t", "]"}]}], "}"}], ",", 
          RowBox[{"thick", "/", "2"}]}], "]"}], ",", " ", "\n", 
        "\t\t\t\t      ", 
        RowBox[{"Circle", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"xc1", "[", "t", "]"}], ",", 
            RowBox[{"yc1", "[", "t", "]"}]}], "}"}], ",", 
          RowBox[{"thick", "/", "2"}]}], "]"}], ",", "  ", "\n", 
        "\t\t\t\t      ", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xl0", "[", "t", "]"}], ",", 
             RowBox[{"yl0", "[", "t", "]"}]}], "}"}], ",", "  ", "\n", 
           "\t\t\t\t\t\t     ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xl1", "[", "t", "]"}], ",", 
             RowBox[{"yl1", "[", "t", "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        " ", "\n", "\t\t\t\t      ", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xu0", "[", "t", "]"}], ",", 
             RowBox[{"yu0", "[", "t", "]"}]}], "}"}], ",", "\n", 
           "\t\t\t\t\t\t     ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"xu1", "[", "t", "]"}], ",", 
             RowBox[{"yu1", "[", "t", "]"}]}], "}"}]}], "}"}], "]"}]}], "\n", 
       "\t\t\t     ", "}"}], "\n", "\t\t     ", "]"}], ",", 
     RowBox[{"Axes", "->", "True"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "l"}], "-", "1"}], ",", 
          RowBox[{"l", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "l"}], " ", "-", "1"}], ",", 
          RowBox[{"l", " ", "+", "1"}]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "->", "1"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tf"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.518455098676*^9, 3.5184551735968*^9}, {
  3.5184555537688*^9, 3.5184555554536*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0.703931999206543, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 7}}, Typeset`size$$ = {360., {179., 184.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`t$158$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$158$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Graphics[{
          Circle[{
            $CellContext`xc0[$CellContext`t$$], 
            $CellContext`yc0[$CellContext`t$$]}, $CellContext`thick/2], 
          Circle[{
            $CellContext`xc1[$CellContext`t$$], 
            $CellContext`yc1[$CellContext`t$$]}, $CellContext`thick/2], 
          Line[{{
             $CellContext`xl0[$CellContext`t$$], 
             $CellContext`yl0[$CellContext`t$$]}, {
             $CellContext`xl1[$CellContext`t$$], 
             $CellContext`yl1[$CellContext`t$$]}}], 
          Line[{{
             $CellContext`xu0[$CellContext`t$$], 
             $CellContext`yu0[$CellContext`t$$]}, {
             $CellContext`xu1[$CellContext`t$$], 
             $CellContext`yu1[$CellContext`t$$]}}]}], Axes -> True, 
        PlotRange -> {{-$CellContext`l - 1, $CellContext`l + 
           1}, {-$CellContext`l - 1, $CellContext`l + 1}}, AspectRatio -> 1], 
      "Specifications" :> {{$CellContext`t$$, 0, 7, 
         AppearanceElements -> {
          "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
           "DirectionButton"}}}, 
      "Options" :> {
       ControlType -> Animator, AppearanceElements -> None, DefaultBaseStyle -> 
        "Animate", DefaultLabelStyle -> "AnimateLabel", SynchronousUpdating -> 
        True, ShrinkingDelay -> 10.}, "DefaultOptions" :> {}],
     ImageSizeCache->{403., {216., 221.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Animate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.518455541242*^9, 3.5195584775058002`*^9, 
  3.53626519723663*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 129, 4, 67, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[733, 30, 69, 0, 34, "Subsection"],
Cell[805, 32, 206, 5, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1036, 41, 336, 8, 27, "Input"],
Cell[1375, 51, 253, 4, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1677, 61, 77, 0, 34, "Subsection"],
Cell[1757, 63, 764, 25, 41, "Text",
 Evaluatable->False],
Cell[2524, 90, 923, 28, 88, "Input"],
Cell[3450, 120, 47, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[3522, 124, 256, 7, 88, "Input"],
Cell[3781, 133, 205, 4, 31, "Output"],
Cell[3989, 139, 205, 4, 29, "Output"],
Cell[4197, 145, 207, 4, 29, "Output"],
Cell[4407, 151, 482, 12, 31, "Output"],
Cell[4892, 165, 454, 12, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5395, 183, 58, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[5478, 187, 42, 0, 24, "Subsubsection"],
Cell[5523, 189, 122, 3, 26, "Text"],
Cell[5648, 194, 68, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[5741, 198, 122, 3, 27, "Input"],
Cell[5866, 203, 203, 5, 29, "Output"]
}, Open  ]],
Cell[6084, 211, 201, 4, 26, "Text"],
Cell[6288, 217, 46, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[6359, 221, 112, 3, 27, "Input"],
Cell[6474, 226, 200, 5, 29, "Output"]
}, Open  ]],
Cell[6689, 234, 48, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[6762, 238, 105, 3, 27, "Input"],
Cell[6870, 243, 133, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7040, 250, 105, 3, 27, "Input"],
Cell[7148, 255, 117, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7302, 262, 105, 3, 27, "Input"],
Cell[7410, 267, 113, 2, 27, "Output"]
}, Open  ]],
Cell[7538, 272, 60, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[7623, 276, 61, 1, 27, "Input"],
Cell[7687, 279, 148, 3, 31, "Output"]
}, Open  ]],
Cell[7850, 285, 27, 0, 26, "Text"],
Cell[7880, 287, 46, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[7951, 291, 78, 2, 27, "Input"],
Cell[8032, 295, 436, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8505, 312, 147, 4, 27, "Input"],
Cell[8655, 318, 436, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9128, 335, 130, 4, 27, "Input"],
Cell[9261, 341, 156, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9454, 350, 201, 6, 27, "Input"],
Cell[9658, 358, 159, 4, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9854, 367, 130, 4, 27, "Input"],
Cell[9987, 373, 111, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10135, 380, 147, 4, 27, "Input"],
Cell[10285, 386, 453, 12, 31, "Output"]
}, Open  ]],
Cell[10753, 401, 27, 0, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10817, 406, 60, 0, 24, "Subsubsection"],
Cell[10880, 408, 50, 0, 26, "Text"],
Cell[10933, 410, 111, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[11069, 417, 165, 5, 27, "Input"],
Cell[11237, 424, 231, 7, 31, "Output"]
}, Open  ]],
Cell[11483, 434, 162, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[11670, 441, 170, 5, 27, "Input"],
Cell[11843, 448, 231, 7, 31, "Output"]
}, Open  ]],
Cell[12089, 458, 250, 4, 26, "Text"],
Cell[12342, 464, 36, 0, 26, "Text"],
Cell[12381, 466, 176, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[12582, 473, 165, 5, 27, "Input"],
Cell[12750, 480, 313, 10, 31, "Output"]
}, Open  ]],
Cell[13078, 493, 140, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[13243, 500, 165, 5, 27, "Input"],
Cell[13411, 507, 307, 10, 31, "Output"]
}, Open  ]],
Cell[13733, 520, 144, 3, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13914, 528, 67, 0, 24, "Subsubsection"],
Cell[13984, 530, 46, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[14055, 534, 279, 8, 27, "Input"],
Cell[14337, 544, 361, 12, 29, "Output"]
}, Open  ]],
Cell[14713, 559, 52, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[14790, 563, 279, 8, 27, "Input"],
Cell[15072, 573, 360, 12, 29, "Output"]
}, Open  ]],
Cell[15447, 588, 36, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[15508, 592, 63, 1, 27, "Input"],
Cell[15574, 595, 224, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15835, 606, 70, 1, 27, "Input"],
Cell[15908, 609, 698, 22, 29, "Output"]
}, Open  ]],
Cell[16621, 634, 94, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[16740, 640, 62, 1, 27, "Input"],
Cell[16805, 643, 717, 26, 29, "Output"]
}, Open  ]],
Cell[17537, 672, 143, 3, 26, "Text"],
Cell[17683, 677, 64, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[17772, 681, 131, 3, 27, "Input"],
Cell[17906, 686, 208, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18163, 698, 67, 0, 24, "Subsubsection"],
Cell[18233, 700, 210, 4, 26, "Text"],
Cell[18446, 706, 69, 0, 26, "Text"],
Cell[18518, 708, 177, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[18720, 720, 531, 17, 27, "Input"],
Cell[19254, 739, 645, 21, 31, "Output"]
}, Open  ]],
Cell[19914, 763, 885, 17, 71, "Text"],
Cell[20802, 782, 241, 9, 26, "Text"],
Cell[CellGroupData[{
Cell[21068, 795, 536, 17, 27, "Input"],
Cell[21607, 814, 636, 21, 29, "Output"]
}, Open  ]],
Cell[22258, 838, 67, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[22350, 842, 109, 3, 27, "Input"],
Cell[22462, 847, 492, 16, 31, "Output"]
}, Open  ]],
Cell[22969, 866, 275, 9, 26, "Text"],
Cell[CellGroupData[{
Cell[23269, 879, 96, 2, 27, "Input"],
Cell[23368, 883, 490, 16, 31, "Output"]
}, Open  ]],
Cell[23873, 902, 193, 8, 26, "Text"],
Cell[24069, 912, 159, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[24253, 924, 109, 3, 27, "Input"],
Cell[24365, 929, 123, 2, 27, "Output"]
}, Open  ]],
Cell[24503, 934, 64, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[24592, 938, 274, 8, 27, "Input"],
Cell[24869, 948, 356, 12, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25262, 965, 80, 2, 27, "Input"],
Cell[25345, 969, 1473, 50, 34, "Output"]
}, Open  ]],
Cell[26833, 1022, 207, 4, 26, "Text"],
Cell[27043, 1028, 253, 5, 41, "Text"],
Cell[27299, 1035, 265, 7, 27, "Input"],
Cell[CellGroupData[{
Cell[27589, 1046, 80, 2, 27, "Input"],
Cell[27672, 1050, 1075, 35, 34, "Output"]
}, Open  ]],
Cell[28762, 1088, 74, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[28861, 1092, 66, 1, 27, "Input"],
Cell[28930, 1095, 876, 28, 31, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29867, 1130, 38, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[29930, 1134, 85, 1, 24, "Subsubsection"],
Cell[30018, 1137, 32188, 828, 303, 28414, 763, "GraphicsData", "PostScript", \
"Graphics"],
Cell[62209, 1967, 329, 6, 41, "Text"],
Cell[62541, 1975, 406, 7, 41, "Text"],
Cell[62950, 1984, 1384, 44, 223, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64371, 2033, 51, 0, 24, "Subsubsection"],
Cell[64425, 2035, 56, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[64506, 2039, 246, 8, 43, "Input"],
Cell[64755, 2049, 285, 7, 31, "Output"],
Cell[65043, 2058, 341, 9, 31, "Output"]
}, Open  ]],
Cell[65399, 2070, 184, 7, 26, "Text"],
Cell[CellGroupData[{
Cell[65608, 2081, 184, 5, 43, "Input"],
Cell[65795, 2088, 278, 7, 50, "Output"],
Cell[66076, 2097, 187, 3, 27, "Output"]
}, Open  ]],
Cell[66278, 2103, 51, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[66354, 2107, 181, 4, 27, "Input"],
Cell[66538, 2113, 386, 10, 46, "Output"]
}, Open  ]],
Cell[66939, 2126, 125, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[67089, 2135, 1038, 30, 27, "Input"],
Cell[68130, 2167, 3872, 112, 34, "Output"]
}, Open  ]],
Cell[72017, 2282, 41, 0, 26, "Text"],
Cell[72061, 2284, 247, 7, 27, "Input"],
Cell[72311, 2293, 108, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[72444, 2302, 247, 8, 27, "Input"],
Cell[72694, 2312, 363, 9, 31, "Output"]
}, Open  ]],
Cell[73072, 2324, 120, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[73217, 2333, 86, 2, 27, "Input"],
Cell[73306, 2337, 609, 18, 34, "Output"]
}, Open  ]],
Cell[73930, 2358, 220, 8, 26, "Text"],
Cell[CellGroupData[{
Cell[74175, 2370, 190, 6, 27, "Input"],
Cell[74368, 2378, 1503, 44, 46, "Output"]
}, Open  ]],
Cell[75886, 2425, 106, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[76017, 2434, 230, 5, 27, "Input"],
Cell[76250, 2441, 689, 18, 46, "Output"]
}, Open  ]],
Cell[76954, 2462, 93, 2, 26, "Text"],
Cell[77050, 2466, 775, 25, 27, "Input"],
Cell[CellGroupData[{
Cell[77850, 2495, 147, 3, 27, "Input"],
Cell[78000, 2500, 680, 16, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78729, 2522, 44, 0, 24, "Subsubsection"],
Cell[78776, 2524, 37, 0, 26, "Text"],
Cell[78816, 2526, 547, 18, 73, "Input"],
Cell[79366, 2546, 50, 0, 26, "Text"],
Cell[79419, 2548, 410, 10, 58, "Input"],
Cell[CellGroupData[{
Cell[79854, 2562, 1141, 24, 27, "Input"],
Cell[80998, 2588, 1410, 30, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82445, 2623, 263, 7, 27, "Input"],
Cell[82711, 2632, 15055, 253, 229, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97815, 2891, 34, 0, 24, "Subsubsection"],
Cell[97852, 2893, 250, 5, 26, "Text"],
Cell[CellGroupData[{
Cell[98127, 2902, 6772, 213, 463, "Input"],
Cell[104902, 3117, 2753, 57, 454, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
