(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     40054,       1369]
NotebookOptionsPosition[     33887,       1156]
NotebookOutlinePosition[     34243,       1172]
CellTagsIndexPosition[     34200,       1169]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Introducing Engineering Vector Notation in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Section",
 Evaluatable->False,
 CellChangeTimes->{{3.5021094237611427`*^9, 3.5021094332948914`*^9}, {
  3.502114177049633*^9, 3.5021141789431543`*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Input the definitions for the vector operations", "Subsection"],

Cell["\<\
Input the vector definition with the command that follows.  The path will \
depend on where  the definitions reside on the local system.\
\>", "Text",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
Get[StringJoin[NotebookDirectory[],\"vectors3.m\"]]\
\>", "Input",
 CellChangeTimes->{{3.502109540864833*^9, 3.502109543462657*^9}, 
   3.5184565761236*^9, 3.536265225470591*^9},
 AspectRatioFixed->True],

Cell[BoxData["\<\"These Engineering Vector algorithms are copyright Alan A. \
Barhorst\"\>"], "Print",
 CellChangeTimes->{
  3.502109545655888*^9, {3.518456577902*^9, 3.5184565891652*^9}, 
   3.536265231502595*^9, 3.536265268120246*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define the symbols used for Unit Vectors", "Subsection"],

Cell[TextData[{
 "Define Unit Vectors and Unit Dyads for however many frames we need for the \
system. For this example we will use four frames of reference, with the frame \
",
 StyleBox["N",
  FontWeight->"Bold"],
 " being the Newtonian frame.  The head ",
 StyleBox["unitVector",
  FontWeight->"Bold"],
 " must be included.  The arguments are ",
 StyleBox["[frame, symbol, direction]",
  FontWeight->"Bold"],
 ".  So unit vector ",
 StyleBox["b[1]=unitVector[B,b,1]",
  FontWeight->"Bold"],
 " is the vector in the ",
 StyleBox["B",
  FontWeight->"Bold"],
 " frame in the ",
 StyleBox["1",
  FontWeight->"Bold"],
 " direction.  "
}], "Text",
 Evaluatable->False,
 CellChangeTimes->{3.502114155234536*^9},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"B", ",", "b", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"c", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"C", ",", "c", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"d", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"D", ",", "d", ",", "a"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"n", "[", "a_", "]"}], ":=", 
  RowBox[{"unitVector", "[", 
   RowBox[{"N", ",", "n", ",", "a"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.518456580788*^9, 3.518456580788*^9}},
 AspectRatioFixed->True],

Cell["Now to see what they look like.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"b", "[", "1", "]"}], "\n", 
 RowBox[{"c", "[", "1", "]"}], "\n", 
 RowBox[{"d", "[", "1", "]"}], "\n", 
 RowBox[{"n", "[", "1", "]"}]}], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["b", "^"], "1"]], "Output",
 CellChangeTimes->{3.502109556045182*^9, 3.5184565905692*^9, 
  3.5362652316356916`*^9, 3.536265268247582*^9}],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["c", "^"], "1"]], "Output",
 CellChangeTimes->{3.502109556045182*^9, 3.5184565905692*^9, 
  3.5362652316356916`*^9, 3.536265268249936*^9}],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["d", "^"], "1"]], "Output",
 CellChangeTimes->{3.502109556045182*^9, 3.5184565905692*^9, 
  3.5362652316356916`*^9, 3.536265268251696*^9}],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["n", "^"], "1"]], "Output",
 CellChangeTimes->{3.502109556045182*^9, 3.5184565905692*^9, 
  3.5362652316356916`*^9, 3.5362652682535143`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operations with the vector notation.", "Subsection"],

Cell[CellGroupData[{

Cell["Normal operations", "Subsubsection"],

Cell["\<\
Now we are in a position to perform vector operation.  Consider the following \
simple operations.\
\>", "Text"],

Cell["In the same frame  right-handed systems are assumed.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], " ", "\[Cross]", " ", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData[
 SubscriptBox[
  OverscriptBox["n", "^"], "3"]], "Output",
 CellChangeTimes->{3.502109563111616*^9, 3.5184565932212*^9, 
  3.5362652317024717`*^9, 3.536265268312253*^9}]
}, Open  ]],

Cell["\<\
where the cross product can be input from the pallet \"\[Cross]\" or by \
typing [Esc]cross[Esc] or by using \"\\[ Cross ] \"  without the extra space \
and the quotation marks.\
\>", "Text"],

Cell["Continuing with the example...", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], "\[Cross]", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  SubscriptBox[
   OverscriptBox["n", "^"], "1"]}]], "Output",
 CellChangeTimes->{3.502109564866728*^9, 3.5184565939076*^9, 
  3.536265231736424*^9, 3.5362652683466377`*^9}]
}, Open  ]],

Cell["The Dot product is also defined.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], ".", 
  RowBox[{"n", "[", "2", "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.502109566522347*^9, 3.5184565945004*^9, 
  3.536265231769994*^9, 3.536265268379897*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "1", "]"}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5021095679101257`*^9, 3.5184565950776*^9, 
  3.5362652318028517`*^9, 3.536265268413863*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.502109569297942*^9, 3.5184565958264*^9, 
  3.5362652318363047`*^9, 3.536265268447114*^9}]
}, Open  ]],

Cell["\<\
The normal i,j and k vectors are predefined relative to theirselves.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"i", " ", "\[Cross]", "j"}]], "Input"],

Cell[BoxData[
 OverscriptBox["\<\"k\"\>", "^"]], "Output",
 CellChangeTimes->{3.5021095707024612`*^9, 3.5184565987904*^9, 
  3.536265231869458*^9, 3.536265268480349*^9}]
}, Open  ]],

Cell["Etcetera...", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Operations between reference frames", "Subsubsection"],

Cell["Consider the following operations.", "Text"],

Cell["\<\
Notice how the cross product has precedence in order for the operation to be \
defined.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], "\[Cross]", 
   RowBox[{"b", "[", "2", "]"}]}], ".", 
  RowBox[{"n", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "3"], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "3"]}]], "Output",
 CellChangeTimes->{3.502109576153804*^9, 3.5184565999136*^9, 
  3.536265231902501*^9, 3.53626526851447*^9}]
}, Open  ]],

Cell["\<\
Now notice how the scalar triple product is utilized to permute the \"b\" \
vectors together such that their cross product is found first.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], " ", "\[Cross]", 
   RowBox[{"n", "[", "2", "]"}]}], ".", 
  RowBox[{"b", "[", "3", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SubscriptBox[
   OverscriptBox["b", "^"], "2"], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "2"]}]], "Output",
 CellChangeTimes->{3.5021095772239122`*^9, 3.5184566004908*^9, 
  3.5362652319366503`*^9, 3.5362652685688343`*^9}]
}, Open  ]],

Cell["\<\
In both cases above, the final Dot product is not defined as of yet.  As in \
the textbook we will reduce this at the latest possible time in the use of \
the symbols in a derivation of the equations of motion for some system.\
\>", "Text"],

Cell["A few more examples.", "Text"],

Cell["\<\
The following is irreducible at this point.  We would need to know more about \
the relative orientation of the coordinate frames.  More on this  below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "1", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "2", "]"}]}], ".", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "1"], "\[Cross]", 
   SubscriptBox[
    OverscriptBox["c", "^"], "2"]}], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "1"]}]], "Output",
 CellChangeTimes->{3.502109581369918*^9, 3.5184566011928*^9, 
  3.5362652319694233`*^9, 3.53626526859801*^9}]
}, Open  ]],

Cell["\<\
The canonical order for Mathematica is to have the Cross product first \
because Cross is before Dot alphabetically.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "[", "3", "]"}], ".", 
  RowBox[{
   RowBox[{"b", "[", "2", "]"}], "\[Cross]", 
   RowBox[{"c", "[", "1", "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox[
    OverscriptBox["b", "^"], "2"], "\[Cross]", 
   SubscriptBox[
    OverscriptBox["c", "^"], "1"]}], ".", 
  SubscriptBox[
   OverscriptBox["n", "^"], "3"]}]], "Output",
 CellChangeTimes->{3.5021095825905123`*^9, 3.5184566027684*^9, 
  3.536265232002665*^9, 3.536265268631393*^9}]
}, Open  ]],

Cell["\<\
Notice how the simple inline notation is used for typing so that it is \
simpler to input, but the fancy output is used.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples with more complicated expressions", "Subsubsection"],

Cell["A vector to some point.", "Text",
 CellChangeTimes->{3.502109609160033*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", "=", " ", 
  RowBox[{
   RowBox[{"p1", " ", 
    RowBox[{"n", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"p2", " ", 
    RowBox[{"n", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{"p3", " ", 
    RowBox[{"n", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{"p3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.502109600029998*^9, 3.5184566036576*^9, 
  3.536265232036384*^9, 3.536265268664936*^9}]
}, Open  ]],

Cell["Another vector to some other point.", "Text",
 CellChangeTimes->{{3.502109627094714*^9, 3.5021096280304623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrT", " ", "=", " ", 
  RowBox[{
   RowBox[{"t1", " ", 
    RowBox[{"n", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"t2", " ", 
    RowBox[{"n", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{"t3", " ", 
    RowBox[{"n", "[", "3", "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{"t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.502109630828682*^9, 3.5184566062004004`*^9, 
  3.5362652320697737`*^9, 3.536265268698285*^9}]
}, Open  ]],

Cell["Now some operations.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", ".", " ", "OrT"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", " ", "t1"}], "+", 
  RowBox[{"p2", " ", "t2"}], "+", 
  RowBox[{"p3", " ", "t3"}]}]], "Output",
 CellChangeTimes->{3.502109634373026*^9, 3.5184566074172*^9, 
  3.536265232104007*^9, 3.536265268731061*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"OrP", " ", "\[Cross]", " ", "OrT"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "p3"}], " ", "t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p2", " ", "t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{"p3", " ", "t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "-", 
  RowBox[{"p1", " ", "t3", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "-", 
  RowBox[{"p2", " ", "t1", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}], "+", 
  RowBox[{"p1", " ", "t2", " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.502109636162751*^9, 3.5184566080880003`*^9, 
  3.536265232137548*^9, 3.536265268764516*^9}]
}, Open  ]],

Cell["\<\
Now if we want to gather like terms we can use the following operation\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"%", "//", "gatherVectors"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "p3"}], " ", "t2"}], "+", 
     RowBox[{"p2", " ", "t3"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "1"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"p3", " ", "t1"}], "-", 
     RowBox[{"p1", " ", "t3"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "p2"}], " ", "t1"}], "+", 
     RowBox[{"p1", " ", "t2"}]}], ")"}], " ", 
   SubscriptBox[
    OverscriptBox["n", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.502109642967152*^9, 3.5184566089616003`*^9, 
  3.536265232170936*^9, 3.536265268797616*^9}]
}, Open  ]],

Cell["\<\
where Mathematica's Postfix function ability is used. The operation \
gatherVectors[x] is the same as x//gatherVectors.\
\>", "Text"],

Cell["I can also chain operations together as follows.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"OrP", " ", "\[Cross]", " ", "OrT"}], " ", ".", " ", 
  RowBox[{"n", "[", "1", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "p3"}], " ", "t2"}], "+", 
  RowBox[{"p2", " ", "t3"}]}]], "Output",
 CellChangeTimes->{3.502109655540382*^9, 3.5184566106932*^9, 
  3.536265232204859*^9, 3.5362652688315268`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example similar to problems from Chapter 1 of the textbook", \
"Subsection",
 CellChangeTimes->{{3.502109807806959*^9, 3.502109821286572*^9}}],

Cell["Here we do some operations on vectors.  Three vectors are", "Text",
 CellChangeTimes->{{3.502109722711842*^9, 3.502109739198354*^9}, {
  3.502110017727715*^9, 3.502110027118368*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1", "=", 
  RowBox[{
   RowBox[{"2", " ", "i"}], " ", "+", " ", 
   RowBox[{"4", " ", "j"}], " ", "+", " ", 
   RowBox[{"6", " ", "k"}]}]}]], "Input",
 CellChangeTimes->{{3.502109747049635*^9, 3.502109761500987*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"4", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{"6", " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.502109762433487*^9, 3.5184566124716*^9, 
  3.536265232237932*^9, 3.536265268865486*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v2", " ", "=", " ", 
  RowBox[{
   RowBox[{"3", " ", "i"}], " ", "+", " ", 
   RowBox[{"5", " ", "j"}], " ", "+", " ", "k"}]}]], "Input",
 CellChangeTimes->{{3.502109764071705*^9, 3.502109783711913*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"5", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  OverscriptBox["\<\"k\"\>", "^"]}]], "Output",
 CellChangeTimes->{3.502109784922917*^9, 3.51845661308*^9, 
  3.536265232271399*^9, 3.536265268898447*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v3", " ", "=", " ", 
  RowBox[{
   RowBox[{"vx", " ", "i"}], " ", "+", " ", 
   RowBox[{"vy", " ", "j"}], " ", "+", " ", 
   RowBox[{"vz", " ", "k"}]}]}]], "Input",
 CellChangeTimes->{{3.502109764071705*^9, 3.502109783711913*^9}, {
  3.502109858585392*^9, 3.5021098861597347`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"vx", " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"vy", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{"vz", " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.502109784922917*^9, 3.502109887518693*^9, 
  3.5184566135792*^9, 3.5362652323047647`*^9, 3.5362652689525337`*^9}]
}, Open  ]],

Cell["Here is the dot product of v1 and v2", "Text",
 CellChangeTimes->{{3.50210978871704*^9, 3.502109793711297*^9}, {
  3.50210989367983*^9, 3.5021099003106127`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1", ".", "v2"}]], "Input",
 CellChangeTimes->{{3.502109827340823*^9, 3.5021098293912897`*^9}}],

Cell[BoxData["32"], "Output",
 CellChangeTimes->{3.502109830017001*^9, 3.5184566141563997`*^9, 
  3.536265232336816*^9, 3.5362652689819937`*^9}]
}, Open  ]],

Cell["Cross product of the same vectors", "Text",
 CellChangeTimes->{{3.5021098329254913`*^9, 3.502109836879217*^9}, {
  3.502109903262719*^9, 3.502109910102462*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1", " ", "\[Cross]", " ", "v2"}]], "Input",
 CellChangeTimes->{{3.502109913969037*^9, 3.502109927911681*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "26"}], " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"16", " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "-", 
  RowBox[{"2", " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.502109928833785*^9, 3.5184566153732*^9, 
  3.536265232371476*^9, 3.5362652690154247`*^9}]
}, Open  ]],

Cell["Here is the projecton of the last vector onto v3", "Text",
 CellChangeTimes->{{3.502109942911663*^9, 3.50210995772758*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"v1", " ", "\[Cross]", " ", "v2"}], ")"}], ".", "v3"}]], "Input",
 CellChangeTimes->{{3.502109913969037*^9, 3.502109927911681*^9}, {
  3.502109985185088*^9, 3.50211000469654*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "26"}], " ", "vx"}], "+", 
  RowBox[{"16", " ", "vy"}], "-", 
  RowBox[{"2", " ", "vz"}]}]], "Output",
 CellChangeTimes->{
  3.502109928833785*^9, {3.502109988073163*^9, 3.5021100056126633`*^9}, 
   3.5184566170892*^9, 3.536265232403857*^9, 3.536265269049185*^9}]
}, Open  ]],

Cell["Etcetera...", "Text",
 CellChangeTimes->{{3.502110056408821*^9, 3.502110073703636*^9}, {
  3.502110137143746*^9, 3.502110162566354*^9}}],

Cell["Here are some mixed-frame vector operations", "Text",
 CellChangeTimes->{{3.502110188048291*^9, 3.502110210534566*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v4", "=", " ", 
  RowBox[{
   RowBox[{"b1", " ", 
    RowBox[{"b", "[", "1", "]"}]}], " ", "+", " ", 
   RowBox[{"b2", " ", 
    RowBox[{"b", "[", "2", "]"}]}], " ", "+", " ", 
   RowBox[{"b3", " ", 
    RowBox[{"b", "[", "3", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.502110214131467*^9, 3.502110247744237*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b1", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "1"]}], "+", 
  RowBox[{"b2", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "2"]}], "+", 
  RowBox[{"b3", " ", 
   SubscriptBox[
    OverscriptBox["b", "^"], "3"]}]}]], "Output",
 CellChangeTimes->{3.502110248726533*^9, 3.5184566176976*^9, 
  3.53626523243832*^9, 3.5362652690823317`*^9}]
}, Open  ]],

Cell["Here is a dot product of mixed frame vectors", "Text",
 CellChangeTimes->{{3.502110351924058*^9, 3.502110364039723*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1Dotv4", "=", 
  RowBox[{"v1", ".", "v4"}]}]], "Input",
 CellChangeTimes->{{3.502110256400692*^9, 3.502110263615466*^9}, {
  3.5021140560181103`*^9, 3.502114063648162*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "b1", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "1"], ".", 
    OverscriptBox["\<\"i\"\>", "^"]}]}], "+", 
  RowBox[{"4", " ", "b1", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "1"], ".", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "+", 
  RowBox[{"6", " ", "b1", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "1"], ".", 
    OverscriptBox["\<\"k\"\>", "^"]}]}], "+", 
  RowBox[{"2", " ", "b2", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "2"], ".", 
    OverscriptBox["\<\"i\"\>", "^"]}]}], "+", 
  RowBox[{"4", " ", "b2", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "2"], ".", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "+", 
  RowBox[{"6", " ", "b2", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "2"], ".", 
    OverscriptBox["\<\"k\"\>", "^"]}]}], "+", 
  RowBox[{"2", " ", "b3", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "3"], ".", 
    OverscriptBox["\<\"i\"\>", "^"]}]}], "+", 
  RowBox[{"4", " ", "b3", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "3"], ".", 
    OverscriptBox["\<\"j\"\>", "^"]}]}], "+", 
  RowBox[{"6", " ", "b3", " ", 
   RowBox[{
    SubscriptBox[
     OverscriptBox["b", "^"], "3"], ".", 
    OverscriptBox["\<\"k\"\>", "^"]}]}]}]], "Output",
 CellChangeTimes->{3.502110264444868*^9, 3.5021140646162233`*^9, 
  3.5184566182592*^9, 3.5362652324725933`*^9, 3.536265269116189*^9}]
}, Open  ]],

Cell["\<\
no further reduction can be made at this time.  We will discuss reducing \
these expression later in the lessons to follow.\
\>", "Text",
 CellChangeTimes->{{3.5021102750434427`*^9, 3.5021102905118027`*^9}, {
  3.502110447702846*^9, 3.502110680454567*^9}, {3.502110744976411*^9, 
  3.502110772414687*^9}}],

Cell["Here is a cross product of mixed frame vectors", "Text",
 CellChangeTimes->{{3.502110351924058*^9, 3.502110364039723*^9}, {
  3.502110786776293*^9, 3.502110790262535*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v1Crossv4", "=", 
  RowBox[{"v1", "\[Cross]", "v4"}]}]], "Input",
 CellChangeTimes->{{3.502110256400692*^9, 3.502110263615466*^9}, {
  3.502110793320294*^9, 3.5021107965916758`*^9}, {3.5021138974093113`*^9, 
  3.50211390796813*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", "b1", " ", 
   RowBox[{
    OverscriptBox["\<\"i\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "1"]}]}], "+", 
  RowBox[{"2", " ", "b2", " ", 
   RowBox[{
    OverscriptBox["\<\"i\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "2"]}]}], "+", 
  RowBox[{"2", " ", "b3", " ", 
   RowBox[{
    OverscriptBox["\<\"i\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}]}], "+", 
  RowBox[{"4", " ", "b1", " ", 
   RowBox[{
    OverscriptBox["\<\"j\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "1"]}]}], "+", 
  RowBox[{"4", " ", "b2", " ", 
   RowBox[{
    OverscriptBox["\<\"j\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "2"]}]}], "+", 
  RowBox[{"4", " ", "b3", " ", 
   RowBox[{
    OverscriptBox["\<\"j\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}]}], "+", 
  RowBox[{"6", " ", "b1", " ", 
   RowBox[{
    OverscriptBox["\<\"k\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "1"]}]}], "+", 
  RowBox[{"6", " ", "b2", " ", 
   RowBox[{
    OverscriptBox["\<\"k\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "2"]}]}], "+", 
  RowBox[{"6", " ", "b3", " ", 
   RowBox[{
    OverscriptBox["\<\"k\"\>", "^"], "\[Cross]", 
    SubscriptBox[
     OverscriptBox["b", "^"], "3"]}]}]}]], "Output",
 CellChangeTimes->{3.502110264444868*^9, 3.5021107978877077`*^9, 
  3.502113908598909*^9, 3.5184566193512*^9, 3.5362652325051317`*^9, 
  3.536265269149618*^9}]
}, Open  ]],

Cell["agian no further reduction can be made at this time.", "Text",
 CellChangeTimes->{{3.502110817865006*^9, 3.5021108207920513`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transforming vectors", "Subsection",
 CellChangeTimes->{{3.502109807806959*^9, 3.502109821286572*^9}, {
  3.5021127429122868`*^9, 3.502112751726816*^9}, {3.5021130332564497`*^9, 
  3.50211303607934*^9}}],

Cell[TextData[{
 "Now suppose frame ",
 StyleBox["B",
  FontSlant->"Italic"],
 " from above is aligned with the base  ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["i", "^"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["j", "^"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["k", "^"], TraditionalForm]]],
 " frame along the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["k", "^"], TraditionalForm]]],
 " axis.  Further suppose that the frame ",
 StyleBox["B",
  FontSlant->"Italic"],
 " is rotated relative to the base frame as shown"
}], "Text",
 CellChangeTimes->{{3.502112755081327*^9, 3.502112900999704*^9}, {
  3.502113528106101*^9, 3.502113529326988*^9}}],

Cell[BoxData[
 GraphicsBox[{
   ArrowBox[{{0.3375, 0.44861111111111107`}, {0.7680555555555556, 
    0.44861111111111107`}}], 
   ArrowBox[{{0.3416814814814815, 0.451324662813102}, {0.3416814814814815, 
    0.9070086705202313}}], 
   ArrowBox[{{0.33789646687973846`, 0.4463816939949011}, {0.709250466754213, 
    0.6827261391506114}}], InsetBox["\[Theta]", Scaled[{0.5, 0.5}], Center], 
   ArrowBox[{{0.3380912865510735, 0.4489890664042153}, {0.07274777759613135, 
    0.8341610980786505}}], InsetBox["\[Theta]", Scaled[{0.5, 0.5}], Center], 
   InsetBox["\[Theta]", Scaled[{0.5, 0.5}], Center], 
   InsetBox["\[Theta]", Scaled[{0.2944444444444445, 0.5666666666666667}], 
    Center], InsetBox[Cell[TextData[Cell[BoxData[
     FormBox[
      OverscriptBox["i", "^"], TraditionalForm]]]],
     GeneratedCell->False,
     CellAutoOverwrite->False,
     CellBaseline->Baseline], {0.7736111111111111, 0.4208333333333334}, {
    Left, Baseline}], InsetBox[Cell[TextData[Cell[BoxData[
     FormBox[
      OverscriptBox["j", "^"], TraditionalForm]]]],
     GeneratedCell->False,
     CellAutoOverwrite->False,
     CellBaseline->Baseline], {0.3680555555555556, 0.8930555555555556}, {
    Left, Baseline}], InsetBox[
    SubscriptBox[Cell[TextData[Cell[BoxData[
      FormBox[
       OverscriptBox["b", "^"], TraditionalForm]]]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline], 
     "1"], {0.7541666666666667, 0.6847222222222222}, {Left, Baseline}], 
   InsetBox[
    SubscriptBox[Cell[TextData[Cell[BoxData[
      FormBox[
       OverscriptBox["b", "^"], TraditionalForm]]]],
      GeneratedCell->False,
      CellAutoOverwrite->False,
      CellBaseline->Baseline], 
     "2"], {0.15000000000000008`, 0.7625000000000002}, {Left, Baseline}], 
   InsetBox[Cell[TextData[{
     Cell[BoxData[
      FormBox[
       OverscriptBox["k", "^"], TraditionalForm]]],
     " and ",
     Cell[BoxData[
      RowBox[{
       SubscriptBox[Cell[TextData[Cell[BoxData[
         FormBox[
          OverscriptBox["b", "^"], TraditionalForm]]]],
         GeneratedCell->False,
         CellAutoOverwrite->False,
         CellBaseline->Baseline], "3"], " "}]],
      CellChangeTimes->{{3.502113056201606*^9, 3.502113178384542*^9}, {
       3.502113215279047*^9, 3.5021134496656637`*^9}}],
     "out of the page"
    }],
     GeneratedCell->False,
     CellAutoOverwrite->False,
     CellBaseline->Baseline], {0.25416666666666676`, 0.35416666666666674`}, {
    Left, Baseline}]},
  ImageSize->{Automatic, 242.},
  PlotRange->{{0, 1}, {0, 1}}]], "Text",
 CellChangeTimes->{{3.502113056201606*^9, 3.502113178384542*^9}, {
   3.502113215279047*^9, 3.502113496463265*^9}, 3.536265249702641*^9}],

Cell["Then the vectors transform as", "Text",
 CellChangeTimes->{{3.502113552086894*^9, 3.502113563608169*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"transBtoIJK", "[", "x_", "]"}], ":=", 
  RowBox[{"x", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"b", "[", "1", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", "i"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", "j"}]}]}], ",", " ", 
     RowBox[{
      RowBox[{"b", "[", "2", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "i"}], "+", " ", 
       RowBox[{
        RowBox[{"Cos", "[", "\[Theta]", "]"}], "j"}]}]}], ",", 
     RowBox[{
      RowBox[{"b", "[", "3", "]"}], "\[Rule]", "k"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.502113569342017*^9, 3.502113671035145*^9}}],

Cell[TextData[{
 "So v4 in the ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["i", "^"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["j", "^"], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["k", "^"], TraditionalForm]]],
 " ",
 " frame is"
}], "Text",
 CellChangeTimes->{{3.502113687789351*^9, 3.502113704088036*^9}, {
  3.5021137574333878`*^9, 3.5021137798086843`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"v4IJK", "=", 
  RowBox[{
   RowBox[{"transBtoIJK", "[", "v4", "]"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.5021137071511183`*^9, 3.502113724671875*^9}, {
  3.502113834465671*^9, 3.502113860832196*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b1", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "-", 
  RowBox[{"b2", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{"b2", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{"b1", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{"b3", " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{
  3.502113725611196*^9, {3.5021138418510857`*^9, 3.502113861931913*^9}, 
   3.5184566229392*^9, 3.536265232771187*^9, 3.53626526926569*^9}]
}, Open  ]],

Cell["Gathering common vectors", "Text",
 CellChangeTimes->{{3.5021137904011927`*^9, 3.5021138073110657`*^9}, {
  3.5021140131285*^9, 3.50211401389505*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gatherVectors", "[", "v4IJK", "]"}]], "Input",
 CellChangeTimes->{{3.50211380931174*^9, 3.502113823601336*^9}, 
   3.502113871418385*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b1", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"b2", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"b2", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"b1", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{"b3", " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{3.502113824343906*^9, 3.502113872097156*^9, 
  3.518456625092*^9, 3.536265232805168*^9, 3.5362652692999773`*^9}]
}, Open  ]],

Cell["\<\
So from above the cross product of v1 and v4 can be written in the base frame \
as\
\>", "Text",
 CellChangeTimes->{{3.502113914783338*^9, 3.502113945264306*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"transBtoIJK", "[", "v1Crossv4", "]"}], "//", "Expand"}], "//", 
  "gatherVectors"}]], "Input",
 CellChangeTimes->{{3.502113969153874*^9, 3.502113997335949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "b3"}], "-", 
     RowBox[{"6", " ", "b2", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"6", " ", "b1", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   OverscriptBox["\<\"i\"\>", "^"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "b3"}], "+", 
     RowBox[{"6", " ", "b1", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
     RowBox[{"6", " ", "b2", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   OverscriptBox["\<\"j\"\>", "^"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "b1", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"2", " ", "b2", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"2", " ", "b1", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
     RowBox[{"4", " ", "b2", " ", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
   OverscriptBox["\<\"k\"\>", "^"]}]}]], "Output",
 CellChangeTimes->{{3.502113983371393*^9, 3.50211399825196*^9}, 
   3.518456625638*^9, 3.5362652328394423`*^9, 3.5362652693329563`*^9}]
}, Open  ]],

Cell["So from above the dot product of v1 and v4 can be written as", "Text",
 CellChangeTimes->{{3.502113914783338*^9, 3.502113945264306*^9}, {
  3.502114079488758*^9, 3.50211410015912*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"transBtoIJK", "[", "v1Dotv4", "]"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.502113969153874*^9, 3.502113997335949*^9}, {
  3.502114083944687*^9, 3.502114088232147*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", "b3"}], "+", 
  RowBox[{"2", " ", "b1", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
  RowBox[{"4", " ", "b2", " ", 
   RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
  RowBox[{"4", " ", "b1", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "-", 
  RowBox[{"2", " ", "b2", " ", 
   RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.502113983371393*^9, 3.50211399825196*^9}, 
   3.5021140893939333`*^9, 3.5184566266364*^9, 3.536265232872611*^9, 
   3.536265269366544*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 633},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 293, 8, 67, "Section",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[885, 34, 69, 0, 34, "Subsection"],
Cell[957, 36, 206, 5, 26, "Text",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1188, 45, 213, 5, 27, "Input"],
Cell[1404, 52, 236, 4, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1689, 62, 62, 0, 34, "Subsection"],
Cell[1754, 64, 732, 25, 41, "Text",
 Evaluatable->False],
Cell[2489, 91, 639, 18, 73, "Input"],
Cell[3131, 111, 47, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[3203, 115, 170, 4, 73, "Input"],
Cell[3376, 121, 183, 4, 31, "Output"],
Cell[3562, 127, 183, 4, 29, "Output"],
Cell[3748, 133, 183, 4, 31, "Output"],
Cell[3934, 139, 185, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4168, 149, 58, 0, 34, "Subsection"],
Cell[CellGroupData[{
Cell[4251, 153, 42, 0, 24, "Subsubsection"],
Cell[4296, 155, 122, 3, 26, "Text"],
Cell[4421, 160, 68, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[4514, 164, 122, 3, 27, "Input"],
Cell[4639, 169, 183, 4, 29, "Output"]
}, Open  ]],
Cell[4837, 176, 201, 4, 26, "Text"],
Cell[5041, 182, 46, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[5112, 186, 112, 3, 27, "Input"],
Cell[5227, 191, 202, 5, 29, "Output"]
}, Open  ]],
Cell[5444, 199, 48, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[5517, 203, 105, 3, 27, "Input"],
Cell[5625, 208, 137, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5799, 215, 105, 3, 27, "Input"],
Cell[5907, 220, 141, 2, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6085, 227, 105, 3, 27, "Input"],
Cell[6193, 232, 139, 2, 27, "Output"]
}, Open  ]],
Cell[6347, 237, 92, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[6464, 243, 61, 1, 27, "Input"],
Cell[6528, 246, 169, 3, 31, "Output"]
}, Open  ]],
Cell[6712, 252, 27, 0, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6776, 257, 60, 0, 24, "Subsubsection"],
Cell[6839, 259, 50, 0, 26, "Text"],
Cell[6892, 261, 111, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[7028, 268, 165, 5, 27, "Input"],
Cell[7196, 275, 250, 7, 31, "Output"]
}, Open  ]],
Cell[7461, 285, 162, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[7648, 292, 170, 5, 27, "Input"],
Cell[7821, 299, 257, 7, 31, "Output"]
}, Open  ]],
Cell[8093, 309, 250, 4, 26, "Text"],
Cell[8346, 315, 36, 0, 26, "Text"],
Cell[8385, 317, 176, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[8586, 324, 165, 5, 27, "Input"],
Cell[8754, 331, 332, 10, 31, "Output"]
}, Open  ]],
Cell[9101, 344, 140, 3, 26, "Text"],
Cell[CellGroupData[{
Cell[9266, 351, 165, 5, 27, "Input"],
Cell[9434, 358, 333, 10, 31, "Output"]
}, Open  ]],
Cell[9782, 371, 144, 3, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9963, 379, 67, 0, 24, "Subsubsection"],
Cell[10033, 381, 81, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[10139, 386, 279, 8, 27, "Input"],
Cell[10421, 396, 385, 12, 29, "Output"]
}, Open  ]],
Cell[10821, 411, 119, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[10965, 416, 279, 8, 27, "Input"],
Cell[11247, 426, 391, 12, 29, "Output"]
}, Open  ]],
Cell[11653, 441, 36, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[11714, 445, 63, 1, 27, "Input"],
Cell[11780, 448, 244, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12061, 459, 70, 1, 27, "Input"],
Cell[12134, 462, 720, 22, 29, "Output"]
}, Open  ]],
Cell[12869, 487, 94, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[12988, 493, 62, 1, 27, "Input"],
Cell[13053, 496, 745, 26, 29, "Output"]
}, Open  ]],
Cell[13813, 525, 143, 3, 26, "Text"],
Cell[13959, 530, 64, 0, 26, "Text"],
Cell[CellGroupData[{
Cell[14048, 534, 131, 3, 27, "Input"],
Cell[14182, 539, 230, 6, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14473, 552, 148, 2, 34, "Subsection"],
Cell[14624, 556, 188, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[14837, 562, 241, 6, 27, "Input"],
Cell[15081, 570, 334, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15452, 584, 227, 5, 27, "Input"],
Cell[15682, 591, 308, 8, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16027, 604, 305, 7, 27, "Input"],
Cell[16335, 613, 363, 9, 31, "Output"]
}, Open  ]],
Cell[16713, 625, 167, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[16905, 631, 119, 2, 27, "Input"],
Cell[17027, 635, 144, 2, 27, "Output"]
}, Open  ]],
Cell[17186, 640, 166, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[17377, 646, 134, 2, 27, "Input"],
Cell[17514, 650, 357, 10, 31, "Output"]
}, Open  ]],
Cell[17886, 663, 129, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[18040, 668, 230, 5, 27, "Input"],
Cell[18273, 675, 314, 8, 27, "Output"]
}, Open  ]],
Cell[18602, 686, 142, 2, 26, "Text"],
Cell[18747, 690, 125, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[18897, 695, 339, 9, 27, "Input"],
Cell[19239, 706, 386, 12, 31, "Output"]
}, Open  ]],
Cell[19640, 721, 126, 1, 26, "Text"],
Cell[CellGroupData[{
Cell[19791, 726, 197, 4, 27, "Input"],
Cell[19991, 732, 1524, 48, 31, "Output"]
}, Open  ]],
Cell[21530, 783, 315, 6, 26, "Text"],
Cell[21848, 791, 177, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[22050, 797, 256, 5, 27, "Input"],
Cell[22309, 804, 1612, 49, 31, "Output"]
}, Open  ]],
Cell[23936, 856, 136, 1, 26, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24109, 862, 209, 3, 34, "Subsection"],
Cell[24321, 867, 715, 26, 31, "Text"],
Cell[25039, 895, 2705, 64, 256, "Text"],
Cell[27747, 961, 111, 1, 26, "Text"],
Cell[27861, 964, 803, 23, 27, "Input"],
Cell[28667, 989, 421, 17, 31, "Text"],
Cell[CellGroupData[{
Cell[29113, 1010, 239, 5, 27, "Input"],
Cell[29355, 1017, 712, 18, 31, "Output"]
}, Open  ]],
Cell[30082, 1038, 156, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[30263, 1044, 161, 3, 27, "Input"],
Cell[30427, 1049, 728, 21, 31, "Output"]
}, Open  ]],
Cell[31170, 1073, 172, 4, 26, "Text"],
Cell[CellGroupData[{
Cell[31367, 1081, 207, 5, 27, "Input"],
Cell[31577, 1088, 1270, 35, 31, "Output"]
}, Open  ]],
Cell[32862, 1126, 190, 2, 26, "Text"],
Cell[CellGroupData[{
Cell[33077, 1132, 214, 4, 27, "Input"],
Cell[33294, 1138, 553, 13, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
